var Module = globalThis.Module;
Module.createLazyFilesystem = function () {
let fsPathCache = [];

// Load a single file into the VFS. Lazy load in browser, preload in Node
let loadFile = function(dir, file, src) {
  if (fsPathCache.includes(`${dir}/${file}`)) {
    return;
  }
  fsPathCache.push(`${dir}/${file}`);

  let fn = ENVIRONMENT_IS_NODE ? FS.createPreloadedFile : FS.createLazyFile;
  FS.mkdirTree(dir);
  fn(dir, file, Module.locateFile(src), true, true);
}

// Lazy load a file from an Emscripten FS image
let loadImage = function(dir, file, src, mountpoint) {
  if (fsPathCache.includes(`${dir}/${file}`)) {
    return;
  }
  fsPathCache.push(`${dir}/${file}`);

  FS.mkdirTree(dir);
  let node = FS.createFile(dir, file, { isDevice: false } , true, true);

  let forceLoadFile = function() {
    if (node.isDevice || node.isFolder || node.link || node.contents) {
      return true;
    }

    if (ENVIRONMENT_IS_NODE) {
      Module.mountImagePath(Module.locateFile(src), mountpoint);

      let mountNode = Module.FS.lookupPath(`${dir}/${file}`).node;
      node.contents = mountNode.contents;
      node.size = mountNode.size;
    } else {
      Module.mountImageUrl(Module.locateFile(src), mountpoint);

      let mountNode = Module.FS.lookupPath(`${dir}/${file}`).node;
      node.contents = new Uint8Array(
        (new FileReaderSync()).readAsArrayBuffer(mountNode.contents)
      );
      node.size = mountNode.size;
    }
  }

  Object.defineProperties(node, {
    usedBytes: {
      get: function() {
        forceLoadFile();
        return node.size;
      }
    }
  });

  let stream_ops = {};
  Object.keys(node.stream_ops).forEach((key) => {
    let fn = node.stream_ops[key];
    stream_ops[key] = (...args) => {
      forceLoadFile();
      return fn(...args);
    };
  });
  node.stream_ops = stream_ops;
}
loadFile('/usr/lib/R/library/translations','DESCRIPTION','vfs/usr/lib/R/library/translations/DESCRIPTION');
loadImage('/usr/lib/R/doc','AUTHORS','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','BioC_mirrors.csv','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','COPYING','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','COPYRIGHTS','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','CRAN_mirrors.csv','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','FAQ','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','KEYWORDS','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','KEYWORDS.db','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS.0','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS.1','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS.2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS.2.rds','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS.3','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS.3.rds','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS.pdf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','NEWS.rds','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','RESOURCES','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc','THANKS','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','NEWS.2.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','NEWS.3.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','NEWS.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','R-nav.css','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','R.css','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','Rlogo.pdf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','Rlogo.svg','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','Search.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','SearchOn.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','about.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','favicon.ico','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','index.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','katex-check.js','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','katex-config.js','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex','LICENSE','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex','README.md','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_AMS-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_AMS-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_AMS-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Caligraphic-Bold.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Caligraphic-Bold.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Caligraphic-Bold.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Caligraphic-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Caligraphic-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Caligraphic-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Fraktur-Bold.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Fraktur-Bold.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Fraktur-Bold.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Fraktur-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Fraktur-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Fraktur-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Bold.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Bold.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Bold.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-BoldItalic.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-BoldItalic.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-BoldItalic.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Italic.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Italic.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Italic.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Main-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Math-BoldItalic.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Math-BoldItalic.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Math-BoldItalic.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Math-Italic.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Math-Italic.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Math-Italic.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Bold.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Bold.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Bold.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Italic.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Italic.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Italic.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_SansSerif-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Script-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Script-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Script-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size1-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size1-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size1-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size2-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size2-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size2-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size3-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size3-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size3-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size4-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size4-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Size4-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Typewriter-Regular.ttf','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Typewriter-Regular.woff','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex/fonts','KaTeX_Typewriter-Regular.woff2','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex','katex.css','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html/katex','katex.js','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','left.jpg','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','logo.jpg','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','mathjax-config.js','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','orcid.svg','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','packages-head-utf8.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','packages.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','prism.css','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','prism.js','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','resources.html','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','right.jpg','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/html','up.jpg','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/manual/images','QQ.png','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/manual/images','ecdf.png','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/manual/images','fig11.png','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/manual/images','fig12.png','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/manual/images','hist.png','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/doc/manual/images','ice.png','vfs/usr/lib/R/doc.data.gz','/usr/lib/R/doc');
loadImage('/usr/lib/R/library/parallel','DESCRIPTION','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel','INDEX','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/Meta','Rd.rds','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/Meta','features.rds','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/Meta','hsearch.rds','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/Meta','links.rds','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/Meta','nsInfo.rds','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/Meta','package.rds','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel','NAMESPACE','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/R','parallel','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/R','parallel.rdb','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/R','parallel.rdx','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/doc','parallel.pdf','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/help','AnIndex','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/help','aliases.rds','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/help','parallel.rdb','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/help','parallel.rdx','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/help','paths.rds','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/html','00Index.html','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/html','R.css','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/libs','parallel.so','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','Master.R','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','RSeed.R','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','multicore1.RR','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','multicore2.RR','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','multicore2.Rout.save','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','multicore3.RR','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','snow1.RR','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','snow2.RR','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/parallel/tests','snow2.Rout.save','vfs/usr/lib/R/library/parallel.data.gz','/usr/lib/R/library/parallel');
loadImage('/usr/lib/R/library/tcltk','DESCRIPTION','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk','INDEX','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/Meta','Rd.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/Meta','demo.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/Meta','features.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/Meta','hsearch.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/Meta','links.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/Meta','nsInfo.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/Meta','package.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk','NAMESPACE','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/R','tcltk','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/demo','tkcanvas.R','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/demo','tkdensity.R','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/demo','tkfaq.R','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/demo','tkttest.R','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','Tk-frontend.R','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','console.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','hierarchy.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','pkgIndex.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','progressbar.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','util-dump.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','util-expand.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','util-number.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','util-string.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','util-tk.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','util.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/exec','widget.tcl','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/help','AnIndex','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/help','aliases.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/help','paths.rds','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/help','tcltk.rdb','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/help','tcltk.rdx','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/html','00Index.html','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/tcltk/html','R.css','vfs/usr/lib/R/library/tcltk.data.gz','/usr/lib/R/library/tcltk');
loadImage('/usr/lib/R/library/translations','DESCRIPTION','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/Meta','features.rds','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/Meta','package.rds','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ar/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/bn/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/bn/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/bn/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ca/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/da/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/de/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en@quot/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/en_GB/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/es/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fa/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fa/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fa/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fa/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/fr/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hi/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/hu/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/id/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/it/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ja/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ko/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/lt/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ne/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ne/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ne/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/nn/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/nn/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/nn/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/nn/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pl/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/pt_BR/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ru/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/sq/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/sq/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/tr/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/tr/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/tr/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/tr/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/tr/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/tr/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/tr/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/tr/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/ur/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_CN/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-base.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-compiler.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-stats4.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R-utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','R.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','RGui.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','grDevices.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','graphics.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','grid.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','methods.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','parallel.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','splines.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','stats.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','tcltk.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','tools.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/library/translations/zh_TW/LC_MESSAGES','utils.mo','vfs/usr/lib/R/library/translations.data.gz','/usr/lib/R/library/translations');
loadImage('/usr/lib/R/share/R','REMOVE.R','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/R','examples-footer.R','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/R','examples-header.R','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/R','nspackloader.R','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/R','tests-startup.R','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/Rd/macros','system.Rd','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/dictionaries','R_Rd_files.rds','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/dictionaries','R_manuals.rds','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/dictionaries','R_vignettes.rds','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/dictionaries','en_stats.rds','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/encodings','Adobe-glyphlist','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/encodings','character-sets','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/java','README','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/java','getsp.class','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','AGPL-3','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','Artistic-2.0','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','BSD_2_clause','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','BSD_3_clause','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','GPL-2','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','GPL-3','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','LGPL-2','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','LGPL-2.1','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','LGPL-3','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','MIT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/licenses','license.db','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','basepkg.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','check_vars_ini.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','check_vars_out.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','clean.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','config.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','lazycomp.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','shlib.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','vars.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/make','winshlib.mk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/sh','echo.sh','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/texmf/bibtex/bib','RJournal.bib','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/texmf/bibtex/bib','Rnews.bib','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/texmf/bibtex/bst','jss.bst','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/texmf/tex/latex','Rd.sty','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/texmf/tex/latex','Sweave.sty','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/texmf/tex/latex','jss.cls','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/texmf/tex/latex','omscmtt.fd','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Abidjan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Accra','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Addis_Ababa','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Algiers','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Asmara','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Asmera','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Bamako','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Bangui','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Banjul','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Bissau','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Blantyre','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Brazzaville','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Bujumbura','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Cairo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Casablanca','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Ceuta','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Conakry','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Dakar','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Dar_es_Salaam','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Djibouti','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Douala','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','El_Aaiun','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Freetown','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Gaborone','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Harare','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Johannesburg','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Juba','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Kampala','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Khartoum','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Kigali','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Kinshasa','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Lagos','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Libreville','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Lome','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Luanda','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Lubumbashi','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Lusaka','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Malabo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Maputo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Maseru','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Mbabane','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Mogadishu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Monrovia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Nairobi','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Ndjamena','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Niamey','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Nouakchott','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Ouagadougou','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Porto-Novo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Sao_Tome','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Timbuktu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Tripoli','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Tunis','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Africa','Windhoek','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Adak','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Anchorage','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Anguilla','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Antigua','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Araguaina','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Buenos_Aires','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Catamarca','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','ComodRivadavia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Cordoba','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Jujuy','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','La_Rioja','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Mendoza','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Rio_Gallegos','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Salta','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','San_Juan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','San_Luis','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Tucuman','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Argentina','Ushuaia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Aruba','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Asuncion','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Atikokan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Atka','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Bahia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Bahia_Banderas','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Barbados','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Belem','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Belize','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Blanc-Sablon','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Boa_Vista','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Bogota','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Boise','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Buenos_Aires','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Cambridge_Bay','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Campo_Grande','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Cancun','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Caracas','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Catamarca','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Cayenne','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Cayman','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Chicago','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Chihuahua','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Ciudad_Juarez','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Coral_Harbour','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Cordoba','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Costa_Rica','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Creston','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Cuiaba','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Curacao','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Danmarkshavn','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Dawson','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Dawson_Creek','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Denver','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Detroit','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Dominica','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Edmonton','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Eirunepe','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','El_Salvador','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Ensenada','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Fort_Nelson','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Fort_Wayne','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Fortaleza','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Glace_Bay','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Godthab','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Goose_Bay','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Grand_Turk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Grenada','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Guadeloupe','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Guatemala','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Guayaquil','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Guyana','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Halifax','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Havana','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Hermosillo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Indiana','Indianapolis','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Indiana','Knox','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Indiana','Marengo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Indiana','Petersburg','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Indiana','Tell_City','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Indiana','Vevay','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Indiana','Vincennes','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Indiana','Winamac','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Indianapolis','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Inuvik','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Iqaluit','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Jamaica','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Jujuy','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Juneau','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Kentucky','Louisville','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/Kentucky','Monticello','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Knox_IN','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Kralendijk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','La_Paz','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Lima','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Los_Angeles','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Louisville','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Lower_Princes','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Maceio','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Managua','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Manaus','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Marigot','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Martinique','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Matamoros','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Mazatlan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Mendoza','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Menominee','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Merida','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Metlakatla','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Mexico_City','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Miquelon','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Moncton','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Monterrey','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Montevideo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Montreal','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Montserrat','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Nassau','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','New_York','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Nipigon','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Nome','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Noronha','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/North_Dakota','Beulah','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/North_Dakota','Center','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America/North_Dakota','New_Salem','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Nuuk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Ojinaga','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Panama','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Pangnirtung','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Paramaribo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Phoenix','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Port-au-Prince','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Port_of_Spain','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Porto_Acre','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Porto_Velho','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Puerto_Rico','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Punta_Arenas','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Rainy_River','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Rankin_Inlet','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Recife','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Regina','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Resolute','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Rio_Branco','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Rosario','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Santa_Isabel','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Santarem','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Santiago','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Santo_Domingo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Sao_Paulo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Scoresbysund','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Shiprock','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Sitka','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','St_Barthelemy','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','St_Johns','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','St_Kitts','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','St_Lucia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','St_Thomas','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','St_Vincent','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Swift_Current','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Tegucigalpa','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Thule','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Thunder_Bay','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Tijuana','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Toronto','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Tortola','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Vancouver','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Virgin','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Whitehorse','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Winnipeg','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Yakutat','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/America','Yellowknife','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Casey','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Davis','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','DumontDUrville','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Macquarie','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Mawson','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','McMurdo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Palmer','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Rothera','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','South_Pole','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Syowa','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Troll','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Antarctica','Vostok','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Arctic','Longyearbyen','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Aden','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Almaty','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Amman','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Anadyr','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Aqtau','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Aqtobe','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Ashgabat','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Ashkhabad','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Atyrau','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Baghdad','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Bahrain','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Baku','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Bangkok','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Barnaul','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Beirut','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Bishkek','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Brunei','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Calcutta','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Chita','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Choibalsan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Chongqing','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Chungking','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Colombo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Dacca','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Damascus','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Dhaka','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Dili','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Dubai','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Dushanbe','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Famagusta','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Gaza','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Harbin','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Hebron','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Ho_Chi_Minh','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Hong_Kong','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Hovd','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Irkutsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Istanbul','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Jakarta','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Jayapura','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Jerusalem','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Kabul','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Kamchatka','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Karachi','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Kashgar','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Kathmandu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Katmandu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Khandyga','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Kolkata','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Krasnoyarsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Kuala_Lumpur','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Kuching','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Kuwait','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Macao','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Macau','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Magadan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Makassar','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Manila','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Muscat','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Nicosia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Novokuznetsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Novosibirsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Omsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Oral','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Phnom_Penh','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Pontianak','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Pyongyang','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Qatar','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Qostanay','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Qyzylorda','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Rangoon','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Riyadh','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Saigon','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Sakhalin','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Samarkand','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Seoul','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Shanghai','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Singapore','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Srednekolymsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Taipei','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Tashkent','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Tbilisi','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Tehran','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Tel_Aviv','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Thimbu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Thimphu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Tokyo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Tomsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Ujung_Pandang','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Ulaanbaatar','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Ulan_Bator','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Urumqi','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Ust-Nera','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Vientiane','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Vladivostok','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Yakutsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Yangon','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Yekaterinburg','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Asia','Yerevan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Azores','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Bermuda','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Canary','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Cape_Verde','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Faeroe','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Faroe','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Jan_Mayen','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Madeira','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Reykjavik','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','South_Georgia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','St_Helena','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Atlantic','Stanley','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','ACT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Adelaide','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Brisbane','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Broken_Hill','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Canberra','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Currie','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Darwin','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Eucla','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Hobart','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','LHI','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Lindeman','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Lord_Howe','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Melbourne','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','NSW','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','North','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Perth','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Queensland','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','South','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Sydney','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Tasmania','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Victoria','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','West','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Australia','Yancowinna','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Brazil','Acre','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Brazil','DeNoronha','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Brazil','East','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Brazil','West','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','CET','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','CST6CDT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Canada','Atlantic','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Canada','Central','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Canada','Eastern','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Canada','Mountain','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Canada','Newfoundland','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Canada','Pacific','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Canada','Saskatchewan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Canada','Yukon','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Chile','Continental','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Chile','EasterIsland','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Cuba','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','EET','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','EST','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','EST5EDT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Egypt','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Eire','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+0','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+1','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+10','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+11','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+12','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+2','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+3','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+4','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+5','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+6','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+7','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+8','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT+9','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-0','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-1','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-10','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-11','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-12','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-13','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-14','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-2','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-3','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-4','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-5','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-6','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-7','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-8','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT-9','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','GMT0','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','Greenwich','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','UCT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','UTC','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','Universal','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Etc','Zulu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Amsterdam','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Andorra','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Astrakhan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Athens','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Belfast','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Belgrade','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Berlin','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Bratislava','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Brussels','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Bucharest','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Budapest','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Busingen','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Chisinau','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Copenhagen','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Dublin','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Gibraltar','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Guernsey','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Helsinki','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Isle_of_Man','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Istanbul','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Jersey','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Kaliningrad','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Kiev','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Kirov','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Kyiv','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Lisbon','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Ljubljana','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','London','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Luxembourg','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Madrid','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Malta','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Mariehamn','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Minsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Monaco','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Moscow','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Nicosia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Oslo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Paris','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Podgorica','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Prague','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Riga','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Rome','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Samara','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','San_Marino','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Sarajevo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Saratov','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Simferopol','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Skopje','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Sofia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Stockholm','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Tallinn','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Tirane','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Tiraspol','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Ulyanovsk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Uzhgorod','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Vaduz','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Vatican','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Vienna','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Vilnius','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Volgograd','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Warsaw','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Zagreb','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Zaporozhye','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Europe','Zurich','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','GB','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','GB-Eire','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','GMT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','GMT+0','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','GMT-0','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','GMT0','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Greenwich','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','HST','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Hongkong','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Iceland','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Antananarivo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Chagos','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Christmas','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Cocos','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Comoro','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Kerguelen','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Mahe','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Maldives','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Mauritius','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Mayotte','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Indian','Reunion','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Iran','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Israel','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Jamaica','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Japan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Kwajalein','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Libya','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','MET','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','MST','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','MST7MDT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Mexico','BajaNorte','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Mexico','BajaSur','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Mexico','General','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','NZ','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','NZ-CHAT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Navajo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','PRC','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','PST8PDT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Apia','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Auckland','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Bougainville','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Chatham','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Chuuk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Easter','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Efate','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Enderbury','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Fakaofo','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Fiji','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Funafuti','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Galapagos','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Gambier','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Guadalcanal','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Guam','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Honolulu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Johnston','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Kanton','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Kiritimati','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Kosrae','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Kwajalein','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Majuro','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Marquesas','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Midway','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Nauru','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Niue','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Norfolk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Noumea','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Pago_Pago','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Palau','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Pitcairn','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Pohnpei','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Ponape','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Port_Moresby','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Rarotonga','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Saipan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Samoa','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Tahiti','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Tarawa','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Tongatapu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Truk','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Wake','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Wallis','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/Pacific','Yap','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Poland','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Portugal','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','ROC','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','ROK','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Singapore','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Turkey','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','UCT','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Alaska','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Aleutian','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Arizona','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Central','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','East-Indiana','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Eastern','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Hawaii','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Indiana-Starke','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Michigan','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Mountain','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Pacific','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo/US','Samoa','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','UTC','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Universal','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','VERSION','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','W-SU','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','WET','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','Zulu','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','iso3166.tab','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','zone.tab','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/share/zoneinfo','zone1970.tab','vfs/usr/lib/R/share.data.gz','/usr/lib/R/share');
loadImage('/usr/lib/R/tests','CRANtools.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','EmbeddedNuls.csv','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests/Examples','datasets-Ex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests/Examples','grDevices-Ex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests/Examples','graphics-Ex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests/Examples','grid-Ex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests/Examples','splines-Ex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests/Examples','stats-Ex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests/Examples','stats4-Ex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests/Examples','tools-Ex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','Makefile','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','Makefile.common','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','PCRE.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','README','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','WinUnicode.dat','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','any-all.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','any-all.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','arima.rda','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','arith-true.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','arith-true.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','arith.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','arith.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','array-subset.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','classes-methods.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','complex.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','complex.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','conditions.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','d-p-q-r-tests.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','d-p-q-r-tests.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','d-p-q-r-tst-2.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datasets.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datasets.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime2.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime2.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime3.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime4.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime4.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime5.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','datetime5.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','demos.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','demos.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','demos2.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','download.file.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','eval-etc.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','eval-etc.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','eval-fns.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','iconv.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','iec60559.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','iec60559.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','internet.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','internet.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','internet2.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','isas-tests.Rin','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','isas-tests.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','lapack.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','lapack.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','libcurl.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','lm-tests.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','lm-tests.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','method-dispatch.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','method-dispatch.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','misc-devel.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','nanbug.rda','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','no-segfault.Rin','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','ok-errors.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','ok-errors.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','p-qbeta-strict-tst.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','p-r-random-tests.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','p-r-random-tests.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','primitives.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','print-tests.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','print-tests.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','r-strict-tst.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-BLAS.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-IO.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-IO.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-IO2.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-IO2.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-S4-examples.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-S4.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-S4.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-examples1.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-examples2.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-examples3.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-packages.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-plot-latin1.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-plot-latin1.pdf.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-plot.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-plot.pdf.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-tests-1a.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-tests-1b.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-tests-1c.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-tests-1d.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-tests-1e.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-tests-2.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-tests-2.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-tests-3.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','reg-translation.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','simple-true.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','simple-true.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','sockets.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','structure.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','structure.Rout.save','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','timezone.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/tests','utf8-regex.R','vfs/usr/lib/R/tests.data.gz','/usr/lib/R/tests');
loadImage('/usr/lib/R/library/base/demo','error.catching.R','vfs/usr/lib/R/library/base/demo.data.gz','/usr/lib/R/library/base/demo');
loadImage('/usr/lib/R/library/base/demo','is.things.R','vfs/usr/lib/R/library/base/demo.data.gz','/usr/lib/R/library/base/demo');
loadImage('/usr/lib/R/library/base/demo','recursion.R','vfs/usr/lib/R/library/base/demo.data.gz','/usr/lib/R/library/base/demo');
loadImage('/usr/lib/R/library/base/demo','scoping.R','vfs/usr/lib/R/library/base/demo.data.gz','/usr/lib/R/library/base/demo');
loadImage('/usr/lib/R/library/base/help','AnIndex','vfs/usr/lib/R/library/base/help.data.gz','/usr/lib/R/library/base/help');
loadImage('/usr/lib/R/library/base/help','aliases.rds','vfs/usr/lib/R/library/base/help.data.gz','/usr/lib/R/library/base/help');
loadImage('/usr/lib/R/library/base/help','base.rdb','vfs/usr/lib/R/library/base/help.data.gz','/usr/lib/R/library/base/help');
loadImage('/usr/lib/R/library/base/help','base.rdx','vfs/usr/lib/R/library/base/help.data.gz','/usr/lib/R/library/base/help');
loadImage('/usr/lib/R/library/base/help','paths.rds','vfs/usr/lib/R/library/base/help.data.gz','/usr/lib/R/library/base/help');
loadImage('/usr/lib/R/library/base/html','00Index.html','vfs/usr/lib/R/library/base/html.data.gz','/usr/lib/R/library/base/html');
loadImage('/usr/lib/R/library/base/html','R.css','vfs/usr/lib/R/library/base/html.data.gz','/usr/lib/R/library/base/html');
loadImage('/usr/lib/R/library/compiler/help','AnIndex','vfs/usr/lib/R/library/compiler/help.data.gz','/usr/lib/R/library/compiler/help');
loadImage('/usr/lib/R/library/compiler/help','aliases.rds','vfs/usr/lib/R/library/compiler/help.data.gz','/usr/lib/R/library/compiler/help');
loadImage('/usr/lib/R/library/compiler/help','compiler.rdb','vfs/usr/lib/R/library/compiler/help.data.gz','/usr/lib/R/library/compiler/help');
loadImage('/usr/lib/R/library/compiler/help','compiler.rdx','vfs/usr/lib/R/library/compiler/help.data.gz','/usr/lib/R/library/compiler/help');
loadImage('/usr/lib/R/library/compiler/help','paths.rds','vfs/usr/lib/R/library/compiler/help.data.gz','/usr/lib/R/library/compiler/help');
loadImage('/usr/lib/R/library/compiler/html','00Index.html','vfs/usr/lib/R/library/compiler/html.data.gz','/usr/lib/R/library/compiler/html');
loadImage('/usr/lib/R/library/compiler/html','R.css','vfs/usr/lib/R/library/compiler/html.data.gz','/usr/lib/R/library/compiler/html');
loadImage('/usr/lib/R/library/compiler/tests','assign.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','basics.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','const.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','curexpr.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','envir.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','jit.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','loop.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','srcref.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','switch.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/compiler/tests','vischk.R','vfs/usr/lib/R/library/compiler/tests.data.gz','/usr/lib/R/library/compiler/tests');
loadImage('/usr/lib/R/library/datasets/help','AnIndex','vfs/usr/lib/R/library/datasets/help.data.gz','/usr/lib/R/library/datasets/help');
loadImage('/usr/lib/R/library/datasets/help','aliases.rds','vfs/usr/lib/R/library/datasets/help.data.gz','/usr/lib/R/library/datasets/help');
loadImage('/usr/lib/R/library/datasets/help','datasets.rdb','vfs/usr/lib/R/library/datasets/help.data.gz','/usr/lib/R/library/datasets/help');
loadImage('/usr/lib/R/library/datasets/help','datasets.rdx','vfs/usr/lib/R/library/datasets/help.data.gz','/usr/lib/R/library/datasets/help');
loadImage('/usr/lib/R/library/datasets/help','paths.rds','vfs/usr/lib/R/library/datasets/help.data.gz','/usr/lib/R/library/datasets/help');
loadImage('/usr/lib/R/library/datasets/html','00Index.html','vfs/usr/lib/R/library/datasets/html.data.gz','/usr/lib/R/library/datasets/html');
loadImage('/usr/lib/R/library/datasets/html','R.css','vfs/usr/lib/R/library/datasets/html.data.gz','/usr/lib/R/library/datasets/html');
loadImage('/usr/lib/R/library/grDevices/afm','ArialMT-Bold.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','ArialMT-BoldItalic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','ArialMT-Italic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','ArialMT.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','CM_boldx_10.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','CM_boldx_italic_10.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','CM_italic_10.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','CM_regular_10.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','CM_symbol_10.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Courier-Bold.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Courier-BoldOblique.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Courier-Oblique.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Courier.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Helvetica-Bold.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Helvetica-BoldOblique.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Helvetica-Oblique.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Helvetica.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','LICENSE.LPPL','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','MustRead.html','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusMonoPS-Bold.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusMonoPS-BoldItalic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusMonoPS-Italic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusMonoPS-Regular.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusRoman-Bold.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusRoman-BoldItalic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusRoman-Italic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusRoman-Regular.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusSans-Bold.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusSans-BoldItalic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusSans-BoldOblique.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusSans-Italic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusSans-Oblique.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','NimbusSans-Regular.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','README','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','StandardSymbolsPS.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Symbol.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Times-Bold.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Times-BoldItalic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Times-Italic.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','Times-Roman.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','ZapfDingbats.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','a010013l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','a010015l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','a010033l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','a010035l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','agd_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','agdo____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','agw_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','agwo____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','b018012l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','b018015l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','b018032l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','b018035l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','bkd_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','bkdi____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','bkl_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','bkli____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','c059013l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','c059016l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','c059033l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','c059036l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','cmbxti10.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','cmti10.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','cob_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','cobo____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','com_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','coo_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','hv______.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','hvb_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','hvbo____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','hvn_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','hvnb____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','hvnbo___.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','hvno____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','hvo_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n019003l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n019004l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n019023l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n019024l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n019043l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n019044l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n019063l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n019064l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n021003l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n021004l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n021023l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n021024l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n022003l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n022004l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n022023l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','n022024l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','ncb_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','ncbi____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','nci_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','ncr_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','p052003l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','p052004l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','p052023l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','p052024l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','pob_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','pobi____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','poi_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','por_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','s050000l.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','sy______.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','tib_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','tibi____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','tii_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/afm','tir_____.afm.gz','vfs/usr/lib/R/library/grDevices/afm.data.gz','/usr/lib/R/library/grDevices/afm');
loadImage('/usr/lib/R/library/grDevices/demo','colors.R','vfs/usr/lib/R/library/grDevices/demo.data.gz','/usr/lib/R/library/grDevices/demo');
loadImage('/usr/lib/R/library/grDevices/demo','hclColors.R','vfs/usr/lib/R/library/grDevices/demo.data.gz','/usr/lib/R/library/grDevices/demo');
loadImage('/usr/lib/R/library/grDevices/enc','AdobeStd.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','AdobeSym.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','CP1250.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','CP1251.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','CP1253.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','CP1257.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','Cyrillic.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','Greek.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','ISOLatin1.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','ISOLatin2.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','ISOLatin7.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','ISOLatin9.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','KOI8-R.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','KOI8-U.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','PDFDoc.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','TeXtext.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/enc','WinAnsi.enc','vfs/usr/lib/R/library/grDevices/enc.data.gz','/usr/lib/R/library/grDevices/enc');
loadImage('/usr/lib/R/library/grDevices/fonts/Montserrat/static','Montserrat-BoldItalic.ttf','vfs/usr/lib/R/library/grDevices/fonts.data.gz','/usr/lib/R/library/grDevices/fonts');
loadImage('/usr/lib/R/library/grDevices/fonts/Montserrat/static','Montserrat-Medium.ttf','vfs/usr/lib/R/library/grDevices/fonts.data.gz','/usr/lib/R/library/grDevices/fonts');
loadImage('/usr/lib/R/library/grDevices/fonts/Roboto','LICENSE.txt','vfs/usr/lib/R/library/grDevices/fonts.data.gz','/usr/lib/R/library/grDevices/fonts');
loadImage('/usr/lib/R/library/grDevices/fonts/Roboto','Roboto-Medium.ttf','vfs/usr/lib/R/library/grDevices/fonts.data.gz','/usr/lib/R/library/grDevices/fonts');
loadImage('/usr/lib/R/library/grDevices/help','AnIndex','vfs/usr/lib/R/library/grDevices/help.data.gz','/usr/lib/R/library/grDevices/help');
loadImage('/usr/lib/R/library/grDevices/help','aliases.rds','vfs/usr/lib/R/library/grDevices/help.data.gz','/usr/lib/R/library/grDevices/help');
loadImage('/usr/lib/R/library/grDevices/help','grDevices.rdb','vfs/usr/lib/R/library/grDevices/help.data.gz','/usr/lib/R/library/grDevices/help');
loadImage('/usr/lib/R/library/grDevices/help','grDevices.rdx','vfs/usr/lib/R/library/grDevices/help.data.gz','/usr/lib/R/library/grDevices/help');
loadImage('/usr/lib/R/library/grDevices/help','paths.rds','vfs/usr/lib/R/library/grDevices/help.data.gz','/usr/lib/R/library/grDevices/help');
loadImage('/usr/lib/R/library/grDevices/html','00Index.html','vfs/usr/lib/R/library/grDevices/html.data.gz','/usr/lib/R/library/grDevices/html');
loadImage('/usr/lib/R/library/grDevices/html','R.css','vfs/usr/lib/R/library/grDevices/html.data.gz','/usr/lib/R/library/grDevices/html');
loadImage('/usr/lib/R/library/grDevices/tests','convertColor-tests.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','encodings.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','encodings.Rout.save','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','encodings2.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','encodings2.Rout.save','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','encodings3.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','encodings3.Rout.save','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','grDev-tsts.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','palettes-tests.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','ps-tests.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','ps-tests.Rout.save','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref-macOS','PDF-encoding.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref-macOS','PS-encoding.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref-windows','Encoding3.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref-windows','PDF-encoding.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref-windows','PS-encoding.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','Encoding3.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PDF-encoding.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PDF-latin2.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-CP1250.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-CP1251.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-CP1253.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-CP1257.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-Cyrillic.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-Greek.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-ISOLatin1.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-ISOLatin2.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-ISOLatin7.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-ISOLatin9.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-KOI8-R.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-KOI8-U.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-WinAnsi.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-cyr.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-encoding.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','PS-latin2.ps','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-CP1250.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-CP1251.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-CP1253.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-CP1257.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-Cyrillic.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-Greek.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-ISOLatin1.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-ISOLatin2.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-ISOLatin7.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-ISOLatin9.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-KOI8-R.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-KOI8-U.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests/ref','pdf-WinAnsi.pdf','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','saved-recordPlot.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','urw-fonts.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/grDevices/tests','zzcheck-encodings.R','vfs/usr/lib/R/library/grDevices/tests.data.gz','/usr/lib/R/library/grDevices/tests');
loadImage('/usr/lib/R/library/graphics/demo','Hershey.R','vfs/usr/lib/R/library/graphics/demo.data.gz','/usr/lib/R/library/graphics/demo');
loadImage('/usr/lib/R/library/graphics/demo','Japanese.R','vfs/usr/lib/R/library/graphics/demo.data.gz','/usr/lib/R/library/graphics/demo');
loadImage('/usr/lib/R/library/graphics/demo','graphics.R','vfs/usr/lib/R/library/graphics/demo.data.gz','/usr/lib/R/library/graphics/demo');
loadImage('/usr/lib/R/library/graphics/demo','image.R','vfs/usr/lib/R/library/graphics/demo.data.gz','/usr/lib/R/library/graphics/demo');
loadImage('/usr/lib/R/library/graphics/demo','persp.R','vfs/usr/lib/R/library/graphics/demo.data.gz','/usr/lib/R/library/graphics/demo');
loadImage('/usr/lib/R/library/graphics/demo','plotmath.R','vfs/usr/lib/R/library/graphics/demo.data.gz','/usr/lib/R/library/graphics/demo');
loadImage('/usr/lib/R/library/graphics/help','AnIndex','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help','aliases.rds','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help/figures','mai.pdf','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help/figures','mai.png','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help/figures','oma.pdf','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help/figures','oma.png','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help/figures','pch.pdf','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help/figures','pch.png','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help/figures','pch.svg','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help','graphics.rdb','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help','graphics.rdx','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/help','paths.rds','vfs/usr/lib/R/library/graphics/help.data.gz','/usr/lib/R/library/graphics/help');
loadImage('/usr/lib/R/library/graphics/html','00Index.html','vfs/usr/lib/R/library/graphics/html.data.gz','/usr/lib/R/library/graphics/html');
loadImage('/usr/lib/R/library/graphics/html','R.css','vfs/usr/lib/R/library/graphics/html.data.gz','/usr/lib/R/library/graphics/html');
loadImage('/usr/lib/R/library/grid/doc','DivByZero.txt','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','changes.txt','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','displaylist.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','frame.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','grid.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','grobs.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','interactive.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','locndimn.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','moveline.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','nonfinite.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','plotexample.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','rotated.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','saveload.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','sharing.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/doc','viewports.pdf','vfs/usr/lib/R/library/grid/doc.data.gz','/usr/lib/R/library/grid/doc');
loadImage('/usr/lib/R/library/grid/help','AnIndex','vfs/usr/lib/R/library/grid/help.data.gz','/usr/lib/R/library/grid/help');
loadImage('/usr/lib/R/library/grid/help','aliases.rds','vfs/usr/lib/R/library/grid/help.data.gz','/usr/lib/R/library/grid/help');
loadImage('/usr/lib/R/library/grid/help','grid.rdb','vfs/usr/lib/R/library/grid/help.data.gz','/usr/lib/R/library/grid/help');
loadImage('/usr/lib/R/library/grid/help','grid.rdx','vfs/usr/lib/R/library/grid/help.data.gz','/usr/lib/R/library/grid/help');
loadImage('/usr/lib/R/library/grid/help','paths.rds','vfs/usr/lib/R/library/grid/help.data.gz','/usr/lib/R/library/grid/help');
loadImage('/usr/lib/R/library/grid/html','00Index.html','vfs/usr/lib/R/library/grid/html.data.gz','/usr/lib/R/library/grid/html');
loadImage('/usr/lib/R/library/grid/html','R.css','vfs/usr/lib/R/library/grid/html.data.gz','/usr/lib/R/library/grid/html');
loadImage('/usr/lib/R/library/grid/tests','bugs.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','clippaths.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','compositing.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','coords.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','glyphs.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','grep.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','grep.Rout.save','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','groups.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','masks.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','nesting.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','paths.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','patterns.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','reg.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','testls.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','testls.Rout.save','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/grid/tests','units.R','vfs/usr/lib/R/library/grid/tests.data.gz','/usr/lib/R/library/grid/tests');
loadImage('/usr/lib/R/library/methods/help','AnIndex','vfs/usr/lib/R/library/methods/help.data.gz','/usr/lib/R/library/methods/help');
loadImage('/usr/lib/R/library/methods/help','aliases.rds','vfs/usr/lib/R/library/methods/help.data.gz','/usr/lib/R/library/methods/help');
loadImage('/usr/lib/R/library/methods/help','methods.rdb','vfs/usr/lib/R/library/methods/help.data.gz','/usr/lib/R/library/methods/help');
loadImage('/usr/lib/R/library/methods/help','methods.rdx','vfs/usr/lib/R/library/methods/help.data.gz','/usr/lib/R/library/methods/help');
loadImage('/usr/lib/R/library/methods/help','paths.rds','vfs/usr/lib/R/library/methods/help.data.gz','/usr/lib/R/library/methods/help');
loadImage('/usr/lib/R/library/methods/html','00Index.html','vfs/usr/lib/R/library/methods/html.data.gz','/usr/lib/R/library/methods/html');
loadImage('/usr/lib/R/library/methods/html','R.css','vfs/usr/lib/R/library/methods/html.data.gz','/usr/lib/R/library/methods/html');
loadImage('/usr/lib/R/library/methods/tests','S3.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','basicRefClass.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','duplicateClass.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','envRefClass.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','fieldAssignments.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','mixinInitialize.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','namesAndSlots.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','nextWithDots.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','refClassExample.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','testConditionalIs.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','testGroupGeneric.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/methods/tests','testIs.R','vfs/usr/lib/R/library/methods/tests.data.gz','/usr/lib/R/library/methods/tests');
loadImage('/usr/lib/R/library/splines/help','AnIndex','vfs/usr/lib/R/library/splines/help.data.gz','/usr/lib/R/library/splines/help');
loadImage('/usr/lib/R/library/splines/help','aliases.rds','vfs/usr/lib/R/library/splines/help.data.gz','/usr/lib/R/library/splines/help');
loadImage('/usr/lib/R/library/splines/help','paths.rds','vfs/usr/lib/R/library/splines/help.data.gz','/usr/lib/R/library/splines/help');
loadImage('/usr/lib/R/library/splines/help','splines.rdb','vfs/usr/lib/R/library/splines/help.data.gz','/usr/lib/R/library/splines/help');
loadImage('/usr/lib/R/library/splines/help','splines.rdx','vfs/usr/lib/R/library/splines/help.data.gz','/usr/lib/R/library/splines/help');
loadImage('/usr/lib/R/library/splines/html','00Index.html','vfs/usr/lib/R/library/splines/html.data.gz','/usr/lib/R/library/splines/html');
loadImage('/usr/lib/R/library/splines/html','R.css','vfs/usr/lib/R/library/splines/html.data.gz','/usr/lib/R/library/splines/html');
loadImage('/usr/lib/R/library/splines/tests','sparse-tst.R','vfs/usr/lib/R/library/splines/tests.data.gz','/usr/lib/R/library/splines/tests');
loadImage('/usr/lib/R/library/splines/tests','spline-tst.R','vfs/usr/lib/R/library/splines/tests.data.gz','/usr/lib/R/library/splines/tests');
loadImage('/usr/lib/R/library/stats/demo','glm.vr.R','vfs/usr/lib/R/library/stats/demo.data.gz','/usr/lib/R/library/stats/demo');
loadImage('/usr/lib/R/library/stats/demo','lm.glm.R','vfs/usr/lib/R/library/stats/demo.data.gz','/usr/lib/R/library/stats/demo');
loadImage('/usr/lib/R/library/stats/demo','nlm.R','vfs/usr/lib/R/library/stats/demo.data.gz','/usr/lib/R/library/stats/demo');
loadImage('/usr/lib/R/library/stats/demo','smooth.R','vfs/usr/lib/R/library/stats/demo.data.gz','/usr/lib/R/library/stats/demo');
loadImage('/usr/lib/R/library/stats/help','AnIndex','vfs/usr/lib/R/library/stats/help.data.gz','/usr/lib/R/library/stats/help');
loadImage('/usr/lib/R/library/stats/help','aliases.rds','vfs/usr/lib/R/library/stats/help.data.gz','/usr/lib/R/library/stats/help');
loadImage('/usr/lib/R/library/stats/help','paths.rds','vfs/usr/lib/R/library/stats/help.data.gz','/usr/lib/R/library/stats/help');
loadImage('/usr/lib/R/library/stats/help','stats.rdb','vfs/usr/lib/R/library/stats/help.data.gz','/usr/lib/R/library/stats/help');
loadImage('/usr/lib/R/library/stats/help','stats.rdx','vfs/usr/lib/R/library/stats/help.data.gz','/usr/lib/R/library/stats/help');
loadImage('/usr/lib/R/library/stats/html','00Index.html','vfs/usr/lib/R/library/stats/html.data.gz','/usr/lib/R/library/stats/html');
loadImage('/usr/lib/R/library/stats/html','R.css','vfs/usr/lib/R/library/stats/html.data.gz','/usr/lib/R/library/stats/html');
loadImage('/usr/lib/R/library/stats/tests','NLSstClosest.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','anorexia.rda','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','arimaML.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','bandwidth.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','bandwidth.Rout.save','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','birthwt.rda','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','cmdscale.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','density_chk.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','dpq-xtra.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','drop1-polr.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','glm-etc.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','glm.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','glm.Rout.save','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','hills.rds','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','ig_glm.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','ks-test.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','ks-test.Rout.save','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','nafns.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','nlm.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','nls.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','nls.Rout.save','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','offsets.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','ppr.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','ppr_test.csv','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','psmirnov.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','psmirnov.Rout.save','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','simulate.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','simulate.Rout.save','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','smooth.spline.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','table-margins.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats/tests','ts-tests.R','vfs/usr/lib/R/library/stats/tests.data.gz','/usr/lib/R/library/stats/tests');
loadImage('/usr/lib/R/library/stats4/help','AnIndex','vfs/usr/lib/R/library/stats4/help.data.gz','/usr/lib/R/library/stats4/help');
loadImage('/usr/lib/R/library/stats4/help','aliases.rds','vfs/usr/lib/R/library/stats4/help.data.gz','/usr/lib/R/library/stats4/help');
loadImage('/usr/lib/R/library/stats4/help','paths.rds','vfs/usr/lib/R/library/stats4/help.data.gz','/usr/lib/R/library/stats4/help');
loadImage('/usr/lib/R/library/stats4/help','stats4.rdb','vfs/usr/lib/R/library/stats4/help.data.gz','/usr/lib/R/library/stats4/help');
loadImage('/usr/lib/R/library/stats4/help','stats4.rdx','vfs/usr/lib/R/library/stats4/help.data.gz','/usr/lib/R/library/stats4/help');
loadImage('/usr/lib/R/library/stats4/html','00Index.html','vfs/usr/lib/R/library/stats4/html.data.gz','/usr/lib/R/library/stats4/html');
loadImage('/usr/lib/R/library/stats4/html','R.css','vfs/usr/lib/R/library/stats4/html.data.gz','/usr/lib/R/library/stats4/html');
loadImage('/usr/lib/R/library/stats4/tests','confint.R','vfs/usr/lib/R/library/stats4/tests.data.gz','/usr/lib/R/library/stats4/tests');
loadImage('/usr/lib/R/library/tools/help','AnIndex','vfs/usr/lib/R/library/tools/help.data.gz','/usr/lib/R/library/tools/help');
loadImage('/usr/lib/R/library/tools/help','aliases.rds','vfs/usr/lib/R/library/tools/help.data.gz','/usr/lib/R/library/tools/help');
loadImage('/usr/lib/R/library/tools/help','paths.rds','vfs/usr/lib/R/library/tools/help.data.gz','/usr/lib/R/library/tools/help');
loadImage('/usr/lib/R/library/tools/help','tools.rdb','vfs/usr/lib/R/library/tools/help.data.gz','/usr/lib/R/library/tools/help');
loadImage('/usr/lib/R/library/tools/help','tools.rdx','vfs/usr/lib/R/library/tools/help.data.gz','/usr/lib/R/library/tools/help');
loadImage('/usr/lib/R/library/tools/html','00Index.html','vfs/usr/lib/R/library/tools/html.data.gz','/usr/lib/R/library/tools/html');
loadImage('/usr/lib/R/library/tools/html','R.css','vfs/usr/lib/R/library/tools/html.data.gz','/usr/lib/R/library/tools/html');
loadImage('/usr/lib/R/library/tools/tests','QC.R','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','Rd-Sexpr-error.Rd','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','Rd-Sexpr-hide-empty.Rd','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','Rd-Sexpr-warning.Rd','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','Rd-braces_ignored.Rd','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','Rd-braces_reported.Rd','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','Rd.R','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','Rd2HTML.R','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','S3.R','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','doi.Rd','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/tools/tests','undoc.R','vfs/usr/lib/R/library/tools/tests.data.gz','/usr/lib/R/library/tools/tests');
loadImage('/usr/lib/R/library/utils/doc','Sweave.pdf','vfs/usr/lib/R/library/utils/doc.data.gz','/usr/lib/R/library/utils/doc');
loadImage('/usr/lib/R/library/utils/help','AnIndex','vfs/usr/lib/R/library/utils/help.data.gz','/usr/lib/R/library/utils/help');
loadImage('/usr/lib/R/library/utils/help','aliases.rds','vfs/usr/lib/R/library/utils/help.data.gz','/usr/lib/R/library/utils/help');
loadImage('/usr/lib/R/library/utils/help','paths.rds','vfs/usr/lib/R/library/utils/help.data.gz','/usr/lib/R/library/utils/help');
loadImage('/usr/lib/R/library/utils/help','utils.rdb','vfs/usr/lib/R/library/utils/help.data.gz','/usr/lib/R/library/utils/help');
loadImage('/usr/lib/R/library/utils/help','utils.rdx','vfs/usr/lib/R/library/utils/help.data.gz','/usr/lib/R/library/utils/help');
loadImage('/usr/lib/R/library/utils/html','00Index.html','vfs/usr/lib/R/library/utils/html.data.gz','/usr/lib/R/library/utils/html');
loadImage('/usr/lib/R/library/utils/html','R.css','vfs/usr/lib/R/library/utils/html.data.gz','/usr/lib/R/library/utils/html');
loadImage('/usr/lib/R/library/utils/misc','exDIF.csv','vfs/usr/lib/R/library/utils/misc.data.gz','/usr/lib/R/library/utils/misc');
loadImage('/usr/lib/R/library/utils/misc','exDIF.dif','vfs/usr/lib/R/library/utils/misc.data.gz','/usr/lib/R/library/utils/misc');
loadImage('/usr/lib/R/library/utils/tests','Sexpr-verb-ex.Rnw','vfs/usr/lib/R/library/utils/tests.data.gz','/usr/lib/R/library/utils/tests');
loadImage('/usr/lib/R/library/utils/tests','Sweave-tst.R','vfs/usr/lib/R/library/utils/tests.data.gz','/usr/lib/R/library/utils/tests');
loadImage('/usr/lib/R/library/utils/tests','charclass.R','vfs/usr/lib/R/library/utils/tests.data.gz','/usr/lib/R/library/utils/tests');
loadImage('/usr/lib/R/library/utils/tests','completion.R','vfs/usr/lib/R/library/utils/tests.data.gz','/usr/lib/R/library/utils/tests');
loadImage('/usr/lib/R/library/utils/tests','customgraphics.Rnw','vfs/usr/lib/R/library/utils/tests.data.gz','/usr/lib/R/library/utils/tests');
loadImage('/usr/lib/R/library/utils/tests','keepsource.Rnw','vfs/usr/lib/R/library/utils/tests.data.gz','/usr/lib/R/library/utils/tests');
loadImage('/usr/lib/R/library/utils/tests','relist.R','vfs/usr/lib/R/library/utils/tests.data.gz','/usr/lib/R/library/utils/tests');
loadImage('/usr/lib/R/library/utils/tests','swv-keepSrc-1.Rnw','vfs/usr/lib/R/library/utils/tests.data.gz','/usr/lib/R/library/utils/tests');
loadImage('/usr/lib/R/library/webr/help','AnIndex','vfs/usr/lib/R/library/webr/help.data.gz','/usr/lib/R/library/webr/help');
loadImage('/usr/lib/R/library/webr/help','aliases.rds','vfs/usr/lib/R/library/webr/help.data.gz','/usr/lib/R/library/webr/help');
loadImage('/usr/lib/R/library/webr/help/figures','logo.png','vfs/usr/lib/R/library/webr/help.data.gz','/usr/lib/R/library/webr/help');
loadImage('/usr/lib/R/library/webr/help','paths.rds','vfs/usr/lib/R/library/webr/help.data.gz','/usr/lib/R/library/webr/help');
loadImage('/usr/lib/R/library/webr/help','webr.rdb','vfs/usr/lib/R/library/webr/help.data.gz','/usr/lib/R/library/webr/help');
loadImage('/usr/lib/R/library/webr/help','webr.rdx','vfs/usr/lib/R/library/webr/help.data.gz','/usr/lib/R/library/webr/help');
loadImage('/usr/lib/R/library/webr/html','00Index.html','vfs/usr/lib/R/library/webr/html.data.gz','/usr/lib/R/library/webr/html');
loadImage('/usr/lib/R/library/webr/html','R.css','vfs/usr/lib/R/library/webr/html.data.gz','/usr/lib/R/library/webr/html');
}
var Module=typeof Module!="undefined"?Module:{};var moduleOverrides=Object.assign({},Module);var arguments_=[];var thisProgram="./this.program";var quit_=(status,toThrow)=>{throw toThrow};var ENVIRONMENT_IS_WEB=typeof window=="object";var ENVIRONMENT_IS_WORKER=typeof importScripts=="function";var ENVIRONMENT_IS_NODE=typeof process=="object"&&typeof process.versions=="object"&&typeof process.versions.node=="string";var ENVIRONMENT_IS_SHELL=!ENVIRONMENT_IS_WEB&&!ENVIRONMENT_IS_NODE&&!ENVIRONMENT_IS_WORKER;var scriptDirectory="";function locateFile(path){if(Module["locateFile"]){return Module["locateFile"](path,scriptDirectory)}return scriptDirectory+path}var read_,readAsync,readBinary;if(ENVIRONMENT_IS_NODE){var fs=require("fs");var nodePath=require("path");if(ENVIRONMENT_IS_WORKER){scriptDirectory=nodePath.dirname(scriptDirectory)+"/"}else{scriptDirectory=__dirname+"/"}read_=(filename,binary)=>{filename=isFileURI(filename)?new URL(filename):nodePath.normalize(filename);return fs.readFileSync(filename,binary?undefined:"utf8")};readBinary=filename=>{var ret=read_(filename,true);if(!ret.buffer){ret=new Uint8Array(ret)}return ret};readAsync=(filename,onload,onerror,binary=true)=>{filename=isFileURI(filename)?new URL(filename):nodePath.normalize(filename);fs.readFile(filename,binary?undefined:"utf8",(err,data)=>{if(err)onerror(err);else onload(binary?data.buffer:data)})};if(!Module["thisProgram"]&&process.argv.length>1){thisProgram=process.argv[1].replace(/\\/g,"/")}arguments_=process.argv.slice(2);if(typeof module!="undefined"){module["exports"]=Module}process.on("uncaughtException",ex=>{if(ex!=="unwind"&&!(ex instanceof ExitStatus)&&!(ex.context instanceof ExitStatus)){throw ex}});quit_=(status,toThrow)=>{process.exitCode=status;throw toThrow};Module["inspect"]=()=>"[Emscripten Module object]"}else if(ENVIRONMENT_IS_WEB||ENVIRONMENT_IS_WORKER){if(ENVIRONMENT_IS_WORKER){scriptDirectory=self.location.href}else if(typeof document!="undefined"&&document.currentScript){scriptDirectory=document.currentScript.src}if(scriptDirectory.indexOf("blob:")!==0){scriptDirectory=scriptDirectory.substr(0,scriptDirectory.replace(/[?#].*/,"").lastIndexOf("/")+1)}else{scriptDirectory=""}{read_=url=>{var xhr=new XMLHttpRequest;xhr.open("GET",url,false);xhr.send(null);return xhr.responseText};if(ENVIRONMENT_IS_WORKER){readBinary=url=>{var xhr=new XMLHttpRequest;xhr.open("GET",url,false);xhr.responseType="arraybuffer";xhr.send(null);return new Uint8Array(xhr.response)}}readAsync=(url,onload,onerror)=>{var xhr=new XMLHttpRequest;xhr.open("GET",url,true);xhr.responseType="arraybuffer";xhr.onload=()=>{if(xhr.status==200||xhr.status==0&&xhr.response){onload(xhr.response);return}onerror()};xhr.onerror=onerror;xhr.send(null)}}}else{}var out=Module["print"]||console.log.bind(console);var err=Module["printErr"]||console.error.bind(console);Object.assign(Module,moduleOverrides);moduleOverrides=null;if(Module["arguments"])arguments_=Module["arguments"];if(Module["thisProgram"])thisProgram=Module["thisProgram"];if(Module["quit"])quit_=Module["quit"];var dynamicLibraries=Module["dynamicLibraries"]||[];var wasmBinary;if(Module["wasmBinary"])wasmBinary=Module["wasmBinary"];if(typeof WebAssembly!="object"){abort("no native wasm support detected")}var wasmMemory;var ABORT=false;var EXITSTATUS;function assert(condition,text){if(!condition){abort(text)}}var HEAP,HEAP8,HEAPU8,HEAP16,HEAPU16,HEAP32,HEAPU32,HEAPF32,HEAP64,HEAPU64,HEAPF64;function updateMemoryViews(){var b=wasmMemory.buffer;Module["HEAP8"]=HEAP8=new Int8Array(b);Module["HEAP16"]=HEAP16=new Int16Array(b);Module["HEAPU8"]=HEAPU8=new Uint8Array(b);Module["HEAPU16"]=HEAPU16=new Uint16Array(b);Module["HEAP32"]=HEAP32=new Int32Array(b);Module["HEAPU32"]=HEAPU32=new Uint32Array(b);Module["HEAPF32"]=HEAPF32=new Float32Array(b);Module["HEAPF64"]=HEAPF64=new Float64Array(b);Module["HEAP64"]=HEAP64=new BigInt64Array(b);Module["HEAPU64"]=HEAPU64=new BigUint64Array(b)}var INITIAL_MEMORY=Module["INITIAL_MEMORY"]||16777216;assert(INITIAL_MEMORY>=1048576,"INITIAL_MEMORY should be larger than STACK_SIZE, was "+INITIAL_MEMORY+"! (STACK_SIZE="+1048576+")");if(Module["wasmMemory"]){wasmMemory=Module["wasmMemory"]}else{wasmMemory=new WebAssembly.Memory({"initial":INITIAL_MEMORY/65536,"maximum":2147483648/65536})}updateMemoryViews();INITIAL_MEMORY=wasmMemory.buffer.byteLength;var __ATPRERUN__=[];var __ATINIT__=[];var __ATMAIN__=[];var __ATEXIT__=[];var __ATPOSTRUN__=[];var __RELOC_FUNCS__=[];var runtimeInitialized=false;var runtimeExited=false;function preRun(){if(Module["preRun"]){if(typeof Module["preRun"]=="function")Module["preRun"]=[Module["preRun"]];while(Module["preRun"].length){addOnPreRun(Module["preRun"].shift())}}callRuntimeCallbacks(__ATPRERUN__)}function initRuntime(){runtimeInitialized=true;callRuntimeCallbacks(__RELOC_FUNCS__);if(!Module["noFSInit"]&&!FS.init.initialized)FS.init();FS.ignorePermissions=false;TTY.init();SOCKFS.root=FS.mount(SOCKFS,{},null);PIPEFS.root=FS.mount(PIPEFS,{},null);callRuntimeCallbacks(__ATINIT__)}function preMain(){callRuntimeCallbacks(__ATMAIN__)}function exitRuntime(){___funcs_on_exit();callRuntimeCallbacks(__ATEXIT__);FS.quit();TTY.shutdown();IDBFS.quit();runtimeExited=true}function postRun(){if(Module["postRun"]){if(typeof Module["postRun"]=="function")Module["postRun"]=[Module["postRun"]];while(Module["postRun"].length){addOnPostRun(Module["postRun"].shift())}}callRuntimeCallbacks(__ATPOSTRUN__)}function addOnPreRun(cb){__ATPRERUN__.unshift(cb)}function addOnInit(cb){__ATINIT__.unshift(cb)}function addOnPreMain(cb){__ATMAIN__.unshift(cb)}function addOnExit(cb){__ATEXIT__.unshift(cb)}function addOnPostRun(cb){__ATPOSTRUN__.unshift(cb)}var runDependencies=0;var runDependencyWatcher=null;var dependenciesFulfilled=null;function getUniqueRunDependency(id){return id}function addRunDependency(id){runDependencies++;if(Module["monitorRunDependencies"]){Module["monitorRunDependencies"](runDependencies)}}function removeRunDependency(id){runDependencies--;if(Module["monitorRunDependencies"]){Module["monitorRunDependencies"](runDependencies)}if(runDependencies==0){if(runDependencyWatcher!==null){clearInterval(runDependencyWatcher);runDependencyWatcher=null}if(dependenciesFulfilled){var callback=dependenciesFulfilled;dependenciesFulfilled=null;callback()}}}function abort(what){if(Module["onAbort"]){Module["onAbort"](what)}what="Aborted("+what+")";err(what);ABORT=true;EXITSTATUS=1;what+=". Build with -sASSERTIONS for more info.";if(runtimeInitialized){___trap()}var e=new WebAssembly.RuntimeError(what);throw e}var dataURIPrefix="data:application/octet-stream;base64,";var isDataURI=filename=>filename.startsWith(dataURIPrefix);var isFileURI=filename=>filename.startsWith("file://");var wasmBinaryFile;wasmBinaryFile="R.bin.wasm";if(!isDataURI(wasmBinaryFile)){wasmBinaryFile=locateFile(wasmBinaryFile)}function getBinarySync(file){if(file==wasmBinaryFile&&wasmBinary){return new Uint8Array(wasmBinary)}if(readBinary){return readBinary(file)}throw"both async and sync fetching of the wasm failed"}function getBinaryPromise(binaryFile){if(!wasmBinary&&(ENVIRONMENT_IS_WEB||ENVIRONMENT_IS_WORKER)){if(typeof fetch=="function"&&!isFileURI(binaryFile)){return fetch(binaryFile,{credentials:"same-origin"}).then(response=>{if(!response["ok"]){throw"failed to load wasm binary file at '"+binaryFile+"'"}return response["arrayBuffer"]()}).catch(()=>getBinarySync(binaryFile))}else if(readAsync){return new Promise((resolve,reject)=>{readAsync(binaryFile,response=>resolve(new Uint8Array(response)),reject)})}}return Promise.resolve().then(()=>getBinarySync(binaryFile))}function instantiateArrayBuffer(binaryFile,imports,receiver){return getBinaryPromise(binaryFile).then(binary=>WebAssembly.instantiate(binary,imports)).then(instance=>instance).then(receiver,reason=>{err(`failed to asynchronously prepare wasm: ${reason}`);abort(reason)})}function instantiateAsync(binary,binaryFile,imports,callback){if(!binary&&typeof WebAssembly.instantiateStreaming=="function"&&!isDataURI(binaryFile)&&!isFileURI(binaryFile)&&!ENVIRONMENT_IS_NODE&&typeof fetch=="function"){return fetch(binaryFile,{credentials:"same-origin"}).then(response=>{var result=WebAssembly.instantiateStreaming(response,imports);return result.then(callback,function(reason){err(`wasm streaming compile failed: ${reason}`);err("falling back to ArrayBuffer instantiation");return instantiateArrayBuffer(binaryFile,imports,callback)})})}return instantiateArrayBuffer(binaryFile,imports,callback)}function createWasm(){var info={"env":wasmImports,"wasi_snapshot_preview1":wasmImports,"GOT.mem":new Proxy(wasmImports,GOTHandler),"GOT.func":new Proxy(wasmImports,GOTHandler)};function receiveInstance(instance,module){wasmExports=instance.exports;wasmExports=relocateExports(wasmExports,1024);var metadata=getDylinkMetadata(module);if(metadata.neededDynlibs){dynamicLibraries=metadata.neededDynlibs.concat(dynamicLibraries)}mergeLibSymbols(wasmExports,"main");LDSO.init();loadDylibs();addOnInit(wasmExports["__wasm_call_ctors"]);__RELOC_FUNCS__.push(wasmExports["__wasm_apply_data_relocs"]);exportWasmSymbols(wasmExports);removeRunDependency("wasm-instantiate");return wasmExports}addRunDependency("wasm-instantiate");function receiveInstantiationResult(result){receiveInstance(result["instance"],result["module"])}if(Module["instantiateWasm"]){try{return Module["instantiateWasm"](info,receiveInstance)}catch(e){err(`Module.instantiateWasm callback failed with error: ${e}`);return false}}instantiateAsync(wasmBinary,wasmBinaryFile,info,receiveInstantiationResult);return{}}var ASM_CONSTS={8301376:$0=>{globalThis.Module.setPrompt(UTF8ToString($0))},8301422:()=>{globalThis.Module.webr.resolveInit()},8301459:()=>globalThis.Module.webr.readConsole(),8301503:()=>{globalThis.Module.webr.handleEvents()},8301541:($0,$1)=>{const title=UTF8ToString($1);globalThis.Module.webr.dataViewer($0,title)},8301623:$0=>{if(!$0){AL.alcErr=40964;return 1}},8301671:$0=>{if(!AL.currentCtx){err("alGetProcAddress() called without a valid context");return 1}if(!$0){AL.currentCtx.err=40963;return 1}}};var runtimeKeepaliveCounter=0;var runtimeKeepalivePush=()=>{runtimeKeepaliveCounter+=1};runtimeKeepalivePush.sig="v";var _emscripten_set_main_loop_timing=(mode,value)=>{Browser.mainLoop.timingMode=mode;Browser.mainLoop.timingValue=value;if(!Browser.mainLoop.func){return 1}if(!Browser.mainLoop.running){runtimeKeepalivePush();Browser.mainLoop.running=true}if(mode==0){Browser.mainLoop.scheduler=function Browser_mainLoop_scheduler_setTimeout(){var timeUntilNextTick=Math.max(0,Browser.mainLoop.tickStartTime+value-_emscripten_get_now())|0;setTimeout(Browser.mainLoop.runner,timeUntilNextTick)};Browser.mainLoop.method="timeout"}else if(mode==1){Browser.mainLoop.scheduler=function Browser_mainLoop_scheduler_rAF(){Browser.requestAnimationFrame(Browser.mainLoop.runner)};Browser.mainLoop.method="rAF"}else if(mode==2){if(typeof setImmediate=="undefined"){var setImmediates=[];var emscriptenMainLoopMessageId="setimmediate";var Browser_setImmediate_messageHandler=event=>{if(event.data===emscriptenMainLoopMessageId||event.data.target===emscriptenMainLoopMessageId){event.stopPropagation();setImmediates.shift()()}};addEventListener("message",Browser_setImmediate_messageHandler,true);setImmediate=function Browser_emulated_setImmediate(func){setImmediates.push(func);if(ENVIRONMENT_IS_WORKER){if(Module["setImmediates"]===undefined)Module["setImmediates"]=[];Module["setImmediates"].push(func);postMessage({target:emscriptenMainLoopMessageId})}else postMessage(emscriptenMainLoopMessageId,"*")}}Browser.mainLoop.scheduler=function Browser_mainLoop_scheduler_setImmediate(){setImmediate(Browser.mainLoop.runner)};Browser.mainLoop.method="immediate"}return 0};_emscripten_set_main_loop_timing.sig="iii";var _emscripten_get_now;_emscripten_get_now=()=>performance.now();_emscripten_get_now.sig="d";function ExitStatus(status){this.name="ExitStatus";this.message=`Program terminated with exit(${status})`;this.status=status}var keepRuntimeAlive=()=>noExitRuntime||runtimeKeepaliveCounter>0;var PATH={isAbs:path=>path.charAt(0)==="/",splitPath:filename=>{var splitPathRe=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;return splitPathRe.exec(filename).slice(1)},normalizeArray:(parts,allowAboveRoot)=>{var up=0;for(var i=parts.length-1;i>=0;i--){var last=parts[i];if(last==="."){parts.splice(i,1)}else if(last===".."){parts.splice(i,1);up++}else if(up){parts.splice(i,1);up--}}if(allowAboveRoot){for(;up;up--){parts.unshift("..")}}return parts},normalize:path=>{var isAbsolute=PATH.isAbs(path),trailingSlash=path.substr(-1)==="/";path=PATH.normalizeArray(path.split("/").filter(p=>!!p),!isAbsolute).join("/");if(!path&&!isAbsolute){path="."}if(path&&trailingSlash){path+="/"}return(isAbsolute?"/":"")+path},dirname:path=>{var result=PATH.splitPath(path),root=result[0],dir=result[1];if(!root&&!dir){return"."}if(dir){dir=dir.substr(0,dir.length-1)}return root+dir},basename:path=>{if(path==="/")return"/";path=PATH.normalize(path);path=path.replace(/\/$/,"");var lastSlash=path.lastIndexOf("/");if(lastSlash===-1)return path;return path.substr(lastSlash+1)},join:function(){var paths=Array.prototype.slice.call(arguments);return PATH.normalize(paths.join("/"))},join2:(l,r)=>PATH.normalize(l+"/"+r)};var initRandomFill=()=>{if(typeof crypto=="object"&&typeof crypto["getRandomValues"]=="function"){return view=>crypto.getRandomValues(view)}else if(ENVIRONMENT_IS_NODE){try{var crypto_module=require("crypto");var randomFillSync=crypto_module["randomFillSync"];if(randomFillSync){return view=>crypto_module["randomFillSync"](view)}var randomBytes=crypto_module["randomBytes"];return view=>(view.set(randomBytes(view.byteLength)),view)}catch(e){}}abort("initRandomDevice")};var randomFill=view=>(randomFill=initRandomFill())(view);var PATH_FS={resolve:function(){var resolvedPath="",resolvedAbsolute=false;for(var i=arguments.length-1;i>=-1&&!resolvedAbsolute;i--){var path=i>=0?arguments[i]:FS.cwd();if(typeof path!="string"){throw new TypeError("Arguments to path.resolve must be strings")}else if(!path){return""}resolvedPath=path+"/"+resolvedPath;resolvedAbsolute=PATH.isAbs(path)}resolvedPath=PATH.normalizeArray(resolvedPath.split("/").filter(p=>!!p),!resolvedAbsolute).join("/");return(resolvedAbsolute?"/":"")+resolvedPath||"."},relative:(from,to)=>{from=PATH_FS.resolve(from).substr(1);to=PATH_FS.resolve(to).substr(1);function trim(arr){var start=0;for(;start<arr.length;start++){if(arr[start]!=="")break}var end=arr.length-1;for(;end>=0;end--){if(arr[end]!=="")break}if(start>end)return[];return arr.slice(start,end-start+1)}var fromParts=trim(from.split("/"));var toParts=trim(to.split("/"));var length=Math.min(fromParts.length,toParts.length);var samePartsLength=length;for(var i=0;i<length;i++){if(fromParts[i]!==toParts[i]){samePartsLength=i;break}}var outputParts=[];for(var i=samePartsLength;i<fromParts.length;i++){outputParts.push("..")}outputParts=outputParts.concat(toParts.slice(samePartsLength));return outputParts.join("/")}};var UTF8Decoder=typeof TextDecoder!="undefined"?new TextDecoder("utf8"):undefined;var UTF8ArrayToString=(heapOrArray,idx,maxBytesToRead)=>{var endIdx=idx+maxBytesToRead;var endPtr=idx;while(heapOrArray[endPtr]&&!(endPtr>=endIdx))++endPtr;if(endPtr-idx>16&&heapOrArray.buffer&&UTF8Decoder){return UTF8Decoder.decode(heapOrArray.subarray(idx,endPtr))}var str="";while(idx<endPtr){var u0=heapOrArray[idx++];if(!(u0&128)){str+=String.fromCharCode(u0);continue}var u1=heapOrArray[idx++]&63;if((u0&224)==192){str+=String.fromCharCode((u0&31)<<6|u1);continue}var u2=heapOrArray[idx++]&63;if((u0&240)==224){u0=(u0&15)<<12|u1<<6|u2}else{u0=(u0&7)<<18|u1<<12|u2<<6|heapOrArray[idx++]&63}if(u0<65536){str+=String.fromCharCode(u0)}else{var ch=u0-65536;str+=String.fromCharCode(55296|ch>>10,56320|ch&1023)}}return str};var FS_stdin_getChar_buffer=[];var lengthBytesUTF8=str=>{var len=0;for(var i=0;i<str.length;++i){var c=str.charCodeAt(i);if(c<=127){len++}else if(c<=2047){len+=2}else if(c>=55296&&c<=57343){len+=4;++i}else{len+=3}}return len};var stringToUTF8Array=(str,heap,outIdx,maxBytesToWrite)=>{if(!(maxBytesToWrite>0))return 0;var startIdx=outIdx;var endIdx=outIdx+maxBytesToWrite-1;for(var i=0;i<str.length;++i){var u=str.charCodeAt(i);if(u>=55296&&u<=57343){var u1=str.charCodeAt(++i);u=65536+((u&1023)<<10)|u1&1023}if(u<=127){if(outIdx>=endIdx)break;heap[outIdx++]=u}else if(u<=2047){if(outIdx+1>=endIdx)break;heap[outIdx++]=192|u>>6;heap[outIdx++]=128|u&63}else if(u<=65535){if(outIdx+2>=endIdx)break;heap[outIdx++]=224|u>>12;heap[outIdx++]=128|u>>6&63;heap[outIdx++]=128|u&63}else{if(outIdx+3>=endIdx)break;heap[outIdx++]=240|u>>18;heap[outIdx++]=128|u>>12&63;heap[outIdx++]=128|u>>6&63;heap[outIdx++]=128|u&63}}heap[outIdx]=0;return outIdx-startIdx};function intArrayFromString(stringy,dontAddNull,length){var len=length>0?length:lengthBytesUTF8(stringy)+1;var u8array=new Array(len);var numBytesWritten=stringToUTF8Array(stringy,u8array,0,u8array.length);if(dontAddNull)u8array.length=numBytesWritten;return u8array}var FS_stdin_getChar=()=>{if(!FS_stdin_getChar_buffer.length){var result=null;if(ENVIRONMENT_IS_NODE){var BUFSIZE=256;var buf=Buffer.alloc(BUFSIZE);var bytesRead=0;var fd=process.stdin.fd;try{bytesRead=fs.readSync(fd,buf)}catch(e){if(e.toString().includes("EOF"))bytesRead=0;else throw e}if(bytesRead>0){result=buf.slice(0,bytesRead).toString("utf-8")}else{result=null}}else if(typeof window!="undefined"&&typeof window.prompt=="function"){result=window.prompt("Input: ");if(result!==null){result+="\n"}}else if(typeof readline=="function"){result=readline();if(result!==null){result+="\n"}}if(!result){return null}FS_stdin_getChar_buffer=intArrayFromString(result,true)}return FS_stdin_getChar_buffer.shift()};var TTY={ttys:[],init(){},shutdown(){},register(dev,ops){TTY.ttys[dev]={input:[],output:[],ops:ops};FS.registerDevice(dev,TTY.stream_ops)},stream_ops:{open(stream){var tty=TTY.ttys[stream.node.rdev];if(!tty){throw new FS.ErrnoError(43)}stream.tty=tty;stream.seekable=false},close(stream){stream.tty.ops.fsync(stream.tty)},fsync(stream){stream.tty.ops.fsync(stream.tty)},read(stream,buffer,offset,length,pos){if(!stream.tty||!stream.tty.ops.get_char){throw new FS.ErrnoError(60)}var bytesRead=0;for(var i=0;i<length;i++){var result;try{result=stream.tty.ops.get_char(stream.tty)}catch(e){throw new FS.ErrnoError(29)}if(result===undefined&&bytesRead===0){throw new FS.ErrnoError(6)}if(result===null||result===undefined)break;bytesRead++;buffer[offset+i]=result}if(bytesRead){stream.node.timestamp=Date.now()}return bytesRead},write(stream,buffer,offset,length,pos){if(!stream.tty||!stream.tty.ops.put_char){throw new FS.ErrnoError(60)}try{for(var i=0;i<length;i++){stream.tty.ops.put_char(stream.tty,buffer[offset+i])}}catch(e){throw new FS.ErrnoError(29)}if(length){stream.node.timestamp=Date.now()}return i}},default_tty_ops:{get_char(tty){return FS_stdin_getChar()},put_char(tty,val){if(val===null||val===10){out(UTF8ArrayToString(tty.output,0));tty.output=[]}else{if(val!=0)tty.output.push(val)}},fsync(tty){if(tty.output&&tty.output.length>0){out(UTF8ArrayToString(tty.output,0));tty.output=[]}},ioctl_tcgets(tty){return{c_iflag:25856,c_oflag:5,c_cflag:191,c_lflag:35387,c_cc:[3,28,127,21,4,0,1,0,17,19,26,0,18,15,23,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}},ioctl_tcsets(tty,optional_actions,data){return 0},ioctl_tiocgwinsz(tty){return[24,80]}},default_tty1_ops:{put_char(tty,val){if(val===null||val===10){err(UTF8ArrayToString(tty.output,0));tty.output=[]}else{if(val!=0)tty.output.push(val)}},fsync(tty){if(tty.output&&tty.output.length>0){err(UTF8ArrayToString(tty.output,0));tty.output=[]}}}};var zeroMemory=(address,size)=>{HEAPU8.fill(0,address,address+size);return address};var alignMemory=(size,alignment)=>Math.ceil(size/alignment)*alignment;var mmapAlloc=size=>{size=alignMemory(size,65536);var ptr=_emscripten_builtin_memalign(65536,size);if(!ptr)return 0;return zeroMemory(ptr,size)};var MEMFS={ops_table:null,mount(mount){return MEMFS.createNode(null,"/",16384|511,0)},createNode(parent,name,mode,dev){if(FS.isBlkdev(mode)||FS.isFIFO(mode)){throw new FS.ErrnoError(63)}if(!MEMFS.ops_table){MEMFS.ops_table={dir:{node:{getattr:MEMFS.node_ops.getattr,setattr:MEMFS.node_ops.setattr,lookup:MEMFS.node_ops.lookup,mknod:MEMFS.node_ops.mknod,rename:MEMFS.node_ops.rename,unlink:MEMFS.node_ops.unlink,rmdir:MEMFS.node_ops.rmdir,readdir:MEMFS.node_ops.readdir,symlink:MEMFS.node_ops.symlink},stream:{llseek:MEMFS.stream_ops.llseek}},file:{node:{getattr:MEMFS.node_ops.getattr,setattr:MEMFS.node_ops.setattr},stream:{llseek:MEMFS.stream_ops.llseek,read:MEMFS.stream_ops.read,write:MEMFS.stream_ops.write,allocate:MEMFS.stream_ops.allocate,mmap:MEMFS.stream_ops.mmap,msync:MEMFS.stream_ops.msync}},link:{node:{getattr:MEMFS.node_ops.getattr,setattr:MEMFS.node_ops.setattr,readlink:MEMFS.node_ops.readlink},stream:{}},chrdev:{node:{getattr:MEMFS.node_ops.getattr,setattr:MEMFS.node_ops.setattr},stream:FS.chrdev_stream_ops}}}var node=FS.createNode(parent,name,mode,dev);if(FS.isDir(node.mode)){node.node_ops=MEMFS.ops_table.dir.node;node.stream_ops=MEMFS.ops_table.dir.stream;node.contents={}}else if(FS.isFile(node.mode)){node.node_ops=MEMFS.ops_table.file.node;node.stream_ops=MEMFS.ops_table.file.stream;node.usedBytes=0;node.contents=null}else if(FS.isLink(node.mode)){node.node_ops=MEMFS.ops_table.link.node;node.stream_ops=MEMFS.ops_table.link.stream}else if(FS.isChrdev(node.mode)){node.node_ops=MEMFS.ops_table.chrdev.node;node.stream_ops=MEMFS.ops_table.chrdev.stream}node.timestamp=Date.now();if(parent){parent.contents[name]=node;parent.timestamp=node.timestamp}return node},getFileDataAsTypedArray(node){if(!node.contents)return new Uint8Array(0);if(node.contents.subarray)return node.contents.subarray(0,node.usedBytes);return new Uint8Array(node.contents)},expandFileStorage(node,newCapacity){var prevCapacity=node.contents?node.contents.length:0;if(prevCapacity>=newCapacity)return;var CAPACITY_DOUBLING_MAX=1024*1024;newCapacity=Math.max(newCapacity,prevCapacity*(prevCapacity<CAPACITY_DOUBLING_MAX?2:1.125)>>>0);if(prevCapacity!=0)newCapacity=Math.max(newCapacity,256);var oldContents=node.contents;node.contents=new Uint8Array(newCapacity);if(node.usedBytes>0)node.contents.set(oldContents.subarray(0,node.usedBytes),0)},resizeFileStorage(node,newSize){if(node.usedBytes==newSize)return;if(newSize==0){node.contents=null;node.usedBytes=0}else{var oldContents=node.contents;node.contents=new Uint8Array(newSize);if(oldContents){node.contents.set(oldContents.subarray(0,Math.min(newSize,node.usedBytes)))}node.usedBytes=newSize}},node_ops:{getattr(node){var attr={};attr.dev=FS.isChrdev(node.mode)?node.id:1;attr.ino=node.id;attr.mode=node.mode;attr.nlink=1;attr.uid=0;attr.gid=0;attr.rdev=node.rdev;if(FS.isDir(node.mode)){attr.size=4096}else if(FS.isFile(node.mode)){attr.size=node.usedBytes}else if(FS.isLink(node.mode)){attr.size=node.link.length}else{attr.size=0}attr.atime=new Date(node.timestamp);attr.mtime=new Date(node.timestamp);attr.ctime=new Date(node.timestamp);attr.blksize=4096;attr.blocks=Math.ceil(attr.size/attr.blksize);return attr},setattr(node,attr){if(attr.mode!==undefined){node.mode=attr.mode}if(attr.timestamp!==undefined){node.timestamp=attr.timestamp}if(attr.size!==undefined){MEMFS.resizeFileStorage(node,attr.size)}},lookup(parent,name){throw FS.genericErrors[44]},mknod(parent,name,mode,dev){return MEMFS.createNode(parent,name,mode,dev)},rename(old_node,new_dir,new_name){if(FS.isDir(old_node.mode)){var new_node;try{new_node=FS.lookupNode(new_dir,new_name)}catch(e){}if(new_node){for(var i in new_node.contents){throw new FS.ErrnoError(55)}}}delete old_node.parent.contents[old_node.name];old_node.parent.timestamp=Date.now();old_node.name=new_name;new_dir.contents[new_name]=old_node;new_dir.timestamp=old_node.parent.timestamp;old_node.parent=new_dir},unlink(parent,name){delete parent.contents[name];parent.timestamp=Date.now()},rmdir(parent,name){var node=FS.lookupNode(parent,name);for(var i in node.contents){throw new FS.ErrnoError(55)}delete parent.contents[name];parent.timestamp=Date.now()},readdir(node){var entries=[".",".."];for(var key in node.contents){if(!node.contents.hasOwnProperty(key)){continue}entries.push(key)}return entries},symlink(parent,newname,oldpath){var node=MEMFS.createNode(parent,newname,511|40960,0);node.link=oldpath;return node},readlink(node){if(!FS.isLink(node.mode)){throw new FS.ErrnoError(28)}return node.link}},stream_ops:{read(stream,buffer,offset,length,position){var contents=stream.node.contents;if(position>=stream.node.usedBytes)return 0;var size=Math.min(stream.node.usedBytes-position,length);if(size>8&&contents.subarray){buffer.set(contents.subarray(position,position+size),offset)}else{for(var i=0;i<size;i++)buffer[offset+i]=contents[position+i]}return size},write(stream,buffer,offset,length,position,canOwn){if(buffer.buffer===HEAP8.buffer){canOwn=false}if(!length)return 0;var node=stream.node;node.timestamp=Date.now();if(buffer.subarray&&(!node.contents||node.contents.subarray)){if(canOwn){node.contents=buffer.subarray(offset,offset+length);node.usedBytes=length;return length}else if(node.usedBytes===0&&position===0){node.contents=buffer.slice(offset,offset+length);node.usedBytes=length;return length}else if(position+length<=node.usedBytes){node.contents.set(buffer.subarray(offset,offset+length),position);return length}}MEMFS.expandFileStorage(node,position+length);if(node.contents.subarray&&buffer.subarray){node.contents.set(buffer.subarray(offset,offset+length),position)}else{for(var i=0;i<length;i++){node.contents[position+i]=buffer[offset+i]}}node.usedBytes=Math.max(node.usedBytes,position+length);return length},llseek(stream,offset,whence){var position=offset;if(whence===1){position+=stream.position}else if(whence===2){if(FS.isFile(stream.node.mode)){position+=stream.node.usedBytes}}if(position<0){throw new FS.ErrnoError(28)}return position},allocate(stream,offset,length){MEMFS.expandFileStorage(stream.node,offset+length);stream.node.usedBytes=Math.max(stream.node.usedBytes,offset+length)},mmap(stream,length,position,prot,flags){if(!FS.isFile(stream.node.mode)){throw new FS.ErrnoError(43)}var ptr;var allocated;var contents=stream.node.contents;if(!(flags&2)&&contents.buffer===HEAP8.buffer){allocated=false;ptr=contents.byteOffset}else{if(position>0||position+length<contents.length){if(contents.subarray){contents=contents.subarray(position,position+length)}else{contents=Array.prototype.slice.call(contents,position,position+length)}}allocated=true;ptr=mmapAlloc(length);if(!ptr){throw new FS.ErrnoError(48)}HEAP8.set(contents,ptr)}return{ptr:ptr,allocated:allocated}},msync(stream,buffer,offset,length,mmapFlags){MEMFS.stream_ops.write(stream,buffer,0,length,offset,false);return 0}}};var asyncLoad=(url,onload,onerror,noRunDep)=>{var dep=!noRunDep?getUniqueRunDependency(`al ${url}`):"";readAsync(url,arrayBuffer=>{assert(arrayBuffer,`Loading data file "${url}" failed (no arrayBuffer).`);onload(new Uint8Array(arrayBuffer));if(dep)removeRunDependency(dep)},event=>{if(onerror){onerror()}else{throw`Loading data file "${url}" failed.`}});if(dep)addRunDependency(dep)};var FS_createDataFile=(parent,name,fileData,canRead,canWrite,canOwn)=>FS.createDataFile(parent,name,fileData,canRead,canWrite,canOwn);var preloadPlugins=Module["preloadPlugins"]||[];var FS_handledByPreloadPlugin=(byteArray,fullname,finish,onerror)=>{if(typeof Browser!="undefined")Browser.init();var handled=false;preloadPlugins.forEach(plugin=>{if(handled)return;if(plugin["canHandle"](fullname)){plugin["handle"](byteArray,fullname,finish,onerror);handled=true}});return handled};var FS_createPreloadedFile=(parent,name,url,canRead,canWrite,onload,onerror,dontCreateFile,canOwn,preFinish)=>{var fullname=name?PATH_FS.resolve(PATH.join2(parent,name)):parent;var dep=getUniqueRunDependency(`cp ${fullname}`);function processData(byteArray){function finish(byteArray){if(preFinish)preFinish();if(!dontCreateFile){FS_createDataFile(parent,name,byteArray,canRead,canWrite,canOwn)}if(onload)onload();removeRunDependency(dep)}if(FS_handledByPreloadPlugin(byteArray,fullname,finish,()=>{if(onerror)onerror();removeRunDependency(dep)})){return}finish(byteArray)}addRunDependency(dep);if(typeof url=="string"){asyncLoad(url,byteArray=>processData(byteArray),onerror)}else{processData(url)}};var FS_modeStringToFlags=str=>{var flagModes={"r":0,"r+":2,"w":512|64|1,"w+":512|64|2,"a":1024|64|1,"a+":1024|64|2};var flags=flagModes[str];if(typeof flags=="undefined"){throw new Error(`Unknown file open mode: ${str}`)}return flags};var FS_getMode=(canRead,canWrite)=>{var mode=0;if(canRead)mode|=292|73;if(canWrite)mode|=146;return mode};var IDBFS={dbs:{},indexedDB:()=>{if(typeof indexedDB!="undefined")return indexedDB;var ret=null;if(typeof window=="object")ret=window.indexedDB||window.mozIndexedDB||window.webkitIndexedDB||window.msIndexedDB;assert(ret,"IDBFS used, but indexedDB not supported");return ret},DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function(mount){return MEMFS.mount.apply(null,arguments)},syncfs:(mount,populate,callback)=>{IDBFS.getLocalSet(mount,(err,local)=>{if(err)return callback(err);IDBFS.getRemoteSet(mount,(err,remote)=>{if(err)return callback(err);var src=populate?remote:local;var dst=populate?local:remote;IDBFS.reconcile(src,dst,callback)})})},quit:()=>{Object.values(IDBFS.dbs).forEach(value=>value.close());IDBFS.dbs={}},getDB:(name,callback)=>{var db=IDBFS.dbs[name];if(db){return callback(null,db)}var req;try{req=IDBFS.indexedDB().open(name,IDBFS.DB_VERSION)}catch(e){return callback(e)}if(!req){return callback("Unable to connect to IndexedDB")}req.onupgradeneeded=e=>{var db=e.target.result;var transaction=e.target.transaction;var fileStore;if(db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)){fileStore=transaction.objectStore(IDBFS.DB_STORE_NAME)}else{fileStore=db.createObjectStore(IDBFS.DB_STORE_NAME)}if(!fileStore.indexNames.contains("timestamp")){fileStore.createIndex("timestamp","timestamp",{unique:false})}};req.onsuccess=()=>{db=req.result;IDBFS.dbs[name]=db;callback(null,db)};req.onerror=e=>{callback(e.target.error);e.preventDefault()}},getLocalSet:(mount,callback)=>{var entries={};function isRealDir(p){return p!=="."&&p!==".."}function toAbsolute(root){return p=>PATH.join2(root,p)}var check=FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));while(check.length){var path=check.pop();var stat;try{stat=FS.stat(path)}catch(e){return callback(e)}if(FS.isDir(stat.mode)){check.push.apply(check,FS.readdir(path).filter(isRealDir).map(toAbsolute(path)))}entries[path]={"timestamp":stat.mtime}}return callback(null,{type:"local",entries:entries})},getRemoteSet:(mount,callback)=>{var entries={};IDBFS.getDB(mount.mountpoint,(err,db)=>{if(err)return callback(err);try{var transaction=db.transaction([IDBFS.DB_STORE_NAME],"readonly");transaction.onerror=e=>{callback(e.target.error);e.preventDefault()};var store=transaction.objectStore(IDBFS.DB_STORE_NAME);var index=store.index("timestamp");index.openKeyCursor().onsuccess=event=>{var cursor=event.target.result;if(!cursor){return callback(null,{type:"remote",db:db,entries:entries})}entries[cursor.primaryKey]={"timestamp":cursor.key};cursor.continue()}}catch(e){return callback(e)}})},loadLocalEntry:(path,callback)=>{var stat,node;try{var lookup=FS.lookupPath(path);node=lookup.node;stat=FS.stat(path)}catch(e){return callback(e)}if(FS.isDir(stat.mode)){return callback(null,{"timestamp":stat.mtime,"mode":stat.mode})}else if(FS.isFile(stat.mode)){node.contents=MEMFS.getFileDataAsTypedArray(node);return callback(null,{"timestamp":stat.mtime,"mode":stat.mode,"contents":node.contents})}else{return callback(new Error("node type not supported"))}},storeLocalEntry:(path,entry,callback)=>{try{if(FS.isDir(entry["mode"])){FS.mkdirTree(path,entry["mode"])}else if(FS.isFile(entry["mode"])){FS.writeFile(path,entry["contents"],{canOwn:true})}else{return callback(new Error("node type not supported"))}FS.chmod(path,entry["mode"]);FS.utime(path,entry["timestamp"],entry["timestamp"])}catch(e){return callback(e)}callback(null)},removeLocalEntry:(path,callback)=>{try{var stat=FS.stat(path);if(FS.isDir(stat.mode)){FS.rmdir(path)}else if(FS.isFile(stat.mode)){FS.unlink(path)}}catch(e){return callback(e)}callback(null)},loadRemoteEntry:(store,path,callback)=>{var req=store.get(path);req.onsuccess=event=>{callback(null,event.target.result)};req.onerror=e=>{callback(e.target.error);e.preventDefault()}},storeRemoteEntry:(store,path,entry,callback)=>{try{var req=store.put(entry,path)}catch(e){callback(e);return}req.onsuccess=()=>{callback(null)};req.onerror=e=>{callback(e.target.error);e.preventDefault()}},removeRemoteEntry:(store,path,callback)=>{var req=store.delete(path);req.onsuccess=()=>{callback(null)};req.onerror=e=>{callback(e.target.error);e.preventDefault()}},reconcile:(src,dst,callback)=>{var total=0;var create=[];Object.keys(src.entries).forEach(function(key){var e=src.entries[key];var e2=dst.entries[key];if(!e2||e["timestamp"].getTime()!=e2["timestamp"].getTime()){create.push(key);total++}});var remove=[];Object.keys(dst.entries).forEach(function(key){if(!src.entries[key]){remove.push(key);total++}});if(!total){return callback(null)}var errored=false;var db=src.type==="remote"?src.db:dst.db;var transaction=db.transaction([IDBFS.DB_STORE_NAME],"readwrite");var store=transaction.objectStore(IDBFS.DB_STORE_NAME);function done(err){if(err&&!errored){errored=true;return callback(err)}}transaction.onerror=e=>{done(this.error);e.preventDefault()};transaction.oncomplete=e=>{if(!errored){callback(null)}};create.sort().forEach(path=>{if(dst.type==="local"){IDBFS.loadRemoteEntry(store,path,(err,entry)=>{if(err)return done(err);IDBFS.storeLocalEntry(path,entry,done)})}else{IDBFS.loadLocalEntry(path,(err,entry)=>{if(err)return done(err);IDBFS.storeRemoteEntry(store,path,entry,done)})}});remove.sort().reverse().forEach(path=>{if(dst.type==="local"){IDBFS.removeLocalEntry(path,done)}else{IDBFS.removeRemoteEntry(store,path,done)}})}};var ERRNO_CODES={};var NODEFS={isWindows:false,staticInit(){NODEFS.isWindows=!!process.platform.match(/^win/);var flags=process.binding("constants");if(flags["fs"]){flags=flags["fs"]}NODEFS.flagsForNodeMap={1024:flags["O_APPEND"],64:flags["O_CREAT"],128:flags["O_EXCL"],256:flags["O_NOCTTY"],0:flags["O_RDONLY"],2:flags["O_RDWR"],4096:flags["O_SYNC"],512:flags["O_TRUNC"],1:flags["O_WRONLY"],131072:flags["O_NOFOLLOW"]}},convertNodeCode(e){var code=e.code;return ERRNO_CODES[code]},mount(mount){return NODEFS.createNode(null,"/",NODEFS.getMode(mount.opts.root),0)},createNode(parent,name,mode,dev){if(!FS.isDir(mode)&&!FS.isFile(mode)&&!FS.isLink(mode)){throw new FS.ErrnoError(28)}var node=FS.createNode(parent,name,mode);node.node_ops=NODEFS.node_ops;node.stream_ops=NODEFS.stream_ops;return node},getMode(path){var stat;try{stat=fs.lstatSync(path);if(NODEFS.isWindows){stat.mode=stat.mode|(stat.mode&292)>>2}}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}return stat.mode},realPath(node){var parts=[];while(node.parent!==node){parts.push(node.name);node=node.parent}parts.push(node.mount.opts.root);parts.reverse();return PATH.join.apply(null,parts)},flagsForNode(flags){flags&=~2097152;flags&=~2048;flags&=~32768;flags&=~524288;flags&=~65536;var newFlags=0;for(var k in NODEFS.flagsForNodeMap){if(flags&k){newFlags|=NODEFS.flagsForNodeMap[k];flags^=k}}if(flags){throw new FS.ErrnoError(28)}return newFlags},node_ops:{getattr(node){var path=NODEFS.realPath(node);var stat;try{stat=fs.lstatSync(path)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}if(NODEFS.isWindows&&!stat.blksize){stat.blksize=4096}if(NODEFS.isWindows&&!stat.blocks){stat.blocks=(stat.size+stat.blksize-1)/stat.blksize|0}return{dev:stat.dev,ino:stat.ino,mode:stat.mode,nlink:stat.nlink,uid:stat.uid,gid:stat.gid,rdev:stat.rdev,size:stat.size,atime:stat.atime,mtime:stat.mtime,ctime:stat.ctime,blksize:stat.blksize,blocks:stat.blocks}},setattr(node,attr){var path=NODEFS.realPath(node);try{if(attr.mode!==undefined){fs.chmodSync(path,attr.mode);node.mode=attr.mode}if(attr.timestamp!==undefined){var date=new Date(attr.timestamp);fs.utimesSync(path,date,date)}if(attr.size!==undefined){fs.truncateSync(path,attr.size)}}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},lookup(parent,name){var path=PATH.join2(NODEFS.realPath(parent),name);var mode=NODEFS.getMode(path);return NODEFS.createNode(parent,name,mode)},mknod(parent,name,mode,dev){var node=NODEFS.createNode(parent,name,mode,dev);var path=NODEFS.realPath(node);try{if(FS.isDir(node.mode)){fs.mkdirSync(path,node.mode)}else{fs.writeFileSync(path,"",{mode:node.mode})}}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}return node},rename(oldNode,newDir,newName){var oldPath=NODEFS.realPath(oldNode);var newPath=PATH.join2(NODEFS.realPath(newDir),newName);try{fs.renameSync(oldPath,newPath)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}oldNode.name=newName},unlink(parent,name){var path=PATH.join2(NODEFS.realPath(parent),name);try{fs.unlinkSync(path)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},rmdir(parent,name){var path=PATH.join2(NODEFS.realPath(parent),name);try{fs.rmdirSync(path)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},readdir(node){var path=NODEFS.realPath(node);try{return fs.readdirSync(path)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},symlink(parent,newName,oldPath){var newPath=PATH.join2(NODEFS.realPath(parent),newName);try{fs.symlinkSync(oldPath,newPath)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},readlink(node){var path=NODEFS.realPath(node);try{path=fs.readlinkSync(path);path=nodePath.relative(nodePath.resolve(node.mount.opts.root),path);return path}catch(e){if(!e.code)throw e;if(e.code==="UNKNOWN")throw new FS.ErrnoError(28);throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}}},stream_ops:{open(stream){var path=NODEFS.realPath(stream.node);try{if(FS.isFile(stream.node.mode)){stream.nfd=fs.openSync(path,NODEFS.flagsForNode(stream.flags))}}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},close(stream){try{if(FS.isFile(stream.node.mode)&&stream.nfd){fs.closeSync(stream.nfd)}}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},read(stream,buffer,offset,length,position){if(length===0)return 0;try{return fs.readSync(stream.nfd,new Int8Array(buffer.buffer,offset,length),{position:position})}catch(e){throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},write(stream,buffer,offset,length,position){try{return fs.writeSync(stream.nfd,new Int8Array(buffer.buffer,offset,length),{position:position})}catch(e){throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}},llseek(stream,offset,whence){var position=offset;if(whence===1){position+=stream.position}else if(whence===2){if(FS.isFile(stream.node.mode)){try{var stat=fs.fstatSync(stream.nfd);position+=stat.size}catch(e){throw new FS.ErrnoError(NODEFS.convertNodeCode(e))}}}if(position<0){throw new FS.ErrnoError(28)}return position},mmap(stream,length,position,prot,flags){if(!FS.isFile(stream.node.mode)){throw new FS.ErrnoError(43)}var ptr=mmapAlloc(length);NODEFS.stream_ops.read(stream,HEAP8,ptr,length,position);return{ptr:ptr,allocated:true}},msync(stream,buffer,offset,length,mmapFlags){NODEFS.stream_ops.write(stream,buffer,0,length,offset,false);return 0}}};var WORKERFS={DIR_MODE:16895,FILE_MODE:33279,reader:null,mount(mount){assert(ENVIRONMENT_IS_WORKER);if(!WORKERFS.reader)WORKERFS.reader=new FileReaderSync;var root=WORKERFS.createNode(null,"/",WORKERFS.DIR_MODE,0);var createdParents={};function ensureParent(path){var parts=path.split("/");var parent=root;for(var i=0;i<parts.length-1;i++){var curr=parts.slice(0,i+1).join("/");if(!createdParents[curr]){createdParents[curr]=WORKERFS.createNode(parent,parts[i],WORKERFS.DIR_MODE,0)}parent=createdParents[curr]}return parent}function base(path){var parts=path.split("/");return parts[parts.length-1]}Array.prototype.forEach.call(mount.opts["files"]||[],function(file){WORKERFS.createNode(ensureParent(file.name),base(file.name),WORKERFS.FILE_MODE,0,file,file.lastModifiedDate)});(mount.opts["blobs"]||[]).forEach(function(obj){WORKERFS.createNode(ensureParent(obj["name"]),base(obj["name"]),WORKERFS.FILE_MODE,0,obj["data"])});(mount.opts["packages"]||[]).forEach(function(pack){pack["metadata"].files.forEach(function(file){var name=file.filename.substr(1);WORKERFS.createNode(ensureParent(name),base(name),WORKERFS.FILE_MODE,0,pack["blob"].slice(file.start,file.end))})});return root},createNode(parent,name,mode,dev,contents,mtime){var node=FS.createNode(parent,name,mode);node.mode=mode;node.node_ops=WORKERFS.node_ops;node.stream_ops=WORKERFS.stream_ops;node.timestamp=(mtime||new Date).getTime();assert(WORKERFS.FILE_MODE!==WORKERFS.DIR_MODE);if(mode===WORKERFS.FILE_MODE){node.size=contents.size;node.contents=contents}else{node.size=4096;node.contents={}}if(parent){parent.contents[name]=node}return node},node_ops:{getattr(node){return{dev:1,ino:node.id,mode:node.mode,nlink:1,uid:0,gid:0,rdev:0,size:node.size,atime:new Date(node.timestamp),mtime:new Date(node.timestamp),ctime:new Date(node.timestamp),blksize:4096,blocks:Math.ceil(node.size/4096)}},setattr(node,attr){if(attr.mode!==undefined){node.mode=attr.mode}if(attr.timestamp!==undefined){node.timestamp=attr.timestamp}},lookup(parent,name){throw new FS.ErrnoError(44)},mknod(parent,name,mode,dev){throw new FS.ErrnoError(63)},rename(oldNode,newDir,newName){throw new FS.ErrnoError(63)},unlink(parent,name){throw new FS.ErrnoError(63)},rmdir(parent,name){throw new FS.ErrnoError(63)},readdir(node){var entries=[".",".."];for(var key in node.contents){if(!node.contents.hasOwnProperty(key)){continue}entries.push(key)}return entries},symlink(parent,newName,oldPath){throw new FS.ErrnoError(63)}},stream_ops:{read(stream,buffer,offset,length,position){if(position>=stream.node.size)return 0;var chunk=stream.node.contents.slice(position,position+length);var ab=WORKERFS.reader.readAsArrayBuffer(chunk);buffer.set(new Uint8Array(ab),offset);return chunk.size},write(stream,buffer,offset,length,position){throw new FS.ErrnoError(29)},llseek(stream,offset,whence){var position=offset;if(whence===1){position+=stream.position}else if(whence===2){if(FS.isFile(stream.node.mode)){position+=stream.node.size}}if(position<0){throw new FS.ErrnoError(28)}return position}}};var FS={root:null,mounts:[],devices:{},streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:null,genericErrors:{},filesystems:null,syncFSRequests:0,lookupPath(path,opts={}){path=PATH_FS.resolve(path);if(!path)return{path:"",node:null};var defaults={follow_mount:true,recurse_count:0};opts=Object.assign(defaults,opts);if(opts.recurse_count>8){throw new FS.ErrnoError(32)}var parts=path.split("/").filter(p=>!!p);var current=FS.root;var current_path="/";for(var i=0;i<parts.length;i++){var islast=i===parts.length-1;if(islast&&opts.parent){break}current=FS.lookupNode(current,parts[i]);current_path=PATH.join2(current_path,parts[i]);if(FS.isMountpoint(current)){if(!islast||islast&&opts.follow_mount){current=current.mounted.root}}if(!islast||opts.follow){var count=0;while(FS.isLink(current.mode)){var link=FS.readlink(current_path);current_path=PATH_FS.resolve(PATH.dirname(current_path),link);var lookup=FS.lookupPath(current_path,{recurse_count:opts.recurse_count+1});current=lookup.node;if(count++>40){throw new FS.ErrnoError(32)}}}}return{path:current_path,node:current}},getPath(node){var path;while(true){if(FS.isRoot(node)){var mount=node.mount.mountpoint;if(!path)return mount;return mount[mount.length-1]!=="/"?`${mount}/${path}`:mount+path}path=path?`${node.name}/${path}`:node.name;node=node.parent}},hashName(parentid,name){var hash=0;for(var i=0;i<name.length;i++){hash=(hash<<5)-hash+name.charCodeAt(i)|0}return(parentid+hash>>>0)%FS.nameTable.length},hashAddNode(node){var hash=FS.hashName(node.parent.id,node.name);node.name_next=FS.nameTable[hash];FS.nameTable[hash]=node},hashRemoveNode(node){var hash=FS.hashName(node.parent.id,node.name);if(FS.nameTable[hash]===node){FS.nameTable[hash]=node.name_next}else{var current=FS.nameTable[hash];while(current){if(current.name_next===node){current.name_next=node.name_next;break}current=current.name_next}}},lookupNode(parent,name){var errCode=FS.mayLookup(parent);if(errCode){throw new FS.ErrnoError(errCode,parent)}var hash=FS.hashName(parent.id,name);for(var node=FS.nameTable[hash];node;node=node.name_next){var nodeName=node.name;if(node.parent.id===parent.id&&nodeName===name){return node}}return FS.lookup(parent,name)},createNode(parent,name,mode,rdev){var node=new FS.FSNode(parent,name,mode,rdev);FS.hashAddNode(node);return node},destroyNode(node){FS.hashRemoveNode(node)},isRoot(node){return node===node.parent},isMountpoint(node){return!!node.mounted},isFile(mode){return(mode&61440)===32768},isDir(mode){return(mode&61440)===16384},isLink(mode){return(mode&61440)===40960},isChrdev(mode){return(mode&61440)===8192},isBlkdev(mode){return(mode&61440)===24576},isFIFO(mode){return(mode&61440)===4096},isSocket(mode){return(mode&49152)===49152},flagsToPermissionString(flag){var perms=["r","w","rw"][flag&3];if(flag&512){perms+="w"}return perms},nodePermissions(node,perms){if(FS.ignorePermissions){return 0}if(perms.includes("r")&&!(node.mode&292)){return 2}else if(perms.includes("w")&&!(node.mode&146)){return 2}else if(perms.includes("x")&&!(node.mode&73)){return 2}return 0},mayLookup(dir){var errCode=FS.nodePermissions(dir,"x");if(errCode)return errCode;if(!dir.node_ops.lookup)return 2;return 0},mayCreate(dir,name){try{var node=FS.lookupNode(dir,name);return 20}catch(e){}return FS.nodePermissions(dir,"wx")},mayDelete(dir,name,isdir){var node;try{node=FS.lookupNode(dir,name)}catch(e){return e.errno}var errCode=FS.nodePermissions(dir,"wx");if(errCode){return errCode}if(isdir){if(!FS.isDir(node.mode)){return 54}if(FS.isRoot(node)||FS.getPath(node)===FS.cwd()){return 10}}else{if(FS.isDir(node.mode)){return 31}}return 0},mayOpen(node,flags){if(!node){return 44}if(FS.isLink(node.mode)){return 32}else if(FS.isDir(node.mode)){if(FS.flagsToPermissionString(flags)!=="r"||flags&512){return 31}}return FS.nodePermissions(node,FS.flagsToPermissionString(flags))},MAX_OPEN_FDS:4096,nextfd(){for(var fd=0;fd<=FS.MAX_OPEN_FDS;fd++){if(!FS.streams[fd]){return fd}}throw new FS.ErrnoError(33)},getStreamChecked(fd){var stream=FS.getStream(fd);if(!stream){throw new FS.ErrnoError(8)}return stream},getStream:fd=>FS.streams[fd],createStream(stream,fd=-1){if(!FS.FSStream){FS.FSStream=function(){this.shared={}};FS.FSStream.prototype={};Object.defineProperties(FS.FSStream.prototype,{object:{get(){return this.node},set(val){this.node=val}},isRead:{get(){return(this.flags&2097155)!==1}},isWrite:{get(){return(this.flags&2097155)!==0}},isAppend:{get(){return this.flags&1024}},flags:{get(){return this.shared.flags},set(val){this.shared.flags=val}},position:{get(){return this.shared.position},set(val){this.shared.position=val}}})}stream=Object.assign(new FS.FSStream,stream);if(fd==-1){fd=FS.nextfd()}stream.fd=fd;FS.streams[fd]=stream;return stream},closeStream(fd){FS.streams[fd]=null},chrdev_stream_ops:{open(stream){var device=FS.getDevice(stream.node.rdev);stream.stream_ops=device.stream_ops;if(stream.stream_ops.open){stream.stream_ops.open(stream)}},llseek(){throw new FS.ErrnoError(70)}},major:dev=>dev>>8,minor:dev=>dev&255,makedev:(ma,mi)=>ma<<8|mi,registerDevice(dev,ops){FS.devices[dev]={stream_ops:ops}},getDevice:dev=>FS.devices[dev],getMounts(mount){var mounts=[];var check=[mount];while(check.length){var m=check.pop();mounts.push(m);check.push.apply(check,m.mounts)}return mounts},syncfs(populate,callback){if(typeof populate=="function"){callback=populate;populate=false}FS.syncFSRequests++;if(FS.syncFSRequests>1){err(`warning: ${FS.syncFSRequests} FS.syncfs operations in flight at once, probably just doing extra work`)}var mounts=FS.getMounts(FS.root.mount);var completed=0;function doCallback(errCode){FS.syncFSRequests--;return callback(errCode)}function done(errCode){if(errCode){if(!done.errored){done.errored=true;return doCallback(errCode)}return}if(++completed>=mounts.length){doCallback(null)}}mounts.forEach(mount=>{if(!mount.type.syncfs){return done(null)}mount.type.syncfs(mount,populate,done)})},mount(type,opts,mountpoint){var root=mountpoint==="/";var pseudo=!mountpoint;var node;if(root&&FS.root){throw new FS.ErrnoError(10)}else if(!root&&!pseudo){var lookup=FS.lookupPath(mountpoint,{follow_mount:false});mountpoint=lookup.path;node=lookup.node;if(FS.isMountpoint(node)){throw new FS.ErrnoError(10)}if(!FS.isDir(node.mode)){throw new FS.ErrnoError(54)}}var mount={type:type,opts:opts,mountpoint:mountpoint,mounts:[]};var mountRoot=type.mount(mount);mountRoot.mount=mount;mount.root=mountRoot;if(root){FS.root=mountRoot}else if(node){node.mounted=mount;if(node.mount){node.mount.mounts.push(mount)}}return mountRoot},unmount(mountpoint){var lookup=FS.lookupPath(mountpoint,{follow_mount:false});if(!FS.isMountpoint(lookup.node)){throw new FS.ErrnoError(28)}var node=lookup.node;var mount=node.mounted;var mounts=FS.getMounts(mount);Object.keys(FS.nameTable).forEach(hash=>{var current=FS.nameTable[hash];while(current){var next=current.name_next;if(mounts.includes(current.mount)){FS.destroyNode(current)}current=next}});node.mounted=null;var idx=node.mount.mounts.indexOf(mount);node.mount.mounts.splice(idx,1)},lookup(parent,name){return parent.node_ops.lookup(parent,name)},mknod(path,mode,dev){var lookup=FS.lookupPath(path,{parent:true});var parent=lookup.node;var name=PATH.basename(path);if(!name||name==="."||name===".."){throw new FS.ErrnoError(28)}var errCode=FS.mayCreate(parent,name);if(errCode){throw new FS.ErrnoError(errCode)}if(!parent.node_ops.mknod){throw new FS.ErrnoError(63)}return parent.node_ops.mknod(parent,name,mode,dev)},create(path,mode){mode=mode!==undefined?mode:438;mode&=4095;mode|=32768;return FS.mknod(path,mode,0)},mkdir(path,mode){mode=mode!==undefined?mode:511;mode&=511|512;mode|=16384;return FS.mknod(path,mode,0)},mkdirTree(path,mode){var dirs=path.split("/");var d="";for(var i=0;i<dirs.length;++i){if(!dirs[i])continue;d+="/"+dirs[i];try{FS.mkdir(d,mode)}catch(e){if(e.errno!=20)throw e}}},mkdev(path,mode,dev){if(typeof dev=="undefined"){dev=mode;mode=438}mode|=8192;return FS.mknod(path,mode,dev)},symlink(oldpath,newpath){if(!PATH_FS.resolve(oldpath)){throw new FS.ErrnoError(44)}var lookup=FS.lookupPath(newpath,{parent:true});var parent=lookup.node;if(!parent){throw new FS.ErrnoError(44)}var newname=PATH.basename(newpath);var errCode=FS.mayCreate(parent,newname);if(errCode){throw new FS.ErrnoError(errCode)}if(!parent.node_ops.symlink){throw new FS.ErrnoError(63)}return parent.node_ops.symlink(parent,newname,oldpath)},rename(old_path,new_path){var old_dirname=PATH.dirname(old_path);var new_dirname=PATH.dirname(new_path);var old_name=PATH.basename(old_path);var new_name=PATH.basename(new_path);var lookup,old_dir,new_dir;lookup=FS.lookupPath(old_path,{parent:true});old_dir=lookup.node;lookup=FS.lookupPath(new_path,{parent:true});new_dir=lookup.node;if(!old_dir||!new_dir)throw new FS.ErrnoError(44);if(old_dir.mount!==new_dir.mount){throw new FS.ErrnoError(75)}var old_node=FS.lookupNode(old_dir,old_name);var relative=PATH_FS.relative(old_path,new_dirname);if(relative.charAt(0)!=="."){throw new FS.ErrnoError(28)}relative=PATH_FS.relative(new_path,old_dirname);if(relative.charAt(0)!=="."){throw new FS.ErrnoError(55)}var new_node;try{new_node=FS.lookupNode(new_dir,new_name)}catch(e){}if(old_node===new_node){return}var isdir=FS.isDir(old_node.mode);var errCode=FS.mayDelete(old_dir,old_name,isdir);if(errCode){throw new FS.ErrnoError(errCode)}errCode=new_node?FS.mayDelete(new_dir,new_name,isdir):FS.mayCreate(new_dir,new_name);if(errCode){throw new FS.ErrnoError(errCode)}if(!old_dir.node_ops.rename){throw new FS.ErrnoError(63)}if(FS.isMountpoint(old_node)||new_node&&FS.isMountpoint(new_node)){throw new FS.ErrnoError(10)}if(new_dir!==old_dir){errCode=FS.nodePermissions(old_dir,"w");if(errCode){throw new FS.ErrnoError(errCode)}}FS.hashRemoveNode(old_node);try{old_dir.node_ops.rename(old_node,new_dir,new_name)}catch(e){throw e}finally{FS.hashAddNode(old_node)}},rmdir(path){var lookup=FS.lookupPath(path,{parent:true});var parent=lookup.node;var name=PATH.basename(path);var node=FS.lookupNode(parent,name);var errCode=FS.mayDelete(parent,name,true);if(errCode){throw new FS.ErrnoError(errCode)}if(!parent.node_ops.rmdir){throw new FS.ErrnoError(63)}if(FS.isMountpoint(node)){throw new FS.ErrnoError(10)}parent.node_ops.rmdir(parent,name);FS.destroyNode(node)},readdir(path){var lookup=FS.lookupPath(path,{follow:true});var node=lookup.node;if(!node.node_ops.readdir){throw new FS.ErrnoError(54)}return node.node_ops.readdir(node)},unlink(path){var lookup=FS.lookupPath(path,{parent:true});var parent=lookup.node;if(!parent){throw new FS.ErrnoError(44)}var name=PATH.basename(path);var node=FS.lookupNode(parent,name);var errCode=FS.mayDelete(parent,name,false);if(errCode){throw new FS.ErrnoError(errCode)}if(!parent.node_ops.unlink){throw new FS.ErrnoError(63)}if(FS.isMountpoint(node)){throw new FS.ErrnoError(10)}parent.node_ops.unlink(parent,name);FS.destroyNode(node)},readlink(path){var lookup=FS.lookupPath(path);var link=lookup.node;if(!link){throw new FS.ErrnoError(44)}if(!link.node_ops.readlink){throw new FS.ErrnoError(28)}return PATH_FS.resolve(FS.getPath(link.parent),link.node_ops.readlink(link))},stat(path,dontFollow){var lookup=FS.lookupPath(path,{follow:!dontFollow});var node=lookup.node;if(!node){throw new FS.ErrnoError(44)}if(!node.node_ops.getattr){throw new FS.ErrnoError(63)}return node.node_ops.getattr(node)},lstat(path){return FS.stat(path,true)},chmod(path,mode,dontFollow){var node;if(typeof path=="string"){var lookup=FS.lookupPath(path,{follow:!dontFollow});node=lookup.node}else{node=path}if(!node.node_ops.setattr){throw new FS.ErrnoError(63)}node.node_ops.setattr(node,{mode:mode&4095|node.mode&~4095,timestamp:Date.now()})},lchmod(path,mode){FS.chmod(path,mode,true)},fchmod(fd,mode){var stream=FS.getStreamChecked(fd);FS.chmod(stream.node,mode)},chown(path,uid,gid,dontFollow){var node;if(typeof path=="string"){var lookup=FS.lookupPath(path,{follow:!dontFollow});node=lookup.node}else{node=path}if(!node.node_ops.setattr){throw new FS.ErrnoError(63)}node.node_ops.setattr(node,{timestamp:Date.now()})},lchown(path,uid,gid){FS.chown(path,uid,gid,true)},fchown(fd,uid,gid){var stream=FS.getStreamChecked(fd);FS.chown(stream.node,uid,gid)},truncate(path,len){if(len<0){throw new FS.ErrnoError(28)}var node;if(typeof path=="string"){var lookup=FS.lookupPath(path,{follow:true});node=lookup.node}else{node=path}if(!node.node_ops.setattr){throw new FS.ErrnoError(63)}if(FS.isDir(node.mode)){throw new FS.ErrnoError(31)}if(!FS.isFile(node.mode)){throw new FS.ErrnoError(28)}var errCode=FS.nodePermissions(node,"w");if(errCode){throw new FS.ErrnoError(errCode)}node.node_ops.setattr(node,{size:len,timestamp:Date.now()})},ftruncate(fd,len){var stream=FS.getStreamChecked(fd);if((stream.flags&2097155)===0){throw new FS.ErrnoError(28)}FS.truncate(stream.node,len)},utime(path,atime,mtime){var lookup=FS.lookupPath(path,{follow:true});var node=lookup.node;node.node_ops.setattr(node,{timestamp:Math.max(atime,mtime)})},open(path,flags,mode){if(path===""){throw new FS.ErrnoError(44)}flags=typeof flags=="string"?FS_modeStringToFlags(flags):flags;mode=typeof mode=="undefined"?438:mode;if(flags&64){mode=mode&4095|32768}else{mode=0}var node;if(typeof path=="object"){node=path}else{path=PATH.normalize(path);try{var lookup=FS.lookupPath(path,{follow:!(flags&131072)});node=lookup.node}catch(e){}}var created=false;if(flags&64){if(node){if(flags&128){throw new FS.ErrnoError(20)}}else{node=FS.mknod(path,mode,0);created=true}}if(!node){throw new FS.ErrnoError(44)}if(FS.isChrdev(node.mode)){flags&=~512}if(flags&65536&&!FS.isDir(node.mode)){throw new FS.ErrnoError(54)}if(!created){var errCode=FS.mayOpen(node,flags);if(errCode){throw new FS.ErrnoError(errCode)}}if(flags&512&&!created){FS.truncate(node,0)}flags&=~(128|512|131072);var stream=FS.createStream({node:node,path:FS.getPath(node),flags:flags,seekable:true,position:0,stream_ops:node.stream_ops,ungotten:[],error:false});if(stream.stream_ops.open){stream.stream_ops.open(stream)}if(Module["logReadFiles"]&&!(flags&1)){if(!FS.readFiles)FS.readFiles={};if(!(path in FS.readFiles)){FS.readFiles[path]=1}}return stream},close(stream){if(FS.isClosed(stream)){throw new FS.ErrnoError(8)}if(stream.getdents)stream.getdents=null;try{if(stream.stream_ops.close){stream.stream_ops.close(stream)}}catch(e){throw e}finally{FS.closeStream(stream.fd)}stream.fd=null},isClosed(stream){return stream.fd===null},llseek(stream,offset,whence){if(FS.isClosed(stream)){throw new FS.ErrnoError(8)}if(!stream.seekable||!stream.stream_ops.llseek){throw new FS.ErrnoError(70)}if(whence!=0&&whence!=1&&whence!=2){throw new FS.ErrnoError(28)}stream.position=stream.stream_ops.llseek(stream,offset,whence);stream.ungotten=[];return stream.position},read(stream,buffer,offset,length,position){if(length<0||position<0){throw new FS.ErrnoError(28)}if(FS.isClosed(stream)){throw new FS.ErrnoError(8)}if((stream.flags&2097155)===1){throw new FS.ErrnoError(8)}if(FS.isDir(stream.node.mode)){throw new FS.ErrnoError(31)}if(!stream.stream_ops.read){throw new FS.ErrnoError(28)}var seeking=typeof position!="undefined";if(!seeking){position=stream.position}else if(!stream.seekable){throw new FS.ErrnoError(70)}var bytesRead=stream.stream_ops.read(stream,buffer,offset,length,position);if(!seeking)stream.position+=bytesRead;return bytesRead},write(stream,buffer,offset,length,position,canOwn){if(length<0||position<0){throw new FS.ErrnoError(28)}if(FS.isClosed(stream)){throw new FS.ErrnoError(8)}if((stream.flags&2097155)===0){throw new FS.ErrnoError(8)}if(FS.isDir(stream.node.mode)){throw new FS.ErrnoError(31)}if(!stream.stream_ops.write){throw new FS.ErrnoError(28)}if(stream.seekable&&stream.flags&1024){FS.llseek(stream,0,2)}var seeking=typeof position!="undefined";if(!seeking){position=stream.position}else if(!stream.seekable){throw new FS.ErrnoError(70)}var bytesWritten=stream.stream_ops.write(stream,buffer,offset,length,position,canOwn);if(!seeking)stream.position+=bytesWritten;return bytesWritten},allocate(stream,offset,length){if(FS.isClosed(stream)){throw new FS.ErrnoError(8)}if(offset<0||length<=0){throw new FS.ErrnoError(28)}if((stream.flags&2097155)===0){throw new FS.ErrnoError(8)}if(!FS.isFile(stream.node.mode)&&!FS.isDir(stream.node.mode)){throw new FS.ErrnoError(43)}if(!stream.stream_ops.allocate){throw new FS.ErrnoError(138)}stream.stream_ops.allocate(stream,offset,length)},mmap(stream,length,position,prot,flags){if((prot&2)!==0&&(flags&2)===0&&(stream.flags&2097155)!==2){throw new FS.ErrnoError(2)}if((stream.flags&2097155)===1){throw new FS.ErrnoError(2)}if(!stream.stream_ops.mmap){throw new FS.ErrnoError(43)}return stream.stream_ops.mmap(stream,length,position,prot,flags)},msync(stream,buffer,offset,length,mmapFlags){if(!stream.stream_ops.msync){return 0}return stream.stream_ops.msync(stream,buffer,offset,length,mmapFlags)},munmap:stream=>0,ioctl(stream,cmd,arg){if(!stream.stream_ops.ioctl){throw new FS.ErrnoError(59)}return stream.stream_ops.ioctl(stream,cmd,arg)},readFile(path,opts={}){opts.flags=opts.flags||0;opts.encoding=opts.encoding||"binary";if(opts.encoding!=="utf8"&&opts.encoding!=="binary"){throw new Error(`Invalid encoding type "${opts.encoding}"`)}var ret;var stream=FS.open(path,opts.flags);var stat=FS.stat(path);var length=stat.size;var buf=new Uint8Array(length);FS.read(stream,buf,0,length,0);if(opts.encoding==="utf8"){ret=UTF8ArrayToString(buf,0)}else if(opts.encoding==="binary"){ret=buf}FS.close(stream);return ret},writeFile(path,data,opts={}){opts.flags=opts.flags||577;var stream=FS.open(path,opts.flags,opts.mode);if(typeof data=="string"){var buf=new Uint8Array(lengthBytesUTF8(data)+1);var actualNumBytes=stringToUTF8Array(data,buf,0,buf.length);FS.write(stream,buf,0,actualNumBytes,undefined,opts.canOwn)}else if(ArrayBuffer.isView(data)){FS.write(stream,data,0,data.byteLength,undefined,opts.canOwn)}else{throw new Error("Unsupported data type")}FS.close(stream)},cwd:()=>FS.currentPath,chdir(path){var lookup=FS.lookupPath(path,{follow:true});if(lookup.node===null){throw new FS.ErrnoError(44)}if(!FS.isDir(lookup.node.mode)){throw new FS.ErrnoError(54)}var errCode=FS.nodePermissions(lookup.node,"x");if(errCode){throw new FS.ErrnoError(errCode)}FS.currentPath=lookup.path},createDefaultDirectories(){FS.mkdir("/tmp");FS.mkdir("/home");FS.mkdir("/home/web_user")},createDefaultDevices(){FS.mkdir("/dev");FS.registerDevice(FS.makedev(1,3),{read:()=>0,write:(stream,buffer,offset,length,pos)=>length});FS.mkdev("/dev/null",FS.makedev(1,3));TTY.register(FS.makedev(5,0),TTY.default_tty_ops);TTY.register(FS.makedev(6,0),TTY.default_tty1_ops);FS.mkdev("/dev/tty",FS.makedev(5,0));FS.mkdev("/dev/tty1",FS.makedev(6,0));var randomBuffer=new Uint8Array(1024),randomLeft=0;var randomByte=()=>{if(randomLeft===0){randomLeft=randomFill(randomBuffer).byteLength}return randomBuffer[--randomLeft]};FS.createDevice("/dev","random",randomByte);FS.createDevice("/dev","urandom",randomByte);FS.mkdir("/dev/shm");FS.mkdir("/dev/shm/tmp")},createSpecialDirectories(){FS.mkdir("/proc");var proc_self=FS.mkdir("/proc/self");FS.mkdir("/proc/self/fd");FS.mount({mount(){var node=FS.createNode(proc_self,"fd",16384|511,73);node.node_ops={lookup(parent,name){var fd=+name;var stream=FS.getStreamChecked(fd);var ret={parent:null,mount:{mountpoint:"fake"},node_ops:{readlink:()=>stream.path}};ret.parent=ret;return ret}};return node}},{},"/proc/self/fd")},createStandardStreams(){if(Module["stdin"]){FS.createDevice("/dev","stdin",Module["stdin"])}else{FS.symlink("/dev/tty","/dev/stdin")}if(Module["stdout"]){FS.createDevice("/dev","stdout",null,Module["stdout"])}else{FS.symlink("/dev/tty","/dev/stdout")}if(Module["stderr"]){FS.createDevice("/dev","stderr",null,Module["stderr"])}else{FS.symlink("/dev/tty1","/dev/stderr")}var stdin=FS.open("/dev/stdin",0);var stdout=FS.open("/dev/stdout",1);var stderr=FS.open("/dev/stderr",1)},ensureErrnoError(){if(FS.ErrnoError)return;FS.ErrnoError=function ErrnoError(errno,node){this.name="ErrnoError";this.node=node;this.setErrno=function(errno){this.errno=errno};this.setErrno(errno);this.message="FS error"};FS.ErrnoError.prototype=new Error;FS.ErrnoError.prototype.constructor=FS.ErrnoError;[44].forEach(code=>{FS.genericErrors[code]=new FS.ErrnoError(code);FS.genericErrors[code].stack="<generic error, no stack>"})},staticInit(){FS.ensureErrnoError();FS.nameTable=new Array(4096);FS.mount(MEMFS,{},"/");FS.createDefaultDirectories();FS.createDefaultDevices();FS.createSpecialDirectories();FS.filesystems={"MEMFS":MEMFS,"IDBFS":IDBFS,"NODEFS":NODEFS,"WORKERFS":WORKERFS}},init(input,output,error){FS.init.initialized=true;FS.ensureErrnoError();Module["stdin"]=input||Module["stdin"];Module["stdout"]=output||Module["stdout"];Module["stderr"]=error||Module["stderr"];FS.createStandardStreams()},quit(){FS.init.initialized=false;_fflush(0);for(var i=0;i<FS.streams.length;i++){var stream=FS.streams[i];if(!stream){continue}FS.close(stream)}},findObject(path,dontResolveLastLink){var ret=FS.analyzePath(path,dontResolveLastLink);if(!ret.exists){return null}return ret.object},analyzePath(path,dontResolveLastLink){try{var lookup=FS.lookupPath(path,{follow:!dontResolveLastLink});path=lookup.path}catch(e){}var ret={isRoot:false,exists:false,error:0,name:null,path:null,object:null,parentExists:false,parentPath:null,parentObject:null};try{var lookup=FS.lookupPath(path,{parent:true});ret.parentExists=true;ret.parentPath=lookup.path;ret.parentObject=lookup.node;ret.name=PATH.basename(path);lookup=FS.lookupPath(path,{follow:!dontResolveLastLink});ret.exists=true;ret.path=lookup.path;ret.object=lookup.node;ret.name=lookup.node.name;ret.isRoot=lookup.path==="/"}catch(e){ret.error=e.errno}return ret},createPath(parent,path,canRead,canWrite){parent=typeof parent=="string"?parent:FS.getPath(parent);var parts=path.split("/").reverse();while(parts.length){var part=parts.pop();if(!part)continue;var current=PATH.join2(parent,part);try{FS.mkdir(current)}catch(e){}parent=current}return current},createFile(parent,name,properties,canRead,canWrite){var path=PATH.join2(typeof parent=="string"?parent:FS.getPath(parent),name);var mode=FS_getMode(canRead,canWrite);return FS.create(path,mode)},createDataFile(parent,name,data,canRead,canWrite,canOwn){var path=name;if(parent){parent=typeof parent=="string"?parent:FS.getPath(parent);path=name?PATH.join2(parent,name):parent}var mode=FS_getMode(canRead,canWrite);var node=FS.create(path,mode);if(data){if(typeof data=="string"){var arr=new Array(data.length);for(var i=0,len=data.length;i<len;++i)arr[i]=data.charCodeAt(i);data=arr}FS.chmod(node,mode|146);var stream=FS.open(node,577);FS.write(stream,data,0,data.length,0,canOwn);FS.close(stream);FS.chmod(node,mode)}return node},createDevice(parent,name,input,output){var path=PATH.join2(typeof parent=="string"?parent:FS.getPath(parent),name);var mode=FS_getMode(!!input,!!output);if(!FS.createDevice.major)FS.createDevice.major=64;var dev=FS.makedev(FS.createDevice.major++,0);FS.registerDevice(dev,{open(stream){stream.seekable=false},close(stream){if(output&&output.buffer&&output.buffer.length){output(10)}},read(stream,buffer,offset,length,pos){var bytesRead=0;for(var i=0;i<length;i++){var result;try{result=input()}catch(e){throw new FS.ErrnoError(29)}if(result===undefined&&bytesRead===0){throw new FS.ErrnoError(6)}if(result===null||result===undefined)break;bytesRead++;buffer[offset+i]=result}if(bytesRead){stream.node.timestamp=Date.now()}return bytesRead},write(stream,buffer,offset,length,pos){for(var i=0;i<length;i++){try{output(buffer[offset+i])}catch(e){throw new FS.ErrnoError(29)}}if(length){stream.node.timestamp=Date.now()}return i}});return FS.mkdev(path,mode,dev)},forceLoadFile(obj){if(obj.isDevice||obj.isFolder||obj.link||obj.contents)return true;if(typeof XMLHttpRequest!="undefined"){throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.")}else if(read_){try{obj.contents=intArrayFromString(read_(obj.url),true);obj.usedBytes=obj.contents.length}catch(e){throw new FS.ErrnoError(29)}}else{throw new Error("Cannot load without read() or XMLHttpRequest.")}},createLazyFile(parent,name,url,canRead,canWrite){function LazyUint8Array(){this.lengthKnown=false;this.chunks=[]}LazyUint8Array.prototype.get=function LazyUint8Array_get(idx){if(idx>this.length-1||idx<0){return undefined}var chunkOffset=idx%this.chunkSize;var chunkNum=idx/this.chunkSize|0;return this.getter(chunkNum)[chunkOffset]};LazyUint8Array.prototype.setDataGetter=function LazyUint8Array_setDataGetter(getter){this.getter=getter};LazyUint8Array.prototype.cacheLength=function LazyUint8Array_cacheLength(){var xhr=new XMLHttpRequest;xhr.open("HEAD",url,false);xhr.send(null);if(!(xhr.status>=200&&xhr.status<300||xhr.status===304))throw new Error("Couldn't load "+url+". Status: "+xhr.status);var datalength=Number(xhr.getResponseHeader("Content-length"));var header;var hasByteServing=(header=xhr.getResponseHeader("Accept-Ranges"))&&header==="bytes";var usesGzip=(header=xhr.getResponseHeader("Content-Encoding"))&&header==="gzip";var chunkSize=1024*1024;if(!hasByteServing)chunkSize=datalength;var doXHR=(from,to)=>{if(from>to)throw new Error("invalid range ("+from+", "+to+") or no bytes requested!");if(to>datalength-1)throw new Error("only "+datalength+" bytes available! programmer error!");var xhr=new XMLHttpRequest;xhr.open("GET",url,false);if(datalength!==chunkSize)xhr.setRequestHeader("Range","bytes="+from+"-"+to);xhr.responseType="arraybuffer";if(xhr.overrideMimeType){xhr.overrideMimeType("text/plain; charset=x-user-defined")}xhr.send(null);if(!(xhr.status>=200&&xhr.status<300||xhr.status===304))throw new Error("Couldn't load "+url+". Status: "+xhr.status);if(xhr.response!==undefined){return new Uint8Array(xhr.response||[])}return intArrayFromString(xhr.responseText||"",true)};var lazyArray=this;lazyArray.setDataGetter(chunkNum=>{var start=chunkNum*chunkSize;var end=(chunkNum+1)*chunkSize-1;end=Math.min(end,datalength-1);if(typeof lazyArray.chunks[chunkNum]=="undefined"){lazyArray.chunks[chunkNum]=doXHR(start,end)}if(typeof lazyArray.chunks[chunkNum]=="undefined")throw new Error("doXHR failed!");return lazyArray.chunks[chunkNum]});if(usesGzip||!datalength){chunkSize=datalength=1;datalength=this.getter(0).length;chunkSize=datalength;console.warn("LazyFiles on gzip forces download of the whole file when length is accessed")}this._length=datalength;this._chunkSize=chunkSize;this.lengthKnown=true};if(typeof XMLHttpRequest!="undefined"){if(!ENVIRONMENT_IS_WORKER)throw"Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc";var lazyArray=new LazyUint8Array;Object.defineProperties(lazyArray,{length:{get:function(){if(!this.lengthKnown){this.cacheLength()}return this._length}},chunkSize:{get:function(){if(!this.lengthKnown){this.cacheLength()}return this._chunkSize}}});var properties={isDevice:false,contents:lazyArray}}else{var properties={isDevice:false,url:url}}var node=FS.createFile(parent,name,properties,canRead,canWrite);if(properties.contents){node.contents=properties.contents}else if(properties.url){node.contents=null;node.url=properties.url}Object.defineProperties(node,{usedBytes:{get:function(){return this.contents.length}}});var stream_ops={};var keys=Object.keys(node.stream_ops);keys.forEach(key=>{var fn=node.stream_ops[key];stream_ops[key]=function forceLoadLazyFile(){FS.forceLoadFile(node);return fn.apply(null,arguments)}});function writeChunks(stream,buffer,offset,length,position){var contents=stream.node.contents;if(position>=contents.length)return 0;var size=Math.min(contents.length-position,length);if(contents.slice){for(var i=0;i<size;i++){buffer[offset+i]=contents[position+i]}}else{for(var i=0;i<size;i++){buffer[offset+i]=contents.get(position+i)}}return size}stream_ops.read=(stream,buffer,offset,length,position)=>{FS.forceLoadFile(node);return writeChunks(stream,buffer,offset,length,position)};stream_ops.mmap=(stream,length,position,prot,flags)=>{FS.forceLoadFile(node);var ptr=mmapAlloc(length);if(!ptr){throw new FS.ErrnoError(48)}writeChunks(stream,HEAP8,ptr,length,position);return{ptr:ptr,allocated:true}};node.stream_ops=stream_ops;return node}};var UTF8ToString=(ptr,maxBytesToRead)=>ptr?UTF8ArrayToString(HEAPU8,ptr,maxBytesToRead):"";var SYSCALLS={DEFAULT_POLLMASK:5,calculateAt(dirfd,path,allowEmpty){if(PATH.isAbs(path)){return path}var dir;if(dirfd===-100){dir=FS.cwd()}else{var dirstream=SYSCALLS.getStreamFromFD(dirfd);dir=dirstream.path}if(path.length==0){if(!allowEmpty){throw new FS.ErrnoError(44)}return dir}return PATH.join2(dir,path)},doStat(func,path,buf){try{var stat=func(path)}catch(e){if(e&&e.node&&PATH.normalize(path)!==PATH.normalize(FS.getPath(e.node))){return-54}throw e}HEAP32[buf>>2]=stat.dev;HEAP32[buf+4>>2]=stat.mode;HEAPU32[buf+8>>2]=stat.nlink;HEAP32[buf+12>>2]=stat.uid;HEAP32[buf+16>>2]=stat.gid;HEAP32[buf+20>>2]=stat.rdev;HEAP64[buf+24>>3]=BigInt(stat.size);HEAP32[buf+32>>2]=4096;HEAP32[buf+36>>2]=stat.blocks;var atime=stat.atime.getTime();var mtime=stat.mtime.getTime();var ctime=stat.ctime.getTime();HEAP64[buf+40>>3]=BigInt(Math.floor(atime/1e3));HEAPU32[buf+48>>2]=atime%1e3*1e3;HEAP64[buf+56>>3]=BigInt(Math.floor(mtime/1e3));HEAPU32[buf+64>>2]=mtime%1e3*1e3;HEAP64[buf+72>>3]=BigInt(Math.floor(ctime/1e3));HEAPU32[buf+80>>2]=ctime%1e3*1e3;HEAP64[buf+88>>3]=BigInt(stat.ino);return 0},doMsync(addr,stream,len,flags,offset){if(!FS.isFile(stream.node.mode)){throw new FS.ErrnoError(43)}if(flags&2){return 0}var buffer=HEAPU8.slice(addr,addr+len);FS.msync(stream,buffer,offset,len,flags)},varargs:undefined,get(){var ret=HEAP32[+SYSCALLS.varargs>>2];SYSCALLS.varargs+=4;return ret},getp(){return SYSCALLS.get()},getStr(ptr){var ret=UTF8ToString(ptr);return ret},getStreamFromFD(fd){var stream=FS.getStreamChecked(fd);return stream}};var _proc_exit=code=>{EXITSTATUS=code;if(!keepRuntimeAlive()){if(Module["onExit"])Module["onExit"](code);ABORT=true}quit_(code,new ExitStatus(code))};_proc_exit.sig="vi";var exitJS=(status,implicit)=>{EXITSTATUS=status;if(!keepRuntimeAlive()){exitRuntime()}_proc_exit(status)};var _exit=exitJS;_exit.sig="vi";var handleException=e=>{if(e instanceof ExitStatus||e=="unwind"){return EXITSTATUS}quit_(1,e)};var maybeExit=()=>{if(runtimeExited){return}if(!keepRuntimeAlive()){try{_exit(EXITSTATUS)}catch(e){handleException(e)}}};var runtimeKeepalivePop=()=>{runtimeKeepaliveCounter-=1};runtimeKeepalivePop.sig="v";var setMainLoop=(browserIterationFunc,fps,simulateInfiniteLoop,arg,noSetTiming)=>{assert(!Browser.mainLoop.func,"emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.");Browser.mainLoop.func=browserIterationFunc;Browser.mainLoop.arg=arg;var thisMainLoopId=Browser.mainLoop.currentlyRunningMainloop;function checkIsRunning(){if(thisMainLoopId<Browser.mainLoop.currentlyRunningMainloop){runtimeKeepalivePop();maybeExit();return false}return true}Browser.mainLoop.running=false;Browser.mainLoop.runner=function Browser_mainLoop_runner(){if(ABORT)return;if(Browser.mainLoop.queue.length>0){var start=Date.now();var blocker=Browser.mainLoop.queue.shift();blocker.func(blocker.arg);if(Browser.mainLoop.remainingBlockers){var remaining=Browser.mainLoop.remainingBlockers;var next=remaining%1==0?remaining-1:Math.floor(remaining);if(blocker.counted){Browser.mainLoop.remainingBlockers=next}else{next=next+.5;Browser.mainLoop.remainingBlockers=(8*remaining+next)/9}}Browser.mainLoop.updateStatus();if(!checkIsRunning())return;setTimeout(Browser.mainLoop.runner,0);return}if(!checkIsRunning())return;Browser.mainLoop.currentFrameNumber=Browser.mainLoop.currentFrameNumber+1|0;if(Browser.mainLoop.timingMode==1&&Browser.mainLoop.timingValue>1&&Browser.mainLoop.currentFrameNumber%Browser.mainLoop.timingValue!=0){Browser.mainLoop.scheduler();return}else if(Browser.mainLoop.timingMode==0){Browser.mainLoop.tickStartTime=_emscripten_get_now()}Browser.mainLoop.runIter(browserIterationFunc);if(!checkIsRunning())return;if(typeof SDL=="object"&&SDL.audio&&SDL.audio.queueNewAudioData)SDL.audio.queueNewAudioData();Browser.mainLoop.scheduler()};if(!noSetTiming){if(fps&&fps>0){_emscripten_set_main_loop_timing(0,1e3/fps)}else{_emscripten_set_main_loop_timing(1,1)}Browser.mainLoop.scheduler()}if(simulateInfiniteLoop){throw"unwind"}};var callUserCallback=func=>{if(runtimeExited||ABORT){return}try{func();maybeExit()}catch(e){handleException(e)}};var safeSetTimeout=(func,timeout)=>{runtimeKeepalivePush();return setTimeout(()=>{runtimeKeepalivePop();callUserCallback(func)},timeout)};var warnOnce=text=>{if(!warnOnce.shown)warnOnce.shown={};if(!warnOnce.shown[text]){warnOnce.shown[text]=1;if(ENVIRONMENT_IS_NODE)text="warning: "+text;err(text)}};var registerWasmPlugin=()=>{var wasmPlugin={"promiseChainEnd":Promise.resolve(),"canHandle":name=>!Module.noWasmDecoding&&name.endsWith(".so"),"handle":(byteArray,name,onload,onerror)=>{wasmPlugin["promiseChainEnd"]=wasmPlugin["promiseChainEnd"].then(()=>loadWebAssemblyModule(byteArray,{loadAsync:true,nodelete:true},name)).then(exports=>{preloadedWasm[name]=exports;onload(byteArray)},error=>{err(`failed to instantiate wasm: ${name}: ${error}`);onerror()})}};preloadPlugins.push(wasmPlugin)};var preloadedWasm={};var Browser={mainLoop:{running:false,scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause(){Browser.mainLoop.scheduler=null;Browser.mainLoop.currentlyRunningMainloop++},resume(){Browser.mainLoop.currentlyRunningMainloop++;var timingMode=Browser.mainLoop.timingMode;var timingValue=Browser.mainLoop.timingValue;var func=Browser.mainLoop.func;Browser.mainLoop.func=null;setMainLoop(func,0,false,Browser.mainLoop.arg,true);_emscripten_set_main_loop_timing(timingMode,timingValue);Browser.mainLoop.scheduler()},updateStatus(){if(Module["setStatus"]){var message=Module["statusMessage"]||"Please wait...";var remaining=Browser.mainLoop.remainingBlockers;var expected=Browser.mainLoop.expectedBlockers;if(remaining){if(remaining<expected){Module["setStatus"](message+" ("+(expected-remaining)+"/"+expected+")")}else{Module["setStatus"](message)}}else{Module["setStatus"]("")}}},runIter(func){if(ABORT)return;if(Module["preMainLoop"]){var preRet=Module["preMainLoop"]();if(preRet===false){return}}callUserCallback(func);if(Module["postMainLoop"])Module["postMainLoop"]()}},isFullscreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init(){if(Browser.initted)return;Browser.initted=true;var imagePlugin={};imagePlugin["canHandle"]=function imagePlugin_canHandle(name){return!Module.noImageDecoding&&/\.(jpg|jpeg|png|bmp)$/i.test(name)};imagePlugin["handle"]=function imagePlugin_handle(byteArray,name,onload,onerror){var b=new Blob([byteArray],{type:Browser.getMimetype(name)});if(b.size!==byteArray.length){b=new Blob([new Uint8Array(byteArray).buffer],{type:Browser.getMimetype(name)})}var url=URL.createObjectURL(b);var img=new Image;img.onload=()=>{assert(img.complete,`Image ${name} could not be decoded`);var canvas=document.createElement("canvas");canvas.width=img.width;canvas.height=img.height;var ctx=canvas.getContext("2d");ctx.drawImage(img,0,0);preloadedImages[name]=canvas;URL.revokeObjectURL(url);if(onload)onload(byteArray)};img.onerror=event=>{err(`Image ${url} could not be decoded`);if(onerror)onerror()};img.src=url};preloadPlugins.push(imagePlugin);var audioPlugin={};audioPlugin["canHandle"]=function audioPlugin_canHandle(name){return!Module.noAudioDecoding&&name.substr(-4)in{".ogg":1,".wav":1,".mp3":1}};audioPlugin["handle"]=function audioPlugin_handle(byteArray,name,onload,onerror){var done=false;function finish(audio){if(done)return;done=true;preloadedAudios[name]=audio;if(onload)onload(byteArray)}function fail(){if(done)return;done=true;preloadedAudios[name]=new Audio;if(onerror)onerror()}var b=new Blob([byteArray],{type:Browser.getMimetype(name)});var url=URL.createObjectURL(b);var audio=new Audio;audio.addEventListener("canplaythrough",()=>finish(audio),false);audio.onerror=function audio_onerror(event){if(done)return;err(`warning: browser could not fully decode audio ${name}, trying slower base64 approach`);function encode64(data){var BASE="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";var PAD="=";var ret="";var leftchar=0;var leftbits=0;for(var i=0;i<data.length;i++){leftchar=leftchar<<8|data[i];leftbits+=8;while(leftbits>=6){var curr=leftchar>>leftbits-6&63;leftbits-=6;ret+=BASE[curr]}}if(leftbits==2){ret+=BASE[(leftchar&3)<<4];ret+=PAD+PAD}else if(leftbits==4){ret+=BASE[(leftchar&15)<<2];ret+=PAD}return ret}audio.src="data:audio/x-"+name.substr(-3)+";base64,"+encode64(byteArray);finish(audio)};audio.src=url;safeSetTimeout(()=>{finish(audio)},1e4)};preloadPlugins.push(audioPlugin);function pointerLockChange(){Browser.pointerLock=document["pointerLockElement"]===Module["canvas"]||document["mozPointerLockElement"]===Module["canvas"]||document["webkitPointerLockElement"]===Module["canvas"]||document["msPointerLockElement"]===Module["canvas"]}var canvas=Module["canvas"];if(canvas){canvas.requestPointerLock=canvas["requestPointerLock"]||canvas["mozRequestPointerLock"]||canvas["webkitRequestPointerLock"]||canvas["msRequestPointerLock"]||(()=>{});canvas.exitPointerLock=document["exitPointerLock"]||document["mozExitPointerLock"]||document["webkitExitPointerLock"]||document["msExitPointerLock"]||(()=>{});canvas.exitPointerLock=canvas.exitPointerLock.bind(document);document.addEventListener("pointerlockchange",pointerLockChange,false);document.addEventListener("mozpointerlockchange",pointerLockChange,false);document.addEventListener("webkitpointerlockchange",pointerLockChange,false);document.addEventListener("mspointerlockchange",pointerLockChange,false);if(Module["elementPointerLock"]){canvas.addEventListener("click",ev=>{if(!Browser.pointerLock&&Module["canvas"].requestPointerLock){Module["canvas"].requestPointerLock();ev.preventDefault()}},false)}}},createContext(canvas,useWebGL,setInModule,webGLContextAttributes){if(useWebGL&&Module.ctx&&canvas==Module.canvas)return Module.ctx;var ctx;var contextHandle;if(useWebGL){var contextAttributes={antialias:false,alpha:false,majorVersion:1};if(webGLContextAttributes){for(var attribute in webGLContextAttributes){contextAttributes[attribute]=webGLContextAttributes[attribute]}}if(typeof GL!="undefined"){contextHandle=GL.createContext(canvas,contextAttributes);if(contextHandle){ctx=GL.getContext(contextHandle).GLctx}}}else{ctx=canvas.getContext("2d")}if(!ctx)return null;if(setInModule){if(!useWebGL)assert(typeof GLctx=="undefined","cannot set in module if GLctx is used, but we are a non-GL context that would replace it");Module.ctx=ctx;if(useWebGL)GL.makeContextCurrent(contextHandle);Module.useWebGL=useWebGL;Browser.moduleContextCreatedCallbacks.forEach(callback=>callback());Browser.init()}return ctx},destroyContext(canvas,useWebGL,setInModule){},fullscreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullscreen(lockPointer,resizeCanvas){Browser.lockPointer=lockPointer;Browser.resizeCanvas=resizeCanvas;if(typeof Browser.lockPointer=="undefined")Browser.lockPointer=true;if(typeof Browser.resizeCanvas=="undefined")Browser.resizeCanvas=false;var canvas=Module["canvas"];function fullscreenChange(){Browser.isFullscreen=false;var canvasContainer=canvas.parentNode;if((document["fullscreenElement"]||document["mozFullScreenElement"]||document["msFullscreenElement"]||document["webkitFullscreenElement"]||document["webkitCurrentFullScreenElement"])===canvasContainer){canvas.exitFullscreen=Browser.exitFullscreen;if(Browser.lockPointer)canvas.requestPointerLock();Browser.isFullscreen=true;if(Browser.resizeCanvas){Browser.setFullscreenCanvasSize()}else{Browser.updateCanvasDimensions(canvas)}}else{canvasContainer.parentNode.insertBefore(canvas,canvasContainer);canvasContainer.parentNode.removeChild(canvasContainer);if(Browser.resizeCanvas){Browser.setWindowedCanvasSize()}else{Browser.updateCanvasDimensions(canvas)}}if(Module["onFullScreen"])Module["onFullScreen"](Browser.isFullscreen);if(Module["onFullscreen"])Module["onFullscreen"](Browser.isFullscreen)}if(!Browser.fullscreenHandlersInstalled){Browser.fullscreenHandlersInstalled=true;document.addEventListener("fullscreenchange",fullscreenChange,false);document.addEventListener("mozfullscreenchange",fullscreenChange,false);document.addEventListener("webkitfullscreenchange",fullscreenChange,false);document.addEventListener("MSFullscreenChange",fullscreenChange,false)}var canvasContainer=document.createElement("div");canvas.parentNode.insertBefore(canvasContainer,canvas);canvasContainer.appendChild(canvas);canvasContainer.requestFullscreen=canvasContainer["requestFullscreen"]||canvasContainer["mozRequestFullScreen"]||canvasContainer["msRequestFullscreen"]||(canvasContainer["webkitRequestFullscreen"]?()=>canvasContainer["webkitRequestFullscreen"](Element["ALLOW_KEYBOARD_INPUT"]):null)||(canvasContainer["webkitRequestFullScreen"]?()=>canvasContainer["webkitRequestFullScreen"](Element["ALLOW_KEYBOARD_INPUT"]):null);canvasContainer.requestFullscreen()},exitFullscreen(){if(!Browser.isFullscreen){return false}var CFS=document["exitFullscreen"]||document["cancelFullScreen"]||document["mozCancelFullScreen"]||document["msExitFullscreen"]||document["webkitCancelFullScreen"]||(()=>{});CFS.apply(document,[]);return true},nextRAF:0,fakeRequestAnimationFrame(func){var now=Date.now();if(Browser.nextRAF===0){Browser.nextRAF=now+1e3/60}else{while(now+2>=Browser.nextRAF){Browser.nextRAF+=1e3/60}}var delay=Math.max(Browser.nextRAF-now,0);setTimeout(func,delay)},requestAnimationFrame(func){if(typeof requestAnimationFrame=="function"){requestAnimationFrame(func);return}var RAF=Browser.fakeRequestAnimationFrame;RAF(func)},safeSetTimeout(func,timeout){return safeSetTimeout(func,timeout)},safeRequestAnimationFrame(func){runtimeKeepalivePush();return Browser.requestAnimationFrame(()=>{runtimeKeepalivePop();callUserCallback(func)})},getMimetype(name){return{"jpg":"image/jpeg","jpeg":"image/jpeg","png":"image/png","bmp":"image/bmp","ogg":"audio/ogg","wav":"audio/wav","mp3":"audio/mpeg"}[name.substr(name.lastIndexOf(".")+1)]},getUserMedia(func){if(!window.getUserMedia){window.getUserMedia=navigator["getUserMedia"]||navigator["mozGetUserMedia"]}window.getUserMedia(func)},getMovementX(event){return event["movementX"]||event["mozMovementX"]||event["webkitMovementX"]||0},getMovementY(event){return event["movementY"]||event["mozMovementY"]||event["webkitMovementY"]||0},getMouseWheelDelta(event){var delta=0;switch(event.type){case"DOMMouseScroll":delta=event.detail/3;break;case"mousewheel":delta=event.wheelDelta/120;break;case"wheel":delta=event.deltaY;switch(event.deltaMode){case 0:delta/=100;break;case 1:delta/=3;break;case 2:delta*=80;break;default:throw"unrecognized mouse wheel delta mode: "+event.deltaMode}break;default:throw"unrecognized mouse wheel event: "+event.type}return delta},mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent(event){if(Browser.pointerLock){if(event.type!="mousemove"&&"mozMovementX"in event){Browser.mouseMovementX=Browser.mouseMovementY=0}else{Browser.mouseMovementX=Browser.getMovementX(event);Browser.mouseMovementY=Browser.getMovementY(event)}if(typeof SDL!="undefined"){Browser.mouseX=SDL.mouseX+Browser.mouseMovementX;Browser.mouseY=SDL.mouseY+Browser.mouseMovementY}else{Browser.mouseX+=Browser.mouseMovementX;Browser.mouseY+=Browser.mouseMovementY}}else{var rect=Module["canvas"].getBoundingClientRect();var cw=Module["canvas"].width;var ch=Module["canvas"].height;var scrollX=typeof window.scrollX!="undefined"?window.scrollX:window.pageXOffset;var scrollY=typeof window.scrollY!="undefined"?window.scrollY:window.pageYOffset;if(event.type==="touchstart"||event.type==="touchend"||event.type==="touchmove"){var touch=event.touch;if(touch===undefined){return}var adjustedX=touch.pageX-(scrollX+rect.left);var adjustedY=touch.pageY-(scrollY+rect.top);adjustedX=adjustedX*(cw/rect.width);adjustedY=adjustedY*(ch/rect.height);var coords={x:adjustedX,y:adjustedY};if(event.type==="touchstart"){Browser.lastTouches[touch.identifier]=coords;Browser.touches[touch.identifier]=coords}else if(event.type==="touchend"||event.type==="touchmove"){var last=Browser.touches[touch.identifier];if(!last)last=coords;Browser.lastTouches[touch.identifier]=last;Browser.touches[touch.identifier]=coords}return}var x=event.pageX-(scrollX+rect.left);var y=event.pageY-(scrollY+rect.top);x=x*(cw/rect.width);y=y*(ch/rect.height);Browser.mouseMovementX=x-Browser.mouseX;Browser.mouseMovementY=y-Browser.mouseY;Browser.mouseX=x;Browser.mouseY=y}},resizeListeners:[],updateResizeListeners(){var canvas=Module["canvas"];Browser.resizeListeners.forEach(listener=>listener(canvas.width,canvas.height))},setCanvasSize(width,height,noUpdates){var canvas=Module["canvas"];Browser.updateCanvasDimensions(canvas,width,height);if(!noUpdates)Browser.updateResizeListeners()},windowedWidth:0,windowedHeight:0,setFullscreenCanvasSize(){if(typeof SDL!="undefined"){var flags=HEAPU32[SDL.screen>>2];flags=flags|8388608;HEAP32[SDL.screen>>2]=flags}Browser.updateCanvasDimensions(Module["canvas"]);Browser.updateResizeListeners()},setWindowedCanvasSize(){if(typeof SDL!="undefined"){var flags=HEAPU32[SDL.screen>>2];flags=flags&~8388608;HEAP32[SDL.screen>>2]=flags}Browser.updateCanvasDimensions(Module["canvas"]);Browser.updateResizeListeners()},updateCanvasDimensions(canvas,wNative,hNative){if(wNative&&hNative){canvas.widthNative=wNative;canvas.heightNative=hNative}else{wNative=canvas.widthNative;hNative=canvas.heightNative}var w=wNative;var h=hNative;if(Module["forcedAspectRatio"]&&Module["forcedAspectRatio"]>0){if(w/h<Module["forcedAspectRatio"]){w=Math.round(h*Module["forcedAspectRatio"])}else{h=Math.round(w/Module["forcedAspectRatio"])}}if((document["fullscreenElement"]||document["mozFullScreenElement"]||document["msFullscreenElement"]||document["webkitFullscreenElement"]||document["webkitCurrentFullScreenElement"])===canvas.parentNode&&typeof screen!="undefined"){var factor=Math.min(screen.width/w,screen.height/h);w=Math.round(w*factor);h=Math.round(h*factor)}if(Browser.resizeCanvas){if(canvas.width!=w)canvas.width=w;if(canvas.height!=h)canvas.height=h;if(typeof canvas.style!="undefined"){canvas.style.removeProperty("width");canvas.style.removeProperty("height")}}else{if(canvas.width!=wNative)canvas.width=wNative;if(canvas.height!=hNative)canvas.height=hNative;if(typeof canvas.style!="undefined"){if(w!=wNative||h!=hNative){canvas.style.setProperty("width",w+"px","important");canvas.style.setProperty("height",h+"px","important")}else{canvas.style.removeProperty("width");canvas.style.removeProperty("height")}}}}};var GOT={};var currentModuleWeakSymbols=new Set([]);var GOTHandler={get(obj,symName){var rtn=GOT[symName];if(!rtn){rtn=GOT[symName]=new WebAssembly.Global({"value":"i32","mutable":true})}if(!currentModuleWeakSymbols.has(symName)){rtn.required=true}return rtn}};var callRuntimeCallbacks=callbacks=>{while(callbacks.length>0){callbacks.shift()(Module)}};var asmjsMangle=x=>{var unmangledSymbols=["stackAlloc","stackSave","stackRestore","getTempRet0","setTempRet0"];if(x=="__main_argc_argv"){x="main"}return x.indexOf("dynCall_")==0||unmangledSymbols.includes(x)?x:"_"+x};var exportWasmSymbols=wasmExports=>{var global_object=typeof process!="undefined"?global:this;for(var __exportedFunc in wasmExports){var jsname=asmjsMangle(__exportedFunc);global_object[jsname]=Module[jsname]=wasmExports[__exportedFunc]}};var getDylinkMetadata=binary=>{var offset=0;var end=0;function getU8(){return binary[offset++]}function getLEB(){var ret=0;var mul=1;while(1){var byte=binary[offset++];ret+=(byte&127)*mul;mul*=128;if(!(byte&128))break}return ret}function getString(){var len=getLEB();offset+=len;return UTF8ArrayToString(binary,offset-len,len)}function failIf(condition,message){if(condition)throw new Error(message)}var name="dylink.0";if(binary instanceof WebAssembly.Module){var dylinkSection=WebAssembly.Module.customSections(binary,name);if(dylinkSection.length===0){name="dylink";dylinkSection=WebAssembly.Module.customSections(binary,name)}failIf(dylinkSection.length===0,"need dylink section");binary=new Uint8Array(dylinkSection[0]);end=binary.length}else{var int32View=new Uint32Array(new Uint8Array(binary.subarray(0,24)).buffer);var magicNumberFound=int32View[0]==1836278016;failIf(!magicNumberFound,"need to see wasm magic number");failIf(binary[8]!==0,"need the dylink section to be first");offset=9;var section_size=getLEB();end=offset+section_size;name=getString()}var customSection={neededDynlibs:[],tlsExports:new Set,weakImports:new Set};if(name=="dylink"){customSection.memorySize=getLEB();customSection.memoryAlign=getLEB();customSection.tableSize=getLEB();customSection.tableAlign=getLEB();var neededDynlibsCount=getLEB();for(var i=0;i<neededDynlibsCount;++i){var libname=getString();customSection.neededDynlibs.push(libname)}}else{failIf(name!=="dylink.0");var WASM_DYLINK_MEM_INFO=1;var WASM_DYLINK_NEEDED=2;var WASM_DYLINK_EXPORT_INFO=3;var WASM_DYLINK_IMPORT_INFO=4;var WASM_SYMBOL_TLS=256;var WASM_SYMBOL_BINDING_MASK=3;var WASM_SYMBOL_BINDING_WEAK=1;while(offset<end){var subsectionType=getU8();var subsectionSize=getLEB();if(subsectionType===WASM_DYLINK_MEM_INFO){customSection.memorySize=getLEB();customSection.memoryAlign=getLEB();customSection.tableSize=getLEB();customSection.tableAlign=getLEB()}else if(subsectionType===WASM_DYLINK_NEEDED){var neededDynlibsCount=getLEB();for(var i=0;i<neededDynlibsCount;++i){libname=getString();customSection.neededDynlibs.push(libname)}}else if(subsectionType===WASM_DYLINK_EXPORT_INFO){var count=getLEB();while(count--){var symname=getString();var flags=getLEB();if(flags&WASM_SYMBOL_TLS){customSection.tlsExports.add(symname)}}}else if(subsectionType===WASM_DYLINK_IMPORT_INFO){var count=getLEB();while(count--){var modname=getString();var symname=getString();var flags=getLEB();if((flags&WASM_SYMBOL_BINDING_MASK)==WASM_SYMBOL_BINDING_WEAK){customSection.weakImports.add(symname)}}}else{offset+=subsectionSize}}}return customSection};function getValue(ptr,type="i8"){if(type.endsWith("*"))type="*";switch(type){case"i1":return HEAP8[ptr>>0];case"i8":return HEAP8[ptr>>0];case"i16":return HEAP16[ptr>>1];case"i32":return HEAP32[ptr>>2];case"i64":return HEAP64[ptr>>3];case"float":return HEAPF32[ptr>>2];case"double":return HEAPF64[ptr>>3];case"*":return HEAPU32[ptr>>2];default:abort(`invalid type for getValue: ${type}`)}}var newDSO=(name,handle,syms)=>{var dso={refcount:Infinity,name:name,exports:syms,global:true};LDSO.loadedLibsByName[name]=dso;if(handle!=undefined){LDSO.loadedLibsByHandle[handle]=dso}return dso};var LDSO={loadedLibsByName:{},loadedLibsByHandle:{},init(){newDSO("__main__",0,wasmImports)}};var ___heap_base=10476800;var getMemory=size=>{if(runtimeInitialized){return zeroMemory(_malloc(size),size)}var ret=___heap_base;var end=ret+alignMemory(size,16);___heap_base=end;GOT["__heap_base"].value=end;return ret};var isInternalSym=symName=>["__cpp_exception","__c_longjmp","__wasm_apply_data_relocs","__dso_handle","__tls_size","__tls_align","__set_stack_limits","_emscripten_tls_init","__wasm_init_tls","__wasm_call_ctors","__start_em_asm","__stop_em_asm","__start_em_js","__stop_em_js"].includes(symName)||symName.startsWith("__em_js__");var uleb128Encode=(n,target)=>{if(n<128){target.push(n)}else{target.push(n%128|128,n>>7)}};var sigToWasmTypes=sig=>{var typeNames={"i":"i32","j":"i64","f":"f32","d":"f64","e":"externref","p":"i32"};var type={parameters:[],results:sig[0]=="v"?[]:[typeNames[sig[0]]]};for(var i=1;i<sig.length;++i){type.parameters.push(typeNames[sig[i]])}return type};var generateFuncType=(sig,target)=>{var sigRet=sig.slice(0,1);var sigParam=sig.slice(1);var typeCodes={"i":127,"p":127,"j":126,"f":125,"d":124,"e":111};target.push(96);uleb128Encode(sigParam.length,target);for(var i=0;i<sigParam.length;++i){target.push(typeCodes[sigParam[i]])}if(sigRet=="v"){target.push(0)}else{target.push(1,typeCodes[sigRet])}};var convertJsFunctionToWasm=(func,sig)=>{if(typeof WebAssembly.Function=="function"){return new WebAssembly.Function(sigToWasmTypes(sig),func)}var typeSectionBody=[1];generateFuncType(sig,typeSectionBody);var bytes=[0,97,115,109,1,0,0,0,1];uleb128Encode(typeSectionBody.length,bytes);bytes.push.apply(bytes,typeSectionBody);bytes.push(2,7,1,1,101,1,102,0,0,7,5,1,1,102,0,0);var module=new WebAssembly.Module(new Uint8Array(bytes));var instance=new WebAssembly.Instance(module,{"e":{"f":func}});var wrappedFunc=instance.exports["f"];return wrappedFunc};var wasmTable=new WebAssembly.Table({"initial":2736,"element":"anyfunc"});var getWasmTableEntry=funcPtr=>wasmTable.get(funcPtr);var updateTableMap=(offset,count)=>{if(functionsInTableMap){for(var i=offset;i<offset+count;i++){var item=getWasmTableEntry(i);if(item){functionsInTableMap.set(item,i)}}}};var functionsInTableMap;var getFunctionAddress=func=>{if(!functionsInTableMap){functionsInTableMap=new WeakMap;updateTableMap(0,wasmTable.length)}return functionsInTableMap.get(func)||0};var freeTableIndexes=[];var getEmptyTableSlot=()=>{if(freeTableIndexes.length){return freeTableIndexes.pop()}try{wasmTable.grow(1)}catch(err){if(!(err instanceof RangeError)){throw err}throw"Unable to grow wasm table. Set ALLOW_TABLE_GROWTH."}return wasmTable.length-1};var setWasmTableEntry=(idx,func)=>wasmTable.set(idx,func);var addFunction=(func,sig)=>{var rtn=getFunctionAddress(func);if(rtn){return rtn}var ret=getEmptyTableSlot();try{setWasmTableEntry(ret,func)}catch(err){if(!(err instanceof TypeError)){throw err}var wrapped=convertJsFunctionToWasm(func,sig);setWasmTableEntry(ret,wrapped)}functionsInTableMap.set(func,ret);return ret};var updateGOT=(exports,replace)=>{for(var symName in exports){if(isInternalSym(symName)){continue}var value=exports[symName];if(!GOT[symName]){GOT[symName]=new WebAssembly.Global({"value":"i32","mutable":true})}if(replace||GOT[symName].value==0){if(typeof value=="function"){GOT[symName].value=addFunction(value)}else if(typeof value=="number"){GOT[symName].value=value}else{err(`unhandled export type for '${symName}': ${typeof value}`)}}}};var relocateExports=(exports,memoryBase,replace)=>{var relocated={};for(var e in exports){var value=exports[e];if(typeof value=="object"){value=value.value}if(typeof value=="number"){value+=memoryBase}relocated[e]=value}updateGOT(relocated,replace);return relocated};var isSymbolDefined=symName=>{var existing=wasmImports[symName];if(!existing||existing.stub){return false}return true};var resolveGlobalSymbol=(symName,direct=false)=>{var sym;if(isSymbolDefined(symName)){sym=wasmImports[symName]}return{sym:sym,name:symName}};var loadWebAssemblyModule=(binary,flags,libName,localScope,handle)=>{var metadata=getDylinkMetadata(binary);currentModuleWeakSymbols=metadata.weakImports;function loadModule(){var firstLoad=!handle||!HEAP8[handle+8>>0];if(firstLoad){var memAlign=Math.pow(2,metadata.memoryAlign);var memoryBase=metadata.memorySize?alignMemory(getMemory(metadata.memorySize+memAlign),memAlign):0;var tableBase=metadata.tableSize?wasmTable.length:0;if(handle){HEAP8[handle+8>>0]=1;HEAPU32[handle+12>>2]=memoryBase;HEAP32[handle+16>>2]=metadata.memorySize;HEAPU32[handle+20>>2]=tableBase;HEAP32[handle+24>>2]=metadata.tableSize}}else{memoryBase=HEAPU32[handle+12>>2];tableBase=HEAPU32[handle+20>>2]}var tableGrowthNeeded=tableBase+metadata.tableSize-wasmTable.length;if(tableGrowthNeeded>0){wasmTable.grow(tableGrowthNeeded)}var moduleExports;function resolveSymbol(sym){var resolved=resolveGlobalSymbol(sym).sym;if(!resolved&&localScope){resolved=localScope[sym]}if(!resolved){resolved=moduleExports[sym]}return resolved}var proxyHandler={get(stubs,prop){switch(prop){case"__memory_base":return memoryBase;case"__table_base":return tableBase}if(prop in wasmImports&&!wasmImports[prop].stub){return wasmImports[prop]}if(!(prop in stubs)){var resolved;stubs[prop]=function(){if(!resolved)resolved=resolveSymbol(prop);return resolved.apply(null,arguments)}}return stubs[prop]}};var proxy=new Proxy({},proxyHandler);var info={"GOT.mem":new Proxy({},GOTHandler),"GOT.func":new Proxy({},GOTHandler),"env":proxy,"wasi_snapshot_preview1":proxy};function postInstantiation(module,instance){updateTableMap(tableBase,metadata.tableSize);moduleExports=relocateExports(instance.exports,memoryBase);if(!flags.allowUndefined){reportUndefinedSymbols()}function addEmAsm(addr,body){var args=[];var arity=0;for(;arity<16;arity++){if(body.indexOf("$"+arity)!=-1){args.push("$"+arity)}else{break}}args=args.join(",");var func=`(${args}) => { ${body} };`;ASM_CONSTS[start]=eval(func)}if("__start_em_asm"in moduleExports){var start=moduleExports["__start_em_asm"];var stop=moduleExports["__stop_em_asm"];while(start<stop){var jsString=UTF8ToString(start);addEmAsm(start,jsString);start=HEAPU8.indexOf(0,start)+1}}function addEmJs(name,cSig,body){var jsArgs=[];cSig=cSig.slice(1,-1);if(cSig!="void"){cSig=cSig.split(",");for(var i in cSig){var jsArg=cSig[i].split(" ").pop();jsArgs.push(jsArg.replace("*",""))}}var func=`(${jsArgs}) => ${body};`;moduleExports[name]=eval(func)}for(var name in moduleExports){if(name.startsWith("__em_js__")){var start=moduleExports[name];var jsString=UTF8ToString(start);var parts=jsString.split("<::>");addEmJs(name.replace("__em_js__",""),parts[0],parts[1]);delete moduleExports[name]}}var applyRelocs=moduleExports["__wasm_apply_data_relocs"];if(applyRelocs){if(runtimeInitialized){applyRelocs()}else{__RELOC_FUNCS__.push(applyRelocs)}}var init=moduleExports["__wasm_call_ctors"];if(init){if(runtimeInitialized){init()}else{__ATINIT__.push(init)}}return moduleExports}if(flags.loadAsync){if(binary instanceof WebAssembly.Module){var instance=new WebAssembly.Instance(binary,info);return Promise.resolve(postInstantiation(binary,instance))}return WebAssembly.instantiate(binary,info).then(result=>postInstantiation(result.module,result.instance))}var module=binary instanceof WebAssembly.Module?binary:new WebAssembly.Module(binary);var instance=new WebAssembly.Instance(module,info);return postInstantiation(module,instance)}if(flags.loadAsync){return metadata.neededDynlibs.reduce((chain,dynNeeded)=>chain.then(()=>loadDynamicLibrary(dynNeeded,flags)),Promise.resolve()).then(loadModule)}metadata.neededDynlibs.forEach(needed=>loadDynamicLibrary(needed,flags,localScope));return loadModule()};var mergeLibSymbols=(exports,libName)=>{for(var sym in exports){if(!exports.hasOwnProperty(sym)){continue}const setImport=target=>{if(!isSymbolDefined(target)){wasmImports[target]=exports[sym]}};setImport(sym);const main_alias="__main_argc_argv";if(sym=="main"){setImport(main_alias)}if(sym==main_alias){setImport("main")}if(sym.startsWith("dynCall_")&&!Module.hasOwnProperty(sym)){Module[sym]=exports[sym]}}};function loadDynamicLibrary(libName,flags={global:true,nodelete:true},localScope,handle){var dso=LDSO.loadedLibsByName[libName];if(dso){if(!flags.global){if(localScope){Object.assign(localScope,dso.exports)}}else if(!dso.global){dso.global=true;mergeLibSymbols(dso.exports,libName)}if(flags.nodelete&&dso.refcount!==Infinity){dso.refcount=Infinity}dso.refcount++;if(handle){LDSO.loadedLibsByHandle[handle]=dso}return flags.loadAsync?Promise.resolve(true):true}dso=newDSO(libName,handle,"loading");dso.refcount=flags.nodelete?Infinity:1;dso.global=flags.global;function loadLibData(){if(handle){var data=HEAPU32[handle+28>>2];var dataSize=HEAPU32[handle+32>>2];if(data&&dataSize){var libData=HEAP8.slice(data,data+dataSize);return flags.loadAsync?Promise.resolve(libData):libData}}var libFile=locateFile(libName);if(flags.loadAsync){return new Promise(function(resolve,reject){asyncLoad(libFile,data=>resolve(data),reject)})}if(!readBinary){throw new Error(`${libFile}: file not found, and synchronous loading of external files is not available`)}return readBinary(libFile)}function getExports(){var preloaded=preloadedWasm[libName];if(preloaded){return flags.loadAsync?Promise.resolve(preloaded):preloaded}if(flags.loadAsync){return loadLibData().then(libData=>loadWebAssemblyModule(libData,flags,libName,localScope,handle))}return loadWebAssemblyModule(loadLibData(),flags,libName,localScope,handle)}function moduleLoaded(exports){if(dso.global){mergeLibSymbols(exports,libName)}else if(localScope){Object.assign(localScope,exports)}dso.exports=exports}if(flags.loadAsync){return getExports().then(exports=>{moduleLoaded(exports);return true})}moduleLoaded(getExports());return true}var reportUndefinedSymbols=()=>{for(var symName in GOT){if(GOT[symName].value==0){var value=resolveGlobalSymbol(symName,true).sym;if(!value&&!GOT[symName].required){continue}if(typeof value=="function"){GOT[symName].value=addFunction(value,value.sig)}else if(typeof value=="number"){GOT[symName].value=value}else{throw new Error(`bad export type for '${symName}': ${typeof value}`)}}}};var loadDylibs=()=>{if(!dynamicLibraries.length){reportUndefinedSymbols();return}addRunDependency("loadDylibs");dynamicLibraries.reduce((chain,lib)=>chain.then(()=>loadDynamicLibrary(lib,{loadAsync:true,global:true,nodelete:true,allowUndefined:true})),Promise.resolve()).then(()=>{reportUndefinedSymbols();removeRunDependency("loadDylibs")})};var noExitRuntime=Module["noExitRuntime"]||false;function setValue(ptr,value,type="i8"){if(type.endsWith("*"))type="*";switch(type){case"i1":HEAP8[ptr>>0]=value;break;case"i8":HEAP8[ptr>>0]=value;break;case"i16":HEAP16[ptr>>1]=value;break;case"i32":HEAP32[ptr>>2]=value;break;case"i64":HEAP64[ptr>>3]=BigInt(value);break;case"float":HEAPF32[ptr>>2]=value;break;case"double":HEAPF64[ptr>>3]=value;break;case"*":HEAPU32[ptr>>2]=value;break;default:abort(`invalid type for setValue: ${type}`)}}function __QQclX20(){return wasmImports["_QQclX20"].apply(null,arguments)}__QQclX20.stub=true;function __QQclX31(){return wasmImports["_QQclX31"].apply(null,arguments)}__QQclX31.stub=true;function __QQclX32(){return wasmImports["_QQclX32"].apply(null,arguments)}__QQclX32.stub=true;function __QQclX3253544147(){return wasmImports["_QQclX3253544147"].apply(null,arguments)}__QQclX3253544147.stub=true;function __QQclX41(){return wasmImports["_QQclX41"].apply(null,arguments)}__QQclX41.stub=true;function __QQclX414C4C(){return wasmImports["_QQclX414C4C"].apply(null,arguments)}__QQclX414C4C.stub=true;function __QQclX416C6C(){return wasmImports["_QQclX416C6C"].apply(null,arguments)}__QQclX416C6C.stub=true;function __QQclX42(){return wasmImports["_QQclX42"].apply(null,arguments)}__QQclX42.stub=true;function __QQclX4252(){return wasmImports["_QQclX4252"].apply(null,arguments)}__QQclX4252.stub=true;function __QQclX425244(){return wasmImports["_QQclX425244"].apply(null,arguments)}__QQclX425244.stub=true;function __QQclX4261636B77617264(){return wasmImports["_QQclX4261636B77617264"].apply(null,arguments)}__QQclX4261636B77617264.stub=true;function __QQclX42617365(){return wasmImports["_QQclX42617365"].apply(null,arguments)}__QQclX42617365.stub=true;function __QQclX43(){return wasmImports["_QQclX43"].apply(null,arguments)}__QQclX43.stub=true;function __QQclX436F6C756D6E77697365(){return wasmImports["_QQclX436F6C756D6E77697365"].apply(null,arguments)}__QQclX436F6C756D6E77697365.stub=true;function __QQclX436F6E6A205472616E73(){return wasmImports["_QQclX436F6E6A205472616E73"].apply(null,arguments)}__QQclX436F6E6A205472616E73.stub=true;function __QQclX436F6E6A7567617465205472616E73706F7365(){return wasmImports["_QQclX436F6E6A7567617465205472616E73706F7365"].apply(null,arguments)}__QQclX436F6E6A7567617465205472616E73706F7365.stub=true;function __QQclX436F6E6A7567617465207472616E73706F7365(){return wasmImports["_QQclX436F6E6A7567617465207472616E73706F7365"].apply(null,arguments)}__QQclX436F6E6A7567617465207472616E73706F7365.stub=true;function __QQclX44(){return wasmImports["_QQclX44"].apply(null,arguments)}__QQclX44.stub=true;function __QQclX444242435344(){return wasmImports["_QQclX444242435344"].apply(null,arguments)}__QQclX444242435344.stub=true;function __QQclX444244534443(){return wasmImports["_QQclX444244534443"].apply(null,arguments)}__QQclX444244534443.stub=true;function __QQclX444244535152(){return wasmImports["_QQclX444244535152"].apply(null,arguments)}__QQclX444244535152.stub=true;function __QQclX444449534E41(){return wasmImports["_QQclX444449534E41"].apply(null,arguments)}__QQclX444449534E41.stub=true;function __QQclX444742425244(){return wasmImports["_QQclX444742425244"].apply(null,arguments)}__QQclX444742425244.stub=true;function __QQclX444742434F4E(){return wasmImports["_QQclX444742434F4E"].apply(null,arguments)}__QQclX444742434F4E.stub=true;function __QQclX444742455155(){return wasmImports["_QQclX444742455155"].apply(null,arguments)}__QQclX444742455155.stub=true;function __QQclX44474245515542(){return wasmImports["_QQclX44474245515542"].apply(null,arguments)}__QQclX44474245515542.stub=true;function __QQclX4447424D5620(){return wasmImports["_QQclX4447424D5620"].apply(null,arguments)}__QQclX4447424D5620.stub=true;function __QQclX444742524653(){return wasmImports["_QQclX444742524653"].apply(null,arguments)}__QQclX444742524653.stub=true;function __QQclX444742535620(){return wasmImports["_QQclX444742535620"].apply(null,arguments)}__QQclX444742535620.stub=true;function __QQclX444742535658(){return wasmImports["_QQclX444742535658"].apply(null,arguments)}__QQclX444742535658.stub=true;function __QQclX444742544632(){return wasmImports["_QQclX444742544632"].apply(null,arguments)}__QQclX444742544632.stub=true;function __QQclX444742545246(){return wasmImports["_QQclX444742545246"].apply(null,arguments)}__QQclX444742545246.stub=true;function __QQclX444742545253(){return wasmImports["_QQclX444742545253"].apply(null,arguments)}__QQclX444742545253.stub=true;function __QQclX44474542414B(){return wasmImports["_QQclX44474542414B"].apply(null,arguments)}__QQclX44474542414B.stub=true;function __QQclX44474542414C(){return wasmImports["_QQclX44474542414C"].apply(null,arguments)}__QQclX44474542414C.stub=true;function __QQclX444745424432(){return wasmImports["_QQclX444745424432"].apply(null,arguments)}__QQclX444745424432.stub=true;function __QQclX444745425244(){return wasmImports["_QQclX444745425244"].apply(null,arguments)}__QQclX444745425244.stub=true;function __QQclX444745434F4E(){return wasmImports["_QQclX444745434F4E"].apply(null,arguments)}__QQclX444745434F4E.stub=true;function __QQclX444745455155(){return wasmImports["_QQclX444745455155"].apply(null,arguments)}__QQclX444745455155.stub=true;function __QQclX44474545515542(){return wasmImports["_QQclX44474545515542"].apply(null,arguments)}__QQclX44474545515542.stub=true;function __QQclX444745455320(){return wasmImports["_QQclX444745455320"].apply(null,arguments)}__QQclX444745455320.stub=true;function __QQclX444745455358(){return wasmImports["_QQclX444745455358"].apply(null,arguments)}__QQclX444745455358.stub=true;function __QQclX444745455620(){return wasmImports["_QQclX444745455620"].apply(null,arguments)}__QQclX444745455620.stub=true;function __QQclX444745455658(){return wasmImports["_QQclX444745455658"].apply(null,arguments)}__QQclX444745455658.stub=true;function __QQclX444745475320(){return wasmImports["_QQclX444745475320"].apply(null,arguments)}__QQclX444745475320.stub=true;function __QQclX444745475620(){return wasmImports["_QQclX444745475620"].apply(null,arguments)}__QQclX444745475620.stub=true;function __QQclX444745484432(){return wasmImports["_QQclX444745484432"].apply(null,arguments)}__QQclX444745484432.stub=true;function __QQclX444745485244(){return wasmImports["_QQclX444745485244"].apply(null,arguments)}__QQclX444745485244.stub=true;function __QQclX4447454A5356(){return wasmImports["_QQclX4447454A5356"].apply(null,arguments)}__QQclX4447454A5356.stub=true;function __QQclX4447454C5132(){return wasmImports["_QQclX4447454C5132"].apply(null,arguments)}__QQclX4447454C5132.stub=true;function __QQclX4447454C5146(){return wasmImports["_QQclX4447454C5146"].apply(null,arguments)}__QQclX4447454C5146.stub=true;function __QQclX4447454C5320(){return wasmImports["_QQclX4447454C5320"].apply(null,arguments)}__QQclX4447454C5320.stub=true;function __QQclX4447454C5344(){return wasmImports["_QQclX4447454C5344"].apply(null,arguments)}__QQclX4447454C5344.stub=true;function __QQclX4447454C5353(){return wasmImports["_QQclX4447454C5353"].apply(null,arguments)}__QQclX4447454C5353.stub=true;function __QQclX4447454C5358(){return wasmImports["_QQclX4447454C5358"].apply(null,arguments)}__QQclX4447454C5358.stub=true;function __QQclX4447454C5359(){return wasmImports["_QQclX4447454C5359"].apply(null,arguments)}__QQclX4447454C5359.stub=true;function __QQclX4447454D4D20(){return wasmImports["_QQclX4447454D4D20"].apply(null,arguments)}__QQclX4447454D4D20.stub=true;function __QQclX4447454D515254(){return wasmImports["_QQclX4447454D515254"].apply(null,arguments)}__QQclX4447454D515254.stub=true;function __QQclX4447454D5620(){return wasmImports["_QQclX4447454D5620"].apply(null,arguments)}__QQclX4447454D5620.stub=true;function __QQclX444745514C32(){return wasmImports["_QQclX444745514C32"].apply(null,arguments)}__QQclX444745514C32.stub=true;function __QQclX444745514C46(){return wasmImports["_QQclX444745514C46"].apply(null,arguments)}__QQclX444745514C46.stub=true;function __QQclX444745515033(){return wasmImports["_QQclX444745515033"].apply(null,arguments)}__QQclX444745515033.stub=true;function __QQclX444745515046(){return wasmImports["_QQclX444745515046"].apply(null,arguments)}__QQclX444745515046.stub=true;function __QQclX444745515232(){return wasmImports["_QQclX444745515232"].apply(null,arguments)}__QQclX444745515232.stub=true;function __QQclX44474551523250(){return wasmImports["_QQclX44474551523250"].apply(null,arguments)}__QQclX44474551523250.stub=true;function __QQclX444745515246(){return wasmImports["_QQclX444745515246"].apply(null,arguments)}__QQclX444745515246.stub=true;function __QQclX44474551524650(){return wasmImports["_QQclX44474551524650"].apply(null,arguments)}__QQclX44474551524650.stub=true;function __QQclX444745515254(){return wasmImports["_QQclX444745515254"].apply(null,arguments)}__QQclX444745515254.stub=true;function __QQclX44474551525432(){return wasmImports["_QQclX44474551525432"].apply(null,arguments)}__QQclX44474551525432.stub=true;function __QQclX44474551525433(){return wasmImports["_QQclX44474551525433"].apply(null,arguments)}__QQclX44474551525433.stub=true;function __QQclX444745522020(){return wasmImports["_QQclX444745522020"].apply(null,arguments)}__QQclX444745522020.stub=true;function __QQclX444745524653(){return wasmImports["_QQclX444745524653"].apply(null,arguments)}__QQclX444745524653.stub=true;function __QQclX444745525132(){return wasmImports["_QQclX444745525132"].apply(null,arguments)}__QQclX444745525132.stub=true;function __QQclX444745525146(){return wasmImports["_QQclX444745525146"].apply(null,arguments)}__QQclX444745525146.stub=true;function __QQclX444745534444(){return wasmImports["_QQclX444745534444"].apply(null,arguments)}__QQclX444745534444.stub=true;function __QQclX444745535620(){return wasmImports["_QQclX444745535620"].apply(null,arguments)}__QQclX444745535620.stub=true;function __QQclX444745535644(){return wasmImports["_QQclX444745535644"].apply(null,arguments)}__QQclX444745535644.stub=true;function __QQclX44474553564A(){return wasmImports["_QQclX44474553564A"].apply(null,arguments)}__QQclX44474553564A.stub=true;function __QQclX444745535658(){return wasmImports["_QQclX444745535658"].apply(null,arguments)}__QQclX444745535658.stub=true;function __QQclX444745544632(){return wasmImports["_QQclX444745544632"].apply(null,arguments)}__QQclX444745544632.stub=true;function __QQclX444745545246(){return wasmImports["_QQclX444745545246"].apply(null,arguments)}__QQclX444745545246.stub=true;function __QQclX44474554524632(){return wasmImports["_QQclX44474554524632"].apply(null,arguments)}__QQclX44474554524632.stub=true;function __QQclX444745545249(){return wasmImports["_QQclX444745545249"].apply(null,arguments)}__QQclX444745545249.stub=true;function __QQclX444745545253(){return wasmImports["_QQclX444745545253"].apply(null,arguments)}__QQclX444745545253.stub=true;function __QQclX44474742414B(){return wasmImports["_QQclX44474742414B"].apply(null,arguments)}__QQclX44474742414B.stub=true;function __QQclX44474742414C(){return wasmImports["_QQclX44474742414C"].apply(null,arguments)}__QQclX44474742414C.stub=true;function __QQclX444747455320(){return wasmImports["_QQclX444747455320"].apply(null,arguments)}__QQclX444747455320.stub=true;function __QQclX444747455358(){return wasmImports["_QQclX444747455358"].apply(null,arguments)}__QQclX444747455358.stub=true;function __QQclX444747455620(){return wasmImports["_QQclX444747455620"].apply(null,arguments)}__QQclX444747455620.stub=true;function __QQclX444747455658(){return wasmImports["_QQclX444747455658"].apply(null,arguments)}__QQclX444747455658.stub=true;function __QQclX444747474C4D(){return wasmImports["_QQclX444747474C4D"].apply(null,arguments)}__QQclX444747474C4D.stub=true;function __QQclX444747485244(){return wasmImports["_QQclX444747485244"].apply(null,arguments)}__QQclX444747485244.stub=true;function __QQclX4447474C5345(){return wasmImports["_QQclX4447474C5345"].apply(null,arguments)}__QQclX4447474C5345.stub=true;function __QQclX444747515246(){return wasmImports["_QQclX444747515246"].apply(null,arguments)}__QQclX444747515246.stub=true;function __QQclX444747525146(){return wasmImports["_QQclX444747525146"].apply(null,arguments)}__QQclX444747525146.stub=true;function __QQclX444747535644(){return wasmImports["_QQclX444747535644"].apply(null,arguments)}__QQclX444747535644.stub=true;function __QQclX444747535650(){return wasmImports["_QQclX444747535650"].apply(null,arguments)}__QQclX444747535650.stub=true;function __QQclX444753564A30(){return wasmImports["_QQclX444753564A30"].apply(null,arguments)}__QQclX444753564A30.stub=true;function __QQclX444753564A31(){return wasmImports["_QQclX444753564A31"].apply(null,arguments)}__QQclX444753564A31.stub=true;function __QQclX444754434F4E(){return wasmImports["_QQclX444754434F4E"].apply(null,arguments)}__QQclX444754434F4E.stub=true;function __QQclX444754524653(){return wasmImports["_QQclX444754524653"].apply(null,arguments)}__QQclX444754524653.stub=true;function __QQclX444754535620(){return wasmImports["_QQclX444754535620"].apply(null,arguments)}__QQclX444754535620.stub=true;function __QQclX444754535658(){return wasmImports["_QQclX444754535658"].apply(null,arguments)}__QQclX444754535658.stub=true;function __QQclX444754545246(){return wasmImports["_QQclX444754545246"].apply(null,arguments)}__QQclX444754545246.stub=true;function __QQclX444754545253(){return wasmImports["_QQclX444754545253"].apply(null,arguments)}__QQclX444754545253.stub=true;function __QQclX44484745515A(){return wasmImports["_QQclX44484745515A"].apply(null,arguments)}__QQclX44484745515A.stub=true;function __QQclX44485345494E(){return wasmImports["_QQclX44485345494E"].apply(null,arguments)}__QQclX44485345494E.stub=true;function __QQclX444853455152(){return wasmImports["_QQclX444853455152"].apply(null,arguments)}__QQclX444853455152.stub=true;function __QQclX444C41454430(){return wasmImports["_QQclX444C41454430"].apply(null,arguments)}__QQclX444C41454430.stub=true;function __QQclX444C41454431(){return wasmImports["_QQclX444C41454431"].apply(null,arguments)}__QQclX444C41454431.stub=true;function __QQclX444C41454432(){return wasmImports["_QQclX444C41454432"].apply(null,arguments)}__QQclX444C41454432.stub=true;function __QQclX444C41454433(){return wasmImports["_QQclX444C41454433"].apply(null,arguments)}__QQclX444C41454433.stub=true;function __QQclX444C41454437(){return wasmImports["_QQclX444C41454437"].apply(null,arguments)}__QQclX444C41454437.stub=true;function __QQclX444C41454438(){return wasmImports["_QQclX444C41454438"].apply(null,arguments)}__QQclX444C41454438.stub=true;function __QQclX444C41454439(){return wasmImports["_QQclX444C41454439"].apply(null,arguments)}__QQclX444C41454439.stub=true;function __QQclX444C41454441(){return wasmImports["_QQclX444C41454441"].apply(null,arguments)}__QQclX444C41454441.stub=true;function __QQclX444C41475446(){return wasmImports["_QQclX444C41475446"].apply(null,arguments)}__QQclX444C41475446.stub=true;function __QQclX444C41475453(){return wasmImports["_QQclX444C41475453"].apply(null,arguments)}__QQclX444C41475453.stub=true;function __QQclX444C414C5330(){return wasmImports["_QQclX444C414C5330"].apply(null,arguments)}__QQclX444C414C5330.stub=true;function __QQclX444C414C5341(){return wasmImports["_QQclX444C414C5341"].apply(null,arguments)}__QQclX444C414C5341.stub=true;function __QQclX444C414C5344(){return wasmImports["_QQclX444C414C5344"].apply(null,arguments)}__QQclX444C414C5344.stub=true;function __QQclX444C41515230(){return wasmImports["_QQclX444C41515230"].apply(null,arguments)}__QQclX444C41515230.stub=true;function __QQclX444C41515233(){return wasmImports["_QQclX444C41515233"].apply(null,arguments)}__QQclX444C41515233.stub=true;function __QQclX444C41515234(){return wasmImports["_QQclX444C41515234"].apply(null,arguments)}__QQclX444C41515234.stub=true;function __QQclX444C41525A42(){return wasmImports["_QQclX444C41525A42"].apply(null,arguments)}__QQclX444C41525A42.stub=true;function __QQclX444C41525A54(){return wasmImports["_QQclX444C41525A54"].apply(null,arguments)}__QQclX444C41525A54.stub=true;function __QQclX444C4153434C(){return wasmImports["_QQclX444C4153434C"].apply(null,arguments)}__QQclX444C4153434C.stub=true;function __QQclX444C41534430(){return wasmImports["_QQclX444C41534430"].apply(null,arguments)}__QQclX444C41534430.stub=true;function __QQclX444C41534431(){return wasmImports["_QQclX444C41534431"].apply(null,arguments)}__QQclX444C41534431.stub=true;function __QQclX444C41534432(){return wasmImports["_QQclX444C41534432"].apply(null,arguments)}__QQclX444C41534432.stub=true;function __QQclX444C41534433(){return wasmImports["_QQclX444C41534433"].apply(null,arguments)}__QQclX444C41534433.stub=true;function __QQclX444C41534436(){return wasmImports["_QQclX444C41534436"].apply(null,arguments)}__QQclX444C41534436.stub=true;function __QQclX444C41534437(){return wasmImports["_QQclX444C41534437"].apply(null,arguments)}__QQclX444C41534437.stub=true;function __QQclX444C41534438(){return wasmImports["_QQclX444C41534438"].apply(null,arguments)}__QQclX444C41534438.stub=true;function __QQclX444C41534441(){return wasmImports["_QQclX444C41534441"].apply(null,arguments)}__QQclX444C41534441.stub=true;function __QQclX444C41534451(){return wasmImports["_QQclX444C41534451"].apply(null,arguments)}__QQclX444C41534451.stub=true;function __QQclX444C41535131(){return wasmImports["_QQclX444C41535131"].apply(null,arguments)}__QQclX444C41535131.stub=true;function __QQclX444C41535132(){return wasmImports["_QQclX444C41535132"].apply(null,arguments)}__QQclX444C41535132.stub=true;function __QQclX444C41535220(){return wasmImports["_QQclX444C41535220"].apply(null,arguments)}__QQclX444C41535220.stub=true;function __QQclX444C41535254(){return wasmImports["_QQclX444C41535254"].apply(null,arguments)}__QQclX444C41535254.stub=true;function __QQclX444C41544253(){return wasmImports["_QQclX444C41544253"].apply(null,arguments)}__QQclX444C41544253.stub=true;function __QQclX444C41545053(){return wasmImports["_QQclX444C41545053"].apply(null,arguments)}__QQclX444C41545053.stub=true;function __QQclX444C41545253(){return wasmImports["_QQclX444C41545253"].apply(null,arguments)}__QQclX444C41545253.stub=true;function __QQclX444C41555532(){return wasmImports["_QQclX444C41555532"].apply(null,arguments)}__QQclX444C41555532.stub=true;function __QQclX444C4155554D(){return wasmImports["_QQclX444C4155554D"].apply(null,arguments)}__QQclX444C4155554D.stub=true;function __QQclX444F50475452(){return wasmImports["_QQclX444F50475452"].apply(null,arguments)}__QQclX444F50475452.stub=true;function __QQclX444F504D5452(){return wasmImports["_QQclX444F504D5452"].apply(null,arguments)}__QQclX444F504D5452.stub=true;function __QQclX444F52435344(){return wasmImports["_QQclX444F52435344"].apply(null,arguments)}__QQclX444F52435344.stub=true;function __QQclX444F5247324C(){return wasmImports["_QQclX444F5247324C"].apply(null,arguments)}__QQclX444F5247324C.stub=true;function __QQclX444F52473252(){return wasmImports["_QQclX444F52473252"].apply(null,arguments)}__QQclX444F52473252.stub=true;function __QQclX444F52474252(){return wasmImports["_QQclX444F52474252"].apply(null,arguments)}__QQclX444F52474252.stub=true;function __QQclX444F52474852(){return wasmImports["_QQclX444F52474852"].apply(null,arguments)}__QQclX444F52474852.stub=true;function __QQclX444F52474C32(){return wasmImports["_QQclX444F52474C32"].apply(null,arguments)}__QQclX444F52474C32.stub=true;function __QQclX444F52474C51(){return wasmImports["_QQclX444F52474C51"].apply(null,arguments)}__QQclX444F52474C51.stub=true;function __QQclX444F5247514C(){return wasmImports["_QQclX444F5247514C"].apply(null,arguments)}__QQclX444F5247514C.stub=true;function __QQclX444F52475152(){return wasmImports["_QQclX444F52475152"].apply(null,arguments)}__QQclX444F52475152.stub=true;function __QQclX444F52475232(){return wasmImports["_QQclX444F52475232"].apply(null,arguments)}__QQclX444F52475232.stub=true;function __QQclX444F52475251(){return wasmImports["_QQclX444F52475251"].apply(null,arguments)}__QQclX444F52475251.stub=true;function __QQclX444F52475452(){return wasmImports["_QQclX444F52475452"].apply(null,arguments)}__QQclX444F52475452.stub=true;function __QQclX444F524D324C(){return wasmImports["_QQclX444F524D324C"].apply(null,arguments)}__QQclX444F524D324C.stub=true;function __QQclX444F524D3252(){return wasmImports["_QQclX444F524D3252"].apply(null,arguments)}__QQclX444F524D3252.stub=true;function __QQclX444F524D4252(){return wasmImports["_QQclX444F524D4252"].apply(null,arguments)}__QQclX444F524D4252.stub=true;function __QQclX444F524D4852(){return wasmImports["_QQclX444F524D4852"].apply(null,arguments)}__QQclX444F524D4852.stub=true;function __QQclX444F524D4C32(){return wasmImports["_QQclX444F524D4C32"].apply(null,arguments)}__QQclX444F524D4C32.stub=true;function __QQclX444F524D4C51(){return wasmImports["_QQclX444F524D4C51"].apply(null,arguments)}__QQclX444F524D4C51.stub=true;function __QQclX444F524D514C(){return wasmImports["_QQclX444F524D514C"].apply(null,arguments)}__QQclX444F524D514C.stub=true;function __QQclX444F524D5152(){return wasmImports["_QQclX444F524D5152"].apply(null,arguments)}__QQclX444F524D5152.stub=true;function __QQclX444F524D5232(){return wasmImports["_QQclX444F524D5232"].apply(null,arguments)}__QQclX444F524D5232.stub=true;function __QQclX444F524D5233(){return wasmImports["_QQclX444F524D5233"].apply(null,arguments)}__QQclX444F524D5233.stub=true;function __QQclX444F524D5251(){return wasmImports["_QQclX444F524D5251"].apply(null,arguments)}__QQclX444F524D5251.stub=true;function __QQclX444F524D525A(){return wasmImports["_QQclX444F524D525A"].apply(null,arguments)}__QQclX444F524D525A.stub=true;function __QQclX444F524D5452(){return wasmImports["_QQclX444F524D5452"].apply(null,arguments)}__QQclX444F524D5452.stub=true;function __QQclX445042434F4E(){return wasmImports["_QQclX445042434F4E"].apply(null,arguments)}__QQclX445042434F4E.stub=true;function __QQclX445042455155(){return wasmImports["_QQclX445042455155"].apply(null,arguments)}__QQclX445042455155.stub=true;function __QQclX445042524653(){return wasmImports["_QQclX445042524653"].apply(null,arguments)}__QQclX445042524653.stub=true;function __QQclX445042535446(){return wasmImports["_QQclX445042535446"].apply(null,arguments)}__QQclX445042535446.stub=true;function __QQclX445042535620(){return wasmImports["_QQclX445042535620"].apply(null,arguments)}__QQclX445042535620.stub=true;function __QQclX445042535658(){return wasmImports["_QQclX445042535658"].apply(null,arguments)}__QQclX445042535658.stub=true;function __QQclX445042544632(){return wasmImports["_QQclX445042544632"].apply(null,arguments)}__QQclX445042544632.stub=true;function __QQclX445042545246(){return wasmImports["_QQclX445042545246"].apply(null,arguments)}__QQclX445042545246.stub=true;function __QQclX445042545253(){return wasmImports["_QQclX445042545253"].apply(null,arguments)}__QQclX445042545253.stub=true;function __QQclX445046545246(){return wasmImports["_QQclX445046545246"].apply(null,arguments)}__QQclX445046545246.stub=true;function __QQclX445046545249(){return wasmImports["_QQclX445046545249"].apply(null,arguments)}__QQclX445046545249.stub=true;function __QQclX445046545253(){return wasmImports["_QQclX445046545253"].apply(null,arguments)}__QQclX445046545253.stub=true;function __QQclX44504F434F4E(){return wasmImports["_QQclX44504F434F4E"].apply(null,arguments)}__QQclX44504F434F4E.stub=true;function __QQclX44504F455155(){return wasmImports["_QQclX44504F455155"].apply(null,arguments)}__QQclX44504F455155.stub=true;function __QQclX44504F45515542(){return wasmImports["_QQclX44504F45515542"].apply(null,arguments)}__QQclX44504F45515542.stub=true;function __QQclX44504F524653(){return wasmImports["_QQclX44504F524653"].apply(null,arguments)}__QQclX44504F524653.stub=true;function __QQclX44504F535620(){return wasmImports["_QQclX44504F535620"].apply(null,arguments)}__QQclX44504F535620.stub=true;function __QQclX44504F535658(){return wasmImports["_QQclX44504F535658"].apply(null,arguments)}__QQclX44504F535658.stub=true;function __QQclX44504F544632(){return wasmImports["_QQclX44504F544632"].apply(null,arguments)}__QQclX44504F544632.stub=true;function __QQclX44504F545246(){return wasmImports["_QQclX44504F545246"].apply(null,arguments)}__QQclX44504F545246.stub=true;function __QQclX44504F54524632(){return wasmImports["_QQclX44504F54524632"].apply(null,arguments)}__QQclX44504F54524632.stub=true;function __QQclX44504F545249(){return wasmImports["_QQclX44504F545249"].apply(null,arguments)}__QQclX44504F545249.stub=true;function __QQclX44504F545253(){return wasmImports["_QQclX44504F545253"].apply(null,arguments)}__QQclX44504F545253.stub=true;function __QQclX445050434F4E(){return wasmImports["_QQclX445050434F4E"].apply(null,arguments)}__QQclX445050434F4E.stub=true;function __QQclX445050455155(){return wasmImports["_QQclX445050455155"].apply(null,arguments)}__QQclX445050455155.stub=true;function __QQclX445050524653(){return wasmImports["_QQclX445050524653"].apply(null,arguments)}__QQclX445050524653.stub=true;function __QQclX445050535620(){return wasmImports["_QQclX445050535620"].apply(null,arguments)}__QQclX445050535620.stub=true;function __QQclX445050535658(){return wasmImports["_QQclX445050535658"].apply(null,arguments)}__QQclX445050535658.stub=true;function __QQclX445050545246(){return wasmImports["_QQclX445050545246"].apply(null,arguments)}__QQclX445050545246.stub=true;function __QQclX445050545249(){return wasmImports["_QQclX445050545249"].apply(null,arguments)}__QQclX445050545249.stub=true;function __QQclX445050545253(){return wasmImports["_QQclX445050545253"].apply(null,arguments)}__QQclX445050545253.stub=true;function __QQclX445053544632(){return wasmImports["_QQclX445053544632"].apply(null,arguments)}__QQclX445053544632.stub=true;function __QQclX445053545246(){return wasmImports["_QQclX445053545246"].apply(null,arguments)}__QQclX445053545246.stub=true;function __QQclX445054434F4E(){return wasmImports["_QQclX445054434F4E"].apply(null,arguments)}__QQclX445054434F4E.stub=true;function __QQclX445054455152(){return wasmImports["_QQclX445054455152"].apply(null,arguments)}__QQclX445054455152.stub=true;function __QQclX445054524653(){return wasmImports["_QQclX445054524653"].apply(null,arguments)}__QQclX445054524653.stub=true;function __QQclX445054535620(){return wasmImports["_QQclX445054535620"].apply(null,arguments)}__QQclX445054535620.stub=true;function __QQclX445054535658(){return wasmImports["_QQclX445054535658"].apply(null,arguments)}__QQclX445054535658.stub=true;function __QQclX445054545246(){return wasmImports["_QQclX445054545246"].apply(null,arguments)}__QQclX445054545246.stub=true;function __QQclX445054545253(){return wasmImports["_QQclX445054545253"].apply(null,arguments)}__QQclX445054545253.stub=true;function __QQclX445342455620(){return wasmImports["_QQclX445342455620"].apply(null,arguments)}__QQclX445342455620.stub=true;function __QQclX445342455644(){return wasmImports["_QQclX445342455644"].apply(null,arguments)}__QQclX445342455644.stub=true;function __QQclX445342455658(){return wasmImports["_QQclX445342455658"].apply(null,arguments)}__QQclX445342455658.stub=true;function __QQclX445342475354(){return wasmImports["_QQclX445342475354"].apply(null,arguments)}__QQclX445342475354.stub=true;function __QQclX4453424756(){return wasmImports["_QQclX4453424756"].apply(null,arguments)}__QQclX4453424756.stub=true;function __QQclX445342475644(){return wasmImports["_QQclX445342475644"].apply(null,arguments)}__QQclX445342475644.stub=true;function __QQclX445342475658(){return wasmImports["_QQclX445342475658"].apply(null,arguments)}__QQclX445342475658.stub=true;function __QQclX4453424D5620(){return wasmImports["_QQclX4453424D5620"].apply(null,arguments)}__QQclX4453424D5620.stub=true;function __QQclX445342545244(){return wasmImports["_QQclX445342545244"].apply(null,arguments)}__QQclX445342545244.stub=true;function __QQclX445346524B20(){return wasmImports["_QQclX445346524B20"].apply(null,arguments)}__QQclX445346524B20.stub=true;function __QQclX445350434F4E(){return wasmImports["_QQclX445350434F4E"].apply(null,arguments)}__QQclX445350434F4E.stub=true;function __QQclX445350455620(){return wasmImports["_QQclX445350455620"].apply(null,arguments)}__QQclX445350455620.stub=true;function __QQclX445350455644(){return wasmImports["_QQclX445350455644"].apply(null,arguments)}__QQclX445350455644.stub=true;function __QQclX445350455658(){return wasmImports["_QQclX445350455658"].apply(null,arguments)}__QQclX445350455658.stub=true;function __QQclX445350475354(){return wasmImports["_QQclX445350475354"].apply(null,arguments)}__QQclX445350475354.stub=true;function __QQclX445350475620(){return wasmImports["_QQclX445350475620"].apply(null,arguments)}__QQclX445350475620.stub=true;function __QQclX445350475644(){return wasmImports["_QQclX445350475644"].apply(null,arguments)}__QQclX445350475644.stub=true;function __QQclX445350475658(){return wasmImports["_QQclX445350475658"].apply(null,arguments)}__QQclX445350475658.stub=true;function __QQclX4453504D5620(){return wasmImports["_QQclX4453504D5620"].apply(null,arguments)}__QQclX4453504D5620.stub=true;function __QQclX445350522020(){return wasmImports["_QQclX445350522020"].apply(null,arguments)}__QQclX445350522020.stub=true;function __QQclX445350523220(){return wasmImports["_QQclX445350523220"].apply(null,arguments)}__QQclX445350523220.stub=true;function __QQclX445350524653(){return wasmImports["_QQclX445350524653"].apply(null,arguments)}__QQclX445350524653.stub=true;function __QQclX445350535620(){return wasmImports["_QQclX445350535620"].apply(null,arguments)}__QQclX445350535620.stub=true;function __QQclX445350535658(){return wasmImports["_QQclX445350535658"].apply(null,arguments)}__QQclX445350535658.stub=true;function __QQclX445350545244(){return wasmImports["_QQclX445350545244"].apply(null,arguments)}__QQclX445350545244.stub=true;function __QQclX445350545246(){return wasmImports["_QQclX445350545246"].apply(null,arguments)}__QQclX445350545246.stub=true;function __QQclX445350545249(){return wasmImports["_QQclX445350545249"].apply(null,arguments)}__QQclX445350545249.stub=true;function __QQclX445350545253(){return wasmImports["_QQclX445350545253"].apply(null,arguments)}__QQclX445350545253.stub=true;function __QQclX44535445425A(){return wasmImports["_QQclX44535445425A"].apply(null,arguments)}__QQclX44535445425A.stub=true;function __QQclX445354454443(){return wasmImports["_QQclX445354454443"].apply(null,arguments)}__QQclX445354454443.stub=true;function __QQclX44535445494E(){return wasmImports["_QQclX44535445494E"].apply(null,arguments)}__QQclX44535445494E.stub=true;function __QQclX445354454D52(){return wasmImports["_QQclX445354454D52"].apply(null,arguments)}__QQclX445354454D52.stub=true;function __QQclX445354455152(){return wasmImports["_QQclX445354455152"].apply(null,arguments)}__QQclX445354455152.stub=true;function __QQclX445354455246(){return wasmImports["_QQclX445354455246"].apply(null,arguments)}__QQclX445354455246.stub=true;function __QQclX445354455620(){return wasmImports["_QQclX445354455620"].apply(null,arguments)}__QQclX445354455620.stub=true;function __QQclX445354455644(){return wasmImports["_QQclX445354455644"].apply(null,arguments)}__QQclX445354455644.stub=true;function __QQclX445354455652(){return wasmImports["_QQclX445354455652"].apply(null,arguments)}__QQclX445354455652.stub=true;function __QQclX445354455658(){return wasmImports["_QQclX445354455658"].apply(null,arguments)}__QQclX445354455658.stub=true;function __QQclX445359434F4E(){return wasmImports["_QQclX445359434F4E"].apply(null,arguments)}__QQclX445359434F4E.stub=true;function __QQclX445359434F4E56(){return wasmImports["_QQclX445359434F4E56"].apply(null,arguments)}__QQclX445359434F4E56.stub=true;function __QQclX44535945515542(){return wasmImports["_QQclX44535945515542"].apply(null,arguments)}__QQclX44535945515542.stub=true;function __QQclX445359455620(){return wasmImports["_QQclX445359455620"].apply(null,arguments)}__QQclX445359455620.stub=true;function __QQclX445359455644(){return wasmImports["_QQclX445359455644"].apply(null,arguments)}__QQclX445359455644.stub=true;function __QQclX445359455652(){return wasmImports["_QQclX445359455652"].apply(null,arguments)}__QQclX445359455652.stub=true;function __QQclX445359455658(){return wasmImports["_QQclX445359455658"].apply(null,arguments)}__QQclX445359455658.stub=true;function __QQclX445359475332(){return wasmImports["_QQclX445359475332"].apply(null,arguments)}__QQclX445359475332.stub=true;function __QQclX445359475354(){return wasmImports["_QQclX445359475354"].apply(null,arguments)}__QQclX445359475354.stub=true;function __QQclX445359475620(){return wasmImports["_QQclX445359475620"].apply(null,arguments)}__QQclX445359475620.stub=true;function __QQclX445359475644(){return wasmImports["_QQclX445359475644"].apply(null,arguments)}__QQclX445359475644.stub=true;function __QQclX445359475658(){return wasmImports["_QQclX445359475658"].apply(null,arguments)}__QQclX445359475658.stub=true;function __QQclX4453594D4D20(){return wasmImports["_QQclX4453594D4D20"].apply(null,arguments)}__QQclX4453594D4D20.stub=true;function __QQclX4453594D5620(){return wasmImports["_QQclX4453594D5620"].apply(null,arguments)}__QQclX4453594D5620.stub=true;function __QQclX445359522020(){return wasmImports["_QQclX445359522020"].apply(null,arguments)}__QQclX445359522020.stub=true;function __QQclX445359523220(){return wasmImports["_QQclX445359523220"].apply(null,arguments)}__QQclX445359523220.stub=true;function __QQclX44535952324B(){return wasmImports["_QQclX44535952324B"].apply(null,arguments)}__QQclX44535952324B.stub=true;function __QQclX445359524653(){return wasmImports["_QQclX445359524653"].apply(null,arguments)}__QQclX445359524653.stub=true;function __QQclX445359524B20(){return wasmImports["_QQclX445359524B20"].apply(null,arguments)}__QQclX445359524B20.stub=true;function __QQclX445359535620(){return wasmImports["_QQclX445359535620"].apply(null,arguments)}__QQclX445359535620.stub=true;function __QQclX445359535658(){return wasmImports["_QQclX445359535658"].apply(null,arguments)}__QQclX445359535658.stub=true;function __QQclX445359544432(){return wasmImports["_QQclX445359544432"].apply(null,arguments)}__QQclX445359544432.stub=true;function __QQclX445359544632(){return wasmImports["_QQclX445359544632"].apply(null,arguments)}__QQclX445359544632.stub=true;function __QQclX445359545244(){return wasmImports["_QQclX445359545244"].apply(null,arguments)}__QQclX445359545244.stub=true;function __QQclX445359545246(){return wasmImports["_QQclX445359545246"].apply(null,arguments)}__QQclX445359545246.stub=true;function __QQclX445359545249(){return wasmImports["_QQclX445359545249"].apply(null,arguments)}__QQclX445359545249.stub=true;function __QQclX44535954524932(){return wasmImports["_QQclX44535954524932"].apply(null,arguments)}__QQclX44535954524932.stub=true;function __QQclX4453595452493258(){return wasmImports["_QQclX4453595452493258"].apply(null,arguments)}__QQclX4453595452493258.stub=true;function __QQclX445359545253(){return wasmImports["_QQclX445359545253"].apply(null,arguments)}__QQclX445359545253.stub=true;function __QQclX44535954525332(){return wasmImports["_QQclX44535954525332"].apply(null,arguments)}__QQclX44535954525332.stub=true;function __QQclX445442434F4E(){return wasmImports["_QQclX445442434F4E"].apply(null,arguments)}__QQclX445442434F4E.stub=true;function __QQclX4454424D5620(){return wasmImports["_QQclX4454424D5620"].apply(null,arguments)}__QQclX4454424D5620.stub=true;function __QQclX445442524653(){return wasmImports["_QQclX445442524653"].apply(null,arguments)}__QQclX445442524653.stub=true;function __QQclX445442535620(){return wasmImports["_QQclX445442535620"].apply(null,arguments)}__QQclX445442535620.stub=true;function __QQclX445442545253(){return wasmImports["_QQclX445442545253"].apply(null,arguments)}__QQclX445442545253.stub=true;function __QQclX445446534D20(){return wasmImports["_QQclX445446534D20"].apply(null,arguments)}__QQclX445446534D20.stub=true;function __QQclX445446545249(){return wasmImports["_QQclX445446545249"].apply(null,arguments)}__QQclX445446545249.stub=true;function __QQclX445446545450(){return wasmImports["_QQclX445446545450"].apply(null,arguments)}__QQclX445446545450.stub=true;function __QQclX445446545452(){return wasmImports["_QQclX445446545452"].apply(null,arguments)}__QQclX445446545452.stub=true;function __QQclX445447455643(){return wasmImports["_QQclX445447455643"].apply(null,arguments)}__QQclX445447455643.stub=true;function __QQclX445447455843(){return wasmImports["_QQclX445447455843"].apply(null,arguments)}__QQclX445447455843.stub=true;function __QQclX44544753454E(){return wasmImports["_QQclX44544753454E"].apply(null,arguments)}__QQclX44544753454E.stub=true;function __QQclX445447534A41(){return wasmImports["_QQclX445447534A41"].apply(null,arguments)}__QQclX445447534A41.stub=true;function __QQclX445447534E41(){return wasmImports["_QQclX445447534E41"].apply(null,arguments)}__QQclX445447534E41.stub=true;function __QQclX445447535932(){return wasmImports["_QQclX445447535932"].apply(null,arguments)}__QQclX445447535932.stub=true;function __QQclX44544753594C(){return wasmImports["_QQclX44544753594C"].apply(null,arguments)}__QQclX44544753594C.stub=true;function __QQclX445450434F4E(){return wasmImports["_QQclX445450434F4E"].apply(null,arguments)}__QQclX445450434F4E.stub=true;function __QQclX4454504D515254(){return wasmImports["_QQclX4454504D515254"].apply(null,arguments)}__QQclX4454504D515254.stub=true;function __QQclX4454504D5620(){return wasmImports["_QQclX4454504D5620"].apply(null,arguments)}__QQclX4454504D5620.stub=true;function __QQclX445450515254(){return wasmImports["_QQclX445450515254"].apply(null,arguments)}__QQclX445450515254.stub=true;function __QQclX44545051525432(){return wasmImports["_QQclX44545051525432"].apply(null,arguments)}__QQclX44545051525432.stub=true;function __QQclX445450524653(){return wasmImports["_QQclX445450524653"].apply(null,arguments)}__QQclX445450524653.stub=true;function __QQclX445450535620(){return wasmImports["_QQclX445450535620"].apply(null,arguments)}__QQclX445450535620.stub=true;function __QQclX445450545249(){return wasmImports["_QQclX445450545249"].apply(null,arguments)}__QQclX445450545249.stub=true;function __QQclX445450545253(){return wasmImports["_QQclX445450545253"].apply(null,arguments)}__QQclX445450545253.stub=true;function __QQclX445450545446(){return wasmImports["_QQclX445450545446"].apply(null,arguments)}__QQclX445450545446.stub=true;function __QQclX445450545452(){return wasmImports["_QQclX445450545452"].apply(null,arguments)}__QQclX445450545452.stub=true;function __QQclX445452434F4E(){return wasmImports["_QQclX445452434F4E"].apply(null,arguments)}__QQclX445452434F4E.stub=true;function __QQclX445452455643(){return wasmImports["_QQclX445452455643"].apply(null,arguments)}__QQclX445452455643.stub=true;function __QQclX44545245564333(){return wasmImports["_QQclX44545245564333"].apply(null,arguments)}__QQclX44545245564333.stub=true;function __QQclX445452455843(){return wasmImports["_QQclX445452455843"].apply(null,arguments)}__QQclX445452455843.stub=true;function __QQclX4454524D4D20(){return wasmImports["_QQclX4454524D4D20"].apply(null,arguments)}__QQclX4454524D4D20.stub=true;function __QQclX4454524D5620(){return wasmImports["_QQclX4454524D5620"].apply(null,arguments)}__QQclX4454524D5620.stub=true;function __QQclX445452524653(){return wasmImports["_QQclX445452524653"].apply(null,arguments)}__QQclX445452524653.stub=true;function __QQclX44545253454E(){return wasmImports["_QQclX44545253454E"].apply(null,arguments)}__QQclX44545253454E.stub=true;function __QQclX445452534D20(){return wasmImports["_QQclX445452534D20"].apply(null,arguments)}__QQclX445452534D20.stub=true;function __QQclX445452534E41(){return wasmImports["_QQclX445452534E41"].apply(null,arguments)}__QQclX445452534E41.stub=true;function __QQclX445452535620(){return wasmImports["_QQclX445452535620"].apply(null,arguments)}__QQclX445452535620.stub=true;function __QQclX44545253594C(){return wasmImports["_QQclX44545253594C"].apply(null,arguments)}__QQclX44545253594C.stub=true;function __QQclX445452544932(){return wasmImports["_QQclX445452544932"].apply(null,arguments)}__QQclX445452544932.stub=true;function __QQclX445452545249(){return wasmImports["_QQclX445452545249"].apply(null,arguments)}__QQclX445452545249.stub=true;function __QQclX445452545253(){return wasmImports["_QQclX445452545253"].apply(null,arguments)}__QQclX445452545253.stub=true;function __QQclX445452545446(){return wasmImports["_QQclX445452545446"].apply(null,arguments)}__QQclX445452545446.stub=true;function __QQclX445452545450(){return wasmImports["_QQclX445452545450"].apply(null,arguments)}__QQclX445452545450.stub=true;function __QQclX44545A525146(){return wasmImports["_QQclX44545A525146"].apply(null,arguments)}__QQclX44545A525146.stub=true;function __QQclX44545A525A46(){return wasmImports["_QQclX44545A525A46"].apply(null,arguments)}__QQclX44545A525A46.stub=true;function __QQclX45(){return wasmImports["_QQclX45"].apply(null,arguments)}__QQclX45.stub=true;function __QQclX45425A(){return wasmImports["_QQclX45425A"].apply(null,arguments)}__QQclX45425A.stub=true;function __QQclX455053(){return wasmImports["_QQclX455053"].apply(null,arguments)}__QQclX455053.stub=true;function __QQclX455643(){return wasmImports["_QQclX455643"].apply(null,arguments)}__QQclX455643.stub=true;function __QQclX455843(){return wasmImports["_QQclX455843"].apply(null,arguments)}__QQclX455843.stub=true;function __QQclX457073696C6F6E(){return wasmImports["_QQclX457073696C6F6E"].apply(null,arguments)}__QQclX457073696C6F6E.stub=true;function __QQclX46(){return wasmImports["_QQclX46"].apply(null,arguments)}__QQclX46.stub=true;function __QQclX466F7277617264(){return wasmImports["_QQclX466F7277617264"].apply(null,arguments)}__QQclX466F7277617264.stub=true;function __QQclX46756C6C(){return wasmImports["_QQclX46756C6C"].apply(null,arguments)}__QQclX46756C6C.stub=true;function __QQclX47(){return wasmImports["_QQclX47"].apply(null,arguments)}__QQclX47.stub=true;function __QQclX4742(){return wasmImports["_QQclX4742"].apply(null,arguments)}__QQclX4742.stub=true;function __QQclX4742324244(){return wasmImports["_QQclX4742324244"].apply(null,arguments)}__QQclX4742324244.stub=true;function __QQclX4745(){return wasmImports["_QQclX4745"].apply(null,arguments)}__QQclX4745.stub=true;function __QQclX4745324742(){return wasmImports["_QQclX4745324742"].apply(null,arguments)}__QQclX4745324742.stub=true;function __QQclX47454C5146(){return wasmImports["_QQclX47454C5146"].apply(null,arguments)}__QQclX47454C5146.stub=true;function __QQclX4745515246(){return wasmImports["_QQclX4745515246"].apply(null,arguments)}__QQclX4745515246.stub=true;function __QQclX4747(){return wasmImports["_QQclX4747"].apply(null,arguments)}__QQclX4747.stub=true;function __QQclX4747484433(){return wasmImports["_QQclX4747484433"].apply(null,arguments)}__QQclX4747484433.stub=true;function __QQclX4747485244(){return wasmImports["_QQclX4747485244"].apply(null,arguments)}__QQclX4747485244.stub=true;function __QQclX475354(){return wasmImports["_QQclX475354"].apply(null,arguments)}__QQclX475354.stub=true;function __QQclX48(){return wasmImports["_QQclX48"].apply(null,arguments)}__QQclX48.stub=true;function __QQclX4842325354(){return wasmImports["_QQclX4842325354"].apply(null,arguments)}__QQclX4842325354.stub=true;function __QQclX484433(){return wasmImports["_QQclX484433"].apply(null,arguments)}__QQclX484433.stub=true;function __QQclX4845(){return wasmImports["_QQclX4845"].apply(null,arguments)}__QQclX4845.stub=true;function __QQclX4845324842(){return wasmImports["_QQclX4845324842"].apply(null,arguments)}__QQclX4845324842.stub=true;function __QQclX4852(){return wasmImports["_QQclX4852"].apply(null,arguments)}__QQclX4852.stub=true;function __QQclX485244(){return wasmImports["_QQclX485244"].apply(null,arguments)}__QQclX485244.stub=true;function __QQclX4853455152(){return wasmImports["_QQclX4853455152"].apply(null,arguments)}__QQclX4853455152.stub=true;function __QQclX49(){return wasmImports["_QQclX49"].apply(null,arguments)}__QQclX49.stub=true;function __QQclX4A(){return wasmImports["_QQclX4A"].apply(null,arguments)}__QQclX4A.stub=true;function __QQclX4C(){return wasmImports["_QQclX4C"].apply(null,arguments)}__QQclX4C.stub=true;function __QQclX4C20(){return wasmImports["_QQclX4C20"].apply(null,arguments)}__QQclX4C20.stub=true;function __QQclX4C41(){return wasmImports["_QQclX4C41"].apply(null,arguments)}__QQclX4C41.stub=true;function __QQclX4C414F5248(){return wasmImports["_QQclX4C414F5248"].apply(null,arguments)}__QQclX4C414F5248.stub=true;function __QQclX4C415152(){return wasmImports["_QQclX4C415152"].apply(null,arguments)}__QQclX4C415152.stub=true;function __QQclX4C43(){return wasmImports["_QQclX4C43"].apply(null,arguments)}__QQclX4C43.stub=true;function __QQclX4C454654(){return wasmImports["_QQclX4C454654"].apply(null,arguments)}__QQclX4C454654.stub=true;function __QQclX4C4E(){return wasmImports["_QQclX4C4E"].apply(null,arguments)}__QQclX4C4E.stub=true;function __QQclX4C51(){return wasmImports["_QQclX4C51"].apply(null,arguments)}__QQclX4C51.stub=true;function __QQclX4C5120(){return wasmImports["_QQclX4C5120"].apply(null,arguments)}__QQclX4C5120.stub=true;function __QQclX4C5146(){return wasmImports["_QQclX4C5146"].apply(null,arguments)}__QQclX4C5146.stub=true;function __QQclX4C54(){return wasmImports["_QQclX4C54"].apply(null,arguments)}__QQclX4C54.stub=true;function __QQclX4C656674(){return wasmImports["_QQclX4C656674"].apply(null,arguments)}__QQclX4C656674.stub=true;function __QQclX4C6F776572(){return wasmImports["_QQclX4C6F776572"].apply(null,arguments)}__QQclX4C6F776572.stub=true;function __QQclX4D(){return wasmImports["_QQclX4D"].apply(null,arguments)}__QQclX4D.stub=true;function __QQclX4D6178(){return wasmImports["_QQclX4D6178"].apply(null,arguments)}__QQclX4D6178.stub=true;function __QQclX4E(){return wasmImports["_QQclX4E"].apply(null,arguments)}__QQclX4E.stub=true;function __QQclX4E4F205452414E53504F5345(){return wasmImports["_QQclX4E4F205452414E53504F5345"].apply(null,arguments)}__QQclX4E4F205452414E53504F5345.stub=true;function __QQclX4E4F4E2D554E4954(){return wasmImports["_QQclX4E4F4E2D554E4954"].apply(null,arguments)}__QQclX4E4F4E2D554E4954.stub=true;function __QQclX4E6F2051(){return wasmImports["_QQclX4E6F2051"].apply(null,arguments)}__QQclX4E6F2051.stub=true;function __QQclX4E6F205472(){return wasmImports["_QQclX4E6F205472"].apply(null,arguments)}__QQclX4E6F205472.stub=true;function __QQclX4E6F205472616E73(){return wasmImports["_QQclX4E6F205472616E73"].apply(null,arguments)}__QQclX4E6F205472616E73.stub=true;function __QQclX4E6F205472616E73706F7365(){return wasmImports["_QQclX4E6F205472616E73706F7365"].apply(null,arguments)}__QQclX4E6F205472616E73706F7365.stub=true;function __QQclX4E6F205544(){return wasmImports["_QQclX4E6F205544"].apply(null,arguments)}__QQclX4E6F205544.stub=true;function __QQclX4E6F207472616E73706F7365(){return wasmImports["_QQclX4E6F207472616E73706F7365"].apply(null,arguments)}__QQclX4E6F207472616E73706F7365.stub=true;function __QQclX4E6F5472616E73(){return wasmImports["_QQclX4E6F5472616E73"].apply(null,arguments)}__QQclX4E6F5472616E73.stub=true;function __QQclX4E6F55(){return wasmImports["_QQclX4E6F55"].apply(null,arguments)}__QQclX4E6F55.stub=true;function __QQclX4E6F56(){return wasmImports["_QQclX4E6F56"].apply(null,arguments)}__QQclX4E6F56.stub=true;function __QQclX4E6F5F5472(){return wasmImports["_QQclX4E6F5F5472"].apply(null,arguments)}__QQclX4E6F5F5472.stub=true;function __QQclX4E6F6E20756E6974(){return wasmImports["_QQclX4E6F6E20756E6974"].apply(null,arguments)}__QQclX4E6F6E20756E6974.stub=true;function __QQclX4E6F6E2D756E6974(){return wasmImports["_QQclX4E6F6E2D756E6974"].apply(null,arguments)}__QQclX4E6F6E2D756E6974.stub=true;function __QQclX4E6F6E756E6974(){return wasmImports["_QQclX4E6F6E756E6974"].apply(null,arguments)}__QQclX4E6F6E756E6974.stub=true;function __QQclX4F(){return wasmImports["_QQclX4F"].apply(null,arguments)}__QQclX4F.stub=true;function __QQclX4F52(){return wasmImports["_QQclX4F52"].apply(null,arguments)}__QQclX4F52.stub=true;function __QQclX4F766572666C6F77(){return wasmImports["_QQclX4F766572666C6F77"].apply(null,arguments)}__QQclX4F766572666C6F77.stub=true;function __QQclX4F766572666C6F77207468726573686F6C64(){return wasmImports["_QQclX4F766572666C6F77207468726573686F6C64"].apply(null,arguments)}__QQclX4F766572666C6F77207468726573686F6C64.stub=true;function __QQclX50(){return wasmImports["_QQclX50"].apply(null,arguments)}__QQclX50.stub=true;function __QQclX5042(){return wasmImports["_QQclX5042"].apply(null,arguments)}__QQclX5042.stub=true;function __QQclX504C4E(){return wasmImports["_QQclX504C4E"].apply(null,arguments)}__QQclX504C4E.stub=true;function __QQclX504F(){return wasmImports["_QQclX504F"].apply(null,arguments)}__QQclX504F.stub=true;function __QQclX505245434953494F4E(){return wasmImports["_QQclX505245434953494F4E"].apply(null,arguments)}__QQclX505245434953494F4E.stub=true;function __QQclX507265636973696F6E(){return wasmImports["_QQclX507265636973696F6E"].apply(null,arguments)}__QQclX507265636973696F6E.stub=true;function __QQclX51(){return wasmImports["_QQclX51"].apply(null,arguments)}__QQclX51.stub=true;function __QQclX514C(){return wasmImports["_QQclX514C"].apply(null,arguments)}__QQclX514C.stub=true;function __QQclX514C43(){return wasmImports["_QQclX514C43"].apply(null,arguments)}__QQclX514C43.stub=true;function __QQclX514C46(){return wasmImports["_QQclX514C46"].apply(null,arguments)}__QQclX514C46.stub=true;function __QQclX514C54(){return wasmImports["_QQclX514C54"].apply(null,arguments)}__QQclX514C54.stub=true;function __QQclX515033524B(){return wasmImports["_QQclX515033524B"].apply(null,arguments)}__QQclX515033524B.stub=true;function __QQclX5152(){return wasmImports["_QQclX5152"].apply(null,arguments)}__QQclX5152.stub=true;function __QQclX515220(){return wasmImports["_QQclX515220"].apply(null,arguments)}__QQclX515220.stub=true;function __QQclX515246(){return wasmImports["_QQclX515246"].apply(null,arguments)}__QQclX515246.stub=true;function __QQclX52(){return wasmImports["_QQclX52"].apply(null,arguments)}__QQclX52.stub=true;function __QQclX5249474854(){return wasmImports["_QQclX5249474854"].apply(null,arguments)}__QQclX5249474854.stub=true;function __QQclX5251(){return wasmImports["_QQclX5251"].apply(null,arguments)}__QQclX5251.stub=true;function __QQclX525146(){return wasmImports["_QQclX525146"].apply(null,arguments)}__QQclX525146.stub=true;function __QQclX5269676874(){return wasmImports["_QQclX5269676874"].apply(null,arguments)}__QQclX5269676874.stub=true;function __QQclX526F7777697365(){return wasmImports["_QQclX526F7777697365"].apply(null,arguments)}__QQclX526F7777697365.stub=true;function __QQclX53(){return wasmImports["_QQclX53"].apply(null,arguments)}__QQclX53.stub=true;function __QQclX53414645204D494E494D554D(){return wasmImports["_QQclX53414645204D494E494D554D"].apply(null,arguments)}__QQclX53414645204D494E494D554D.stub=true;function __QQclX534146454D494E(){return wasmImports["_QQclX534146454D494E"].apply(null,arguments)}__QQclX534146454D494E.stub=true;function __QQclX5342325354(){return wasmImports["_QQclX5342325354"].apply(null,arguments)}__QQclX5342325354.stub=true;function __QQclX5354(){return wasmImports["_QQclX5354"].apply(null,arguments)}__QQclX5354.stub=true;function __QQclX5356(){return wasmImports["_QQclX5356"].apply(null,arguments)}__QQclX5356.stub=true;function __QQclX5359(){return wasmImports["_QQclX5359"].apply(null,arguments)}__QQclX5359.stub=true;function __QQclX5359325342(){return wasmImports["_QQclX5359325342"].apply(null,arguments)}__QQclX5359325342.stub=true;function __QQclX53594C(){return wasmImports["_QQclX53594C"].apply(null,arguments)}__QQclX53594C.stub=true;function __QQclX5361664D696E(){return wasmImports["_QQclX5361664D696E"].apply(null,arguments)}__QQclX5361664D696E.stub=true;function __QQclX53616665204D696E696D756D(){return wasmImports["_QQclX53616665204D696E696D756D"].apply(null,arguments)}__QQclX53616665204D696E696D756D.stub=true;function __QQclX53616665206D696E696D756D(){return wasmImports["_QQclX53616665206D696E696D756D"].apply(null,arguments)}__QQclX53616665206D696E696D756D.stub=true;function __QQclX536166654D696E696D756D(){return wasmImports["_QQclX536166654D696E696D756D"].apply(null,arguments)}__QQclX536166654D696E696D756D.stub=true;function __QQclX54(){return wasmImports["_QQclX54"].apply(null,arguments)}__QQclX54.stub=true;function __QQclX5452(){return wasmImports["_QQclX5452"].apply(null,arguments)}__QQclX5452.stub=true;function __QQclX545244(){return wasmImports["_QQclX545244"].apply(null,arguments)}__QQclX545244.stub=true;function __QQclX545246(){return wasmImports["_QQclX545246"].apply(null,arguments)}__QQclX545246.stub=true;function __QQclX545249(){return wasmImports["_QQclX545249"].apply(null,arguments)}__QQclX545249.stub=true;function __QQclX545253(){return wasmImports["_QQclX545253"].apply(null,arguments)}__QQclX545253.stub=true;function __QQclX5472616E73(){return wasmImports["_QQclX5472616E73"].apply(null,arguments)}__QQclX5472616E73.stub=true;function __QQclX5472616E73706F7365(){return wasmImports["_QQclX5472616E73706F7365"].apply(null,arguments)}__QQclX5472616E73706F7365.stub=true;function __QQclX55(){return wasmImports["_QQclX55"].apply(null,arguments)}__QQclX55.stub=true;function __QQclX554E(){return wasmImports["_QQclX554E"].apply(null,arguments)}__QQclX554E.stub=true;function __QQclX554E4954(){return wasmImports["_QQclX554E4954"].apply(null,arguments)}__QQclX554E4954.stub=true;function __QQclX55554D(){return wasmImports["_QQclX55554D"].apply(null,arguments)}__QQclX55554D.stub=true;function __QQclX556E6974(){return wasmImports["_QQclX556E6974"].apply(null,arguments)}__QQclX556E6974.stub=true;function __QQclX5570706572(){return wasmImports["_QQclX5570706572"].apply(null,arguments)}__QQclX5570706572.stub=true;function __QQclX56(){return wasmImports["_QQclX56"].apply(null,arguments)}__QQclX56.stub=true;function __QQclX57(){return wasmImports["_QQclX57"].apply(null,arguments)}__QQclX57.stub=true;function __QQclX58(){return wasmImports["_QQclX58"].apply(null,arguments)}__QQclX58.stub=true;function __QQclX59(){return wasmImports["_QQclX59"].apply(null,arguments)}__QQclX59.stub=true;function __QQclX5A(){return wasmImports["_QQclX5A"].apply(null,arguments)}__QQclX5A.stub=true;function __QQclX5A4244535152(){return wasmImports["_QQclX5A4244535152"].apply(null,arguments)}__QQclX5A4244535152.stub=true;function __QQclX5A4742434F4E(){return wasmImports["_QQclX5A4742434F4E"].apply(null,arguments)}__QQclX5A4742434F4E.stub=true;function __QQclX5A4742455155(){return wasmImports["_QQclX5A4742455155"].apply(null,arguments)}__QQclX5A4742455155.stub=true;function __QQclX5A47424D5620(){return wasmImports["_QQclX5A47424D5620"].apply(null,arguments)}__QQclX5A47424D5620.stub=true;function __QQclX5A4742524653(){return wasmImports["_QQclX5A4742524653"].apply(null,arguments)}__QQclX5A4742524653.stub=true;function __QQclX5A4742535620(){return wasmImports["_QQclX5A4742535620"].apply(null,arguments)}__QQclX5A4742535620.stub=true;function __QQclX5A4742535658(){return wasmImports["_QQclX5A4742535658"].apply(null,arguments)}__QQclX5A4742535658.stub=true;function __QQclX5A4742544632(){return wasmImports["_QQclX5A4742544632"].apply(null,arguments)}__QQclX5A4742544632.stub=true;function __QQclX5A4742545246(){return wasmImports["_QQclX5A4742545246"].apply(null,arguments)}__QQclX5A4742545246.stub=true;function __QQclX5A4742545253(){return wasmImports["_QQclX5A4742545253"].apply(null,arguments)}__QQclX5A4742545253.stub=true;function __QQclX5A474542414B(){return wasmImports["_QQclX5A474542414B"].apply(null,arguments)}__QQclX5A474542414B.stub=true;function __QQclX5A474542414C(){return wasmImports["_QQclX5A474542414C"].apply(null,arguments)}__QQclX5A474542414C.stub=true;function __QQclX5A4745424432(){return wasmImports["_QQclX5A4745424432"].apply(null,arguments)}__QQclX5A4745424432.stub=true;function __QQclX5A4745425244(){return wasmImports["_QQclX5A4745425244"].apply(null,arguments)}__QQclX5A4745425244.stub=true;function __QQclX5A4745434F4E(){return wasmImports["_QQclX5A4745434F4E"].apply(null,arguments)}__QQclX5A4745434F4E.stub=true;function __QQclX5A4745455155(){return wasmImports["_QQclX5A4745455155"].apply(null,arguments)}__QQclX5A4745455155.stub=true;function __QQclX5A4745455320(){return wasmImports["_QQclX5A4745455320"].apply(null,arguments)}__QQclX5A4745455320.stub=true;function __QQclX5A4745455620(){return wasmImports["_QQclX5A4745455620"].apply(null,arguments)}__QQclX5A4745455620.stub=true;function __QQclX5A4745455658(){return wasmImports["_QQclX5A4745455658"].apply(null,arguments)}__QQclX5A4745455658.stub=true;function __QQclX5A4745484432(){return wasmImports["_QQclX5A4745484432"].apply(null,arguments)}__QQclX5A4745484432.stub=true;function __QQclX5A4745485244(){return wasmImports["_QQclX5A4745485244"].apply(null,arguments)}__QQclX5A4745485244.stub=true;function __QQclX5A47454C5132(){return wasmImports["_QQclX5A47454C5132"].apply(null,arguments)}__QQclX5A47454C5132.stub=true;function __QQclX5A47454C5146(){return wasmImports["_QQclX5A47454C5146"].apply(null,arguments)}__QQclX5A47454C5146.stub=true;function __QQclX5A47454C5320(){return wasmImports["_QQclX5A47454C5320"].apply(null,arguments)}__QQclX5A47454C5320.stub=true;function __QQclX5A47454C5344(){return wasmImports["_QQclX5A47454C5344"].apply(null,arguments)}__QQclX5A47454C5344.stub=true;function __QQclX5A47454D4D20(){return wasmImports["_QQclX5A47454D4D20"].apply(null,arguments)}__QQclX5A47454D4D20.stub=true;function __QQclX5A47454D5620(){return wasmImports["_QQclX5A47454D5620"].apply(null,arguments)}__QQclX5A47454D5620.stub=true;function __QQclX5A4745515033(){return wasmImports["_QQclX5A4745515033"].apply(null,arguments)}__QQclX5A4745515033.stub=true;function __QQclX5A4745515232(){return wasmImports["_QQclX5A4745515232"].apply(null,arguments)}__QQclX5A4745515232.stub=true;function __QQclX5A4745515246(){return wasmImports["_QQclX5A4745515246"].apply(null,arguments)}__QQclX5A4745515246.stub=true;function __QQclX5A4745524320(){return wasmImports["_QQclX5A4745524320"].apply(null,arguments)}__QQclX5A4745524320.stub=true;function __QQclX5A4745524653(){return wasmImports["_QQclX5A4745524653"].apply(null,arguments)}__QQclX5A4745524653.stub=true;function __QQclX5A4745525520(){return wasmImports["_QQclX5A4745525520"].apply(null,arguments)}__QQclX5A4745525520.stub=true;function __QQclX5A4745534444(){return wasmImports["_QQclX5A4745534444"].apply(null,arguments)}__QQclX5A4745534444.stub=true;function __QQclX5A4745535620(){return wasmImports["_QQclX5A4745535620"].apply(null,arguments)}__QQclX5A4745535620.stub=true;function __QQclX5A4745535644(){return wasmImports["_QQclX5A4745535644"].apply(null,arguments)}__QQclX5A4745535644.stub=true;function __QQclX5A4745535658(){return wasmImports["_QQclX5A4745535658"].apply(null,arguments)}__QQclX5A4745535658.stub=true;function __QQclX5A4745544632(){return wasmImports["_QQclX5A4745544632"].apply(null,arguments)}__QQclX5A4745544632.stub=true;function __QQclX5A4745545246(){return wasmImports["_QQclX5A4745545246"].apply(null,arguments)}__QQclX5A4745545246.stub=true;function __QQclX5A474554524632(){return wasmImports["_QQclX5A474554524632"].apply(null,arguments)}__QQclX5A474554524632.stub=true;function __QQclX5A4745545249(){return wasmImports["_QQclX5A4745545249"].apply(null,arguments)}__QQclX5A4745545249.stub=true;function __QQclX5A4745545253(){return wasmImports["_QQclX5A4745545253"].apply(null,arguments)}__QQclX5A4745545253.stub=true;function __QQclX5A474742414B(){return wasmImports["_QQclX5A474742414B"].apply(null,arguments)}__QQclX5A474742414B.stub=true;function __QQclX5A474742414C(){return wasmImports["_QQclX5A474742414C"].apply(null,arguments)}__QQclX5A474742414C.stub=true;function __QQclX5A4747455320(){return wasmImports["_QQclX5A4747455320"].apply(null,arguments)}__QQclX5A4747455320.stub=true;function __QQclX5A4747455620(){return wasmImports["_QQclX5A4747455620"].apply(null,arguments)}__QQclX5A4747455620.stub=true;function __QQclX5A4747485244(){return wasmImports["_QQclX5A4747485244"].apply(null,arguments)}__QQclX5A4747485244.stub=true;function __QQclX5A4754434F4E(){return wasmImports["_QQclX5A4754434F4E"].apply(null,arguments)}__QQclX5A4754434F4E.stub=true;function __QQclX5A4754524653(){return wasmImports["_QQclX5A4754524653"].apply(null,arguments)}__QQclX5A4754524653.stub=true;function __QQclX5A4754535620(){return wasmImports["_QQclX5A4754535620"].apply(null,arguments)}__QQclX5A4754535620.stub=true;function __QQclX5A4754535658(){return wasmImports["_QQclX5A4754535658"].apply(null,arguments)}__QQclX5A4754535658.stub=true;function __QQclX5A4754545246(){return wasmImports["_QQclX5A4754545246"].apply(null,arguments)}__QQclX5A4754545246.stub=true;function __QQclX5A4754545253(){return wasmImports["_QQclX5A4754545253"].apply(null,arguments)}__QQclX5A4754545253.stub=true;function __QQclX5A48424D5620(){return wasmImports["_QQclX5A48424D5620"].apply(null,arguments)}__QQclX5A48424D5620.stub=true;function __QQclX5A4845434F4E(){return wasmImports["_QQclX5A4845434F4E"].apply(null,arguments)}__QQclX5A4845434F4E.stub=true;function __QQclX5A4845455620(){return wasmImports["_QQclX5A4845455620"].apply(null,arguments)}__QQclX5A4845455620.stub=true;function __QQclX5A4845455644(){return wasmImports["_QQclX5A4845455644"].apply(null,arguments)}__QQclX5A4845455644.stub=true;function __QQclX5A48454D4D20(){return wasmImports["_QQclX5A48454D4D20"].apply(null,arguments)}__QQclX5A48454D4D20.stub=true;function __QQclX5A48454D5620(){return wasmImports["_QQclX5A48454D5620"].apply(null,arguments)}__QQclX5A48454D5620.stub=true;function __QQclX5A4845522020(){return wasmImports["_QQclX5A4845522020"].apply(null,arguments)}__QQclX5A4845522020.stub=true;function __QQclX5A4845523220(){return wasmImports["_QQclX5A4845523220"].apply(null,arguments)}__QQclX5A4845523220.stub=true;function __QQclX5A484552324B(){return wasmImports["_QQclX5A484552324B"].apply(null,arguments)}__QQclX5A484552324B.stub=true;function __QQclX5A4845524B20(){return wasmImports["_QQclX5A4845524B20"].apply(null,arguments)}__QQclX5A4845524B20.stub=true;function __QQclX5A4845544432(){return wasmImports["_QQclX5A4845544432"].apply(null,arguments)}__QQclX5A4845544432.stub=true;function __QQclX5A4845544632(){return wasmImports["_QQclX5A4845544632"].apply(null,arguments)}__QQclX5A4845544632.stub=true;function __QQclX5A4845545244(){return wasmImports["_QQclX5A4845545244"].apply(null,arguments)}__QQclX5A4845545244.stub=true;function __QQclX5A4845545246(){return wasmImports["_QQclX5A4845545246"].apply(null,arguments)}__QQclX5A4845545246.stub=true;function __QQclX5A4845545249(){return wasmImports["_QQclX5A4845545249"].apply(null,arguments)}__QQclX5A4845545249.stub=true;function __QQclX5A4845545253(){return wasmImports["_QQclX5A4845545253"].apply(null,arguments)}__QQclX5A4845545253.stub=true;function __QQclX5A484745515A(){return wasmImports["_QQclX5A484745515A"].apply(null,arguments)}__QQclX5A484745515A.stub=true;function __QQclX5A4850434F4E(){return wasmImports["_QQclX5A4850434F4E"].apply(null,arguments)}__QQclX5A4850434F4E.stub=true;function __QQclX5A4850455620(){return wasmImports["_QQclX5A4850455620"].apply(null,arguments)}__QQclX5A4850455620.stub=true;function __QQclX5A48504D5620(){return wasmImports["_QQclX5A48504D5620"].apply(null,arguments)}__QQclX5A48504D5620.stub=true;function __QQclX5A4850522020(){return wasmImports["_QQclX5A4850522020"].apply(null,arguments)}__QQclX5A4850522020.stub=true;function __QQclX5A4850523220(){return wasmImports["_QQclX5A4850523220"].apply(null,arguments)}__QQclX5A4850523220.stub=true;function __QQclX5A4850545244(){return wasmImports["_QQclX5A4850545244"].apply(null,arguments)}__QQclX5A4850545244.stub=true;function __QQclX5A4850545246(){return wasmImports["_QQclX5A4850545246"].apply(null,arguments)}__QQclX5A4850545246.stub=true;function __QQclX5A4850545249(){return wasmImports["_QQclX5A4850545249"].apply(null,arguments)}__QQclX5A4850545249.stub=true;function __QQclX5A4850545253(){return wasmImports["_QQclX5A4850545253"].apply(null,arguments)}__QQclX5A4850545253.stub=true;function __QQclX5A4853455152(){return wasmImports["_QQclX5A4853455152"].apply(null,arguments)}__QQclX5A4853455152.stub=true;function __QQclX5A4C41454430(){return wasmImports["_QQclX5A4C41454430"].apply(null,arguments)}__QQclX5A4C41454430.stub=true;function __QQclX5A4C41454437(){return wasmImports["_QQclX5A4C41454437"].apply(null,arguments)}__QQclX5A4C41454437.stub=true;function __QQclX5A4C41454438(){return wasmImports["_QQclX5A4C41454438"].apply(null,arguments)}__QQclX5A4C41454438.stub=true;function __QQclX5A4C414C5330(){return wasmImports["_QQclX5A4C414C5330"].apply(null,arguments)}__QQclX5A4C414C5330.stub=true;function __QQclX5A4C414C5341(){return wasmImports["_QQclX5A4C414C5341"].apply(null,arguments)}__QQclX5A4C414C5341.stub=true;function __QQclX5A4C414C5344(){return wasmImports["_QQclX5A4C414C5344"].apply(null,arguments)}__QQclX5A4C414C5344.stub=true;function __QQclX5A4C41515230(){return wasmImports["_QQclX5A4C41515230"].apply(null,arguments)}__QQclX5A4C41515230.stub=true;function __QQclX5A4C41515233(){return wasmImports["_QQclX5A4C41515233"].apply(null,arguments)}__QQclX5A4C41515233.stub=true;function __QQclX5A4C41515234(){return wasmImports["_QQclX5A4C41515234"].apply(null,arguments)}__QQclX5A4C41515234.stub=true;function __QQclX5A4C4153434C(){return wasmImports["_QQclX5A4C4153434C"].apply(null,arguments)}__QQclX5A4C4153434C.stub=true;function __QQclX5A4C41535220(){return wasmImports["_QQclX5A4C41535220"].apply(null,arguments)}__QQclX5A4C41535220.stub=true;function __QQclX5A4C41544253(){return wasmImports["_QQclX5A4C41544253"].apply(null,arguments)}__QQclX5A4C41544253.stub=true;function __QQclX5A4C41545053(){return wasmImports["_QQclX5A4C41545053"].apply(null,arguments)}__QQclX5A4C41545053.stub=true;function __QQclX5A4C41545253(){return wasmImports["_QQclX5A4C41545253"].apply(null,arguments)}__QQclX5A4C41545253.stub=true;function __QQclX5A4C41555532(){return wasmImports["_QQclX5A4C41555532"].apply(null,arguments)}__QQclX5A4C41555532.stub=true;function __QQclX5A4C4155554D(){return wasmImports["_QQclX5A4C4155554D"].apply(null,arguments)}__QQclX5A4C4155554D.stub=true;function __QQclX5A5042544632(){return wasmImports["_QQclX5A5042544632"].apply(null,arguments)}__QQclX5A5042544632.stub=true;function __QQclX5A5042545246(){return wasmImports["_QQclX5A5042545246"].apply(null,arguments)}__QQclX5A5042545246.stub=true;function __QQclX5A504F434F4E(){return wasmImports["_QQclX5A504F434F4E"].apply(null,arguments)}__QQclX5A504F434F4E.stub=true;function __QQclX5A504F455155(){return wasmImports["_QQclX5A504F455155"].apply(null,arguments)}__QQclX5A504F455155.stub=true;function __QQclX5A504F524653(){return wasmImports["_QQclX5A504F524653"].apply(null,arguments)}__QQclX5A504F524653.stub=true;function __QQclX5A504F535620(){return wasmImports["_QQclX5A504F535620"].apply(null,arguments)}__QQclX5A504F535620.stub=true;function __QQclX5A504F535658(){return wasmImports["_QQclX5A504F535658"].apply(null,arguments)}__QQclX5A504F535658.stub=true;function __QQclX5A504F544632(){return wasmImports["_QQclX5A504F544632"].apply(null,arguments)}__QQclX5A504F544632.stub=true;function __QQclX5A504F545246(){return wasmImports["_QQclX5A504F545246"].apply(null,arguments)}__QQclX5A504F545246.stub=true;function __QQclX5A504F54524632(){return wasmImports["_QQclX5A504F54524632"].apply(null,arguments)}__QQclX5A504F54524632.stub=true;function __QQclX5A504F545249(){return wasmImports["_QQclX5A504F545249"].apply(null,arguments)}__QQclX5A504F545249.stub=true;function __QQclX5A504F545253(){return wasmImports["_QQclX5A504F545253"].apply(null,arguments)}__QQclX5A504F545253.stub=true;function __QQclX5A5050434F4E(){return wasmImports["_QQclX5A5050434F4E"].apply(null,arguments)}__QQclX5A5050434F4E.stub=true;function __QQclX5A5050545246(){return wasmImports["_QQclX5A5050545246"].apply(null,arguments)}__QQclX5A5050545246.stub=true;function __QQclX5A5050545249(){return wasmImports["_QQclX5A5050545249"].apply(null,arguments)}__QQclX5A5050545249.stub=true;function __QQclX5A5050545253(){return wasmImports["_QQclX5A5050545253"].apply(null,arguments)}__QQclX5A5050545253.stub=true;function __QQclX5A5053544632(){return wasmImports["_QQclX5A5053544632"].apply(null,arguments)}__QQclX5A5053544632.stub=true;function __QQclX5A5053545246(){return wasmImports["_QQclX5A5053545246"].apply(null,arguments)}__QQclX5A5053545246.stub=true;function __QQclX5A5350434F4E(){return wasmImports["_QQclX5A5350434F4E"].apply(null,arguments)}__QQclX5A5350434F4E.stub=true;function __QQclX5A53504D5620(){return wasmImports["_QQclX5A53504D5620"].apply(null,arguments)}__QQclX5A53504D5620.stub=true;function __QQclX5A5350522020(){return wasmImports["_QQclX5A5350522020"].apply(null,arguments)}__QQclX5A5350522020.stub=true;function __QQclX5A5350545246(){return wasmImports["_QQclX5A5350545246"].apply(null,arguments)}__QQclX5A5350545246.stub=true;function __QQclX5A5350545249(){return wasmImports["_QQclX5A5350545249"].apply(null,arguments)}__QQclX5A5350545249.stub=true;function __QQclX5A5350545253(){return wasmImports["_QQclX5A5350545253"].apply(null,arguments)}__QQclX5A5350545253.stub=true;function __QQclX5A5354454443(){return wasmImports["_QQclX5A5354454443"].apply(null,arguments)}__QQclX5A5354454443.stub=true;function __QQclX5A5354455152(){return wasmImports["_QQclX5A5354455152"].apply(null,arguments)}__QQclX5A5354455152.stub=true;function __QQclX5A5359434F4E(){return wasmImports["_QQclX5A5359434F4E"].apply(null,arguments)}__QQclX5A5359434F4E.stub=true;function __QQclX5A53594D4D20(){return wasmImports["_QQclX5A53594D4D20"].apply(null,arguments)}__QQclX5A53594D4D20.stub=true;function __QQclX5A53594D5620(){return wasmImports["_QQclX5A53594D5620"].apply(null,arguments)}__QQclX5A53594D5620.stub=true;function __QQclX5A5359522020(){return wasmImports["_QQclX5A5359522020"].apply(null,arguments)}__QQclX5A5359522020.stub=true;function __QQclX5A535952324B(){return wasmImports["_QQclX5A535952324B"].apply(null,arguments)}__QQclX5A535952324B.stub=true;function __QQclX5A5359524B20(){return wasmImports["_QQclX5A5359524B20"].apply(null,arguments)}__QQclX5A5359524B20.stub=true;function __QQclX5A5359544632(){return wasmImports["_QQclX5A5359544632"].apply(null,arguments)}__QQclX5A5359544632.stub=true;function __QQclX5A5359545246(){return wasmImports["_QQclX5A5359545246"].apply(null,arguments)}__QQclX5A5359545246.stub=true;function __QQclX5A5359545249(){return wasmImports["_QQclX5A5359545249"].apply(null,arguments)}__QQclX5A5359545249.stub=true;function __QQclX5A5359545253(){return wasmImports["_QQclX5A5359545253"].apply(null,arguments)}__QQclX5A5359545253.stub=true;function __QQclX5A54424D5620(){return wasmImports["_QQclX5A54424D5620"].apply(null,arguments)}__QQclX5A54424D5620.stub=true;function __QQclX5A5442535620(){return wasmImports["_QQclX5A5442535620"].apply(null,arguments)}__QQclX5A5442535620.stub=true;function __QQclX5A5447455643(){return wasmImports["_QQclX5A5447455643"].apply(null,arguments)}__QQclX5A5447455643.stub=true;function __QQclX5A5447455843(){return wasmImports["_QQclX5A5447455843"].apply(null,arguments)}__QQclX5A5447455843.stub=true;function __QQclX5A544753454E(){return wasmImports["_QQclX5A544753454E"].apply(null,arguments)}__QQclX5A544753454E.stub=true;function __QQclX5A5447535932(){return wasmImports["_QQclX5A5447535932"].apply(null,arguments)}__QQclX5A5447535932.stub=true;function __QQclX5A544753594C(){return wasmImports["_QQclX5A544753594C"].apply(null,arguments)}__QQclX5A544753594C.stub=true;function __QQclX5A5450434F4E(){return wasmImports["_QQclX5A5450434F4E"].apply(null,arguments)}__QQclX5A5450434F4E.stub=true;function __QQclX5A54504D5620(){return wasmImports["_QQclX5A54504D5620"].apply(null,arguments)}__QQclX5A54504D5620.stub=true;function __QQclX5A5450535620(){return wasmImports["_QQclX5A5450535620"].apply(null,arguments)}__QQclX5A5450535620.stub=true;function __QQclX5A5450545249(){return wasmImports["_QQclX5A5450545249"].apply(null,arguments)}__QQclX5A5450545249.stub=true;function __QQclX5A5450545253(){return wasmImports["_QQclX5A5450545253"].apply(null,arguments)}__QQclX5A5450545253.stub=true;function __QQclX5A5452434F4E(){return wasmImports["_QQclX5A5452434F4E"].apply(null,arguments)}__QQclX5A5452434F4E.stub=true;function __QQclX5A5452455643(){return wasmImports["_QQclX5A5452455643"].apply(null,arguments)}__QQclX5A5452455643.stub=true;function __QQclX5A545245564333(){return wasmImports["_QQclX5A545245564333"].apply(null,arguments)}__QQclX5A545245564333.stub=true;function __QQclX5A5452455843(){return wasmImports["_QQclX5A5452455843"].apply(null,arguments)}__QQclX5A5452455843.stub=true;function __QQclX5A54524D4D20(){return wasmImports["_QQclX5A54524D4D20"].apply(null,arguments)}__QQclX5A54524D4D20.stub=true;function __QQclX5A54524D5620(){return wasmImports["_QQclX5A54524D5620"].apply(null,arguments)}__QQclX5A54524D5620.stub=true;function __QQclX5A545253454E(){return wasmImports["_QQclX5A545253454E"].apply(null,arguments)}__QQclX5A545253454E.stub=true;function __QQclX5A5452534D20(){return wasmImports["_QQclX5A5452534D20"].apply(null,arguments)}__QQclX5A5452534D20.stub=true;function __QQclX5A5452534E41(){return wasmImports["_QQclX5A5452534E41"].apply(null,arguments)}__QQclX5A5452534E41.stub=true;function __QQclX5A5452535620(){return wasmImports["_QQclX5A5452535620"].apply(null,arguments)}__QQclX5A5452535620.stub=true;function __QQclX5A545253594C(){return wasmImports["_QQclX5A545253594C"].apply(null,arguments)}__QQclX5A545253594C.stub=true;function __QQclX5A5452544932(){return wasmImports["_QQclX5A5452544932"].apply(null,arguments)}__QQclX5A5452544932.stub=true;function __QQclX5A5452545249(){return wasmImports["_QQclX5A5452545249"].apply(null,arguments)}__QQclX5A5452545249.stub=true;function __QQclX5A5452545253(){return wasmImports["_QQclX5A5452545253"].apply(null,arguments)}__QQclX5A5452545253.stub=true;function __QQclX5A554E47324C(){return wasmImports["_QQclX5A554E47324C"].apply(null,arguments)}__QQclX5A554E47324C.stub=true;function __QQclX5A554E473252(){return wasmImports["_QQclX5A554E473252"].apply(null,arguments)}__QQclX5A554E473252.stub=true;function __QQclX5A554E474252(){return wasmImports["_QQclX5A554E474252"].apply(null,arguments)}__QQclX5A554E474252.stub=true;function __QQclX5A554E474852(){return wasmImports["_QQclX5A554E474852"].apply(null,arguments)}__QQclX5A554E474852.stub=true;function __QQclX5A554E474C32(){return wasmImports["_QQclX5A554E474C32"].apply(null,arguments)}__QQclX5A554E474C32.stub=true;function __QQclX5A554E474C51(){return wasmImports["_QQclX5A554E474C51"].apply(null,arguments)}__QQclX5A554E474C51.stub=true;function __QQclX5A554E47514C(){return wasmImports["_QQclX5A554E47514C"].apply(null,arguments)}__QQclX5A554E47514C.stub=true;function __QQclX5A554E475152(){return wasmImports["_QQclX5A554E475152"].apply(null,arguments)}__QQclX5A554E475152.stub=true;function __QQclX5A554E475232(){return wasmImports["_QQclX5A554E475232"].apply(null,arguments)}__QQclX5A554E475232.stub=true;function __QQclX5A554E475251(){return wasmImports["_QQclX5A554E475251"].apply(null,arguments)}__QQclX5A554E475251.stub=true;function __QQclX5A554E475452(){return wasmImports["_QQclX5A554E475452"].apply(null,arguments)}__QQclX5A554E475452.stub=true;function __QQclX5A554E4D324C(){return wasmImports["_QQclX5A554E4D324C"].apply(null,arguments)}__QQclX5A554E4D324C.stub=true;function __QQclX5A554E4D3252(){return wasmImports["_QQclX5A554E4D3252"].apply(null,arguments)}__QQclX5A554E4D3252.stub=true;function __QQclX5A554E4D4252(){return wasmImports["_QQclX5A554E4D4252"].apply(null,arguments)}__QQclX5A554E4D4252.stub=true;function __QQclX5A554E4D4852(){return wasmImports["_QQclX5A554E4D4852"].apply(null,arguments)}__QQclX5A554E4D4852.stub=true;function __QQclX5A554E4D4C32(){return wasmImports["_QQclX5A554E4D4C32"].apply(null,arguments)}__QQclX5A554E4D4C32.stub=true;function __QQclX5A554E4D4C51(){return wasmImports["_QQclX5A554E4D4C51"].apply(null,arguments)}__QQclX5A554E4D4C51.stub=true;function __QQclX5A554E4D514C(){return wasmImports["_QQclX5A554E4D514C"].apply(null,arguments)}__QQclX5A554E4D514C.stub=true;function __QQclX5A554E4D5152(){return wasmImports["_QQclX5A554E4D5152"].apply(null,arguments)}__QQclX5A554E4D5152.stub=true;function __QQclX5A554E4D5452(){return wasmImports["_QQclX5A554E4D5452"].apply(null,arguments)}__QQclX5A554E4D5452.stub=true;function __QQclX5A5550475452(){return wasmImports["_QQclX5A5550475452"].apply(null,arguments)}__QQclX5A5550475452.stub=true;function __QQclX63(){return wasmImports["_QQclX63"].apply(null,arguments)}__QQclX63.stub=true;function __QQclX6E(){return wasmImports["_QQclX6E"].apply(null,arguments)}__QQclX6E.stub=true;function __QQclX74(){return wasmImports["_QQclX74"].apply(null,arguments)}__QQclX74.stub=true;function __QQclX784F52424442(){return wasmImports["_QQclX784F52424442"].apply(null,arguments)}__QQclX784F52424442.stub=true;function __QQclXd508bd4b36136b084c68941b4b791b1d(){return wasmImports["_QQclXd508bd4b36136b084c68941b4b791b1d"].apply(null,arguments)}__QQclXd508bd4b36136b084c68941b4b791b1d.stub=true;var ___assert_fail=(condition,filename,line,func)=>{abort(`Assertion failed: ${UTF8ToString(condition)}, at: `+[filename?UTF8ToString(filename):"unknown filename",line,func?UTF8ToString(func):"unknown function"])};___assert_fail.sig="vppip";var ___c_longjmp=new WebAssembly.Tag({"parameters":["i32"]});var ___call_sighandler=(fp,sig)=>getWasmTableEntry(fp)(sig);___call_sighandler.sig="vpi";var ___cpp_exception=new WebAssembly.Tag({"parameters":["i32"]});var ___memory_base=new WebAssembly.Global({"value":"i32","mutable":false},1024);var ___stack_high=10476800;var ___stack_low=9428224;var ___stack_pointer=new WebAssembly.Global({"value":"i32","mutable":true},10476800);function ___syscall__newselect(nfds,readfds,writefds,exceptfds,timeout){try{var total=0;var srcReadLow=readfds?HEAP32[readfds>>2]:0,srcReadHigh=readfds?HEAP32[readfds+4>>2]:0;var srcWriteLow=writefds?HEAP32[writefds>>2]:0,srcWriteHigh=writefds?HEAP32[writefds+4>>2]:0;var srcExceptLow=exceptfds?HEAP32[exceptfds>>2]:0,srcExceptHigh=exceptfds?HEAP32[exceptfds+4>>2]:0;var dstReadLow=0,dstReadHigh=0;var dstWriteLow=0,dstWriteHigh=0;var dstExceptLow=0,dstExceptHigh=0;var allLow=(readfds?HEAP32[readfds>>2]:0)|(writefds?HEAP32[writefds>>2]:0)|(exceptfds?HEAP32[exceptfds>>2]:0);var allHigh=(readfds?HEAP32[readfds+4>>2]:0)|(writefds?HEAP32[writefds+4>>2]:0)|(exceptfds?HEAP32[exceptfds+4>>2]:0);var check=function(fd,low,high,val){return fd<32?low&val:high&val};for(var fd=0;fd<nfds;fd++){var mask=1<<fd%32;if(!check(fd,allLow,allHigh,mask)){continue}var stream=SYSCALLS.getStreamFromFD(fd);var flags=SYSCALLS.DEFAULT_POLLMASK;if(stream.stream_ops.poll){var timeoutInMillis=-1;if(timeout){var tv_sec=readfds?HEAP32[timeout>>2]:0,tv_usec=readfds?HEAP32[timeout+8>>2]:0;timeoutInMillis=(tv_sec+tv_usec/1e6)*1e3}flags=stream.stream_ops.poll(stream,timeoutInMillis)}if(flags&1&&check(fd,srcReadLow,srcReadHigh,mask)){fd<32?dstReadLow=dstReadLow|mask:dstReadHigh=dstReadHigh|mask;total++}if(flags&4&&check(fd,srcWriteLow,srcWriteHigh,mask)){fd<32?dstWriteLow=dstWriteLow|mask:dstWriteHigh=dstWriteHigh|mask;total++}if(flags&2&&check(fd,srcExceptLow,srcExceptHigh,mask)){fd<32?dstExceptLow=dstExceptLow|mask:dstExceptHigh=dstExceptHigh|mask;total++}}if(readfds){HEAP32[readfds>>2]=dstReadLow;HEAP32[readfds+4>>2]=dstReadHigh}if(writefds){HEAP32[writefds>>2]=dstWriteLow;HEAP32[writefds+4>>2]=dstWriteHigh}if(exceptfds){HEAP32[exceptfds>>2]=dstExceptLow;HEAP32[exceptfds+4>>2]=dstExceptHigh}return total}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall__newselect.sig="iipppp";var SOCKFS={mount(mount){Module["websocket"]=Module["websocket"]&&"object"===typeof Module["websocket"]?Module["websocket"]:{};Module["websocket"]._callbacks={};Module["websocket"]["on"]=function(event,callback){if("function"===typeof callback){this._callbacks[event]=callback}return this};Module["websocket"].emit=function(event,param){if("function"===typeof this._callbacks[event]){this._callbacks[event].call(this,param)}};return FS.createNode(null,"/",16384|511,0)},createSocket(family,type,protocol){type&=~526336;var streaming=type==1;if(streaming&&protocol&&protocol!=6){throw new FS.ErrnoError(66)}var sock={family:family,type:type,protocol:protocol,server:null,error:null,peers:{},pending:[],recv_queue:[],sock_ops:SOCKFS.websocket_sock_ops};var name=SOCKFS.nextname();var node=FS.createNode(SOCKFS.root,name,49152,0);node.sock=sock;var stream=FS.createStream({path:name,node:node,flags:2,seekable:false,stream_ops:SOCKFS.stream_ops});sock.stream=stream;return sock},getSocket(fd){var stream=FS.getStream(fd);if(!stream||!FS.isSocket(stream.node.mode)){return null}return stream.node.sock},stream_ops:{poll(stream){var sock=stream.node.sock;return sock.sock_ops.poll(sock)},ioctl(stream,request,varargs){var sock=stream.node.sock;return sock.sock_ops.ioctl(sock,request,varargs)},read(stream,buffer,offset,length,position){var sock=stream.node.sock;var msg=sock.sock_ops.recvmsg(sock,length);if(!msg){return 0}buffer.set(msg.buffer,offset);return msg.buffer.length},write(stream,buffer,offset,length,position){var sock=stream.node.sock;return sock.sock_ops.sendmsg(sock,buffer,offset,length)},close(stream){var sock=stream.node.sock;sock.sock_ops.close(sock)}},nextname(){if(!SOCKFS.nextname.current){SOCKFS.nextname.current=0}return"socket["+SOCKFS.nextname.current+++"]"},websocket_sock_ops:{createPeer(sock,addr,port){var ws;if(typeof addr=="object"){ws=addr;addr=null;port=null}if(ws){if(ws._socket){addr=ws._socket.remoteAddress;port=ws._socket.remotePort}else{var result=/ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);if(!result){throw new Error("WebSocket URL must be in the format ws(s)://address:port")}addr=result[1];port=parseInt(result[2],10)}}else{try{var runtimeConfig=Module["websocket"]&&"object"===typeof Module["websocket"];var url="ws:#".replace("#","//");if(runtimeConfig){if("string"===typeof Module["websocket"]["url"]){url=Module["websocket"]["url"]}}if(url==="ws://"||url==="wss://"){var parts=addr.split("/");url=url+parts[0]+":"+port+"/"+parts.slice(1).join("/")}var subProtocols="binary";if(runtimeConfig){if("string"===typeof Module["websocket"]["subprotocol"]){subProtocols=Module["websocket"]["subprotocol"]}}var opts=undefined;if(subProtocols!=="null"){subProtocols=subProtocols.replace(/^ +| +$/g,"").split(/ *, */);opts=subProtocols}if(runtimeConfig&&null===Module["websocket"]["subprotocol"]){subProtocols="null";opts=undefined}var WebSocketConstructor;if(ENVIRONMENT_IS_NODE){WebSocketConstructor=require("ws")}else{WebSocketConstructor=WebSocket}ws=new WebSocketConstructor(url,opts);ws.binaryType="arraybuffer"}catch(e){throw new FS.ErrnoError(23)}}var peer={addr:addr,port:port,socket:ws,dgram_send_queue:[]};SOCKFS.websocket_sock_ops.addPeer(sock,peer);SOCKFS.websocket_sock_ops.handlePeerEvents(sock,peer);if(sock.type===2&&typeof sock.sport!="undefined"){peer.dgram_send_queue.push(new Uint8Array([255,255,255,255,"p".charCodeAt(0),"o".charCodeAt(0),"r".charCodeAt(0),"t".charCodeAt(0),(sock.sport&65280)>>8,sock.sport&255]))}return peer},getPeer(sock,addr,port){return sock.peers[addr+":"+port]},addPeer(sock,peer){sock.peers[peer.addr+":"+peer.port]=peer},removePeer(sock,peer){delete sock.peers[peer.addr+":"+peer.port]},handlePeerEvents(sock,peer){var first=true;var handleOpen=function(){Module["websocket"].emit("open",sock.stream.fd);try{var queued=peer.dgram_send_queue.shift();while(queued){peer.socket.send(queued);queued=peer.dgram_send_queue.shift()}}catch(e){peer.socket.close()}};function handleMessage(data){if(typeof data=="string"){var encoder=new TextEncoder;data=encoder.encode(data)}else{assert(data.byteLength!==undefined);if(data.byteLength==0){return}data=new Uint8Array(data)}var wasfirst=first;first=false;if(wasfirst&&data.length===10&&data[0]===255&&data[1]===255&&data[2]===255&&data[3]===255&&data[4]==="p".charCodeAt(0)&&data[5]==="o".charCodeAt(0)&&data[6]==="r".charCodeAt(0)&&data[7]==="t".charCodeAt(0)){var newport=data[8]<<8|data[9];SOCKFS.websocket_sock_ops.removePeer(sock,peer);peer.port=newport;SOCKFS.websocket_sock_ops.addPeer(sock,peer);return}sock.recv_queue.push({addr:peer.addr,port:peer.port,data:data});Module["websocket"].emit("message",sock.stream.fd)}if(ENVIRONMENT_IS_NODE){peer.socket.on("open",handleOpen);peer.socket.on("message",function(data,isBinary){if(!isBinary){return}handleMessage(new Uint8Array(data).buffer)});peer.socket.on("close",function(){Module["websocket"].emit("close",sock.stream.fd)});peer.socket.on("error",function(error){sock.error=14;Module["websocket"].emit("error",[sock.stream.fd,sock.error,"ECONNREFUSED: Connection refused"])})}else{peer.socket.onopen=handleOpen;peer.socket.onclose=function(){Module["websocket"].emit("close",sock.stream.fd)};peer.socket.onmessage=function peer_socket_onmessage(event){handleMessage(event.data)};peer.socket.onerror=function(error){sock.error=14;Module["websocket"].emit("error",[sock.stream.fd,sock.error,"ECONNREFUSED: Connection refused"])}}},poll(sock){if(sock.type===1&&sock.server){return sock.pending.length?64|1:0}var mask=0;var dest=sock.type===1?SOCKFS.websocket_sock_ops.getPeer(sock,sock.daddr,sock.dport):null;if(sock.recv_queue.length||!dest||dest&&dest.socket.readyState===dest.socket.CLOSING||dest&&dest.socket.readyState===dest.socket.CLOSED){mask|=64|1}if(!dest||dest&&dest.socket.readyState===dest.socket.OPEN){mask|=4}if(dest&&dest.socket.readyState===dest.socket.CLOSING||dest&&dest.socket.readyState===dest.socket.CLOSED){mask|=16}return mask},ioctl(sock,request,arg){switch(request){case 21531:var bytes=0;if(sock.recv_queue.length){bytes=sock.recv_queue[0].data.length}HEAP32[arg>>2]=bytes;return 0;default:return 28}},close(sock){if(sock.server){try{sock.server.close()}catch(e){}sock.server=null}var peers=Object.keys(sock.peers);for(var i=0;i<peers.length;i++){var peer=sock.peers[peers[i]];try{peer.socket.close()}catch(e){}SOCKFS.websocket_sock_ops.removePeer(sock,peer)}return 0},bind(sock,addr,port){if(typeof sock.saddr!="undefined"||typeof sock.sport!="undefined"){throw new FS.ErrnoError(28)}sock.saddr=addr;sock.sport=port;if(sock.type===2){if(sock.server){sock.server.close();sock.server=null}try{sock.sock_ops.listen(sock,0)}catch(e){if(!(e.name==="ErrnoError"))throw e;if(e.errno!==138)throw e}}},connect(sock,addr,port){if(sock.server){throw new FS.ErrnoError(138)}if(typeof sock.daddr!="undefined"&&typeof sock.dport!="undefined"){var dest=SOCKFS.websocket_sock_ops.getPeer(sock,sock.daddr,sock.dport);if(dest){if(dest.socket.readyState===dest.socket.CONNECTING){throw new FS.ErrnoError(7)}else{throw new FS.ErrnoError(30)}}}var peer=SOCKFS.websocket_sock_ops.createPeer(sock,addr,port);sock.daddr=peer.addr;sock.dport=peer.port;throw new FS.ErrnoError(26)},listen(sock,backlog){if(!ENVIRONMENT_IS_NODE){throw new FS.ErrnoError(138)}if(sock.server){throw new FS.ErrnoError(28)}var WebSocketServer=require("ws").Server;var host=sock.saddr;sock.server=new WebSocketServer({host:host,port:sock.sport});Module["websocket"].emit("listen",sock.stream.fd);sock.server.on("connection",function(ws){if(sock.type===1){var newsock=SOCKFS.createSocket(sock.family,sock.type,sock.protocol);var peer=SOCKFS.websocket_sock_ops.createPeer(newsock,ws);newsock.daddr=peer.addr;newsock.dport=peer.port;sock.pending.push(newsock);Module["websocket"].emit("connection",newsock.stream.fd)}else{SOCKFS.websocket_sock_ops.createPeer(sock,ws);Module["websocket"].emit("connection",sock.stream.fd)}});sock.server.on("close",function(){Module["websocket"].emit("close",sock.stream.fd);sock.server=null});sock.server.on("error",function(error){sock.error=23;Module["websocket"].emit("error",[sock.stream.fd,sock.error,"EHOSTUNREACH: Host is unreachable"])})},accept(listensock){if(!listensock.server||!listensock.pending.length){throw new FS.ErrnoError(28)}var newsock=listensock.pending.shift();newsock.stream.flags=listensock.stream.flags;return newsock},getname(sock,peer){var addr,port;if(peer){if(sock.daddr===undefined||sock.dport===undefined){throw new FS.ErrnoError(53)}addr=sock.daddr;port=sock.dport}else{addr=sock.saddr||0;port=sock.sport||0}return{addr:addr,port:port}},sendmsg(sock,buffer,offset,length,addr,port){if(sock.type===2){if(addr===undefined||port===undefined){addr=sock.daddr;port=sock.dport}if(addr===undefined||port===undefined){throw new FS.ErrnoError(17)}}else{addr=sock.daddr;port=sock.dport}var dest=SOCKFS.websocket_sock_ops.getPeer(sock,addr,port);if(sock.type===1){if(!dest||dest.socket.readyState===dest.socket.CLOSING||dest.socket.readyState===dest.socket.CLOSED){throw new FS.ErrnoError(53)}else if(dest.socket.readyState===dest.socket.CONNECTING){throw new FS.ErrnoError(6)}}if(ArrayBuffer.isView(buffer)){offset+=buffer.byteOffset;buffer=buffer.buffer}var data;data=buffer.slice(offset,offset+length);if(sock.type===2){if(!dest||dest.socket.readyState!==dest.socket.OPEN){if(!dest||dest.socket.readyState===dest.socket.CLOSING||dest.socket.readyState===dest.socket.CLOSED){dest=SOCKFS.websocket_sock_ops.createPeer(sock,addr,port)}dest.dgram_send_queue.push(data);return length}}try{dest.socket.send(data);return length}catch(e){throw new FS.ErrnoError(28)}},recvmsg(sock,length){if(sock.type===1&&sock.server){throw new FS.ErrnoError(53)}var queued=sock.recv_queue.shift();if(!queued){if(sock.type===1){var dest=SOCKFS.websocket_sock_ops.getPeer(sock,sock.daddr,sock.dport);if(!dest){throw new FS.ErrnoError(53)}if(dest.socket.readyState===dest.socket.CLOSING||dest.socket.readyState===dest.socket.CLOSED){return null}throw new FS.ErrnoError(6)}throw new FS.ErrnoError(6)}var queuedLength=queued.data.byteLength||queued.data.length;var queuedOffset=queued.data.byteOffset||0;var queuedBuffer=queued.data.buffer||queued.data;var bytesRead=Math.min(length,queuedLength);var res={buffer:new Uint8Array(queuedBuffer,queuedOffset,bytesRead),addr:queued.addr,port:queued.port};if(sock.type===1&&bytesRead<queuedLength){var bytesRemaining=queuedLength-bytesRead;queued.data=new Uint8Array(queuedBuffer,queuedOffset+bytesRead,bytesRemaining);sock.recv_queue.unshift(queued)}return res}}};var getSocketFromFD=fd=>{var socket=SOCKFS.getSocket(fd);if(!socket)throw new FS.ErrnoError(8);return socket};var setErrNo=value=>{HEAP32[___errno_location()>>2]=value;return value};var Sockets={BUFFER_SIZE:10240,MAX_BUFFER_SIZE:10485760,nextFd:1,fds:{},nextport:1,maxport:65535,peer:null,connections:{},portmap:{},localAddr:4261412874,addrPool:[33554442,50331658,67108874,83886090,100663306,117440522,134217738,150994954,167772170,184549386,201326602,218103818,234881034]};var inetPton4=str=>{var b=str.split(".");for(var i=0;i<4;i++){var tmp=Number(b[i]);if(isNaN(tmp))return null;b[i]=tmp}return(b[0]|b[1]<<8|b[2]<<16|b[3]<<24)>>>0};var jstoi_q=str=>parseInt(str);var inetPton6=str=>{var words;var w,offset,z,i;var valid6regx=/^((?=.*::)(?!.*::.+::)(::)?([\dA-F]{1,4}:(:|\b)|){5}|([\dA-F]{1,4}:){6})((([\dA-F]{1,4}((?!\3)::|:\b|$))|(?!\2\3)){2}|(((2[0-4]|1\d|[1-9])?\d|25[0-5])\.?\b){4})$/i;var parts=[];if(!valid6regx.test(str)){return null}if(str==="::"){return[0,0,0,0,0,0,0,0]}if(str.startsWith("::")){str=str.replace("::","Z:")}else{str=str.replace("::",":Z:")}if(str.indexOf(".")>0){str=str.replace(new RegExp("[.]","g"),":");words=str.split(":");words[words.length-4]=jstoi_q(words[words.length-4])+jstoi_q(words[words.length-3])*256;words[words.length-3]=jstoi_q(words[words.length-2])+jstoi_q(words[words.length-1])*256;words=words.slice(0,words.length-2)}else{words=str.split(":")}offset=0;z=0;for(w=0;w<words.length;w++){if(typeof words[w]=="string"){if(words[w]==="Z"){for(z=0;z<8-words.length+1;z++){parts[w+z]=0}offset=z-1}else{parts[w+offset]=_htons(parseInt(words[w],16))}}else{parts[w+offset]=words[w]}}return[parts[1]<<16|parts[0],parts[3]<<16|parts[2],parts[5]<<16|parts[4],parts[7]<<16|parts[6]]};var writeSockaddr=(sa,family,addr,port,addrlen)=>{switch(family){case 2:addr=inetPton4(addr);zeroMemory(sa,16);if(addrlen){HEAP32[addrlen>>2]=16}HEAP16[sa>>1]=family;HEAP32[sa+4>>2]=addr;HEAP16[sa+2>>1]=_htons(port);break;case 10:addr=inetPton6(addr);zeroMemory(sa,28);if(addrlen){HEAP32[addrlen>>2]=28}HEAP32[sa>>2]=family;HEAP32[sa+8>>2]=addr[0];HEAP32[sa+12>>2]=addr[1];HEAP32[sa+16>>2]=addr[2];HEAP32[sa+20>>2]=addr[3];HEAP16[sa+2>>1]=_htons(port);break;default:return 5}return 0};var DNS={address_map:{id:1,addrs:{},names:{}},lookup_name(name){var res=inetPton4(name);if(res!==null){return name}res=inetPton6(name);if(res!==null){return name}var addr;if(DNS.address_map.addrs[name]){addr=DNS.address_map.addrs[name]}else{var id=DNS.address_map.id++;assert(id<65535,"exceeded max address mappings of 65535");addr="172.29."+(id&255)+"."+(id&65280);DNS.address_map.names[addr]=name;DNS.address_map.addrs[name]=addr}return addr},lookup_addr(addr){if(DNS.address_map.names[addr]){return DNS.address_map.names[addr]}return null}};function ___syscall_accept4(fd,addr,addrlen,flags,d1,d2){try{var sock=getSocketFromFD(fd);var newsock=sock.sock_ops.accept(sock);if(addr){var errno=writeSockaddr(addr,newsock.family,DNS.lookup_name(newsock.daddr),newsock.dport,addrlen)}return newsock.stream.fd}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_accept4.sig="iippiii";var inetNtop4=addr=>(addr&255)+"."+(addr>>8&255)+"."+(addr>>16&255)+"."+(addr>>24&255);var inetNtop6=ints=>{var str="";var word=0;var longest=0;var lastzero=0;var zstart=0;var len=0;var i=0;var parts=[ints[0]&65535,ints[0]>>16,ints[1]&65535,ints[1]>>16,ints[2]&65535,ints[2]>>16,ints[3]&65535,ints[3]>>16];var hasipv4=true;var v4part="";for(i=0;i<5;i++){if(parts[i]!==0){hasipv4=false;break}}if(hasipv4){v4part=inetNtop4(parts[6]|parts[7]<<16);if(parts[5]===-1){str="::ffff:";str+=v4part;return str}if(parts[5]===0){str="::";if(v4part==="0.0.0.0")v4part="";if(v4part==="0.0.0.1")v4part="1";str+=v4part;return str}}for(word=0;word<8;word++){if(parts[word]===0){if(word-lastzero>1){len=0}lastzero=word;len++}if(len>longest){longest=len;zstart=word-longest+1}}for(word=0;word<8;word++){if(longest>1){if(parts[word]===0&&word>=zstart&&word<zstart+longest){if(word===zstart){str+=":";if(zstart===0)str+=":"}continue}}str+=Number(_ntohs(parts[word]&65535)).toString(16);str+=word<7?":":""}return str};var readSockaddr=(sa,salen)=>{var family=HEAP16[sa>>1];var port=_ntohs(HEAPU16[sa+2>>1]);var addr;switch(family){case 2:if(salen!==16){return{errno:28}}addr=HEAP32[sa+4>>2];addr=inetNtop4(addr);break;case 10:if(salen!==28){return{errno:28}}addr=[HEAP32[sa+8>>2],HEAP32[sa+12>>2],HEAP32[sa+16>>2],HEAP32[sa+20>>2]];addr=inetNtop6(addr);break;default:return{errno:5}}return{family:family,addr:addr,port:port}};var getSocketAddress=(addrp,addrlen,allowNull)=>{if(allowNull&&addrp===0)return null;var info=readSockaddr(addrp,addrlen);if(info.errno)throw new FS.ErrnoError(info.errno);info.addr=DNS.lookup_addr(info.addr)||info.addr;return info};function ___syscall_bind(fd,addr,addrlen,d1,d2,d3){try{var sock=getSocketFromFD(fd);var info=getSocketAddress(addr,addrlen);sock.sock_ops.bind(sock,info.addr,info.port);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_bind.sig="iippiii";function ___syscall_chdir(path){try{path=SYSCALLS.getStr(path);FS.chdir(path);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_chdir.sig="ip";function ___syscall_chmod(path,mode){try{path=SYSCALLS.getStr(path);FS.chmod(path,mode);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_chmod.sig="ipi";function ___syscall_connect(fd,addr,addrlen,d1,d2,d3){try{var sock=getSocketFromFD(fd);var info=getSocketAddress(addr,addrlen);sock.sock_ops.connect(sock,info.addr,info.port);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_connect.sig="iippiii";function ___syscall_dup(fd){try{var old=SYSCALLS.getStreamFromFD(fd);return FS.createStream(old).fd}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_dup.sig="ii";function ___syscall_dup3(fd,newfd,flags){try{var old=SYSCALLS.getStreamFromFD(fd);if(old.fd===newfd)return-28;var existing=FS.getStream(newfd);if(existing)FS.close(existing);return FS.createStream(old,newfd).fd}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_dup3.sig="iiii";function ___syscall_faccessat(dirfd,path,amode,flags){try{path=SYSCALLS.getStr(path);path=SYSCALLS.calculateAt(dirfd,path);if(amode&~7){return-28}var lookup=FS.lookupPath(path,{follow:true});var node=lookup.node;if(!node){return-44}var perms="";if(amode&4)perms+="r";if(amode&2)perms+="w";if(amode&1)perms+="x";if(perms&&FS.nodePermissions(node,perms)){return-2}return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_faccessat.sig="iipii";var ___syscall_fadvise64=(fd,offset,len,advice)=>0;___syscall_fadvise64.sig="iijji";var MAX_INT53=9007199254740992;var MIN_INT53=-9007199254740992;var bigintToI53Checked=num=>num<MIN_INT53||num>MAX_INT53?NaN:Number(num);function ___syscall_fallocate(fd,mode,offset,len){offset=bigintToI53Checked(offset);len=bigintToI53Checked(len);try{if(isNaN(offset))return 61;var stream=SYSCALLS.getStreamFromFD(fd);FS.allocate(stream,offset,len);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fallocate.sig="iiijj";function ___syscall_fchdir(fd){try{var stream=SYSCALLS.getStreamFromFD(fd);FS.chdir(stream.path);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fchdir.sig="ii";function ___syscall_fchmod(fd,mode){try{FS.fchmod(fd,mode);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fchmod.sig="iii";function ___syscall_fchmodat(dirfd,path,mode,varargs){SYSCALLS.varargs=varargs;try{path=SYSCALLS.getStr(path);path=SYSCALLS.calculateAt(dirfd,path);FS.chmod(path,mode);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fchmodat.sig="iipip";function ___syscall_fchown32(fd,owner,group){try{FS.fchown(fd,owner,group);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fchown32.sig="iiii";function ___syscall_fchownat(dirfd,path,owner,group,flags){try{path=SYSCALLS.getStr(path);var nofollow=flags&256;flags=flags&~256;path=SYSCALLS.calculateAt(dirfd,path);(nofollow?FS.lchown:FS.chown)(path,owner,group);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fchownat.sig="iipiii";function ___syscall_fcntl64(fd,cmd,varargs){SYSCALLS.varargs=varargs;try{var stream=SYSCALLS.getStreamFromFD(fd);switch(cmd){case 0:{var arg=SYSCALLS.get();if(arg<0){return-28}while(FS.streams[arg]){arg++}var newStream;newStream=FS.createStream(stream,arg);return newStream.fd}case 1:case 2:return 0;case 3:return stream.flags;case 4:{var arg=SYSCALLS.get();stream.flags|=arg;return 0}case 5:{var arg=SYSCALLS.getp();var offset=0;HEAP16[arg+offset>>1]=2;return 0}case 6:case 7:return 0;case 16:case 8:return-28;case 9:setErrNo(28);return-1;default:{return-28}}}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fcntl64.sig="iiip";function ___syscall_fdatasync(fd){try{var stream=SYSCALLS.getStreamFromFD(fd);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fdatasync.sig="ii";function ___syscall_fstat64(fd,buf){try{var stream=SYSCALLS.getStreamFromFD(fd);return SYSCALLS.doStat(FS.stat,stream.path,buf)}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fstat64.sig="iip";function ___syscall_statfs64(path,size,buf){try{path=SYSCALLS.getStr(path);HEAP32[buf+4>>2]=4096;HEAP32[buf+40>>2]=4096;HEAP32[buf+8>>2]=1e6;HEAP32[buf+12>>2]=5e5;HEAP32[buf+16>>2]=5e5;HEAP32[buf+20>>2]=FS.nextInode;HEAP32[buf+24>>2]=1e6;HEAP32[buf+28>>2]=42;HEAP32[buf+44>>2]=2;HEAP32[buf+36>>2]=255;return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_statfs64.sig="ippp";function ___syscall_fstatfs64(fd,size,buf){try{var stream=SYSCALLS.getStreamFromFD(fd);return ___syscall_statfs64(0,size,buf)}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_fstatfs64.sig="iipp";function ___syscall_ftruncate64(fd,length){length=bigintToI53Checked(length);try{if(isNaN(length))return 61;FS.ftruncate(fd,length);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_ftruncate64.sig="iij";var stringToUTF8=(str,outPtr,maxBytesToWrite)=>stringToUTF8Array(str,HEAPU8,outPtr,maxBytesToWrite);function ___syscall_getcwd(buf,size){try{if(size===0)return-28;var cwd=FS.cwd();var cwdLengthInBytes=lengthBytesUTF8(cwd)+1;if(size<cwdLengthInBytes)return-68;stringToUTF8(cwd,buf,size);return cwdLengthInBytes}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_getcwd.sig="ipp";function ___syscall_getdents64(fd,dirp,count){try{var stream=SYSCALLS.getStreamFromFD(fd);if(!stream.getdents){stream.getdents=FS.readdir(stream.path)}var struct_size=280;var pos=0;var off=FS.llseek(stream,0,1);var idx=Math.floor(off/struct_size);while(idx<stream.getdents.length&&pos+struct_size<=count){var id;var type;var name=stream.getdents[idx];if(name==="."){id=stream.node.id;type=4}else if(name===".."){var lookup=FS.lookupPath(stream.path,{parent:true});id=lookup.node.id;type=4}else{var child=FS.lookupNode(stream.node,name);id=child.id;type=FS.isChrdev(child.mode)?2:FS.isDir(child.mode)?4:FS.isLink(child.mode)?10:8}HEAP64[dirp+pos>>3]=BigInt(id);HEAP64[dirp+pos+8>>3]=BigInt((idx+1)*struct_size);HEAP16[dirp+pos+16>>1]=280;HEAP8[dirp+pos+18>>0]=type;stringToUTF8(name,dirp+pos+19,256);pos+=struct_size;idx+=1}FS.llseek(stream,idx*struct_size,0);return pos}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_getdents64.sig="iipp";function ___syscall_getpeername(fd,addr,addrlen,d1,d2,d3){try{var sock=getSocketFromFD(fd);if(!sock.daddr){return-53}var errno=writeSockaddr(addr,sock.family,DNS.lookup_name(sock.daddr),sock.dport,addrlen);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_getpeername.sig="iippiii";function ___syscall_getsockname(fd,addr,addrlen,d1,d2,d3){try{var sock=getSocketFromFD(fd);var errno=writeSockaddr(addr,sock.family,DNS.lookup_name(sock.saddr||"0.0.0.0"),sock.sport,addrlen);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_getsockname.sig="iippiii";function ___syscall_getsockopt(fd,level,optname,optval,optlen,d1){try{var sock=getSocketFromFD(fd);if(level===1){if(optname===4){HEAP32[optval>>2]=sock.error;HEAP32[optlen>>2]=4;sock.error=null;return 0}}return-50}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_getsockopt.sig="iiiippi";function ___syscall_ioctl(fd,op,varargs){SYSCALLS.varargs=varargs;try{var stream=SYSCALLS.getStreamFromFD(fd);switch(op){case 21509:{if(!stream.tty)return-59;return 0}case 21505:{if(!stream.tty)return-59;if(stream.tty.ops.ioctl_tcgets){var termios=stream.tty.ops.ioctl_tcgets(stream);var argp=SYSCALLS.getp();HEAP32[argp>>2]=termios.c_iflag||0;HEAP32[argp+4>>2]=termios.c_oflag||0;HEAP32[argp+8>>2]=termios.c_cflag||0;HEAP32[argp+12>>2]=termios.c_lflag||0;for(var i=0;i<32;i++){HEAP8[argp+i+17>>0]=termios.c_cc[i]||0}return 0}return 0}case 21510:case 21511:case 21512:{if(!stream.tty)return-59;return 0}case 21506:case 21507:case 21508:{if(!stream.tty)return-59;if(stream.tty.ops.ioctl_tcsets){var argp=SYSCALLS.getp();var c_iflag=HEAP32[argp>>2];var c_oflag=HEAP32[argp+4>>2];var c_cflag=HEAP32[argp+8>>2];var c_lflag=HEAP32[argp+12>>2];var c_cc=[];for(var i=0;i<32;i++){c_cc.push(HEAP8[argp+i+17>>0])}return stream.tty.ops.ioctl_tcsets(stream.tty,op,{c_iflag:c_iflag,c_oflag:c_oflag,c_cflag:c_cflag,c_lflag:c_lflag,c_cc:c_cc})}return 0}case 21519:{if(!stream.tty)return-59;var argp=SYSCALLS.getp();HEAP32[argp>>2]=0;return 0}case 21520:{if(!stream.tty)return-59;return-28}case 21531:{var argp=SYSCALLS.getp();return FS.ioctl(stream,op,argp)}case 21523:{if(!stream.tty)return-59;if(stream.tty.ops.ioctl_tiocgwinsz){var winsize=stream.tty.ops.ioctl_tiocgwinsz(stream.tty);var argp=SYSCALLS.getp();HEAP16[argp>>1]=winsize[0];HEAP16[argp+2>>1]=winsize[1]}return 0}case 21524:{if(!stream.tty)return-59;return 0}case 21515:{if(!stream.tty)return-59;return 0}default:return-28}}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_ioctl.sig="iiip";function ___syscall_listen(fd,backlog){try{var sock=getSocketFromFD(fd);sock.sock_ops.listen(sock,backlog);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_listen.sig="iiiiiii";function ___syscall_lstat64(path,buf){try{path=SYSCALLS.getStr(path);return SYSCALLS.doStat(FS.lstat,path,buf)}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_lstat64.sig="ipp";function ___syscall_mkdirat(dirfd,path,mode){try{path=SYSCALLS.getStr(path);path=SYSCALLS.calculateAt(dirfd,path);path=PATH.normalize(path);if(path[path.length-1]==="/")path=path.substr(0,path.length-1);FS.mkdir(path,mode,0);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_mkdirat.sig="iipi";function ___syscall_mknodat(dirfd,path,mode,dev){try{path=SYSCALLS.getStr(path);path=SYSCALLS.calculateAt(dirfd,path);switch(mode&61440){case 32768:case 8192:case 24576:case 4096:case 49152:break;default:return-28}FS.mknod(path,mode,dev);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_mknodat.sig="iipii";function ___syscall_newfstatat(dirfd,path,buf,flags){try{path=SYSCALLS.getStr(path);var nofollow=flags&256;var allowEmpty=flags&4096;flags=flags&~6400;path=SYSCALLS.calculateAt(dirfd,path,allowEmpty);return SYSCALLS.doStat(nofollow?FS.lstat:FS.stat,path,buf)}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_newfstatat.sig="iippi";function ___syscall_openat(dirfd,path,flags,varargs){SYSCALLS.varargs=varargs;try{path=SYSCALLS.getStr(path);path=SYSCALLS.calculateAt(dirfd,path);var mode=varargs?SYSCALLS.get():0;return FS.open(path,flags,mode).fd}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_openat.sig="iipip";var PIPEFS={BUCKET_BUFFER_SIZE:8192,mount(mount){return FS.createNode(null,"/",16384|511,0)},createPipe(){var pipe={buckets:[],refcnt:2};pipe.buckets.push({buffer:new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),offset:0,roffset:0});var rName=PIPEFS.nextname();var wName=PIPEFS.nextname();var rNode=FS.createNode(PIPEFS.root,rName,4096,0);var wNode=FS.createNode(PIPEFS.root,wName,4096,0);rNode.pipe=pipe;wNode.pipe=pipe;var readableStream=FS.createStream({path:rName,node:rNode,flags:0,seekable:false,stream_ops:PIPEFS.stream_ops});rNode.stream=readableStream;var writableStream=FS.createStream({path:wName,node:wNode,flags:1,seekable:false,stream_ops:PIPEFS.stream_ops});wNode.stream=writableStream;return{readable_fd:readableStream.fd,writable_fd:writableStream.fd}},stream_ops:{poll(stream){var pipe=stream.node.pipe;if((stream.flags&2097155)===1){return 256|4}if(pipe.buckets.length>0){for(var i=0;i<pipe.buckets.length;i++){var bucket=pipe.buckets[i];if(bucket.offset-bucket.roffset>0){return 64|1}}}return 0},ioctl(stream,request,varargs){return 28},fsync(stream){return 28},read(stream,buffer,offset,length,position){var pipe=stream.node.pipe;var currentLength=0;for(var i=0;i<pipe.buckets.length;i++){var bucket=pipe.buckets[i];currentLength+=bucket.offset-bucket.roffset}var data=buffer.subarray(offset,offset+length);if(length<=0){return 0}if(currentLength==0){throw new FS.ErrnoError(6)}var toRead=Math.min(currentLength,length);var totalRead=toRead;var toRemove=0;for(var i=0;i<pipe.buckets.length;i++){var currBucket=pipe.buckets[i];var bucketSize=currBucket.offset-currBucket.roffset;if(toRead<=bucketSize){var tmpSlice=currBucket.buffer.subarray(currBucket.roffset,currBucket.offset);if(toRead<bucketSize){tmpSlice=tmpSlice.subarray(0,toRead);currBucket.roffset+=toRead}else{toRemove++}data.set(tmpSlice);break}else{var tmpSlice=currBucket.buffer.subarray(currBucket.roffset,currBucket.offset);data.set(tmpSlice);data=data.subarray(tmpSlice.byteLength);toRead-=tmpSlice.byteLength;toRemove++}}if(toRemove&&toRemove==pipe.buckets.length){toRemove--;pipe.buckets[toRemove].offset=0;pipe.buckets[toRemove].roffset=0}pipe.buckets.splice(0,toRemove);return totalRead},write(stream,buffer,offset,length,position){var pipe=stream.node.pipe;var data=buffer.subarray(offset,offset+length);var dataLen=data.byteLength;if(dataLen<=0){return 0}var currBucket=null;if(pipe.buckets.length==0){currBucket={buffer:new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),offset:0,roffset:0};pipe.buckets.push(currBucket)}else{currBucket=pipe.buckets[pipe.buckets.length-1]}assert(currBucket.offset<=PIPEFS.BUCKET_BUFFER_SIZE);var freeBytesInCurrBuffer=PIPEFS.BUCKET_BUFFER_SIZE-currBucket.offset;if(freeBytesInCurrBuffer>=dataLen){currBucket.buffer.set(data,currBucket.offset);currBucket.offset+=dataLen;return dataLen}else if(freeBytesInCurrBuffer>0){currBucket.buffer.set(data.subarray(0,freeBytesInCurrBuffer),currBucket.offset);currBucket.offset+=freeBytesInCurrBuffer;data=data.subarray(freeBytesInCurrBuffer,data.byteLength)}var numBuckets=data.byteLength/PIPEFS.BUCKET_BUFFER_SIZE|0;var remElements=data.byteLength%PIPEFS.BUCKET_BUFFER_SIZE;for(var i=0;i<numBuckets;i++){var newBucket={buffer:new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),offset:PIPEFS.BUCKET_BUFFER_SIZE,roffset:0};pipe.buckets.push(newBucket);newBucket.buffer.set(data.subarray(0,PIPEFS.BUCKET_BUFFER_SIZE));data=data.subarray(PIPEFS.BUCKET_BUFFER_SIZE,data.byteLength)}if(remElements>0){var newBucket={buffer:new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),offset:data.byteLength,roffset:0};pipe.buckets.push(newBucket);newBucket.buffer.set(data)}return dataLen},close(stream){var pipe=stream.node.pipe;pipe.refcnt--;if(pipe.refcnt===0){pipe.buckets=null}}},nextname(){if(!PIPEFS.nextname.current){PIPEFS.nextname.current=0}return"pipe["+PIPEFS.nextname.current+++"]"}};function ___syscall_pipe(fdPtr){try{if(fdPtr==0){throw new FS.ErrnoError(21)}var res=PIPEFS.createPipe();HEAP32[fdPtr>>2]=res.readable_fd;HEAP32[fdPtr+4>>2]=res.writable_fd;return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_pipe.sig="ip";function ___syscall_poll(fds,nfds,timeout){try{var nonzero=0;for(var i=0;i<nfds;i++){var pollfd=fds+8*i;var fd=HEAP32[pollfd>>2];var events=HEAP16[pollfd+4>>1];var mask=32;var stream=FS.getStream(fd);if(stream){mask=SYSCALLS.DEFAULT_POLLMASK;if(stream.stream_ops.poll){mask=stream.stream_ops.poll(stream,-1)}}mask&=events|8|16;if(mask)nonzero++;HEAP16[pollfd+6>>1]=mask}return nonzero}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_poll.sig="ipii";function ___syscall_readlinkat(dirfd,path,buf,bufsize){try{path=SYSCALLS.getStr(path);path=SYSCALLS.calculateAt(dirfd,path);if(bufsize<=0)return-28;var ret=FS.readlink(path);var len=Math.min(bufsize,lengthBytesUTF8(ret));var endChar=HEAP8[buf+len];stringToUTF8(ret,buf,bufsize+1);HEAP8[buf+len]=endChar;return len}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_readlinkat.sig="iippp";function ___syscall_recvfrom(fd,buf,len,flags,addr,addrlen){try{var sock=getSocketFromFD(fd);var msg=sock.sock_ops.recvmsg(sock,len);if(!msg)return 0;if(addr){var errno=writeSockaddr(addr,sock.family,DNS.lookup_name(msg.addr),msg.port,addrlen)}HEAPU8.set(msg.buffer,buf);return msg.buffer.byteLength}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_recvfrom.sig="iippipp";function ___syscall_recvmsg(fd,message,flags,d1,d2,d3){try{var sock=getSocketFromFD(fd);var iov=HEAPU32[message+8>>2];var num=HEAP32[message+12>>2];var total=0;for(var i=0;i<num;i++){total+=HEAP32[iov+(8*i+4)>>2]}var msg=sock.sock_ops.recvmsg(sock,total);if(!msg)return 0;var name=HEAPU32[message>>2];if(name){var errno=writeSockaddr(name,sock.family,DNS.lookup_name(msg.addr),msg.port)}var bytesRead=0;var bytesRemaining=msg.buffer.byteLength;for(var i=0;bytesRemaining>0&&i<num;i++){var iovbase=HEAPU32[iov+(8*i+0)>>2];var iovlen=HEAP32[iov+(8*i+4)>>2];if(!iovlen){continue}var length=Math.min(iovlen,bytesRemaining);var buf=msg.buffer.subarray(bytesRead,bytesRead+length);HEAPU8.set(buf,iovbase+bytesRead);bytesRead+=length;bytesRemaining-=length}return bytesRead}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_recvmsg.sig="iipiiii";function ___syscall_renameat(olddirfd,oldpath,newdirfd,newpath){try{oldpath=SYSCALLS.getStr(oldpath);newpath=SYSCALLS.getStr(newpath);oldpath=SYSCALLS.calculateAt(olddirfd,oldpath);newpath=SYSCALLS.calculateAt(newdirfd,newpath);FS.rename(oldpath,newpath);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_renameat.sig="iipip";function ___syscall_rmdir(path){try{path=SYSCALLS.getStr(path);FS.rmdir(path);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_rmdir.sig="ip";function ___syscall_sendmsg(fd,message,flags,d1,d2,d3){try{var sock=getSocketFromFD(fd);var iov=HEAPU32[message+8>>2];var num=HEAP32[message+12>>2];var addr,port;var name=HEAPU32[message>>2];var namelen=HEAP32[message+4>>2];if(name){var info=readSockaddr(name,namelen);if(info.errno)return-info.errno;port=info.port;addr=DNS.lookup_addr(info.addr)||info.addr}var total=0;for(var i=0;i<num;i++){total+=HEAP32[iov+(8*i+4)>>2]}var view=new Uint8Array(total);var offset=0;for(var i=0;i<num;i++){var iovbase=HEAPU32[iov+(8*i+0)>>2];var iovlen=HEAP32[iov+(8*i+4)>>2];for(var j=0;j<iovlen;j++){view[offset++]=HEAP8[iovbase+j>>0]}}return sock.sock_ops.sendmsg(sock,view,0,total,addr,port)}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_sendmsg.sig="iipippi";function ___syscall_sendto(fd,message,length,flags,addr,addr_len){try{var sock=getSocketFromFD(fd);var dest=getSocketAddress(addr,addr_len,true);if(!dest){return FS.write(sock.stream,HEAP8,message,length)}return sock.sock_ops.sendmsg(sock,HEAP8,message,length,dest.addr,dest.port)}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_sendto.sig="iippipp";function ___syscall_socket(domain,type,protocol){try{var sock=SOCKFS.createSocket(domain,type,protocol);return sock.stream.fd}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_socket.sig="iiiiiii";function ___syscall_stat64(path,buf){try{path=SYSCALLS.getStr(path);return SYSCALLS.doStat(FS.stat,path,buf)}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_stat64.sig="ipp";function ___syscall_symlink(target,linkpath){try{target=SYSCALLS.getStr(target);linkpath=SYSCALLS.getStr(linkpath);FS.symlink(target,linkpath);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_symlink.sig="ipp";function ___syscall_symlinkat(target,newdirfd,linkpath){try{linkpath=SYSCALLS.calculateAt(newdirfd,linkpath);FS.symlink(target,linkpath);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_symlinkat.sig="ipip";function ___syscall_truncate64(path,length){length=bigintToI53Checked(length);try{if(isNaN(length))return 61;path=SYSCALLS.getStr(path);FS.truncate(path,length);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_truncate64.sig="ipj";function ___syscall_unlinkat(dirfd,path,flags){try{path=SYSCALLS.getStr(path);path=SYSCALLS.calculateAt(dirfd,path);if(flags===0){FS.unlink(path)}else if(flags===512){FS.rmdir(path)}else{abort("Invalid flags passed to unlinkat")}return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_unlinkat.sig="iipi";var readI53FromI64=ptr=>HEAPU32[ptr>>2]+HEAP32[ptr+4>>2]*4294967296;function ___syscall_utimensat(dirfd,path,times,flags){try{path=SYSCALLS.getStr(path);path=SYSCALLS.calculateAt(dirfd,path,true);if(!times){var atime=Date.now();var mtime=atime}else{var seconds=readI53FromI64(times);var nanoseconds=HEAP32[times+8>>2];atime=seconds*1e3+nanoseconds/(1e3*1e3);times+=16;seconds=readI53FromI64(times);nanoseconds=HEAP32[times+8>>2];mtime=seconds*1e3+nanoseconds/(1e3*1e3)}FS.utime(path,atime,mtime);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}___syscall_utimensat.sig="iippi";var ___table_base=new WebAssembly.Global({"value":"i32","mutable":false},1);var ENV={};var stringToUTF8OnStack=str=>{var size=lengthBytesUTF8(str)+1;var ret=stackAlloc(size);stringToUTF8(str,ret,size);return ret};var withStackSave=f=>{var stack=stackSave();var ret=f();stackRestore(stack);return ret};var dlSetError=msg=>{withStackSave(()=>{var cmsg=stringToUTF8OnStack(msg);___dl_seterr(cmsg,0)})};var dlopenInternal=(handle,jsflags)=>{var filename=UTF8ToString(handle+36);var flags=HEAP32[handle+4>>2];filename=PATH.normalize(filename);var searchpaths=[];var global=Boolean(flags&256);var localScope=global?null:{};var combinedFlags={global:global,nodelete:Boolean(flags&4096),loadAsync:jsflags.loadAsync};if(jsflags.loadAsync){return loadDynamicLibrary(filename,combinedFlags,localScope,handle)}try{return loadDynamicLibrary(filename,combinedFlags,localScope,handle)}catch(e){dlSetError(`Could not load dynamic lib: ${filename}\n${e}`);return 0}};var __dlopen_js=handle=>dlopenInternal(handle,{loadAsync:false});__dlopen_js.sig="pp";var __dlsym_js=(handle,symbol,symbolIndex)=>{symbol=UTF8ToString(symbol);var result;var newSymIndex;var lib=LDSO.loadedLibsByHandle[handle];if(!lib.exports.hasOwnProperty(symbol)||lib.exports[symbol].stub){dlSetError(`Tried to lookup unknown symbol "${symbol}" in dynamic lib: ${lib.name}`);return 0}newSymIndex=Object.keys(lib.exports).indexOf(symbol);result=lib.exports[symbol];if(typeof result=="function"){var addr=getFunctionAddress(result);if(addr){result=addr}else{result=addFunction(result,result.sig);HEAPU32[symbolIndex>>2]=newSymIndex}}return result};__dlsym_js.sig="pppp";var __emscripten_dlopen_js=(handle,onsuccess,onerror,user_data)=>{function errorCallback(e){var filename=UTF8ToString(handle+36);dlSetError(`'Could not load dynamic lib: ${filename}\n${e}`);runtimeKeepalivePop();callUserCallback(()=>getWasmTableEntry(onerror)(handle,user_data))}function successCallback(){runtimeKeepalivePop();callUserCallback(()=>getWasmTableEntry(onsuccess)(handle,user_data))}runtimeKeepalivePush();var promise=dlopenInternal(handle,{loadAsync:true});if(promise){promise.then(successCallback,errorCallback)}else{errorCallback()}};__emscripten_dlopen_js.sig="vpppp";function __emscripten_fetch_free(id){if(Fetch.xhrs.has(id)){var xhr=Fetch.xhrs.get(id);Fetch.xhrs.free(id);if(xhr.readyState>0&&xhr.readyState<4){xhr.abort()}}}__emscripten_fetch_free.sig="vi";function __emscripten_fetch_get_response_headers(id,dst,dstSizeBytes){var responseHeaders=Fetch.xhrs.get(id).getAllResponseHeaders();var lengthBytes=lengthBytesUTF8(responseHeaders)+1;stringToUTF8(responseHeaders,dst,dstSizeBytes);return Math.min(lengthBytes,dstSizeBytes)}__emscripten_fetch_get_response_headers.sig="pipp";function __emscripten_fetch_get_response_headers_length(id){return lengthBytesUTF8(Fetch.xhrs.get(id).getAllResponseHeaders())+1}__emscripten_fetch_get_response_headers_length.sig="pi";var __emscripten_fs_load_embedded_files=ptr=>{do{var name_addr=HEAPU32[ptr>>2];ptr+=4;var len=HEAPU32[ptr>>2];ptr+=4;var content=HEAPU32[ptr>>2];ptr+=4;var name=UTF8ToString(name_addr);FS.createPath("/",PATH.dirname(name),true,true);FS.createDataFile(name,null,HEAP8.subarray(content,content+len),true,true,true)}while(HEAPU32[ptr>>2])};__emscripten_fs_load_embedded_files.sig="vp";var nowIsMonotonic=true;var __emscripten_get_now_is_monotonic=()=>nowIsMonotonic;__emscripten_get_now_is_monotonic.sig="i";var __emscripten_get_progname=(str,len)=>{stringToUTF8(thisProgram,str,len)};__emscripten_get_progname.sig="vpi";var __emscripten_runtime_keepalive_clear=()=>{noExitRuntime=false;runtimeKeepaliveCounter=0};__emscripten_runtime_keepalive_clear.sig="v";var __emscripten_set_offscreencanvas_size=(target,width,height)=>-1;__emscripten_set_offscreencanvas_size.sig="ipii";function __gmtime_js(time,tmPtr){time=bigintToI53Checked(time);var date=new Date(time*1e3);HEAP32[tmPtr>>2]=date.getUTCSeconds();HEAP32[tmPtr+4>>2]=date.getUTCMinutes();HEAP32[tmPtr+8>>2]=date.getUTCHours();HEAP32[tmPtr+12>>2]=date.getUTCDate();HEAP32[tmPtr+16>>2]=date.getUTCMonth();HEAP32[tmPtr+20>>2]=date.getUTCFullYear()-1900;HEAP32[tmPtr+24>>2]=date.getUTCDay();var start=Date.UTC(date.getUTCFullYear(),0,1,0,0,0,0);var yday=(date.getTime()-start)/(1e3*60*60*24)|0;HEAP32[tmPtr+28>>2]=yday}__gmtime_js.sig="vjp";var isLeapYear=year=>year%4===0&&(year%100!==0||year%400===0);var MONTH_DAYS_LEAP_CUMULATIVE=[0,31,60,91,121,152,182,213,244,274,305,335];var MONTH_DAYS_REGULAR_CUMULATIVE=[0,31,59,90,120,151,181,212,243,273,304,334];var ydayFromDate=date=>{var leap=isLeapYear(date.getFullYear());var monthDaysCumulative=leap?MONTH_DAYS_LEAP_CUMULATIVE:MONTH_DAYS_REGULAR_CUMULATIVE;var yday=monthDaysCumulative[date.getMonth()]+date.getDate()-1;return yday};function __localtime_js(time,tmPtr){time=bigintToI53Checked(time);var date=new Date(time*1e3);HEAP32[tmPtr>>2]=date.getSeconds();HEAP32[tmPtr+4>>2]=date.getMinutes();HEAP32[tmPtr+8>>2]=date.getHours();HEAP32[tmPtr+12>>2]=date.getDate();HEAP32[tmPtr+16>>2]=date.getMonth();HEAP32[tmPtr+20>>2]=date.getFullYear()-1900;HEAP32[tmPtr+24>>2]=date.getDay();var yday=ydayFromDate(date)|0;HEAP32[tmPtr+28>>2]=yday;HEAP32[tmPtr+36>>2]=-(date.getTimezoneOffset()*60);var start=new Date(date.getFullYear(),0,1);var summerOffset=new Date(date.getFullYear(),6,1).getTimezoneOffset();var winterOffset=start.getTimezoneOffset();var dst=(summerOffset!=winterOffset&&date.getTimezoneOffset()==Math.min(winterOffset,summerOffset))|0;HEAP32[tmPtr+32>>2]=dst}__localtime_js.sig="vjp";var __mktime_js=function(tmPtr){var ret=(()=>{var date=new Date(HEAP32[tmPtr+20>>2]+1900,HEAP32[tmPtr+16>>2],HEAP32[tmPtr+12>>2],HEAP32[tmPtr+8>>2],HEAP32[tmPtr+4>>2],HEAP32[tmPtr>>2],0);var dst=HEAP32[tmPtr+32>>2];var guessedOffset=date.getTimezoneOffset();var start=new Date(date.getFullYear(),0,1);var summerOffset=new Date(date.getFullYear(),6,1).getTimezoneOffset();var winterOffset=start.getTimezoneOffset();var dstOffset=Math.min(winterOffset,summerOffset);if(dst<0){HEAP32[tmPtr+32>>2]=Number(summerOffset!=winterOffset&&dstOffset==guessedOffset)}else if(dst>0!=(dstOffset==guessedOffset)){var nonDstOffset=Math.max(winterOffset,summerOffset);var trueOffset=dst>0?dstOffset:nonDstOffset;date.setTime(date.getTime()+(trueOffset-guessedOffset)*6e4)}HEAP32[tmPtr+24>>2]=date.getDay();var yday=ydayFromDate(date)|0;HEAP32[tmPtr+28>>2]=yday;HEAP32[tmPtr>>2]=date.getSeconds();HEAP32[tmPtr+4>>2]=date.getMinutes();HEAP32[tmPtr+8>>2]=date.getHours();HEAP32[tmPtr+12>>2]=date.getDate();HEAP32[tmPtr+16>>2]=date.getMonth();HEAP32[tmPtr+20>>2]=date.getYear();return date.getTime()/1e3})();return BigInt(ret)};__mktime_js.sig="jp";function __mmap_js(len,prot,flags,fd,offset,allocated,addr){offset=bigintToI53Checked(offset);try{if(isNaN(offset))return 61;var stream=SYSCALLS.getStreamFromFD(fd);var res=FS.mmap(stream,len,offset,prot,flags);var ptr=res.ptr;HEAP32[allocated>>2]=res.allocated;HEAPU32[addr>>2]=ptr;return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}__mmap_js.sig="ipiiijpp";function __msync_js(addr,len,prot,flags,fd,offset){offset=bigintToI53Checked(offset);try{if(isNaN(offset))return 61;SYSCALLS.doMsync(addr,SYSCALLS.getStreamFromFD(fd),len,flags,offset);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}__msync_js.sig="ippiiij";function __munmap_js(addr,len,prot,flags,fd,offset){offset=bigintToI53Checked(offset);try{if(isNaN(offset))return 61;var stream=SYSCALLS.getStreamFromFD(fd);if(prot&2){SYSCALLS.doMsync(addr,stream,len,flags,offset)}FS.munmap(stream)}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return-e.errno}}__munmap_js.sig="ippiiij";var timers={};var __setitimer_js=(which,timeout_ms)=>{if(timers[which]){clearTimeout(timers[which].id);delete timers[which]}if(!timeout_ms)return 0;var id=setTimeout(()=>{delete timers[which];callUserCallback(()=>__emscripten_timeout(which,_emscripten_get_now()))},timeout_ms);timers[which]={id:id,timeout_ms:timeout_ms};return 0};__setitimer_js.sig="iid";var __timegm_js=function(tmPtr){var ret=(()=>{var time=Date.UTC(HEAP32[tmPtr+20>>2]+1900,HEAP32[tmPtr+16>>2],HEAP32[tmPtr+12>>2],HEAP32[tmPtr+8>>2],HEAP32[tmPtr+4>>2],HEAP32[tmPtr>>2],0);var date=new Date(time);HEAP32[tmPtr+24>>2]=date.getUTCDay();var start=Date.UTC(date.getUTCFullYear(),0,1,0,0,0,0);var yday=(date.getTime()-start)/(1e3*60*60*24)|0;HEAP32[tmPtr+28>>2]=yday;return date.getTime()/1e3})();return BigInt(ret)};__timegm_js.sig="jp";var stringToNewUTF8=str=>{var size=lengthBytesUTF8(str)+1;var ret=_malloc(size);if(ret)stringToUTF8(str,ret,size);return ret};var __tzset_js=(timezone,daylight,tzname)=>{var currentYear=(new Date).getFullYear();var winter=new Date(currentYear,0,1);var summer=new Date(currentYear,6,1);var winterOffset=winter.getTimezoneOffset();var summerOffset=summer.getTimezoneOffset();var stdTimezoneOffset=Math.max(winterOffset,summerOffset);HEAPU32[timezone>>2]=stdTimezoneOffset*60;HEAP32[daylight>>2]=Number(winterOffset!=summerOffset);function extractZone(date){var match=date.toTimeString().match(/\(([A-Za-z ]+)\)$/);return match?match[1]:"GMT"}var winterName=extractZone(winter);var summerName=extractZone(summer);var winterNamePtr=stringToNewUTF8(winterName);var summerNamePtr=stringToNewUTF8(summerName);if(summerOffset<winterOffset){HEAPU32[tzname>>2]=winterNamePtr;HEAPU32[tzname+4>>2]=summerNamePtr}else{HEAPU32[tzname>>2]=summerNamePtr;HEAPU32[tzname+4>>2]=winterNamePtr}};__tzset_js.sig="vppp";var _abort=()=>{abort("")};_abort.sig="v";var AL={QUEUE_INTERVAL:25,QUEUE_LOOKAHEAD:.1,DEVICE_NAME:"Emscripten OpenAL",CAPTURE_DEVICE_NAME:"Emscripten OpenAL capture",ALC_EXTENSIONS:{ALC_SOFT_pause_device:true,ALC_SOFT_HRTF:true},AL_EXTENSIONS:{AL_EXT_float32:true,AL_SOFT_loop_points:true,AL_SOFT_source_length:true,AL_EXT_source_distance_model:true,AL_SOFT_source_spatialize:true},_alcErr:0,alcErr:0,deviceRefCounts:{},alcStringCache:{},paused:false,stringCache:{},contexts:{},currentCtx:null,buffers:{0:{id:0,refCount:0,audioBuf:null,frequency:0,bytesPerSample:2,channels:1,length:0}},paramArray:[],_nextId:1,newId:()=>AL.freeIds.length>0?AL.freeIds.pop():AL._nextId++,freeIds:[],scheduleContextAudio:ctx=>{if(Browser.mainLoop.timingMode===1&&document["visibilityState"]!="visible"){return}for(var i in ctx.sources){AL.scheduleSourceAudio(ctx.sources[i])}},scheduleSourceAudio:(src,lookahead)=>{if(Browser.mainLoop.timingMode===1&&document["visibilityState"]!="visible"){return}if(src.state!==4114){return}var currentTime=AL.updateSourceTime(src);var startTime=src.bufStartTime;var startOffset=src.bufOffset;var bufCursor=src.bufsProcessed;for(var i=0;i<src.audioQueue.length;i++){var audioSrc=src.audioQueue[i];startTime=audioSrc._startTime+audioSrc._duration;startOffset=0;bufCursor+=audioSrc._skipCount+1}if(!lookahead){lookahead=AL.QUEUE_LOOKAHEAD}var lookaheadTime=currentTime+lookahead;var skipCount=0;while(startTime<lookaheadTime){if(bufCursor>=src.bufQueue.length){if(src.looping){bufCursor%=src.bufQueue.length}else{break}}var buf=src.bufQueue[bufCursor%src.bufQueue.length];if(buf.length===0){skipCount++;if(skipCount===src.bufQueue.length){break}}else{var audioSrc=src.context.audioCtx.createBufferSource();audioSrc.buffer=buf.audioBuf;audioSrc.playbackRate.value=src.playbackRate;if(buf.audioBuf._loopStart||buf.audioBuf._loopEnd){audioSrc.loopStart=buf.audioBuf._loopStart;audioSrc.loopEnd=buf.audioBuf._loopEnd}var duration=0;if(src.type===4136&&src.looping){duration=Number.POSITIVE_INFINITY;audioSrc.loop=true;if(buf.audioBuf._loopStart){audioSrc.loopStart=buf.audioBuf._loopStart}if(buf.audioBuf._loopEnd){audioSrc.loopEnd=buf.audioBuf._loopEnd}}else{duration=(buf.audioBuf.duration-startOffset)/src.playbackRate}audioSrc._startOffset=startOffset;audioSrc._duration=duration;audioSrc._skipCount=skipCount;skipCount=0;audioSrc.connect(src.gain);if(typeof audioSrc.start!="undefined"){startTime=Math.max(startTime,src.context.audioCtx.currentTime);audioSrc.start(startTime,startOffset)}else if(typeof audioSrc.noteOn!="undefined"){startTime=Math.max(startTime,src.context.audioCtx.currentTime);audioSrc.noteOn(startTime)}audioSrc._startTime=startTime;src.audioQueue.push(audioSrc);startTime+=duration}startOffset=0;bufCursor++}},updateSourceTime:src=>{var currentTime=src.context.audioCtx.currentTime;if(src.state!==4114){return currentTime}if(!isFinite(src.bufStartTime)){src.bufStartTime=currentTime-src.bufOffset/src.playbackRate;src.bufOffset=0}var nextStartTime=0;while(src.audioQueue.length){var audioSrc=src.audioQueue[0];src.bufsProcessed+=audioSrc._skipCount;nextStartTime=audioSrc._startTime+audioSrc._duration;if(currentTime<nextStartTime){break}src.audioQueue.shift();src.bufStartTime=nextStartTime;src.bufOffset=0;src.bufsProcessed++}if(src.bufsProcessed>=src.bufQueue.length&&!src.looping){AL.setSourceState(src,4116)}else if(src.type===4136&&src.looping){var buf=src.bufQueue[0];if(buf.length===0){src.bufOffset=0}else{var delta=(currentTime-src.bufStartTime)*src.playbackRate;var loopStart=buf.audioBuf._loopStart||0;var loopEnd=buf.audioBuf._loopEnd||buf.audioBuf.duration;if(loopEnd<=loopStart){loopEnd=buf.audioBuf.duration}if(delta<loopEnd){src.bufOffset=delta}else{src.bufOffset=loopStart+(delta-loopStart)%(loopEnd-loopStart)}}}else if(src.audioQueue[0]){src.bufOffset=(currentTime-src.audioQueue[0]._startTime)*src.playbackRate}else{if(src.type!==4136&&src.looping){var srcDuration=AL.sourceDuration(src)/src.playbackRate;if(srcDuration>0){src.bufStartTime+=Math.floor((currentTime-src.bufStartTime)/srcDuration)*srcDuration}}for(var i=0;i<src.bufQueue.length;i++){if(src.bufsProcessed>=src.bufQueue.length){if(src.looping){src.bufsProcessed%=src.bufQueue.length}else{AL.setSourceState(src,4116);break}}var buf=src.bufQueue[src.bufsProcessed];if(buf.length>0){nextStartTime=src.bufStartTime+buf.audioBuf.duration/src.playbackRate;if(currentTime<nextStartTime){src.bufOffset=(currentTime-src.bufStartTime)*src.playbackRate;break}src.bufStartTime=nextStartTime}src.bufOffset=0;src.bufsProcessed++}}return currentTime},cancelPendingSourceAudio:src=>{AL.updateSourceTime(src);for(var i=1;i<src.audioQueue.length;i++){var audioSrc=src.audioQueue[i];audioSrc.stop()}if(src.audioQueue.length>1){src.audioQueue.length=1}},stopSourceAudio:src=>{for(var i=0;i<src.audioQueue.length;i++){src.audioQueue[i].stop()}src.audioQueue.length=0},setSourceState:(src,state)=>{if(state===4114){if(src.state===4114||src.state==4116){src.bufsProcessed=0;src.bufOffset=0}else{}AL.stopSourceAudio(src);src.state=4114;src.bufStartTime=Number.NEGATIVE_INFINITY;AL.scheduleSourceAudio(src)}else if(state===4115){if(src.state===4114){AL.updateSourceTime(src);AL.stopSourceAudio(src);src.state=4115}}else if(state===4116){if(src.state!==4113){src.state=4116;src.bufsProcessed=src.bufQueue.length;src.bufStartTime=Number.NEGATIVE_INFINITY;src.bufOffset=0;AL.stopSourceAudio(src)}}else if(state===4113){if(src.state!==4113){src.state=4113;src.bufsProcessed=0;src.bufStartTime=Number.NEGATIVE_INFINITY;src.bufOffset=0;AL.stopSourceAudio(src)}}},initSourcePanner:src=>{if(src.type===4144){return}var templateBuf=AL.buffers[0];for(var i=0;i<src.bufQueue.length;i++){if(src.bufQueue[i].id!==0){templateBuf=src.bufQueue[i];break}}if(src.spatialize===1||src.spatialize===2&&templateBuf.channels===1){if(src.panner){return}src.panner=src.context.audioCtx.createPanner();AL.updateSourceGlobal(src);AL.updateSourceSpace(src);src.panner.connect(src.context.gain);src.gain.disconnect();src.gain.connect(src.panner)}else{if(!src.panner){return}src.panner.disconnect();src.gain.disconnect();src.gain.connect(src.context.gain);src.panner=null}},updateContextGlobal:ctx=>{for(var i in ctx.sources){AL.updateSourceGlobal(ctx.sources[i])}},updateSourceGlobal:src=>{var panner=src.panner;if(!panner){return}panner.refDistance=src.refDistance;panner.maxDistance=src.maxDistance;panner.rolloffFactor=src.rolloffFactor;panner.panningModel=src.context.hrtf?"HRTF":"equalpower";var distanceModel=src.context.sourceDistanceModel?src.distanceModel:src.context.distanceModel;switch(distanceModel){case 0:panner.distanceModel="inverse";panner.refDistance=340282e33;break;case 53249:case 53250:panner.distanceModel="inverse";break;case 53251:case 53252:panner.distanceModel="linear";break;case 53253:case 53254:panner.distanceModel="exponential";break}},updateListenerSpace:ctx=>{var listener=ctx.audioCtx.listener;if(listener.positionX){listener.positionX.value=ctx.listener.position[0];listener.positionY.value=ctx.listener.position[1];listener.positionZ.value=ctx.listener.position[2]}else{listener.setPosition(ctx.listener.position[0],ctx.listener.position[1],ctx.listener.position[2])}if(listener.forwardX){listener.forwardX.value=ctx.listener.direction[0];listener.forwardY.value=ctx.listener.direction[1];listener.forwardZ.value=ctx.listener.direction[2];listener.upX.value=ctx.listener.up[0];listener.upY.value=ctx.listener.up[1];listener.upZ.value=ctx.listener.up[2]}else{listener.setOrientation(ctx.listener.direction[0],ctx.listener.direction[1],ctx.listener.direction[2],ctx.listener.up[0],ctx.listener.up[1],ctx.listener.up[2])}for(var i in ctx.sources){AL.updateSourceSpace(ctx.sources[i])}},updateSourceSpace:src=>{if(!src.panner){return}var panner=src.panner;var posX=src.position[0];var posY=src.position[1];var posZ=src.position[2];var dirX=src.direction[0];var dirY=src.direction[1];var dirZ=src.direction[2];var listener=src.context.listener;var lPosX=listener.position[0];var lPosY=listener.position[1];var lPosZ=listener.position[2];if(src.relative){var lBackX=-listener.direction[0];var lBackY=-listener.direction[1];var lBackZ=-listener.direction[2];var lUpX=listener.up[0];var lUpY=listener.up[1];var lUpZ=listener.up[2];var inverseMagnitude=(x,y,z)=>{var length=Math.sqrt(x*x+y*y+z*z);if(length<Number.EPSILON){return 0}return 1/length};var invMag=inverseMagnitude(lBackX,lBackY,lBackZ);lBackX*=invMag;lBackY*=invMag;lBackZ*=invMag;invMag=inverseMagnitude(lUpX,lUpY,lUpZ);lUpX*=invMag;lUpY*=invMag;lUpZ*=invMag;var lRightX=lUpY*lBackZ-lUpZ*lBackY;var lRightY=lUpZ*lBackX-lUpX*lBackZ;var lRightZ=lUpX*lBackY-lUpY*lBackX;invMag=inverseMagnitude(lRightX,lRightY,lRightZ);lRightX*=invMag;lRightY*=invMag;lRightZ*=invMag;lUpX=lBackY*lRightZ-lBackZ*lRightY;lUpY=lBackZ*lRightX-lBackX*lRightZ;lUpZ=lBackX*lRightY-lBackY*lRightX;var oldX=dirX;var oldY=dirY;var oldZ=dirZ;dirX=oldX*lRightX+oldY*lUpX+oldZ*lBackX;dirY=oldX*lRightY+oldY*lUpY+oldZ*lBackY;dirZ=oldX*lRightZ+oldY*lUpZ+oldZ*lBackZ;oldX=posX;oldY=posY;oldZ=posZ;posX=oldX*lRightX+oldY*lUpX+oldZ*lBackX;posY=oldX*lRightY+oldY*lUpY+oldZ*lBackY;posZ=oldX*lRightZ+oldY*lUpZ+oldZ*lBackZ;posX+=lPosX;posY+=lPosY;posZ+=lPosZ}if(panner.positionX){if(posX!=panner.positionX.value)panner.positionX.value=posX;if(posY!=panner.positionY.value)panner.positionY.value=posY;if(posZ!=panner.positionZ.value)panner.positionZ.value=posZ}else{panner.setPosition(posX,posY,posZ)}if(panner.orientationX){if(dirX!=panner.orientationX.value)panner.orientationX.value=dirX;if(dirY!=panner.orientationY.value)panner.orientationY.value=dirY;if(dirZ!=panner.orientationZ.value)panner.orientationZ.value=dirZ}else{panner.setOrientation(dirX,dirY,dirZ)}var oldShift=src.dopplerShift;var velX=src.velocity[0];var velY=src.velocity[1];var velZ=src.velocity[2];var lVelX=listener.velocity[0];var lVelY=listener.velocity[1];var lVelZ=listener.velocity[2];if(posX===lPosX&&posY===lPosY&&posZ===lPosZ||velX===lVelX&&velY===lVelY&&velZ===lVelZ){src.dopplerShift=1}else{var speedOfSound=src.context.speedOfSound;var dopplerFactor=src.context.dopplerFactor;var slX=lPosX-posX;var slY=lPosY-posY;var slZ=lPosZ-posZ;var magSl=Math.sqrt(slX*slX+slY*slY+slZ*slZ);var vls=(slX*lVelX+slY*lVelY+slZ*lVelZ)/magSl;var vss=(slX*velX+slY*velY+slZ*velZ)/magSl;vls=Math.min(vls,speedOfSound/dopplerFactor);vss=Math.min(vss,speedOfSound/dopplerFactor);src.dopplerShift=(speedOfSound-dopplerFactor*vls)/(speedOfSound-dopplerFactor*vss)}if(src.dopplerShift!==oldShift){AL.updateSourceRate(src)}},updateSourceRate:src=>{if(src.state===4114){AL.cancelPendingSourceAudio(src);var audioSrc=src.audioQueue[0];if(!audioSrc){return}var duration;if(src.type===4136&&src.looping){duration=Number.POSITIVE_INFINITY}else{duration=(audioSrc.buffer.duration-audioSrc._startOffset)/src.playbackRate}audioSrc._duration=duration;audioSrc.playbackRate.value=src.playbackRate;AL.scheduleSourceAudio(src)}},sourceDuration:src=>{var length=0;for(var i=0;i<src.bufQueue.length;i++){var audioBuf=src.bufQueue[i].audioBuf;length+=audioBuf?audioBuf.duration:0}return length},sourceTell:src=>{AL.updateSourceTime(src);var offset=0;for(var i=0;i<src.bufsProcessed;i++){if(src.bufQueue[i].audioBuf){offset+=src.bufQueue[i].audioBuf.duration}}offset+=src.bufOffset;return offset},sourceSeek:(src,offset)=>{var playing=src.state==4114;if(playing){AL.setSourceState(src,4113)}if(src.bufQueue[src.bufsProcessed].audioBuf!==null){src.bufsProcessed=0;while(offset>src.bufQueue[src.bufsProcessed].audioBuf.duration){offset-=src.bufQueue[src.bufsProcessed].audiobuf.duration;src.bufsProcessed++}src.bufOffset=offset}if(playing){AL.setSourceState(src,4114)}},getGlobalParam:(funcname,param)=>{if(!AL.currentCtx){return null}switch(param){case 49152:return AL.currentCtx.dopplerFactor;case 49155:return AL.currentCtx.speedOfSound;case 53248:return AL.currentCtx.distanceModel;default:AL.currentCtx.err=40962;return null}},setGlobalParam:(funcname,param,value)=>{if(!AL.currentCtx){return}switch(param){case 49152:if(!Number.isFinite(value)||value<0){AL.currentCtx.err=40963;return}AL.currentCtx.dopplerFactor=value;AL.updateListenerSpace(AL.currentCtx);break;case 49155:if(!Number.isFinite(value)||value<=0){AL.currentCtx.err=40963;return}AL.currentCtx.speedOfSound=value;AL.updateListenerSpace(AL.currentCtx);break;case 53248:switch(value){case 0:case 53249:case 53250:case 53251:case 53252:case 53253:case 53254:AL.currentCtx.distanceModel=value;AL.updateContextGlobal(AL.currentCtx);break;default:AL.currentCtx.err=40963;return}break;default:AL.currentCtx.err=40962;return}},getListenerParam:(funcname,param)=>{if(!AL.currentCtx){return null}switch(param){case 4100:return AL.currentCtx.listener.position;case 4102:return AL.currentCtx.listener.velocity;case 4111:return AL.currentCtx.listener.direction.concat(AL.currentCtx.listener.up);case 4106:return AL.currentCtx.gain.gain.value;default:AL.currentCtx.err=40962;return null}},setListenerParam:(funcname,param,value)=>{if(!AL.currentCtx){return}if(value===null){AL.currentCtx.err=40962;return}var listener=AL.currentCtx.listener;switch(param){case 4100:if(!Number.isFinite(value[0])||!Number.isFinite(value[1])||!Number.isFinite(value[2])){AL.currentCtx.err=40963;return}listener.position[0]=value[0];listener.position[1]=value[1];listener.position[2]=value[2];AL.updateListenerSpace(AL.currentCtx);break;case 4102:if(!Number.isFinite(value[0])||!Number.isFinite(value[1])||!Number.isFinite(value[2])){AL.currentCtx.err=40963;return}listener.velocity[0]=value[0];listener.velocity[1]=value[1];listener.velocity[2]=value[2];AL.updateListenerSpace(AL.currentCtx);break;case 4106:if(!Number.isFinite(value)||value<0){AL.currentCtx.err=40963;return}AL.currentCtx.gain.gain.value=value;break;case 4111:if(!Number.isFinite(value[0])||!Number.isFinite(value[1])||!Number.isFinite(value[2])||!Number.isFinite(value[3])||!Number.isFinite(value[4])||!Number.isFinite(value[5])){AL.currentCtx.err=40963;return}listener.direction[0]=value[0];listener.direction[1]=value[1];listener.direction[2]=value[2];listener.up[0]=value[3];listener.up[1]=value[4];listener.up[2]=value[5];AL.updateListenerSpace(AL.currentCtx);break;default:AL.currentCtx.err=40962;return}},getBufferParam:(funcname,bufferId,param)=>{if(!AL.currentCtx){return}var buf=AL.buffers[bufferId];if(!buf||bufferId===0){AL.currentCtx.err=40961;return}switch(param){case 8193:return buf.frequency;case 8194:return buf.bytesPerSample*8;case 8195:return buf.channels;case 8196:return buf.length*buf.bytesPerSample*buf.channels;case 8213:if(buf.length===0){return[0,0]}return[(buf.audioBuf._loopStart||0)*buf.frequency,(buf.audioBuf._loopEnd||buf.length)*buf.frequency];default:AL.currentCtx.err=40962;return null}},setBufferParam:(funcname,bufferId,param,value)=>{if(!AL.currentCtx){return}var buf=AL.buffers[bufferId];if(!buf||bufferId===0){AL.currentCtx.err=40961;return}if(value===null){AL.currentCtx.err=40962;return}switch(param){case 8196:if(value!==0){AL.currentCtx.err=40963;return}break;case 8213:if(value[0]<0||value[0]>buf.length||value[1]<0||value[1]>buf.Length||value[0]>=value[1]){AL.currentCtx.err=40963;return}if(buf.refCount>0){AL.currentCtx.err=40964;return}if(buf.audioBuf){buf.audioBuf._loopStart=value[0]/buf.frequency;buf.audioBuf._loopEnd=value[1]/buf.frequency}break;default:AL.currentCtx.err=40962;return}},getSourceParam:(funcname,sourceId,param)=>{if(!AL.currentCtx){return null}var src=AL.currentCtx.sources[sourceId];if(!src){AL.currentCtx.err=40961;return null}switch(param){case 514:return src.relative;case 4097:return src.coneInnerAngle;case 4098:return src.coneOuterAngle;case 4099:return src.pitch;case 4100:return src.position;case 4101:return src.direction;case 4102:return src.velocity;case 4103:return src.looping;case 4105:if(src.type===4136){return src.bufQueue[0].id}return 0;case 4106:return src.gain.gain.value;case 4109:return src.minGain;case 4110:return src.maxGain;case 4112:return src.state;case 4117:if(src.bufQueue.length===1&&src.bufQueue[0].id===0){return 0}return src.bufQueue.length;case 4118:if(src.bufQueue.length===1&&src.bufQueue[0].id===0||src.looping){return 0}return src.bufsProcessed;case 4128:return src.refDistance;case 4129:return src.rolloffFactor;case 4130:return src.coneOuterGain;case 4131:return src.maxDistance;case 4132:return AL.sourceTell(src);case 4133:var offset=AL.sourceTell(src);if(offset>0){offset*=src.bufQueue[0].frequency}return offset;case 4134:var offset=AL.sourceTell(src);if(offset>0){offset*=src.bufQueue[0].frequency*src.bufQueue[0].bytesPerSample}return offset;case 4135:return src.type;case 4628:return src.spatialize;case 8201:var length=0;var bytesPerFrame=0;for(var i=0;i<src.bufQueue.length;i++){length+=src.bufQueue[i].length;if(src.bufQueue[i].id!==0){bytesPerFrame=src.bufQueue[i].bytesPerSample*src.bufQueue[i].channels}}return length*bytesPerFrame;case 8202:var length=0;for(var i=0;i<src.bufQueue.length;i++){length+=src.bufQueue[i].length}return length;case 8203:return AL.sourceDuration(src);case 53248:return src.distanceModel;default:AL.currentCtx.err=40962;return null}},setSourceParam:(funcname,sourceId,param,value)=>{if(!AL.currentCtx){return}var src=AL.currentCtx.sources[sourceId];if(!src){AL.currentCtx.err=40961;return}if(value===null){AL.currentCtx.err=40962;return}switch(param){case 514:if(value===1){src.relative=true;AL.updateSourceSpace(src)}else if(value===0){src.relative=false;AL.updateSourceSpace(src)}else{AL.currentCtx.err=40963;return}break;case 4097:if(!Number.isFinite(value)){AL.currentCtx.err=40963;return}src.coneInnerAngle=value;if(src.panner){src.panner.coneInnerAngle=value%360}break;case 4098:if(!Number.isFinite(value)){AL.currentCtx.err=40963;return}src.coneOuterAngle=value;if(src.panner){src.panner.coneOuterAngle=value%360}break;case 4099:if(!Number.isFinite(value)||value<=0){AL.currentCtx.err=40963;return}if(src.pitch===value){break}src.pitch=value;AL.updateSourceRate(src);break;case 4100:if(!Number.isFinite(value[0])||!Number.isFinite(value[1])||!Number.isFinite(value[2])){AL.currentCtx.err=40963;return}src.position[0]=value[0];src.position[1]=value[1];src.position[2]=value[2];AL.updateSourceSpace(src);break;case 4101:if(!Number.isFinite(value[0])||!Number.isFinite(value[1])||!Number.isFinite(value[2])){AL.currentCtx.err=40963;return}src.direction[0]=value[0];src.direction[1]=value[1];src.direction[2]=value[2];AL.updateSourceSpace(src);break;case 4102:if(!Number.isFinite(value[0])||!Number.isFinite(value[1])||!Number.isFinite(value[2])){AL.currentCtx.err=40963;return}src.velocity[0]=value[0];src.velocity[1]=value[1];src.velocity[2]=value[2];AL.updateSourceSpace(src);break;case 4103:if(value===1){src.looping=true;AL.updateSourceTime(src);if(src.type===4136&&src.audioQueue.length>0){var audioSrc=src.audioQueue[0];audioSrc.loop=true;audioSrc._duration=Number.POSITIVE_INFINITY}}else if(value===0){src.looping=false;var currentTime=AL.updateSourceTime(src);if(src.type===4136&&src.audioQueue.length>0){var audioSrc=src.audioQueue[0];audioSrc.loop=false;audioSrc._duration=src.bufQueue[0].audioBuf.duration/src.playbackRate;audioSrc._startTime=currentTime-src.bufOffset/src.playbackRate}}else{AL.currentCtx.err=40963;return}break;case 4105:if(src.state===4114||src.state===4115){AL.currentCtx.err=40964;return}if(value===0){for(var i in src.bufQueue){src.bufQueue[i].refCount--}src.bufQueue.length=1;src.bufQueue[0]=AL.buffers[0];src.bufsProcessed=0;src.type=4144}else{var buf=AL.buffers[value];if(!buf){AL.currentCtx.err=40963;return}for(var i in src.bufQueue){src.bufQueue[i].refCount--}src.bufQueue.length=0;buf.refCount++;src.bufQueue=[buf];src.bufsProcessed=0;src.type=4136}AL.initSourcePanner(src);AL.scheduleSourceAudio(src);break;case 4106:if(!Number.isFinite(value)||value<0){AL.currentCtx.err=40963;return}src.gain.gain.value=value;break;case 4109:if(!Number.isFinite(value)||value<0||value>Math.min(src.maxGain,1)){AL.currentCtx.err=40963;return}src.minGain=value;break;case 4110:if(!Number.isFinite(value)||value<Math.max(0,src.minGain)||value>1){AL.currentCtx.err=40963;return}src.maxGain=value;break;case 4128:if(!Number.isFinite(value)||value<0){AL.currentCtx.err=40963;return}src.refDistance=value;if(src.panner){src.panner.refDistance=value}break;case 4129:if(!Number.isFinite(value)||value<0){AL.currentCtx.err=40963;return}src.rolloffFactor=value;if(src.panner){src.panner.rolloffFactor=value}break;case 4130:if(!Number.isFinite(value)||value<0||value>1){AL.currentCtx.err=40963;return}src.coneOuterGain=value;if(src.panner){src.panner.coneOuterGain=value}break;case 4131:if(!Number.isFinite(value)||value<0){AL.currentCtx.err=40963;return}src.maxDistance=value;if(src.panner){src.panner.maxDistance=value}break;case 4132:if(value<0||value>AL.sourceDuration(src)){AL.currentCtx.err=40963;return}AL.sourceSeek(src,value);break;case 4133:var srcLen=AL.sourceDuration(src);if(srcLen>0){var frequency;for(var bufId in src.bufQueue){if(bufId){frequency=src.bufQueue[bufId].frequency;break}}value/=frequency}if(value<0||value>srcLen){AL.currentCtx.err=40963;return}AL.sourceSeek(src,value);break;case 4134:var srcLen=AL.sourceDuration(src);if(srcLen>0){var bytesPerSec;for(var bufId in src.bufQueue){if(bufId){var buf=src.bufQueue[bufId];bytesPerSec=buf.frequency*buf.bytesPerSample*buf.channels;break}}value/=bytesPerSec}if(value<0||value>srcLen){AL.currentCtx.err=40963;return}AL.sourceSeek(src,value);break;case 4628:if(value!==0&&value!==1&&value!==2){AL.currentCtx.err=40963;return}src.spatialize=value;AL.initSourcePanner(src);break;case 8201:case 8202:case 8203:AL.currentCtx.err=40964;break;case 53248:switch(value){case 0:case 53249:case 53250:case 53251:case 53252:case 53253:case 53254:src.distanceModel=value;if(AL.currentCtx.sourceDistanceModel){AL.updateContextGlobal(AL.currentCtx)}break;default:AL.currentCtx.err=40963;return}break;default:AL.currentCtx.err=40962;return}},captures:{},sharedCaptureAudioCtx:null,requireValidCaptureDevice:(deviceId,funcname)=>{if(deviceId===0){AL.alcErr=40961;return null}var c=AL.captures[deviceId];if(!c){AL.alcErr=40961;return null}var err=c.mediaStreamError;if(err){AL.alcErr=40961;return null}return c}};var _alBuffer3f=(bufferId,param,value0,value1,value2)=>{AL.setBufferParam("alBuffer3f",bufferId,param,null)};_alBuffer3f.sig="viifff";var _alBuffer3i=(bufferId,param,value0,value1,value2)=>{AL.setBufferParam("alBuffer3i",bufferId,param,null)};_alBuffer3i.sig="viiiii";var _alBufferData=(bufferId,format,pData,size,freq)=>{if(!AL.currentCtx){return}var buf=AL.buffers[bufferId];if(!buf){AL.currentCtx.err=40963;return}if(freq<=0){AL.currentCtx.err=40963;return}var audioBuf=null;try{switch(format){case 4352:if(size>0){audioBuf=AL.currentCtx.audioCtx.createBuffer(1,size,freq);var channel0=audioBuf.getChannelData(0);for(var i=0;i<size;++i){channel0[i]=HEAPU8[pData++]*.0078125-1}}buf.bytesPerSample=1;buf.channels=1;buf.length=size;break;case 4353:if(size>0){audioBuf=AL.currentCtx.audioCtx.createBuffer(1,size>>1,freq);var channel0=audioBuf.getChannelData(0);pData>>=1;for(var i=0;i<size>>1;++i){channel0[i]=HEAP16[pData++]*30517578125e-15}}buf.bytesPerSample=2;buf.channels=1;buf.length=size>>1;break;case 4354:if(size>0){audioBuf=AL.currentCtx.audioCtx.createBuffer(2,size>>1,freq);var channel0=audioBuf.getChannelData(0);var channel1=audioBuf.getChannelData(1);for(var i=0;i<size>>1;++i){channel0[i]=HEAPU8[pData++]*.0078125-1;channel1[i]=HEAPU8[pData++]*.0078125-1}}buf.bytesPerSample=1;buf.channels=2;buf.length=size>>1;break;case 4355:if(size>0){audioBuf=AL.currentCtx.audioCtx.createBuffer(2,size>>2,freq);var channel0=audioBuf.getChannelData(0);var channel1=audioBuf.getChannelData(1);pData>>=1;for(var i=0;i<size>>2;++i){channel0[i]=HEAP16[pData++]*30517578125e-15;channel1[i]=HEAP16[pData++]*30517578125e-15}}buf.bytesPerSample=2;buf.channels=2;buf.length=size>>2;break;case 65552:if(size>0){audioBuf=AL.currentCtx.audioCtx.createBuffer(1,size>>2,freq);var channel0=audioBuf.getChannelData(0);pData>>=2;for(var i=0;i<size>>2;++i){channel0[i]=HEAPF32[pData++]}}buf.bytesPerSample=4;buf.channels=1;buf.length=size>>2;break;case 65553:if(size>0){audioBuf=AL.currentCtx.audioCtx.createBuffer(2,size>>3,freq);var channel0=audioBuf.getChannelData(0);var channel1=audioBuf.getChannelData(1);pData>>=2;for(var i=0;i<size>>3;++i){channel0[i]=HEAPF32[pData++];channel1[i]=HEAPF32[pData++]}}buf.bytesPerSample=4;buf.channels=2;buf.length=size>>3;break;default:AL.currentCtx.err=40963;return}buf.frequency=freq;buf.audioBuf=audioBuf}catch(e){AL.currentCtx.err=40963;return}};_alBufferData.sig="viipii";var _alBufferf=(bufferId,param,value)=>{AL.setBufferParam("alBufferf",bufferId,param,null)};_alBufferf.sig="viif";var _alBufferfv=(bufferId,param,pValues)=>{if(!AL.currentCtx){return}if(!pValues){AL.currentCtx.err=40963;return}AL.setBufferParam("alBufferfv",bufferId,param,null)};_alBufferfv.sig="viip";var _alBufferi=(bufferId,param,value)=>{AL.setBufferParam("alBufferi",bufferId,param,null)};_alBufferi.sig="viii";var _alBufferiv=(bufferId,param,pValues)=>{if(!AL.currentCtx){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 8213:AL.paramArray[0]=HEAP32[pValues>>2];AL.paramArray[1]=HEAP32[pValues+4>>2];AL.setBufferParam("alBufferiv",bufferId,param,AL.paramArray);break;default:AL.setBufferParam("alBufferiv",bufferId,param,null);break}};_alBufferiv.sig="viip";var _alDeleteBuffers=(count,pBufferIds)=>{if(!AL.currentCtx){return}for(var i=0;i<count;++i){var bufId=HEAP32[pBufferIds+i*4>>2];if(bufId===0){continue}if(!AL.buffers[bufId]){AL.currentCtx.err=40961;return}if(AL.buffers[bufId].refCount){AL.currentCtx.err=40964;return}}for(var i=0;i<count;++i){var bufId=HEAP32[pBufferIds+i*4>>2];if(bufId===0){continue}AL.deviceRefCounts[AL.buffers[bufId].deviceId]--;delete AL.buffers[bufId];AL.freeIds.push(bufId)}};_alDeleteBuffers.sig="vip";var _alSourcei=(sourceId,param,value)=>{switch(param){case 514:case 4097:case 4098:case 4103:case 4105:case 4128:case 4129:case 4131:case 4132:case 4133:case 4134:case 4628:case 8201:case 8202:case 53248:AL.setSourceParam("alSourcei",sourceId,param,value);break;default:AL.setSourceParam("alSourcei",sourceId,param,null);break}};_alSourcei.sig="viii";var _alDeleteSources=(count,pSourceIds)=>{if(!AL.currentCtx){return}for(var i=0;i<count;++i){var srcId=HEAP32[pSourceIds+i*4>>2];if(!AL.currentCtx.sources[srcId]){AL.currentCtx.err=40961;return}}for(var i=0;i<count;++i){var srcId=HEAP32[pSourceIds+i*4>>2];AL.setSourceState(AL.currentCtx.sources[srcId],4116);_alSourcei(srcId,4105,0);delete AL.currentCtx.sources[srcId];AL.freeIds.push(srcId)}};_alDeleteSources.sig="vip";var _alDisable=param=>{if(!AL.currentCtx){return}switch(param){case"AL_SOURCE_DISTANCE_MODEL":AL.currentCtx.sourceDistanceModel=false;AL.updateContextGlobal(AL.currentCtx);break;default:AL.currentCtx.err=40962;return}};_alDisable.sig="vi";var _alDistanceModel=model=>{AL.setGlobalParam("alDistanceModel",53248,model)};_alDistanceModel.sig="vi";var _alDopplerFactor=value=>{AL.setGlobalParam("alDopplerFactor",49152,value)};_alDopplerFactor.sig="vf";var _alDopplerVelocity=value=>{warnOnce("alDopplerVelocity() is deprecated, and only kept for compatibility with OpenAL 1.0. Use alSpeedOfSound() instead.");if(!AL.currentCtx){return}if(value<=0){AL.currentCtx.err=40963;return}};_alDopplerVelocity.sig="vf";var _alEnable=param=>{if(!AL.currentCtx){return}switch(param){case"AL_SOURCE_DISTANCE_MODEL":AL.currentCtx.sourceDistanceModel=true;AL.updateContextGlobal(AL.currentCtx);break;default:AL.currentCtx.err=40962;return}};_alEnable.sig="vi";var _alGenBuffers=(count,pBufferIds)=>{if(!AL.currentCtx){return}for(var i=0;i<count;++i){var buf={deviceId:AL.currentCtx.deviceId,id:AL.newId(),refCount:0,audioBuf:null,frequency:0,bytesPerSample:2,channels:1,length:0};AL.deviceRefCounts[buf.deviceId]++;AL.buffers[buf.id]=buf;HEAP32[pBufferIds+i*4>>2]=buf.id}};_alGenBuffers.sig="vip";var _alGenSources=(count,pSourceIds)=>{if(!AL.currentCtx){return}for(var i=0;i<count;++i){var gain=AL.currentCtx.audioCtx.createGain();gain.connect(AL.currentCtx.gain);var src={context:AL.currentCtx,id:AL.newId(),type:4144,state:4113,bufQueue:[AL.buffers[0]],audioQueue:[],looping:false,pitch:1,dopplerShift:1,gain:gain,minGain:0,maxGain:1,panner:null,bufsProcessed:0,bufStartTime:Number.NEGATIVE_INFINITY,bufOffset:0,relative:false,refDistance:1,maxDistance:340282e33,rolloffFactor:1,position:[0,0,0],velocity:[0,0,0],direction:[0,0,0],coneOuterGain:0,coneInnerAngle:360,coneOuterAngle:360,distanceModel:53250,spatialize:2,get playbackRate(){return this.pitch*this.dopplerShift}};AL.currentCtx.sources[src.id]=src;HEAP32[pSourceIds+i*4>>2]=src.id}};_alGenSources.sig="vip";var _alGetBoolean=param=>{var val=AL.getGlobalParam("alGetBoolean",param);if(val===null){return 0}switch(param){case 49152:case 49155:case 53248:return val!==0?1:0;default:AL.currentCtx.err=40962;return 0}};_alGetBoolean.sig="ii";var _alGetBooleanv=(param,pValues)=>{var val=AL.getGlobalParam("alGetBooleanv",param);if(val===null||!pValues){return}switch(param){case 49152:case 49155:case 53248:HEAP8[pValues>>0]=val;break;default:AL.currentCtx.err=40962;return}};_alGetBooleanv.sig="vip";var _alGetBuffer3f=(bufferId,param,pValue0,pValue1,pValue2)=>{var val=AL.getBufferParam("alGetBuffer3f",bufferId,param);if(val===null){return}if(!pValue0||!pValue1||!pValue2){AL.currentCtx.err=40963;return}AL.currentCtx.err=40962};_alGetBuffer3f.sig="viippp";var _alGetBuffer3i=(bufferId,param,pValue0,pValue1,pValue2)=>{var val=AL.getBufferParam("alGetBuffer3i",bufferId,param);if(val===null){return}if(!pValue0||!pValue1||!pValue2){AL.currentCtx.err=40963;return}AL.currentCtx.err=40962};_alGetBuffer3i.sig="viippp";var _alGetBufferf=(bufferId,param,pValue)=>{var val=AL.getBufferParam("alGetBufferf",bufferId,param);if(val===null){return}if(!pValue){AL.currentCtx.err=40963;return}AL.currentCtx.err=40962};_alGetBufferf.sig="viip";var _alGetBufferfv=(bufferId,param,pValues)=>{var val=AL.getBufferParam("alGetBufferfv",bufferId,param);if(val===null){return}if(!pValues){AL.currentCtx.err=40963;return}AL.currentCtx.err=40962};_alGetBufferfv.sig="viip";var _alGetBufferi=(bufferId,param,pValue)=>{var val=AL.getBufferParam("alGetBufferi",bufferId,param);if(val===null){return}if(!pValue){AL.currentCtx.err=40963;return}switch(param){case 8193:case 8194:case 8195:case 8196:HEAP32[pValue>>2]=val;break;default:AL.currentCtx.err=40962;return}};_alGetBufferi.sig="viip";var _alGetBufferiv=(bufferId,param,pValues)=>{var val=AL.getBufferParam("alGetBufferiv",bufferId,param);if(val===null){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 8193:case 8194:case 8195:case 8196:HEAP32[pValues>>2]=val;break;case 8213:HEAP32[pValues>>2]=val[0];HEAP32[pValues+4>>2]=val[1];break;default:AL.currentCtx.err=40962;return}};_alGetBufferiv.sig="viip";var _alGetDouble=param=>{var val=AL.getGlobalParam("alGetDouble",param);if(val===null){return 0}switch(param){case 49152:case 49155:case 53248:return val;default:AL.currentCtx.err=40962;return 0}};_alGetDouble.sig="di";var _alGetDoublev=(param,pValues)=>{var val=AL.getGlobalParam("alGetDoublev",param);if(val===null||!pValues){return}switch(param){case 49152:case 49155:case 53248:HEAPF64[pValues>>3]=val;break;default:AL.currentCtx.err=40962;return}};_alGetDoublev.sig="vip";var _alGetEnumValue=pEnumName=>{if(!AL.currentCtx){return 0}if(!pEnumName){AL.currentCtx.err=40963;return 0}var name=UTF8ToString(pEnumName);switch(name){case"AL_BITS":return 8194;case"AL_BUFFER":return 4105;case"AL_BUFFERS_PROCESSED":return 4118;case"AL_BUFFERS_QUEUED":return 4117;case"AL_BYTE_OFFSET":return 4134;case"AL_CHANNELS":return 8195;case"AL_CONE_INNER_ANGLE":return 4097;case"AL_CONE_OUTER_ANGLE":return 4098;case"AL_CONE_OUTER_GAIN":return 4130;case"AL_DIRECTION":return 4101;case"AL_DISTANCE_MODEL":return 53248;case"AL_DOPPLER_FACTOR":return 49152;case"AL_DOPPLER_VELOCITY":return 49153;case"AL_EXPONENT_DISTANCE":return 53253;case"AL_EXPONENT_DISTANCE_CLAMPED":return 53254;case"AL_EXTENSIONS":return 45060;case"AL_FORMAT_MONO16":return 4353;case"AL_FORMAT_MONO8":return 4352;case"AL_FORMAT_STEREO16":return 4355;case"AL_FORMAT_STEREO8":return 4354;case"AL_FREQUENCY":return 8193;case"AL_GAIN":return 4106;case"AL_INITIAL":return 4113;case"AL_INVALID":return-1;case"AL_ILLEGAL_ENUM":case"AL_INVALID_ENUM":return 40962;case"AL_INVALID_NAME":return 40961;case"AL_ILLEGAL_COMMAND":case"AL_INVALID_OPERATION":return 40964;case"AL_INVALID_VALUE":return 40963;case"AL_INVERSE_DISTANCE":return 53249;case"AL_INVERSE_DISTANCE_CLAMPED":return 53250;case"AL_LINEAR_DISTANCE":return 53251;case"AL_LINEAR_DISTANCE_CLAMPED":return 53252;case"AL_LOOPING":return 4103;case"AL_MAX_DISTANCE":return 4131;case"AL_MAX_GAIN":return 4110;case"AL_MIN_GAIN":return 4109;case"AL_NONE":return 0;case"AL_NO_ERROR":return 0;case"AL_ORIENTATION":return 4111;case"AL_OUT_OF_MEMORY":return 40965;case"AL_PAUSED":return 4115;case"AL_PENDING":return 8209;case"AL_PITCH":return 4099;case"AL_PLAYING":return 4114;case"AL_POSITION":return 4100;case"AL_PROCESSED":return 8210;case"AL_REFERENCE_DISTANCE":return 4128;case"AL_RENDERER":return 45059;case"AL_ROLLOFF_FACTOR":return 4129;case"AL_SAMPLE_OFFSET":return 4133;case"AL_SEC_OFFSET":return 4132;case"AL_SIZE":return 8196;case"AL_SOURCE_RELATIVE":return 514;case"AL_SOURCE_STATE":return 4112;case"AL_SOURCE_TYPE":return 4135;case"AL_SPEED_OF_SOUND":return 49155;case"AL_STATIC":return 4136;case"AL_STOPPED":return 4116;case"AL_STREAMING":return 4137;case"AL_UNDETERMINED":return 4144;case"AL_UNUSED":return 8208;case"AL_VELOCITY":return 4102;case"AL_VENDOR":return 45057;case"AL_VERSION":return 45058;case"AL_AUTO_SOFT":return 2;case"AL_SOURCE_DISTANCE_MODEL":return 512;case"AL_SOURCE_SPATIALIZE_SOFT":return 4628;case"AL_LOOP_POINTS_SOFT":return 8213;case"AL_BYTE_LENGTH_SOFT":return 8201;case"AL_SAMPLE_LENGTH_SOFT":return 8202;case"AL_SEC_LENGTH_SOFT":return 8203;case"AL_FORMAT_MONO_FLOAT32":return 65552;case"AL_FORMAT_STEREO_FLOAT32":return 65553;default:AL.currentCtx.err=40963;return 0}};_alGetEnumValue.sig="ip";var _alGetError=()=>{if(!AL.currentCtx){return 40964}var err=AL.currentCtx.err;AL.currentCtx.err=0;return err};_alGetError.sig="i";var _alGetFloat=param=>{var val=AL.getGlobalParam("alGetFloat",param);if(val===null){return 0}switch(param){case 49152:case 49155:case 53248:return val;default:return 0}};_alGetFloat.sig="fi";var _alGetFloatv=(param,pValues)=>{var val=AL.getGlobalParam("alGetFloatv",param);if(val===null||!pValues){return}switch(param){case 49152:case 49155:case 53248:HEAPF32[pValues>>2]=val;break;default:AL.currentCtx.err=40962;return}};_alGetFloatv.sig="vip";var _alGetInteger=param=>{var val=AL.getGlobalParam("alGetInteger",param);if(val===null){return 0}switch(param){case 49152:case 49155:case 53248:return val;default:AL.currentCtx.err=40962;return 0}};_alGetInteger.sig="ii";var _alGetIntegerv=(param,pValues)=>{var val=AL.getGlobalParam("alGetIntegerv",param);if(val===null||!pValues){return}switch(param){case 49152:case 49155:case 53248:HEAP32[pValues>>2]=val;break;default:AL.currentCtx.err=40962;return}};_alGetIntegerv.sig="vip";var _alGetListener3f=(param,pValue0,pValue1,pValue2)=>{var val=AL.getListenerParam("alGetListener3f",param);if(val===null){return}if(!pValue0||!pValue1||!pValue2){AL.currentCtx.err=40963;return}switch(param){case 4100:case 4102:HEAPF32[pValue0>>2]=val[0];HEAPF32[pValue1>>2]=val[1];HEAPF32[pValue2>>2]=val[2];break;default:AL.currentCtx.err=40962;return}};_alGetListener3f.sig="vippp";var _alGetListener3i=(param,pValue0,pValue1,pValue2)=>{var val=AL.getListenerParam("alGetListener3i",param);if(val===null){return}if(!pValue0||!pValue1||!pValue2){AL.currentCtx.err=40963;return}switch(param){case 4100:case 4102:HEAP32[pValue0>>2]=val[0];HEAP32[pValue1>>2]=val[1];HEAP32[pValue2>>2]=val[2];break;default:AL.currentCtx.err=40962;return}};_alGetListener3i.sig="vippp";var _alGetListenerf=(param,pValue)=>{var val=AL.getListenerParam("alGetListenerf",param);if(val===null){return}if(!pValue){AL.currentCtx.err=40963;return}switch(param){case 4106:HEAPF32[pValue>>2]=val;break;default:AL.currentCtx.err=40962;return}};_alGetListenerf.sig="vip";var _alGetListenerfv=(param,pValues)=>{var val=AL.getListenerParam("alGetListenerfv",param);if(val===null){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 4100:case 4102:HEAPF32[pValues>>2]=val[0];HEAPF32[pValues+4>>2]=val[1];HEAPF32[pValues+8>>2]=val[2];break;case 4111:HEAPF32[pValues>>2]=val[0];HEAPF32[pValues+4>>2]=val[1];HEAPF32[pValues+8>>2]=val[2];HEAPF32[pValues+12>>2]=val[3];HEAPF32[pValues+16>>2]=val[4];HEAPF32[pValues+20>>2]=val[5];break;default:AL.currentCtx.err=40962;return}};_alGetListenerfv.sig="vip";var _alGetListeneri=(param,pValue)=>{var val=AL.getListenerParam("alGetListeneri",param);if(val===null){return}if(!pValue){AL.currentCtx.err=40963;return}AL.currentCtx.err=40962};_alGetListeneri.sig="vip";var _alGetListeneriv=(param,pValues)=>{var val=AL.getListenerParam("alGetListeneriv",param);if(val===null){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 4100:case 4102:HEAP32[pValues>>2]=val[0];HEAP32[pValues+4>>2]=val[1];HEAP32[pValues+8>>2]=val[2];break;case 4111:HEAP32[pValues>>2]=val[0];HEAP32[pValues+4>>2]=val[1];HEAP32[pValues+8>>2]=val[2];HEAP32[pValues+12>>2]=val[3];HEAP32[pValues+16>>2]=val[4];HEAP32[pValues+20>>2]=val[5];break;default:AL.currentCtx.err=40962;return}};_alGetListeneriv.sig="vip";var _alGetSource3f=(sourceId,param,pValue0,pValue1,pValue2)=>{var val=AL.getSourceParam("alGetSource3f",sourceId,param);if(val===null){return}if(!pValue0||!pValue1||!pValue2){AL.currentCtx.err=40963;return}switch(param){case 4100:case 4101:case 4102:HEAPF32[pValue0>>2]=val[0];HEAPF32[pValue1>>2]=val[1];HEAPF32[pValue2>>2]=val[2];break;default:AL.currentCtx.err=40962;return}};_alGetSource3f.sig="viippp";var _alGetSource3i=(sourceId,param,pValue0,pValue1,pValue2)=>{var val=AL.getSourceParam("alGetSource3i",sourceId,param);if(val===null){return}if(!pValue0||!pValue1||!pValue2){AL.currentCtx.err=40963;return}switch(param){case 4100:case 4101:case 4102:HEAP32[pValue0>>2]=val[0];HEAP32[pValue1>>2]=val[1];HEAP32[pValue2>>2]=val[2];break;default:AL.currentCtx.err=40962;return}};_alGetSource3i.sig="viippp";var _alGetSourcef=(sourceId,param,pValue)=>{var val=AL.getSourceParam("alGetSourcef",sourceId,param);if(val===null){return}if(!pValue){AL.currentCtx.err=40963;return}switch(param){case 4097:case 4098:case 4099:case 4106:case 4109:case 4110:case 4128:case 4129:case 4130:case 4131:case 4132:case 4133:case 4134:case 8203:HEAPF32[pValue>>2]=val;break;default:AL.currentCtx.err=40962;return}};_alGetSourcef.sig="viip";var _alGetSourcefv=(sourceId,param,pValues)=>{var val=AL.getSourceParam("alGetSourcefv",sourceId,param);if(val===null){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 4097:case 4098:case 4099:case 4106:case 4109:case 4110:case 4128:case 4129:case 4130:case 4131:case 4132:case 4133:case 4134:case 8203:HEAPF32[pValues>>2]=val[0];break;case 4100:case 4101:case 4102:HEAPF32[pValues>>2]=val[0];HEAPF32[pValues+4>>2]=val[1];HEAPF32[pValues+8>>2]=val[2];break;default:AL.currentCtx.err=40962;return}};_alGetSourcefv.sig="viip";var _alGetSourcei=(sourceId,param,pValue)=>{var val=AL.getSourceParam("alGetSourcei",sourceId,param);if(val===null){return}if(!pValue){AL.currentCtx.err=40963;return}switch(param){case 514:case 4097:case 4098:case 4103:case 4105:case 4112:case 4117:case 4118:case 4128:case 4129:case 4131:case 4132:case 4133:case 4134:case 4135:case 4628:case 8201:case 8202:case 53248:HEAP32[pValue>>2]=val;break;default:AL.currentCtx.err=40962;return}};_alGetSourcei.sig="viip";var _alGetSourceiv=(sourceId,param,pValues)=>{var val=AL.getSourceParam("alGetSourceiv",sourceId,param);if(val===null){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 514:case 4097:case 4098:case 4103:case 4105:case 4112:case 4117:case 4118:case 4128:case 4129:case 4131:case 4132:case 4133:case 4134:case 4135:case 4628:case 8201:case 8202:case 53248:HEAP32[pValues>>2]=val;break;case 4100:case 4101:case 4102:HEAP32[pValues>>2]=val[0];HEAP32[pValues+4>>2]=val[1];HEAP32[pValues+8>>2]=val[2];break;default:AL.currentCtx.err=40962;return}};_alGetSourceiv.sig="viip";var _alGetString=param=>{if(AL.stringCache[param]){return AL.stringCache[param]}var ret;switch(param){case 0:ret="No Error";break;case 40961:ret="Invalid Name";break;case 40962:ret="Invalid Enum";break;case 40963:ret="Invalid Value";break;case 40964:ret="Invalid Operation";break;case 40965:ret="Out of Memory";break;case 45057:ret="Emscripten";break;case 45058:ret="1.1";break;case 45059:ret="WebAudio";break;case 45060:ret="";for(var ext in AL.AL_EXTENSIONS){ret=ret.concat(ext);ret=ret.concat(" ")}ret=ret.trim();break;default:if(AL.currentCtx){AL.currentCtx.err=40962}else{}return 0}ret=stringToNewUTF8(ret);AL.stringCache[param]=ret;return ret};_alGetString.sig="pi";var _alIsBuffer=bufferId=>{if(!AL.currentCtx){return false}if(bufferId>AL.buffers.length){return false}if(!AL.buffers[bufferId]){return false}return true};_alIsBuffer.sig="ii";var _alIsEnabled=param=>{if(!AL.currentCtx){return 0}switch(param){case"AL_SOURCE_DISTANCE_MODEL":return AL.currentCtx.sourceDistanceModel?0:1;default:AL.currentCtx.err=40962;return 0}};_alIsEnabled.sig="ii";var _alIsExtensionPresent=pExtName=>{var name=UTF8ToString(pExtName);return AL.AL_EXTENSIONS[name]?1:0};_alIsExtensionPresent.sig="ip";var _alIsSource=sourceId=>{if(!AL.currentCtx){return false}if(!AL.currentCtx.sources[sourceId]){return false}return true};_alIsSource.sig="ii";var _alListener3f=(param,value0,value1,value2)=>{switch(param){case 4100:case 4102:AL.paramArray[0]=value0;AL.paramArray[1]=value1;AL.paramArray[2]=value2;AL.setListenerParam("alListener3f",param,AL.paramArray);break;default:AL.setListenerParam("alListener3f",param,null);break}};_alListener3f.sig="vifff";var _alListener3i=(param,value0,value1,value2)=>{switch(param){case 4100:case 4102:AL.paramArray[0]=value0;AL.paramArray[1]=value1;AL.paramArray[2]=value2;AL.setListenerParam("alListener3i",param,AL.paramArray);break;default:AL.setListenerParam("alListener3i",param,null);break}};_alListener3i.sig="viiii";var _alListenerf=(param,value)=>{switch(param){case 4106:AL.setListenerParam("alListenerf",param,value);break;default:AL.setListenerParam("alListenerf",param,null);break}};_alListenerf.sig="vif";var _alListenerfv=(param,pValues)=>{if(!AL.currentCtx){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 4100:case 4102:AL.paramArray[0]=HEAPF32[pValues>>2];AL.paramArray[1]=HEAPF32[pValues+4>>2];AL.paramArray[2]=HEAPF32[pValues+8>>2];AL.setListenerParam("alListenerfv",param,AL.paramArray);break;case 4111:AL.paramArray[0]=HEAPF32[pValues>>2];AL.paramArray[1]=HEAPF32[pValues+4>>2];AL.paramArray[2]=HEAPF32[pValues+8>>2];AL.paramArray[3]=HEAPF32[pValues+12>>2];AL.paramArray[4]=HEAPF32[pValues+16>>2];AL.paramArray[5]=HEAPF32[pValues+20>>2];AL.setListenerParam("alListenerfv",param,AL.paramArray);break;default:AL.setListenerParam("alListenerfv",param,null);break}};_alListenerfv.sig="vip";var _alListeneri=(param,value)=>{AL.setListenerParam("alListeneri",param,null)};_alListeneri.sig="vii";var _alListeneriv=(param,pValues)=>{if(!AL.currentCtx){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 4100:case 4102:AL.paramArray[0]=HEAP32[pValues>>2];AL.paramArray[1]=HEAP32[pValues+4>>2];AL.paramArray[2]=HEAP32[pValues+8>>2];AL.setListenerParam("alListeneriv",param,AL.paramArray);break;case 4111:AL.paramArray[0]=HEAP32[pValues>>2];AL.paramArray[1]=HEAP32[pValues+4>>2];AL.paramArray[2]=HEAP32[pValues+8>>2];AL.paramArray[3]=HEAP32[pValues+12>>2];AL.paramArray[4]=HEAP32[pValues+16>>2];AL.paramArray[5]=HEAP32[pValues+20>>2];AL.setListenerParam("alListeneriv",param,AL.paramArray);break;default:AL.setListenerParam("alListeneriv",param,null);break}};_alListeneriv.sig="vip";var _alSource3f=(sourceId,param,value0,value1,value2)=>{switch(param){case 4100:case 4101:case 4102:AL.paramArray[0]=value0;AL.paramArray[1]=value1;AL.paramArray[2]=value2;AL.setSourceParam("alSource3f",sourceId,param,AL.paramArray);break;default:AL.setSourceParam("alSource3f",sourceId,param,null);break}};_alSource3f.sig="viifff";var _alSource3i=(sourceId,param,value0,value1,value2)=>{switch(param){case 4100:case 4101:case 4102:AL.paramArray[0]=value0;AL.paramArray[1]=value1;AL.paramArray[2]=value2;AL.setSourceParam("alSource3i",sourceId,param,AL.paramArray);break;default:AL.setSourceParam("alSource3i",sourceId,param,null);break}};_alSource3i.sig="viiiii";var _alSourcePause=sourceId=>{if(!AL.currentCtx){return}var src=AL.currentCtx.sources[sourceId];if(!src){AL.currentCtx.err=40961;return}AL.setSourceState(src,4115)};_alSourcePause.sig="vi";var _alSourcePausev=(count,pSourceIds)=>{if(!AL.currentCtx){return}if(!pSourceIds){AL.currentCtx.err=40963}for(var i=0;i<count;++i){if(!AL.currentCtx.sources[HEAP32[pSourceIds+i*4>>2]]){AL.currentCtx.err=40961;return}}for(var i=0;i<count;++i){var srcId=HEAP32[pSourceIds+i*4>>2];AL.setSourceState(AL.currentCtx.sources[srcId],4115)}};_alSourcePausev.sig="vip";var _alSourcePlay=sourceId=>{if(!AL.currentCtx){return}var src=AL.currentCtx.sources[sourceId];if(!src){AL.currentCtx.err=40961;return}AL.setSourceState(src,4114)};_alSourcePlay.sig="vi";var _alSourcePlayv=(count,pSourceIds)=>{if(!AL.currentCtx){return}if(!pSourceIds){AL.currentCtx.err=40963}for(var i=0;i<count;++i){if(!AL.currentCtx.sources[HEAP32[pSourceIds+i*4>>2]]){AL.currentCtx.err=40961;return}}for(var i=0;i<count;++i){var srcId=HEAP32[pSourceIds+i*4>>2];AL.setSourceState(AL.currentCtx.sources[srcId],4114)}};_alSourcePlayv.sig="vip";var _alSourceQueueBuffers=(sourceId,count,pBufferIds)=>{if(!AL.currentCtx){return}var src=AL.currentCtx.sources[sourceId];if(!src){AL.currentCtx.err=40961;return}if(src.type===4136){AL.currentCtx.err=40964;return}if(count===0){return}var templateBuf=AL.buffers[0];for(var i=0;i<src.bufQueue.length;i++){if(src.bufQueue[i].id!==0){templateBuf=src.bufQueue[i];break}}for(var i=0;i<count;++i){var bufId=HEAP32[pBufferIds+i*4>>2];var buf=AL.buffers[bufId];if(!buf){AL.currentCtx.err=40961;return}if(templateBuf.id!==0&&(buf.frequency!==templateBuf.frequency||buf.bytesPerSample!==templateBuf.bytesPerSample||buf.channels!==templateBuf.channels)){AL.currentCtx.err=40964}}if(src.bufQueue.length===1&&src.bufQueue[0].id===0){src.bufQueue.length=0}src.type=4137;for(var i=0;i<count;++i){var bufId=HEAP32[pBufferIds+i*4>>2];var buf=AL.buffers[bufId];buf.refCount++;src.bufQueue.push(buf)}if(src.looping){AL.cancelPendingSourceAudio(src)}AL.initSourcePanner(src);AL.scheduleSourceAudio(src)};_alSourceQueueBuffers.sig="viip";var _alSourceRewind=sourceId=>{if(!AL.currentCtx){return}var src=AL.currentCtx.sources[sourceId];if(!src){AL.currentCtx.err=40961;return}AL.setSourceState(src,4116);AL.setSourceState(src,4113)};_alSourceRewind.sig="vi";var _alSourceRewindv=(count,pSourceIds)=>{if(!AL.currentCtx){return}if(!pSourceIds){AL.currentCtx.err=40963}for(var i=0;i<count;++i){if(!AL.currentCtx.sources[HEAP32[pSourceIds+i*4>>2]]){AL.currentCtx.err=40961;return}}for(var i=0;i<count;++i){var srcId=HEAP32[pSourceIds+i*4>>2];AL.setSourceState(AL.currentCtx.sources[srcId],4113)}};_alSourceRewindv.sig="vip";var _alSourceStop=sourceId=>{if(!AL.currentCtx){return}var src=AL.currentCtx.sources[sourceId];if(!src){AL.currentCtx.err=40961;return}AL.setSourceState(src,4116)};_alSourceStop.sig="vi";var _alSourceStopv=(count,pSourceIds)=>{if(!AL.currentCtx){return}if(!pSourceIds){AL.currentCtx.err=40963}for(var i=0;i<count;++i){if(!AL.currentCtx.sources[HEAP32[pSourceIds+i*4>>2]]){AL.currentCtx.err=40961;return}}for(var i=0;i<count;++i){var srcId=HEAP32[pSourceIds+i*4>>2];AL.setSourceState(AL.currentCtx.sources[srcId],4116)}};_alSourceStopv.sig="vip";var _alSourceUnqueueBuffers=(sourceId,count,pBufferIds)=>{if(!AL.currentCtx){return}var src=AL.currentCtx.sources[sourceId];if(!src){AL.currentCtx.err=40961;return}if(count>(src.bufQueue.length===1&&src.bufQueue[0].id===0?0:src.bufsProcessed)){AL.currentCtx.err=40963;return}if(count===0){return}for(var i=0;i<count;i++){var buf=src.bufQueue.shift();buf.refCount--;HEAP32[pBufferIds+i*4>>2]=buf.id;src.bufsProcessed--}if(src.bufQueue.length===0){src.bufQueue.push(AL.buffers[0])}AL.initSourcePanner(src);AL.scheduleSourceAudio(src)};_alSourceUnqueueBuffers.sig="viip";var _alSourcef=(sourceId,param,value)=>{switch(param){case 4097:case 4098:case 4099:case 4106:case 4109:case 4110:case 4128:case 4129:case 4130:case 4131:case 4132:case 4133:case 4134:case 8203:AL.setSourceParam("alSourcef",sourceId,param,value);break;default:AL.setSourceParam("alSourcef",sourceId,param,null);break}};_alSourcef.sig="viif";var _alSourcefv=(sourceId,param,pValues)=>{if(!AL.currentCtx){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 4097:case 4098:case 4099:case 4106:case 4109:case 4110:case 4128:case 4129:case 4130:case 4131:case 4132:case 4133:case 4134:case 8203:var val=HEAPF32[pValues>>2];AL.setSourceParam("alSourcefv",sourceId,param,val);break;case 4100:case 4101:case 4102:AL.paramArray[0]=HEAPF32[pValues>>2];AL.paramArray[1]=HEAPF32[pValues+4>>2];AL.paramArray[2]=HEAPF32[pValues+8>>2];AL.setSourceParam("alSourcefv",sourceId,param,AL.paramArray);break;default:AL.setSourceParam("alSourcefv",sourceId,param,null);break}};_alSourcefv.sig="viip";var _alSourceiv=(sourceId,param,pValues)=>{if(!AL.currentCtx){return}if(!pValues){AL.currentCtx.err=40963;return}switch(param){case 514:case 4097:case 4098:case 4103:case 4105:case 4128:case 4129:case 4131:case 4132:case 4133:case 4134:case 4628:case 8201:case 8202:case 53248:var val=HEAP32[pValues>>2];AL.setSourceParam("alSourceiv",sourceId,param,val);break;case 4100:case 4101:case 4102:AL.paramArray[0]=HEAP32[pValues>>2];AL.paramArray[1]=HEAP32[pValues+4>>2];AL.paramArray[2]=HEAP32[pValues+8>>2];AL.setSourceParam("alSourceiv",sourceId,param,AL.paramArray);break;default:AL.setSourceParam("alSourceiv",sourceId,param,null);break}};_alSourceiv.sig="viip";var _alSpeedOfSound=value=>{AL.setGlobalParam("alSpeedOfSound",49155,value)};_alSpeedOfSound.sig="vf";var _alcCaptureCloseDevice=deviceId=>{var c=AL.requireValidCaptureDevice(deviceId,"alcCaptureCloseDevice");if(!c)return false;delete AL.captures[deviceId];AL.freeIds.push(deviceId);if(c.mediaStreamSourceNode)c.mediaStreamSourceNode.disconnect();if(c.mergerNode)c.mergerNode.disconnect();if(c.splitterNode)c.splitterNode.disconnect();if(c.scriptProcessorNode)c.scriptProcessorNode.disconnect();if(c.mediaStream){c.mediaStream.getTracks().forEach(track=>track.stop())}delete c.buffers;c.capturedFrameCount=0;c.isCapturing=false;return true};_alcCaptureCloseDevice.sig="ip";var listenOnce=(object,event,func)=>{object.addEventListener(event,func,{"once":true})};var autoResumeAudioContext=(ctx,elements)=>{if(!elements){elements=[document,document.getElementById("canvas")]}["keydown","mousedown","touchstart"].forEach(event=>{elements.forEach(element=>{if(element){listenOnce(element,event,()=>{if(ctx.state==="suspended")ctx.resume()})}})})};var _alcCaptureOpenDevice=(pDeviceName,requestedSampleRate,format,bufferFrameCapacity)=>{var resolvedDeviceName=AL.CAPTURE_DEVICE_NAME;if(pDeviceName!==0){resolvedDeviceName=UTF8ToString(pDeviceName);if(resolvedDeviceName!==AL.CAPTURE_DEVICE_NAME){AL.alcErr=40965;return 0}}if(bufferFrameCapacity<0){AL.alcErr=40964;return 0}navigator.getUserMedia=navigator.getUserMedia||navigator.webkitGetUserMedia||navigator.mozGetUserMedia||navigator.msGetUserMedia;var has_getUserMedia=navigator.getUserMedia||navigator.mediaDevices&&navigator.mediaDevices.getUserMedia;if(!has_getUserMedia){AL.alcErr=40965;return 0}var AudioContext=window.AudioContext||window.webkitAudioContext;if(!AL.sharedCaptureAudioCtx){try{AL.sharedCaptureAudioCtx=new AudioContext}catch(e){AL.alcErr=40965;return 0}}autoResumeAudioContext(AL.sharedCaptureAudioCtx);var outputChannelCount;switch(format){case 65552:case 4353:case 4352:outputChannelCount=1;break;case 65553:case 4355:case 4354:outputChannelCount=2;break;default:AL.alcErr=40964;return 0}function newF32Array(cap){return new Float32Array(cap)}function newI16Array(cap){return new Int16Array(cap)}function newU8Array(cap){return new Uint8Array(cap)}var requestedSampleType;var newSampleArray;switch(format){case 65552:case 65553:requestedSampleType="f32";newSampleArray=newF32Array;break;case 4353:case 4355:requestedSampleType="i16";newSampleArray=newI16Array;break;case 4352:case 4354:requestedSampleType="u8";newSampleArray=newU8Array;break}var buffers=[];try{for(var chan=0;chan<outputChannelCount;++chan){buffers[chan]=newSampleArray(bufferFrameCapacity)}}catch(e){AL.alcErr=40965;return 0}var newCapture={audioCtx:AL.sharedCaptureAudioCtx,deviceName:resolvedDeviceName,requestedSampleRate:requestedSampleRate,requestedSampleType:requestedSampleType,outputChannelCount:outputChannelCount,inputChannelCount:null,mediaStreamError:null,mediaStreamSourceNode:null,mediaStream:null,mergerNode:null,splitterNode:null,scriptProcessorNode:null,isCapturing:false,buffers:buffers,get bufferFrameCapacity(){return buffers[0].length},capturePlayhead:0,captureReadhead:0,capturedFrameCount:0};var onError=mediaStreamError=>{newCapture.mediaStreamError=mediaStreamError};var onSuccess=mediaStream=>{newCapture.mediaStreamSourceNode=newCapture.audioCtx.createMediaStreamSource(mediaStream);newCapture.mediaStream=mediaStream;var inputChannelCount=1;switch(newCapture.mediaStreamSourceNode.channelCountMode){case"max":inputChannelCount=outputChannelCount;break;case"clamped-max":inputChannelCount=Math.min(outputChannelCount,newCapture.mediaStreamSourceNode.channelCount);break;case"explicit":inputChannelCount=newCapture.mediaStreamSourceNode.channelCount;break}newCapture.inputChannelCount=inputChannelCount;var processorFrameCount=512;newCapture.scriptProcessorNode=newCapture.audioCtx.createScriptProcessor(processorFrameCount,inputChannelCount,outputChannelCount);if(inputChannelCount>outputChannelCount){newCapture.mergerNode=newCapture.audioCtx.createChannelMerger(inputChannelCount);newCapture.mediaStreamSourceNode.connect(newCapture.mergerNode);newCapture.mergerNode.connect(newCapture.scriptProcessorNode)}else if(inputChannelCount<outputChannelCount){newCapture.splitterNode=newCapture.audioCtx.createChannelSplitter(outputChannelCount);newCapture.mediaStreamSourceNode.connect(newCapture.splitterNode);newCapture.splitterNode.connect(newCapture.scriptProcessorNode)}else{newCapture.mediaStreamSourceNode.connect(newCapture.scriptProcessorNode)}newCapture.scriptProcessorNode.connect(newCapture.audioCtx.destination);newCapture.scriptProcessorNode.onaudioprocess=audioProcessingEvent=>{if(!newCapture.isCapturing){return}var c=newCapture;var srcBuf=audioProcessingEvent.inputBuffer;switch(format){case 65552:var channel0=srcBuf.getChannelData(0);for(var i=0;i<srcBuf.length;++i){var wi=(c.capturePlayhead+i)%c.bufferFrameCapacity;c.buffers[0][wi]=channel0[i]}break;case 65553:var channel0=srcBuf.getChannelData(0);var channel1=srcBuf.getChannelData(1);for(var i=0;i<srcBuf.length;++i){var wi=(c.capturePlayhead+i)%c.bufferFrameCapacity;c.buffers[0][wi]=channel0[i];c.buffers[1][wi]=channel1[i]}break;case 4353:var channel0=srcBuf.getChannelData(0);for(var i=0;i<srcBuf.length;++i){var wi=(c.capturePlayhead+i)%c.bufferFrameCapacity;c.buffers[0][wi]=channel0[i]*32767}break;case 4355:var channel0=srcBuf.getChannelData(0);var channel1=srcBuf.getChannelData(1);for(var i=0;i<srcBuf.length;++i){var wi=(c.capturePlayhead+i)%c.bufferFrameCapacity;c.buffers[0][wi]=channel0[i]*32767;c.buffers[1][wi]=channel1[i]*32767}break;case 4352:var channel0=srcBuf.getChannelData(0);for(var i=0;i<srcBuf.length;++i){var wi=(c.capturePlayhead+i)%c.bufferFrameCapacity;c.buffers[0][wi]=(channel0[i]+1)*127}break;case 4354:var channel0=srcBuf.getChannelData(0);var channel1=srcBuf.getChannelData(1);for(var i=0;i<srcBuf.length;++i){var wi=(c.capturePlayhead+i)%c.bufferFrameCapacity;c.buffers[0][wi]=(channel0[i]+1)*127;c.buffers[1][wi]=(channel1[i]+1)*127}break}c.capturePlayhead+=srcBuf.length;c.capturePlayhead%=c.bufferFrameCapacity;c.capturedFrameCount+=srcBuf.length;c.capturedFrameCount=Math.min(c.capturedFrameCount,c.bufferFrameCapacity)}};if(navigator.mediaDevices&&navigator.mediaDevices.getUserMedia){navigator.mediaDevices.getUserMedia({audio:true}).then(onSuccess).catch(onError)}else{navigator.getUserMedia({audio:true},onSuccess,onError)}var id=AL.newId();AL.captures[id]=newCapture;return id};_alcCaptureOpenDevice.sig="ppiii";var _alcCaptureSamples=(deviceId,pFrames,requestedFrameCount)=>{var c=AL.requireValidCaptureDevice(deviceId,"alcCaptureSamples");if(!c)return;var dstfreq=c.requestedSampleRate;var srcfreq=c.audioCtx.sampleRate;var fratio=srcfreq/dstfreq;if(requestedFrameCount<0||requestedFrameCount>c.capturedFrameCount/fratio){AL.alcErr=40964;return}function setF32Sample(i,sample){HEAPF32[pFrames+4*i>>2]=sample}function setI16Sample(i,sample){HEAP16[pFrames+2*i>>1]=sample}function setU8Sample(i,sample){HEAP8[pFrames+i>>0]=sample}var setSample;switch(c.requestedSampleType){case"f32":setSample=setF32Sample;break;case"i16":setSample=setI16Sample;break;case"u8":setSample=setU8Sample;break;default:return}if(Math.floor(fratio)==fratio){for(var i=0,frame_i=0;frame_i<requestedFrameCount;++frame_i){for(var chan=0;chan<c.buffers.length;++chan,++i){setSample(i,c.buffers[chan][c.captureReadhead])}c.captureReadhead=(fratio+c.captureReadhead)%c.bufferFrameCapacity}}else{for(var i=0,frame_i=0;frame_i<requestedFrameCount;++frame_i){var lefti=Math.floor(c.captureReadhead);var righti=Math.ceil(c.captureReadhead);var d=c.captureReadhead-lefti;for(var chan=0;chan<c.buffers.length;++chan,++i){var lefts=c.buffers[chan][lefti];var rights=c.buffers[chan][righti];setSample(i,(1-d)*lefts+d*rights)}c.captureReadhead=(c.captureReadhead+fratio)%c.bufferFrameCapacity}}c.capturedFrameCount=0};_alcCaptureSamples.sig="vppi";var _alcCaptureStart=deviceId=>{var c=AL.requireValidCaptureDevice(deviceId,"alcCaptureStart");if(!c)return;if(c.isCapturing){return}c.isCapturing=true;c.capturedFrameCount=0;c.capturePlayhead=0};_alcCaptureStart.sig="vp";var _alcCaptureStop=deviceId=>{var c=AL.requireValidCaptureDevice(deviceId,"alcCaptureStop");if(!c)return;c.isCapturing=false};_alcCaptureStop.sig="vp";var _alcCloseDevice=deviceId=>{if(!(deviceId in AL.deviceRefCounts)||AL.deviceRefCounts[deviceId]>0){return 0}delete AL.deviceRefCounts[deviceId];AL.freeIds.push(deviceId);return 1};_alcCloseDevice.sig="ip";var _alcCreateContext=(deviceId,pAttrList)=>{if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return 0}var options=null;var attrs=[];var hrtf=null;pAttrList>>=2;if(pAttrList){var attr=0;var val=0;while(true){attr=HEAP32[pAttrList++];attrs.push(attr);if(attr===0){break}val=HEAP32[pAttrList++];attrs.push(val);switch(attr){case 4103:if(!options){options={}}options.sampleRate=val;break;case 4112:case 4113:break;case 6546:switch(val){case 0:hrtf=false;break;case 1:hrtf=true;break;case 2:break;default:AL.alcErr=40964;return 0}break;case 6550:if(val!==0){AL.alcErr=40964;return 0}break;default:AL.alcErr=40964;return 0}}}var AudioContext=window.AudioContext||window.webkitAudioContext;var ac=null;try{if(options){ac=new AudioContext(options)}else{ac=new AudioContext}}catch(e){if(e.name==="NotSupportedError"){AL.alcErr=40964}else{AL.alcErr=40961}return 0}autoResumeAudioContext(ac);if(typeof ac.createGain=="undefined"){ac.createGain=ac.createGainNode}var gain=ac.createGain();gain.connect(ac.destination);var ctx={deviceId:deviceId,id:AL.newId(),attrs:attrs,audioCtx:ac,listener:{position:[0,0,0],velocity:[0,0,0],direction:[0,0,0],up:[0,0,0]},sources:[],interval:setInterval(()=>AL.scheduleContextAudio(ctx),AL.QUEUE_INTERVAL),gain:gain,distanceModel:53250,speedOfSound:343.3,dopplerFactor:1,sourceDistanceModel:false,hrtf:hrtf||false,_err:0,get err(){return this._err},set err(val){if(this._err===0||val===0){this._err=val}}};AL.deviceRefCounts[deviceId]++;AL.contexts[ctx.id]=ctx;if(hrtf!==null){for(var ctxId in AL.contexts){var c=AL.contexts[ctxId];if(c.deviceId===deviceId){c.hrtf=hrtf;AL.updateContextGlobal(c)}}}return ctx.id};_alcCreateContext.sig="ppp";var _alcDestroyContext=contextId=>{var ctx=AL.contexts[contextId];if(AL.currentCtx===ctx){AL.alcErr=40962;return}if(AL.contexts[contextId].interval){clearInterval(AL.contexts[contextId].interval)}AL.deviceRefCounts[ctx.deviceId]--;delete AL.contexts[contextId];AL.freeIds.push(contextId)};_alcDestroyContext.sig="vp";var _alcGetContextsDevice=contextId=>{if(contextId in AL.contexts){return AL.contexts[contextId].deviceId}return 0};_alcGetContextsDevice.sig="pp";var _alcGetCurrentContext=()=>{if(AL.currentCtx!==null){return AL.currentCtx.id}return 0};_alcGetCurrentContext.sig="p";var _alcGetEnumValue=(deviceId,pEnumName)=>{if(deviceId!==0&&!(deviceId in AL.deviceRefCounts)){return 0}else if(!pEnumName){AL.alcErr=40964;return 0}var name=UTF8ToString(pEnumName);switch(name){case"ALC_NO_ERROR":return 0;case"ALC_INVALID_DEVICE":return 40961;case"ALC_INVALID_CONTEXT":return 40962;case"ALC_INVALID_ENUM":return 40963;case"ALC_INVALID_VALUE":return 40964;case"ALC_OUT_OF_MEMORY":return 40965;case"ALC_MAJOR_VERSION":return 4096;case"ALC_MINOR_VERSION":return 4097;case"ALC_ATTRIBUTES_SIZE":return 4098;case"ALC_ALL_ATTRIBUTES":return 4099;case"ALC_DEFAULT_DEVICE_SPECIFIER":return 4100;case"ALC_DEVICE_SPECIFIER":return 4101;case"ALC_EXTENSIONS":return 4102;case"ALC_FREQUENCY":return 4103;case"ALC_REFRESH":return 4104;case"ALC_SYNC":return 4105;case"ALC_MONO_SOURCES":return 4112;case"ALC_STEREO_SOURCES":return 4113;case"ALC_CAPTURE_DEVICE_SPECIFIER":return 784;case"ALC_CAPTURE_DEFAULT_DEVICE_SPECIFIER":return 785;case"ALC_CAPTURE_SAMPLES":return 786;case"ALC_HRTF_SOFT":return 6546;case"ALC_HRTF_ID_SOFT":return 6550;case"ALC_DONT_CARE_SOFT":return 2;case"ALC_HRTF_STATUS_SOFT":return 6547;case"ALC_NUM_HRTF_SPECIFIERS_SOFT":return 6548;case"ALC_HRTF_SPECIFIER_SOFT":return 6549;case"ALC_HRTF_DISABLED_SOFT":return 0;case"ALC_HRTF_ENABLED_SOFT":return 1;case"ALC_HRTF_DENIED_SOFT":return 2;case"ALC_HRTF_REQUIRED_SOFT":return 3;case"ALC_HRTF_HEADPHONES_DETECTED_SOFT":return 4;case"ALC_HRTF_UNSUPPORTED_FORMAT_SOFT":return 5;default:AL.alcErr=40964;return 0}};_alcGetEnumValue.sig="ipp";var _alcGetError=deviceId=>{var err=AL.alcErr;AL.alcErr=0;return err};_alcGetError.sig="ip";var _alcGetIntegerv=(deviceId,param,size,pValues)=>{if(size===0||!pValues){return}switch(param){case 4096:HEAP32[pValues>>2]=1;break;case 4097:HEAP32[pValues>>2]=1;break;case 4098:if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}if(!AL.currentCtx){AL.alcErr=40962;return}HEAP32[pValues>>2]=AL.currentCtx.attrs.length;break;case 4099:if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}if(!AL.currentCtx){AL.alcErr=40962;return}for(var i=0;i<AL.currentCtx.attrs.length;i++){HEAP32[pValues+i*4>>2]=AL.currentCtx.attrs[i]}break;case 4103:if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}if(!AL.currentCtx){AL.alcErr=40962;return}HEAP32[pValues>>2]=AL.currentCtx.audioCtx.sampleRate;break;case 4112:case 4113:if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}if(!AL.currentCtx){AL.alcErr=40962;return}HEAP32[pValues>>2]=2147483647;break;case 6546:case 6547:if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}var hrtfStatus=0;for(var ctxId in AL.contexts){var ctx=AL.contexts[ctxId];if(ctx.deviceId===deviceId){hrtfStatus=ctx.hrtf?1:0}}HEAP32[pValues>>2]=hrtfStatus;break;case 6548:if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}HEAP32[pValues>>2]=1;break;case 131075:if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}if(!AL.currentCtx){AL.alcErr=40962;return}HEAP32[pValues>>2]=1;case 786:var c=AL.requireValidCaptureDevice(deviceId,"alcGetIntegerv");if(!c){return}var n=c.capturedFrameCount;var dstfreq=c.requestedSampleRate;var srcfreq=c.audioCtx.sampleRate;var nsamples=Math.floor(n*(dstfreq/srcfreq));HEAP32[pValues>>2]=nsamples;break;default:AL.alcErr=40963;return}};_alcGetIntegerv.sig="vpiip";var _alcGetString=(deviceId,param)=>{if(AL.alcStringCache[param]){return AL.alcStringCache[param]}var ret;switch(param){case 0:ret="No Error";break;case 40961:ret="Invalid Device";break;case 40962:ret="Invalid Context";break;case 40963:ret="Invalid Enum";break;case 40964:ret="Invalid Value";break;case 40965:ret="Out of Memory";break;case 4100:if(typeof AudioContext!="undefined"||typeof webkitAudioContext!="undefined"){ret=AL.DEVICE_NAME}else{return 0}break;case 4101:if(typeof AudioContext!="undefined"||typeof webkitAudioContext!="undefined"){ret=AL.DEVICE_NAME.concat("\0")}else{ret="\0"}break;case 785:ret=AL.CAPTURE_DEVICE_NAME;break;case 784:if(deviceId===0)ret=AL.CAPTURE_DEVICE_NAME.concat("\0");else{var c=AL.requireValidCaptureDevice(deviceId,"alcGetString");if(!c){return 0}ret=c.deviceName}break;case 4102:if(!deviceId){AL.alcErr=40961;return 0}ret="";for(var ext in AL.ALC_EXTENSIONS){ret=ret.concat(ext);ret=ret.concat(" ")}ret=ret.trim();break;default:AL.alcErr=40963;return 0}ret=stringToNewUTF8(ret);AL.alcStringCache[param]=ret;return ret};_alcGetString.sig="ppi";var _alcIsExtensionPresent=(deviceId,pExtName)=>{var name=UTF8ToString(pExtName);return AL.ALC_EXTENSIONS[name]?1:0};_alcIsExtensionPresent.sig="ipp";var _alcMakeContextCurrent=contextId=>{if(contextId===0){AL.currentCtx=null}else{AL.currentCtx=AL.contexts[contextId]}return 1};_alcMakeContextCurrent.sig="ip";var _alcOpenDevice=pDeviceName=>{if(pDeviceName){var name=UTF8ToString(pDeviceName);if(name!==AL.DEVICE_NAME){return 0}}if(typeof AudioContext!="undefined"||typeof webkitAudioContext!="undefined"){var deviceId=AL.newId();AL.deviceRefCounts[deviceId]=0;return deviceId}return 0};_alcOpenDevice.sig="pp";var _alcProcessContext=contextId=>{};_alcProcessContext.sig="vp";var _alcSuspendContext=contextId=>{};_alcSuspendContext.sig="vp";function _dasum_(){return wasmImports["dasum_"].apply(null,arguments)}_dasum_.stub=true;function _daxpy_(){return wasmImports["daxpy_"].apply(null,arguments)}_daxpy_.stub=true;function _dcopy_(){return wasmImports["dcopy_"].apply(null,arguments)}_dcopy_.stub=true;function _ddot_(){return wasmImports["ddot_"].apply(null,arguments)}_ddot_.stub=true;function _dgbmv_(){return wasmImports["dgbmv_"].apply(null,arguments)}_dgbmv_.stub=true;function _dgemm_(){return wasmImports["dgemm_"].apply(null,arguments)}_dgemm_.stub=true;function _dgemv_(){return wasmImports["dgemv_"].apply(null,arguments)}_dgemv_.stub=true;function _dger_(){return wasmImports["dger_"].apply(null,arguments)}_dger_.stub=true;function _dnrm2_(){return wasmImports["dnrm2_"].apply(null,arguments)}_dnrm2_.stub=true;function _drot_(){return wasmImports["drot_"].apply(null,arguments)}_drot_.stub=true;function _drotg_(){return wasmImports["drotg_"].apply(null,arguments)}_drotg_.stub=true;function _drotm_(){return wasmImports["drotm_"].apply(null,arguments)}_drotm_.stub=true;function _dsbmv_(){return wasmImports["dsbmv_"].apply(null,arguments)}_dsbmv_.stub=true;function _dscal_(){return wasmImports["dscal_"].apply(null,arguments)}_dscal_.stub=true;function _dspmv_(){return wasmImports["dspmv_"].apply(null,arguments)}_dspmv_.stub=true;function _dspr2_(){return wasmImports["dspr2_"].apply(null,arguments)}_dspr2_.stub=true;function _dspr_(){return wasmImports["dspr_"].apply(null,arguments)}_dspr_.stub=true;function _dswap_(){return wasmImports["dswap_"].apply(null,arguments)}_dswap_.stub=true;function _dsymm_(){return wasmImports["dsymm_"].apply(null,arguments)}_dsymm_.stub=true;function _dsymv_(){return wasmImports["dsymv_"].apply(null,arguments)}_dsymv_.stub=true;function _dsyr2_(){return wasmImports["dsyr2_"].apply(null,arguments)}_dsyr2_.stub=true;function _dsyr2k_(){return wasmImports["dsyr2k_"].apply(null,arguments)}_dsyr2k_.stub=true;function _dsyr_(){return wasmImports["dsyr_"].apply(null,arguments)}_dsyr_.stub=true;function _dsyrk_(){return wasmImports["dsyrk_"].apply(null,arguments)}_dsyrk_.stub=true;function _dtbmv_(){return wasmImports["dtbmv_"].apply(null,arguments)}_dtbmv_.stub=true;function _dtbsv_(){return wasmImports["dtbsv_"].apply(null,arguments)}_dtbsv_.stub=true;function _dtpmv_(){return wasmImports["dtpmv_"].apply(null,arguments)}_dtpmv_.stub=true;function _dtpsv_(){return wasmImports["dtpsv_"].apply(null,arguments)}_dtpsv_.stub=true;function _dtrmm_(){return wasmImports["dtrmm_"].apply(null,arguments)}_dtrmm_.stub=true;function _dtrmv_(){return wasmImports["dtrmv_"].apply(null,arguments)}_dtrmv_.stub=true;function _dtrsm_(){return wasmImports["dtrsm_"].apply(null,arguments)}_dtrsm_.stub=true;function _dtrsv_(){return wasmImports["dtrsv_"].apply(null,arguments)}_dtrsv_.stub=true;function _dzasum_(){return wasmImports["dzasum_"].apply(null,arguments)}_dzasum_.stub=true;function _dznrm2_(){return wasmImports["dznrm2_"].apply(null,arguments)}_dznrm2_.stub=true;var _emscripten_alcDevicePauseSOFT=deviceId=>{if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}if(AL.paused){return}AL.paused=true;for(var ctxId in AL.contexts){var ctx=AL.contexts[ctxId];if(ctx.deviceId!==deviceId){continue}ctx.audioCtx.suspend();clearInterval(ctx.interval);ctx.interval=null}};_emscripten_alcDevicePauseSOFT.sig="vi";var _emscripten_alcDeviceResumeSOFT=deviceId=>{if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return}if(!AL.paused){return}AL.paused=false;for(var ctxId in AL.contexts){var ctx=AL.contexts[ctxId];if(ctx.deviceId!==deviceId){continue}ctx.interval=setInterval(()=>AL.scheduleContextAudio(ctx),AL.QUEUE_INTERVAL);ctx.audioCtx.resume()}};_emscripten_alcDeviceResumeSOFT.sig="vi";var _emscripten_alcGetStringiSOFT=(deviceId,param,index)=>{if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return 0}if(AL.alcStringCache[param]){return AL.alcStringCache[param]}var ret;switch(param){case 6549:if(index===0){ret="Web Audio HRTF"}else{AL.alcErr=40964;return 0}break;default:if(index!==0){AL.alcErr=40963;return 0}return _alcGetString(deviceId,param)}ret=stringToNewUTF8(ret);AL.alcStringCache[param]=ret;return ret};_emscripten_alcGetStringiSOFT.sig="iiii";var _emscripten_alcResetDeviceSOFT=(deviceId,pAttrList)=>{if(!(deviceId in AL.deviceRefCounts)){AL.alcErr=40961;return 0}var hrtf=null;pAttrList>>=2;if(pAttrList){var attr=0;var val=0;while(true){attr=HEAP32[pAttrList++];if(attr===0){break}val=HEAP32[pAttrList++];switch(attr){case 6546:if(val===1){hrtf=true}else if(val===0){hrtf=false}break}}}if(hrtf!==null){for(var ctxId in AL.contexts){var ctx=AL.contexts[ctxId];if(ctx.deviceId===deviceId){ctx.hrtf=hrtf;AL.updateContextGlobal(ctx)}}}return 1};_emscripten_alcResetDeviceSOFT.sig="iii";var readEmAsmArgsArray=[];var readEmAsmArgs=(sigPtr,buf)=>{readEmAsmArgsArray.length=0;var ch;while(ch=HEAPU8[sigPtr++]){var wide=ch!=105;wide&=ch!=112;buf+=wide&&buf%8?4:0;readEmAsmArgsArray.push(ch==112?HEAPU32[buf>>2]:ch==106?HEAP64[buf>>3]:ch==105?HEAP32[buf>>2]:HEAPF64[buf>>3]);buf+=wide?8:4}return readEmAsmArgsArray};var runEmAsmFunction=(code,sigPtr,argbuf)=>{var args=readEmAsmArgs(sigPtr,argbuf);return ASM_CONSTS[code].apply(null,args)};var _emscripten_asm_const_int=(code,sigPtr,argbuf)=>runEmAsmFunction(code,sigPtr,argbuf);_emscripten_asm_const_int.sig="ippp";var _emscripten_console_error=str=>{console.error(UTF8ToString(str))};_emscripten_console_error.sig="vp";var _emscripten_console_log=str=>{console.log(UTF8ToString(str))};_emscripten_console_log.sig="vp";var _emscripten_console_warn=str=>{console.warn(UTF8ToString(str))};_emscripten_console_warn.sig="vp";var _emscripten_date_now=()=>Date.now();_emscripten_date_now.sig="d";var _emscripten_err=str=>err(UTF8ToString(str));_emscripten_err.sig="vp";var getHeapMax=()=>2147483648;var _emscripten_get_heap_max=()=>getHeapMax();_emscripten_get_heap_max.sig="p";var _emscripten_get_now_res=()=>{if(ENVIRONMENT_IS_NODE){return 1}return 1e3};_emscripten_get_now_res.sig="d";var webgl_enable_ANGLE_instanced_arrays=ctx=>{var ext=ctx.getExtension("ANGLE_instanced_arrays");if(ext){ctx["vertexAttribDivisor"]=(index,divisor)=>ext["vertexAttribDivisorANGLE"](index,divisor);ctx["drawArraysInstanced"]=(mode,first,count,primcount)=>ext["drawArraysInstancedANGLE"](mode,first,count,primcount);ctx["drawElementsInstanced"]=(mode,count,type,indices,primcount)=>ext["drawElementsInstancedANGLE"](mode,count,type,indices,primcount);return 1}};var webgl_enable_OES_vertex_array_object=ctx=>{var ext=ctx.getExtension("OES_vertex_array_object");if(ext){ctx["createVertexArray"]=()=>ext["createVertexArrayOES"]();ctx["deleteVertexArray"]=vao=>ext["deleteVertexArrayOES"](vao);ctx["bindVertexArray"]=vao=>ext["bindVertexArrayOES"](vao);ctx["isVertexArray"]=vao=>ext["isVertexArrayOES"](vao);return 1}};var webgl_enable_WEBGL_draw_buffers=ctx=>{var ext=ctx.getExtension("WEBGL_draw_buffers");if(ext){ctx["drawBuffers"]=(n,bufs)=>ext["drawBuffersWEBGL"](n,bufs);return 1}};var webgl_enable_WEBGL_multi_draw=ctx=>!!(ctx.multiDrawWebgl=ctx.getExtension("WEBGL_multi_draw"));var GL={counter:1,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],shaders:[],vaos:[],contexts:[],offscreenCanvases:{},queries:[],stringCache:{},unpackAlignment:4,recordError:function recordError(errorCode){if(!GL.lastError){GL.lastError=errorCode}},getNewId:table=>{var ret=GL.counter++;for(var i=table.length;i<ret;i++){table[i]=null}return ret},getSource:(shader,count,string,length)=>{var source="";for(var i=0;i<count;++i){var len=length?HEAP32[length+i*4>>2]:-1;source+=UTF8ToString(HEAP32[string+i*4>>2],len<0?undefined:len)}return source},createContext:(canvas,webGLContextAttributes)=>{if(!canvas.getContextSafariWebGL2Fixed){canvas.getContextSafariWebGL2Fixed=canvas.getContext;function fixedGetContext(ver,attrs){var gl=canvas.getContextSafariWebGL2Fixed(ver,attrs);return ver=="webgl"==gl instanceof WebGLRenderingContext?gl:null}canvas.getContext=fixedGetContext}var ctx=canvas.getContext("webgl",webGLContextAttributes);if(!ctx)return 0;var handle=GL.registerContext(ctx,webGLContextAttributes);return handle},registerContext:(ctx,webGLContextAttributes)=>{var handle=GL.getNewId(GL.contexts);var context={handle:handle,attributes:webGLContextAttributes,version:webGLContextAttributes.majorVersion,GLctx:ctx};if(ctx.canvas)ctx.canvas.GLctxObject=context;GL.contexts[handle]=context;if(typeof webGLContextAttributes.enableExtensionsByDefault=="undefined"||webGLContextAttributes.enableExtensionsByDefault){GL.initExtensions(context)}return handle},makeContextCurrent:contextHandle=>{GL.currentContext=GL.contexts[contextHandle];Module.ctx=GLctx=GL.currentContext&&GL.currentContext.GLctx;return!(contextHandle&&!GLctx)},getContext:contextHandle=>GL.contexts[contextHandle],deleteContext:contextHandle=>{if(GL.currentContext===GL.contexts[contextHandle])GL.currentContext=null;if(typeof JSEvents=="object")JSEvents.removeAllHandlersOnTarget(GL.contexts[contextHandle].GLctx.canvas);if(GL.contexts[contextHandle]&&GL.contexts[contextHandle].GLctx.canvas)GL.contexts[contextHandle].GLctx.canvas.GLctxObject=undefined;GL.contexts[contextHandle]=null},initExtensions:context=>{if(!context)context=GL.currentContext;if(context.initExtensionsDone)return;context.initExtensionsDone=true;var GLctx=context.GLctx;webgl_enable_ANGLE_instanced_arrays(GLctx);webgl_enable_OES_vertex_array_object(GLctx);webgl_enable_WEBGL_draw_buffers(GLctx);{GLctx.disjointTimerQueryExt=GLctx.getExtension("EXT_disjoint_timer_query")}webgl_enable_WEBGL_multi_draw(GLctx);var exts=GLctx.getSupportedExtensions()||[];exts.forEach(ext=>{if(!ext.includes("lose_context")&&!ext.includes("debug")){GLctx.getExtension(ext)}})}};function _glActiveTexture(x0){GLctx.activeTexture(x0)}_glActiveTexture.sig="vi";var _emscripten_glActiveTexture=_glActiveTexture;var _glAttachShader=(program,shader)=>{GLctx.attachShader(GL.programs[program],GL.shaders[shader])};_glAttachShader.sig="vii";var _emscripten_glAttachShader=_glAttachShader;var _glBeginQueryEXT=(target,id)=>{GLctx.disjointTimerQueryExt["beginQueryEXT"](target,GL.queries[id])};_glBeginQueryEXT.sig="vii";var _emscripten_glBeginQueryEXT=_glBeginQueryEXT;var _glBindAttribLocation=(program,index,name)=>{GLctx.bindAttribLocation(GL.programs[program],index,UTF8ToString(name))};_glBindAttribLocation.sig="viip";var _emscripten_glBindAttribLocation=_glBindAttribLocation;var _glBindBuffer=(target,buffer)=>{GLctx.bindBuffer(target,GL.buffers[buffer])};_glBindBuffer.sig="vii";var _emscripten_glBindBuffer=_glBindBuffer;var _glBindFramebuffer=(target,framebuffer)=>{GLctx.bindFramebuffer(target,GL.framebuffers[framebuffer])};_glBindFramebuffer.sig="vii";var _emscripten_glBindFramebuffer=_glBindFramebuffer;var _glBindRenderbuffer=(target,renderbuffer)=>{GLctx.bindRenderbuffer(target,GL.renderbuffers[renderbuffer])};_glBindRenderbuffer.sig="vii";var _emscripten_glBindRenderbuffer=_glBindRenderbuffer;var _glBindTexture=(target,texture)=>{GLctx.bindTexture(target,GL.textures[texture])};_glBindTexture.sig="vii";var _emscripten_glBindTexture=_glBindTexture;var _glBindVertexArray=vao=>{GLctx.bindVertexArray(GL.vaos[vao])};_glBindVertexArray.sig="vi";var _glBindVertexArrayOES=_glBindVertexArray;_glBindVertexArrayOES.sig="vi";var _emscripten_glBindVertexArrayOES=_glBindVertexArrayOES;function _glBlendColor(x0,x1,x2,x3){GLctx.blendColor(x0,x1,x2,x3)}_glBlendColor.sig="vffff";var _emscripten_glBlendColor=_glBlendColor;function _glBlendEquation(x0){GLctx.blendEquation(x0)}_glBlendEquation.sig="vi";var _emscripten_glBlendEquation=_glBlendEquation;function _glBlendEquationSeparate(x0,x1){GLctx.blendEquationSeparate(x0,x1)}_glBlendEquationSeparate.sig="vii";var _emscripten_glBlendEquationSeparate=_glBlendEquationSeparate;function _glBlendFunc(x0,x1){GLctx.blendFunc(x0,x1)}_glBlendFunc.sig="vii";var _emscripten_glBlendFunc=_glBlendFunc;function _glBlendFuncSeparate(x0,x1,x2,x3){GLctx.blendFuncSeparate(x0,x1,x2,x3)}_glBlendFuncSeparate.sig="viiii";var _emscripten_glBlendFuncSeparate=_glBlendFuncSeparate;var _glBufferData=(target,size,data,usage)=>{GLctx.bufferData(target,data?HEAPU8.subarray(data,data+size):size,usage)};_glBufferData.sig="vippi";var _emscripten_glBufferData=_glBufferData;var _glBufferSubData=(target,offset,size,data)=>{GLctx.bufferSubData(target,offset,HEAPU8.subarray(data,data+size))};_glBufferSubData.sig="vippp";var _emscripten_glBufferSubData=_glBufferSubData;function _glCheckFramebufferStatus(x0){return GLctx.checkFramebufferStatus(x0)}_glCheckFramebufferStatus.sig="ii";var _emscripten_glCheckFramebufferStatus=_glCheckFramebufferStatus;function _glClear(x0){GLctx.clear(x0)}_glClear.sig="vi";var _emscripten_glClear=_glClear;function _glClearColor(x0,x1,x2,x3){GLctx.clearColor(x0,x1,x2,x3)}_glClearColor.sig="vffff";var _emscripten_glClearColor=_glClearColor;function _glClearDepthf(x0){GLctx.clearDepth(x0)}_glClearDepthf.sig="vf";var _emscripten_glClearDepthf=_glClearDepthf;function _glClearStencil(x0){GLctx.clearStencil(x0)}_glClearStencil.sig="vi";var _emscripten_glClearStencil=_glClearStencil;var _glColorMask=(red,green,blue,alpha)=>{GLctx.colorMask(!!red,!!green,!!blue,!!alpha)};_glColorMask.sig="viiii";var _emscripten_glColorMask=_glColorMask;var _glCompileShader=shader=>{GLctx.compileShader(GL.shaders[shader])};_glCompileShader.sig="vi";var _emscripten_glCompileShader=_glCompileShader;var _glCompressedTexImage2D=(target,level,internalFormat,width,height,border,imageSize,data)=>{GLctx.compressedTexImage2D(target,level,internalFormat,width,height,border,data?HEAPU8.subarray(data,data+imageSize):null)};_glCompressedTexImage2D.sig="viiiiiiip";var _emscripten_glCompressedTexImage2D=_glCompressedTexImage2D;var _glCompressedTexSubImage2D=(target,level,xoffset,yoffset,width,height,format,imageSize,data)=>{GLctx.compressedTexSubImage2D(target,level,xoffset,yoffset,width,height,format,data?HEAPU8.subarray(data,data+imageSize):null)};_glCompressedTexSubImage2D.sig="viiiiiiiip";var _emscripten_glCompressedTexSubImage2D=_glCompressedTexSubImage2D;function _glCopyTexImage2D(x0,x1,x2,x3,x4,x5,x6,x7){GLctx.copyTexImage2D(x0,x1,x2,x3,x4,x5,x6,x7)}_glCopyTexImage2D.sig="viiiiiiii";var _emscripten_glCopyTexImage2D=_glCopyTexImage2D;function _glCopyTexSubImage2D(x0,x1,x2,x3,x4,x5,x6,x7){GLctx.copyTexSubImage2D(x0,x1,x2,x3,x4,x5,x6,x7)}_glCopyTexSubImage2D.sig="viiiiiiii";var _emscripten_glCopyTexSubImage2D=_glCopyTexSubImage2D;var _glCreateProgram=()=>{var id=GL.getNewId(GL.programs);var program=GLctx.createProgram();program.name=id;program.maxUniformLength=program.maxAttributeLength=program.maxUniformBlockNameLength=0;program.uniformIdCounter=1;GL.programs[id]=program;return id};_glCreateProgram.sig="i";var _emscripten_glCreateProgram=_glCreateProgram;var _glCreateShader=shaderType=>{var id=GL.getNewId(GL.shaders);GL.shaders[id]=GLctx.createShader(shaderType);return id};_glCreateShader.sig="ii";var _emscripten_glCreateShader=_glCreateShader;function _glCullFace(x0){GLctx.cullFace(x0)}_glCullFace.sig="vi";var _emscripten_glCullFace=_glCullFace;var _glDeleteBuffers=(n,buffers)=>{for(var i=0;i<n;i++){var id=HEAP32[buffers+i*4>>2];var buffer=GL.buffers[id];if(!buffer)continue;GLctx.deleteBuffer(buffer);buffer.name=0;GL.buffers[id]=null}};_glDeleteBuffers.sig="vip";var _emscripten_glDeleteBuffers=_glDeleteBuffers;var _glDeleteFramebuffers=(n,framebuffers)=>{for(var i=0;i<n;++i){var id=HEAP32[framebuffers+i*4>>2];var framebuffer=GL.framebuffers[id];if(!framebuffer)continue;GLctx.deleteFramebuffer(framebuffer);framebuffer.name=0;GL.framebuffers[id]=null}};_glDeleteFramebuffers.sig="vip";var _emscripten_glDeleteFramebuffers=_glDeleteFramebuffers;var _glDeleteProgram=id=>{if(!id)return;var program=GL.programs[id];if(!program){GL.recordError(1281);return}GLctx.deleteProgram(program);program.name=0;GL.programs[id]=null};_glDeleteProgram.sig="vi";var _emscripten_glDeleteProgram=_glDeleteProgram;var _glDeleteQueriesEXT=(n,ids)=>{for(var i=0;i<n;i++){var id=HEAP32[ids+i*4>>2];var query=GL.queries[id];if(!query)continue;GLctx.disjointTimerQueryExt["deleteQueryEXT"](query);GL.queries[id]=null}};_glDeleteQueriesEXT.sig="vii";var _emscripten_glDeleteQueriesEXT=_glDeleteQueriesEXT;var _glDeleteRenderbuffers=(n,renderbuffers)=>{for(var i=0;i<n;i++){var id=HEAP32[renderbuffers+i*4>>2];var renderbuffer=GL.renderbuffers[id];if(!renderbuffer)continue;GLctx.deleteRenderbuffer(renderbuffer);renderbuffer.name=0;GL.renderbuffers[id]=null}};_glDeleteRenderbuffers.sig="vip";var _emscripten_glDeleteRenderbuffers=_glDeleteRenderbuffers;var _glDeleteShader=id=>{if(!id)return;var shader=GL.shaders[id];if(!shader){GL.recordError(1281);return}GLctx.deleteShader(shader);GL.shaders[id]=null};_glDeleteShader.sig="vi";var _emscripten_glDeleteShader=_glDeleteShader;var _glDeleteTextures=(n,textures)=>{for(var i=0;i<n;i++){var id=HEAP32[textures+i*4>>2];var texture=GL.textures[id];if(!texture)continue;GLctx.deleteTexture(texture);texture.name=0;GL.textures[id]=null}};_glDeleteTextures.sig="vip";var _emscripten_glDeleteTextures=_glDeleteTextures;var _glDeleteVertexArrays=(n,vaos)=>{for(var i=0;i<n;i++){var id=HEAP32[vaos+i*4>>2];GLctx.deleteVertexArray(GL.vaos[id]);GL.vaos[id]=null}};_glDeleteVertexArrays.sig="vip";var _glDeleteVertexArraysOES=_glDeleteVertexArrays;_glDeleteVertexArraysOES.sig="vip";var _emscripten_glDeleteVertexArraysOES=_glDeleteVertexArraysOES;function _glDepthFunc(x0){GLctx.depthFunc(x0)}_glDepthFunc.sig="vi";var _emscripten_glDepthFunc=_glDepthFunc;var _glDepthMask=flag=>{GLctx.depthMask(!!flag)};_glDepthMask.sig="vi";var _emscripten_glDepthMask=_glDepthMask;function _glDepthRangef(x0,x1){GLctx.depthRange(x0,x1)}_glDepthRangef.sig="vff";var _emscripten_glDepthRangef=_glDepthRangef;var _glDetachShader=(program,shader)=>{GLctx.detachShader(GL.programs[program],GL.shaders[shader])};_glDetachShader.sig="vii";var _emscripten_glDetachShader=_glDetachShader;function _glDisable(x0){GLctx.disable(x0)}_glDisable.sig="vi";var _emscripten_glDisable=_glDisable;var _glDisableVertexAttribArray=index=>{GLctx.disableVertexAttribArray(index)};_glDisableVertexAttribArray.sig="vi";var _emscripten_glDisableVertexAttribArray=_glDisableVertexAttribArray;var _glDrawArrays=(mode,first,count)=>{GLctx.drawArrays(mode,first,count)};_glDrawArrays.sig="viii";var _emscripten_glDrawArrays=_glDrawArrays;var _glDrawArraysInstanced=(mode,first,count,primcount)=>{GLctx.drawArraysInstanced(mode,first,count,primcount)};_glDrawArraysInstanced.sig="viiii";var _glDrawArraysInstancedANGLE=_glDrawArraysInstanced;var _emscripten_glDrawArraysInstancedANGLE=_glDrawArraysInstancedANGLE;var tempFixedLengthArray=[];var _glDrawBuffers=(n,bufs)=>{var bufArray=tempFixedLengthArray[n];for(var i=0;i<n;i++){bufArray[i]=HEAP32[bufs+i*4>>2]}GLctx.drawBuffers(bufArray)};_glDrawBuffers.sig="vip";var _glDrawBuffersWEBGL=_glDrawBuffers;var _emscripten_glDrawBuffersWEBGL=_glDrawBuffersWEBGL;var _glDrawElements=(mode,count,type,indices)=>{GLctx.drawElements(mode,count,type,indices)};_glDrawElements.sig="viiip";var _emscripten_glDrawElements=_glDrawElements;var _glDrawElementsInstanced=(mode,count,type,indices,primcount)=>{GLctx.drawElementsInstanced(mode,count,type,indices,primcount)};_glDrawElementsInstanced.sig="viiipi";var _glDrawElementsInstancedANGLE=_glDrawElementsInstanced;var _emscripten_glDrawElementsInstancedANGLE=_glDrawElementsInstancedANGLE;function _glEnable(x0){GLctx.enable(x0)}_glEnable.sig="vi";var _emscripten_glEnable=_glEnable;var _glEnableVertexAttribArray=index=>{GLctx.enableVertexAttribArray(index)};_glEnableVertexAttribArray.sig="vi";var _emscripten_glEnableVertexAttribArray=_glEnableVertexAttribArray;var _glEndQueryEXT=target=>{GLctx.disjointTimerQueryExt["endQueryEXT"](target)};_glEndQueryEXT.sig="vi";var _emscripten_glEndQueryEXT=_glEndQueryEXT;function _glFinish(){GLctx.finish()}_glFinish.sig="v";var _emscripten_glFinish=_glFinish;function _glFlush(){GLctx.flush()}_glFlush.sig="v";var _emscripten_glFlush=_glFlush;var _glFramebufferRenderbuffer=(target,attachment,renderbuffertarget,renderbuffer)=>{GLctx.framebufferRenderbuffer(target,attachment,renderbuffertarget,GL.renderbuffers[renderbuffer])};_glFramebufferRenderbuffer.sig="viiii";var _emscripten_glFramebufferRenderbuffer=_glFramebufferRenderbuffer;var _glFramebufferTexture2D=(target,attachment,textarget,texture,level)=>{GLctx.framebufferTexture2D(target,attachment,textarget,GL.textures[texture],level)};_glFramebufferTexture2D.sig="viiiii";var _emscripten_glFramebufferTexture2D=_glFramebufferTexture2D;function _glFrontFace(x0){GLctx.frontFace(x0)}_glFrontFace.sig="vi";var _emscripten_glFrontFace=_glFrontFace;var __glGenObject=(n,buffers,createFunction,objectTable)=>{for(var i=0;i<n;i++){var buffer=GLctx[createFunction]();var id=buffer&&GL.getNewId(objectTable);if(buffer){buffer.name=id;objectTable[id]=buffer}else{GL.recordError(1282)}HEAP32[buffers+i*4>>2]=id}};var _glGenBuffers=(n,buffers)=>{__glGenObject(n,buffers,"createBuffer",GL.buffers)};_glGenBuffers.sig="vip";var _emscripten_glGenBuffers=_glGenBuffers;var _glGenFramebuffers=(n,ids)=>{__glGenObject(n,ids,"createFramebuffer",GL.framebuffers)};_glGenFramebuffers.sig="vip";var _emscripten_glGenFramebuffers=_glGenFramebuffers;var _glGenQueriesEXT=(n,ids)=>{for(var i=0;i<n;i++){var query=GLctx.disjointTimerQueryExt["createQueryEXT"]();if(!query){GL.recordError(1282);while(i<n)HEAP32[ids+i++*4>>2]=0;return}var id=GL.getNewId(GL.queries);query.name=id;GL.queries[id]=query;HEAP32[ids+i*4>>2]=id}};_glGenQueriesEXT.sig="vii";var _emscripten_glGenQueriesEXT=_glGenQueriesEXT;var _glGenRenderbuffers=(n,renderbuffers)=>{__glGenObject(n,renderbuffers,"createRenderbuffer",GL.renderbuffers)};_glGenRenderbuffers.sig="vip";var _emscripten_glGenRenderbuffers=_glGenRenderbuffers;var _glGenTextures=(n,textures)=>{__glGenObject(n,textures,"createTexture",GL.textures)};_glGenTextures.sig="vip";var _emscripten_glGenTextures=_glGenTextures;function _glGenVertexArrays(n,arrays){__glGenObject(n,arrays,"createVertexArray",GL.vaos)}_glGenVertexArrays.sig="vip";var _glGenVertexArraysOES=_glGenVertexArrays;_glGenVertexArraysOES.sig="vip";var _emscripten_glGenVertexArraysOES=_glGenVertexArraysOES;function _glGenerateMipmap(x0){GLctx.generateMipmap(x0)}_glGenerateMipmap.sig="vi";var _emscripten_glGenerateMipmap=_glGenerateMipmap;var __glGetActiveAttribOrUniform=(funcName,program,index,bufSize,length,size,type,name)=>{program=GL.programs[program];var info=GLctx[funcName](program,index);if(info){var numBytesWrittenExclNull=name&&stringToUTF8(info.name,name,bufSize);if(length)HEAP32[length>>2]=numBytesWrittenExclNull;if(size)HEAP32[size>>2]=info.size;if(type)HEAP32[type>>2]=info.type}};var _glGetActiveAttrib=(program,index,bufSize,length,size,type,name)=>{__glGetActiveAttribOrUniform("getActiveAttrib",program,index,bufSize,length,size,type,name)};_glGetActiveAttrib.sig="viiipppp";var _emscripten_glGetActiveAttrib=_glGetActiveAttrib;var _glGetActiveUniform=(program,index,bufSize,length,size,type,name)=>{__glGetActiveAttribOrUniform("getActiveUniform",program,index,bufSize,length,size,type,name)};_glGetActiveUniform.sig="viiipppp";var _emscripten_glGetActiveUniform=_glGetActiveUniform;var _glGetAttachedShaders=(program,maxCount,count,shaders)=>{var result=GLctx.getAttachedShaders(GL.programs[program]);var len=result.length;if(len>maxCount){len=maxCount}HEAP32[count>>2]=len;for(var i=0;i<len;++i){var id=GL.shaders.indexOf(result[i]);HEAP32[shaders+i*4>>2]=id}};_glGetAttachedShaders.sig="viipp";var _emscripten_glGetAttachedShaders=_glGetAttachedShaders;var _glGetAttribLocation=(program,name)=>GLctx.getAttribLocation(GL.programs[program],UTF8ToString(name));_glGetAttribLocation.sig="iip";var _emscripten_glGetAttribLocation=_glGetAttribLocation;var writeI53ToI64=(ptr,num)=>{HEAPU32[ptr>>2]=num;var lower=HEAPU32[ptr>>2];HEAPU32[ptr+4>>2]=(num-lower)/4294967296};var emscriptenWebGLGet=(name_,p,type)=>{if(!p){GL.recordError(1281);return}var ret=undefined;switch(name_){case 36346:ret=1;break;case 36344:if(type!=0&&type!=1){GL.recordError(1280)}return;case 36345:ret=0;break;case 34466:var formats=GLctx.getParameter(34467);ret=formats?formats.length:0;break}if(ret===undefined){var result=GLctx.getParameter(name_);switch(typeof result){case"number":ret=result;break;case"boolean":ret=result?1:0;break;case"string":GL.recordError(1280);return;case"object":if(result===null){switch(name_){case 34964:case 35725:case 34965:case 36006:case 36007:case 32873:case 34229:case 34068:{ret=0;break}default:{GL.recordError(1280);return}}}else if(result instanceof Float32Array||result instanceof Uint32Array||result instanceof Int32Array||result instanceof Array){for(var i=0;i<result.length;++i){switch(type){case 0:HEAP32[p+i*4>>2]=result[i];break;case 2:HEAPF32[p+i*4>>2]=result[i];break;case 4:HEAP8[p+i>>0]=result[i]?1:0;break}}return}else{try{ret=result.name|0}catch(e){GL.recordError(1280);err("GL_INVALID_ENUM in glGet"+type+"v: Unknown object returned from WebGL getParameter("+name_+")! (error: "+e+")");return}}break;default:GL.recordError(1280);err("GL_INVALID_ENUM in glGet"+type+"v: Native code calling glGet"+type+"v("+name_+") and it returns "+result+" of type "+typeof result+"!");return}}switch(type){case 1:writeI53ToI64(p,ret);break;case 0:HEAP32[p>>2]=ret;break;case 2:HEAPF32[p>>2]=ret;break;case 4:HEAP8[p>>0]=ret?1:0;break}};var _glGetBooleanv=(name_,p)=>{emscriptenWebGLGet(name_,p,4)};_glGetBooleanv.sig="vip";var _emscripten_glGetBooleanv=_glGetBooleanv;var _glGetBufferParameteriv=(target,value,data)=>{if(!data){GL.recordError(1281);return}HEAP32[data>>2]=GLctx.getBufferParameter(target,value)};_glGetBufferParameteriv.sig="viip";var _emscripten_glGetBufferParameteriv=_glGetBufferParameteriv;var _glGetError=()=>{var error=GLctx.getError()||GL.lastError;GL.lastError=0;return error};_glGetError.sig="i";var _emscripten_glGetError=_glGetError;var _glGetFloatv=(name_,p)=>{emscriptenWebGLGet(name_,p,2)};_glGetFloatv.sig="vip";var _emscripten_glGetFloatv=_glGetFloatv;var _glGetFramebufferAttachmentParameteriv=(target,attachment,pname,params)=>{var result=GLctx.getFramebufferAttachmentParameter(target,attachment,pname);if(result instanceof WebGLRenderbuffer||result instanceof WebGLTexture){result=result.name|0}HEAP32[params>>2]=result};_glGetFramebufferAttachmentParameteriv.sig="viiip";var _emscripten_glGetFramebufferAttachmentParameteriv=_glGetFramebufferAttachmentParameteriv;var _glGetIntegerv=(name_,p)=>{emscriptenWebGLGet(name_,p,0)};_glGetIntegerv.sig="vip";var _emscripten_glGetIntegerv=_glGetIntegerv;var _glGetProgramInfoLog=(program,maxLength,length,infoLog)=>{var log=GLctx.getProgramInfoLog(GL.programs[program]);if(log===null)log="(unknown error)";var numBytesWrittenExclNull=maxLength>0&&infoLog?stringToUTF8(log,infoLog,maxLength):0;if(length)HEAP32[length>>2]=numBytesWrittenExclNull};_glGetProgramInfoLog.sig="viipp";var _emscripten_glGetProgramInfoLog=_glGetProgramInfoLog;var _glGetProgramiv=(program,pname,p)=>{if(!p){GL.recordError(1281);return}if(program>=GL.counter){GL.recordError(1281);return}program=GL.programs[program];if(pname==35716){var log=GLctx.getProgramInfoLog(program);if(log===null)log="(unknown error)";HEAP32[p>>2]=log.length+1}else if(pname==35719){if(!program.maxUniformLength){for(var i=0;i<GLctx.getProgramParameter(program,35718);++i){program.maxUniformLength=Math.max(program.maxUniformLength,GLctx.getActiveUniform(program,i).name.length+1)}}HEAP32[p>>2]=program.maxUniformLength}else if(pname==35722){if(!program.maxAttributeLength){for(var i=0;i<GLctx.getProgramParameter(program,35721);++i){program.maxAttributeLength=Math.max(program.maxAttributeLength,GLctx.getActiveAttrib(program,i).name.length+1)}}HEAP32[p>>2]=program.maxAttributeLength}else if(pname==35381){if(!program.maxUniformBlockNameLength){for(var i=0;i<GLctx.getProgramParameter(program,35382);++i){program.maxUniformBlockNameLength=Math.max(program.maxUniformBlockNameLength,GLctx.getActiveUniformBlockName(program,i).length+1)}}HEAP32[p>>2]=program.maxUniformBlockNameLength}else{HEAP32[p>>2]=GLctx.getProgramParameter(program,pname)}};_glGetProgramiv.sig="viip";var _emscripten_glGetProgramiv=_glGetProgramiv;var _glGetQueryObjecti64vEXT=(id,pname,params)=>{if(!params){GL.recordError(1281);return}var query=GL.queries[id];var param;{param=GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query,pname)}var ret;if(typeof param=="boolean"){ret=param?1:0}else{ret=param}writeI53ToI64(params,ret)};_glGetQueryObjecti64vEXT.sig="viii";var _emscripten_glGetQueryObjecti64vEXT=_glGetQueryObjecti64vEXT;var _glGetQueryObjectivEXT=(id,pname,params)=>{if(!params){GL.recordError(1281);return}var query=GL.queries[id];var param=GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query,pname);var ret;if(typeof param=="boolean"){ret=param?1:0}else{ret=param}HEAP32[params>>2]=ret};_glGetQueryObjectivEXT.sig="viii";var _emscripten_glGetQueryObjectivEXT=_glGetQueryObjectivEXT;var _glGetQueryObjectui64vEXT=_glGetQueryObjecti64vEXT;var _emscripten_glGetQueryObjectui64vEXT=_glGetQueryObjectui64vEXT;var _glGetQueryObjectuivEXT=_glGetQueryObjectivEXT;var _emscripten_glGetQueryObjectuivEXT=_glGetQueryObjectuivEXT;var _glGetQueryivEXT=(target,pname,params)=>{if(!params){GL.recordError(1281);return}HEAP32[params>>2]=GLctx.disjointTimerQueryExt["getQueryEXT"](target,pname)};_glGetQueryivEXT.sig="viii";var _emscripten_glGetQueryivEXT=_glGetQueryivEXT;var _glGetRenderbufferParameteriv=(target,pname,params)=>{if(!params){GL.recordError(1281);return}HEAP32[params>>2]=GLctx.getRenderbufferParameter(target,pname)};_glGetRenderbufferParameteriv.sig="viip";var _emscripten_glGetRenderbufferParameteriv=_glGetRenderbufferParameteriv;var _glGetShaderInfoLog=(shader,maxLength,length,infoLog)=>{var log=GLctx.getShaderInfoLog(GL.shaders[shader]);if(log===null)log="(unknown error)";var numBytesWrittenExclNull=maxLength>0&&infoLog?stringToUTF8(log,infoLog,maxLength):0;if(length)HEAP32[length>>2]=numBytesWrittenExclNull};_glGetShaderInfoLog.sig="viipp";var _emscripten_glGetShaderInfoLog=_glGetShaderInfoLog;var _glGetShaderPrecisionFormat=(shaderType,precisionType,range,precision)=>{var result=GLctx.getShaderPrecisionFormat(shaderType,precisionType);HEAP32[range>>2]=result.rangeMin;HEAP32[range+4>>2]=result.rangeMax;HEAP32[precision>>2]=result.precision};_glGetShaderPrecisionFormat.sig="viipp";var _emscripten_glGetShaderPrecisionFormat=_glGetShaderPrecisionFormat;var _glGetShaderSource=(shader,bufSize,length,source)=>{var result=GLctx.getShaderSource(GL.shaders[shader]);if(!result)return;var numBytesWrittenExclNull=bufSize>0&&source?stringToUTF8(result,source,bufSize):0;if(length)HEAP32[length>>2]=numBytesWrittenExclNull};_glGetShaderSource.sig="viipp";var _emscripten_glGetShaderSource=_glGetShaderSource;var _glGetShaderiv=(shader,pname,p)=>{if(!p){GL.recordError(1281);return}if(pname==35716){var log=GLctx.getShaderInfoLog(GL.shaders[shader]);if(log===null)log="(unknown error)";var logLength=log?log.length+1:0;HEAP32[p>>2]=logLength}else if(pname==35720){var source=GLctx.getShaderSource(GL.shaders[shader]);var sourceLength=source?source.length+1:0;HEAP32[p>>2]=sourceLength}else{HEAP32[p>>2]=GLctx.getShaderParameter(GL.shaders[shader],pname)}};_glGetShaderiv.sig="viip";var _emscripten_glGetShaderiv=_glGetShaderiv;var _glGetString=name_=>{var ret=GL.stringCache[name_];if(!ret){switch(name_){case 7939:var exts=GLctx.getSupportedExtensions()||[];exts=exts.concat(exts.map(e=>"GL_"+e));ret=stringToNewUTF8(exts.join(" "));break;case 7936:case 7937:case 37445:case 37446:var s=GLctx.getParameter(name_);if(!s){GL.recordError(1280)}ret=s&&stringToNewUTF8(s);break;case 7938:var glVersion=GLctx.getParameter(7938);{glVersion="OpenGL ES 2.0 ("+glVersion+")"}ret=stringToNewUTF8(glVersion);break;case 35724:var glslVersion=GLctx.getParameter(35724);var ver_re=/^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/;var ver_num=glslVersion.match(ver_re);if(ver_num!==null){if(ver_num[1].length==3)ver_num[1]=ver_num[1]+"0";glslVersion="OpenGL ES GLSL ES "+ver_num[1]+" ("+glslVersion+")"}ret=stringToNewUTF8(glslVersion);break;default:GL.recordError(1280)}GL.stringCache[name_]=ret}return ret};_glGetString.sig="pi";var _emscripten_glGetString=_glGetString;var _glGetTexParameterfv=(target,pname,params)=>{if(!params){GL.recordError(1281);return}HEAPF32[params>>2]=GLctx.getTexParameter(target,pname)};_glGetTexParameterfv.sig="viip";var _emscripten_glGetTexParameterfv=_glGetTexParameterfv;var _glGetTexParameteriv=(target,pname,params)=>{if(!params){GL.recordError(1281);return}HEAP32[params>>2]=GLctx.getTexParameter(target,pname)};_glGetTexParameteriv.sig="viip";var _emscripten_glGetTexParameteriv=_glGetTexParameteriv;var webglGetLeftBracePos=name=>name.slice(-1)=="]"&&name.lastIndexOf("[");var webglPrepareUniformLocationsBeforeFirstUse=program=>{var uniformLocsById=program.uniformLocsById,uniformSizeAndIdsByName=program.uniformSizeAndIdsByName,i,j;if(!uniformLocsById){program.uniformLocsById=uniformLocsById={};program.uniformArrayNamesById={};for(i=0;i<GLctx.getProgramParameter(program,35718);++i){var u=GLctx.getActiveUniform(program,i);var nm=u.name;var sz=u.size;var lb=webglGetLeftBracePos(nm);var arrayName=lb>0?nm.slice(0,lb):nm;var id=program.uniformIdCounter;program.uniformIdCounter+=sz;uniformSizeAndIdsByName[arrayName]=[sz,id];for(j=0;j<sz;++j){uniformLocsById[id]=j;program.uniformArrayNamesById[id++]=arrayName}}}};var _glGetUniformLocation=(program,name)=>{name=UTF8ToString(name);if(program=GL.programs[program]){webglPrepareUniformLocationsBeforeFirstUse(program);var uniformLocsById=program.uniformLocsById;var arrayIndex=0;var uniformBaseName=name;var leftBrace=webglGetLeftBracePos(name);if(leftBrace>0){arrayIndex=jstoi_q(name.slice(leftBrace+1))>>>0;uniformBaseName=name.slice(0,leftBrace)}var sizeAndId=program.uniformSizeAndIdsByName[uniformBaseName];if(sizeAndId&&arrayIndex<sizeAndId[0]){arrayIndex+=sizeAndId[1];if(uniformLocsById[arrayIndex]=uniformLocsById[arrayIndex]||GLctx.getUniformLocation(program,name)){return arrayIndex}}}else{GL.recordError(1281)}return-1};_glGetUniformLocation.sig="iip";var _emscripten_glGetUniformLocation=_glGetUniformLocation;var webglGetUniformLocation=location=>{var p=GLctx.currentProgram;if(p){var webglLoc=p.uniformLocsById[location];if(typeof webglLoc=="number"){p.uniformLocsById[location]=webglLoc=GLctx.getUniformLocation(p,p.uniformArrayNamesById[location]+(webglLoc>0?"["+webglLoc+"]":""))}return webglLoc}else{GL.recordError(1282)}};var emscriptenWebGLGetUniform=(program,location,params,type)=>{if(!params){GL.recordError(1281);return}program=GL.programs[program];webglPrepareUniformLocationsBeforeFirstUse(program);var data=GLctx.getUniform(program,webglGetUniformLocation(location));if(typeof data=="number"||typeof data=="boolean"){switch(type){case 0:HEAP32[params>>2]=data;break;case 2:HEAPF32[params>>2]=data;break}}else{for(var i=0;i<data.length;i++){switch(type){case 0:HEAP32[params+i*4>>2]=data[i];break;case 2:HEAPF32[params+i*4>>2]=data[i];break}}}};var _glGetUniformfv=(program,location,params)=>{emscriptenWebGLGetUniform(program,location,params,2)};_glGetUniformfv.sig="viip";var _emscripten_glGetUniformfv=_glGetUniformfv;var _glGetUniformiv=(program,location,params)=>{emscriptenWebGLGetUniform(program,location,params,0)};_glGetUniformiv.sig="viip";var _emscripten_glGetUniformiv=_glGetUniformiv;var _glGetVertexAttribPointerv=(index,pname,pointer)=>{if(!pointer){GL.recordError(1281);return}HEAP32[pointer>>2]=GLctx.getVertexAttribOffset(index,pname)};_glGetVertexAttribPointerv.sig="viip";var _emscripten_glGetVertexAttribPointerv=_glGetVertexAttribPointerv;var emscriptenWebGLGetVertexAttrib=(index,pname,params,type)=>{if(!params){GL.recordError(1281);return}var data=GLctx.getVertexAttrib(index,pname);if(pname==34975){HEAP32[params>>2]=data&&data["name"]}else if(typeof data=="number"||typeof data=="boolean"){switch(type){case 0:HEAP32[params>>2]=data;break;case 2:HEAPF32[params>>2]=data;break;case 5:HEAP32[params>>2]=Math.fround(data);break}}else{for(var i=0;i<data.length;i++){switch(type){case 0:HEAP32[params+i*4>>2]=data[i];break;case 2:HEAPF32[params+i*4>>2]=data[i];break;case 5:HEAP32[params+i*4>>2]=Math.fround(data[i]);break}}}};var _glGetVertexAttribfv=(index,pname,params)=>{emscriptenWebGLGetVertexAttrib(index,pname,params,2)};_glGetVertexAttribfv.sig="viip";var _emscripten_glGetVertexAttribfv=_glGetVertexAttribfv;var _glGetVertexAttribiv=(index,pname,params)=>{emscriptenWebGLGetVertexAttrib(index,pname,params,5)};_glGetVertexAttribiv.sig="viip";var _emscripten_glGetVertexAttribiv=_glGetVertexAttribiv;function _glHint(x0,x1){GLctx.hint(x0,x1)}_glHint.sig="vii";var _emscripten_glHint=_glHint;var _glIsBuffer=buffer=>{var b=GL.buffers[buffer];if(!b)return 0;return GLctx.isBuffer(b)};_glIsBuffer.sig="ii";var _emscripten_glIsBuffer=_glIsBuffer;function _glIsEnabled(x0){return GLctx.isEnabled(x0)}_glIsEnabled.sig="ii";var _emscripten_glIsEnabled=_glIsEnabled;var _glIsFramebuffer=framebuffer=>{var fb=GL.framebuffers[framebuffer];if(!fb)return 0;return GLctx.isFramebuffer(fb)};_glIsFramebuffer.sig="ii";var _emscripten_glIsFramebuffer=_glIsFramebuffer;var _glIsProgram=program=>{program=GL.programs[program];if(!program)return 0;return GLctx.isProgram(program)};_glIsProgram.sig="ii";var _emscripten_glIsProgram=_glIsProgram;var _glIsQueryEXT=id=>{var query=GL.queries[id];if(!query)return 0;return GLctx.disjointTimerQueryExt["isQueryEXT"](query)};_glIsQueryEXT.sig="ii";var _emscripten_glIsQueryEXT=_glIsQueryEXT;var _glIsRenderbuffer=renderbuffer=>{var rb=GL.renderbuffers[renderbuffer];if(!rb)return 0;return GLctx.isRenderbuffer(rb)};_glIsRenderbuffer.sig="ii";var _emscripten_glIsRenderbuffer=_glIsRenderbuffer;var _glIsShader=shader=>{var s=GL.shaders[shader];if(!s)return 0;return GLctx.isShader(s)};_glIsShader.sig="ii";var _emscripten_glIsShader=_glIsShader;var _glIsTexture=id=>{var texture=GL.textures[id];if(!texture)return 0;return GLctx.isTexture(texture)};_glIsTexture.sig="ii";var _emscripten_glIsTexture=_glIsTexture;var _glIsVertexArray=array=>{var vao=GL.vaos[array];if(!vao)return 0;return GLctx.isVertexArray(vao)};_glIsVertexArray.sig="ii";var _glIsVertexArrayOES=_glIsVertexArray;_glIsVertexArrayOES.sig="ii";var _emscripten_glIsVertexArrayOES=_glIsVertexArrayOES;function _glLineWidth(x0){GLctx.lineWidth(x0)}_glLineWidth.sig="vf";var _emscripten_glLineWidth=_glLineWidth;var _glLinkProgram=program=>{program=GL.programs[program];GLctx.linkProgram(program);program.uniformLocsById=0;program.uniformSizeAndIdsByName={}};_glLinkProgram.sig="vi";var _emscripten_glLinkProgram=_glLinkProgram;var _glPixelStorei=(pname,param)=>{if(pname==3317){GL.unpackAlignment=param}GLctx.pixelStorei(pname,param)};_glPixelStorei.sig="vii";var _emscripten_glPixelStorei=_glPixelStorei;function _glPolygonOffset(x0,x1){GLctx.polygonOffset(x0,x1)}_glPolygonOffset.sig="vff";var _emscripten_glPolygonOffset=_glPolygonOffset;var _glQueryCounterEXT=(id,target)=>{GLctx.disjointTimerQueryExt["queryCounterEXT"](GL.queries[id],target)};_glQueryCounterEXT.sig="vii";var _emscripten_glQueryCounterEXT=_glQueryCounterEXT;var computeUnpackAlignedImageSize=(width,height,sizePerPixel,alignment)=>{function roundedToNextMultipleOf(x,y){return x+y-1&-y}var plainRowSize=width*sizePerPixel;var alignedRowSize=roundedToNextMultipleOf(plainRowSize,alignment);return height*alignedRowSize};var colorChannelsInGlTextureFormat=format=>{var colorChannels={5:3,6:4,8:2,29502:3,29504:4};return colorChannels[format-6402]||1};var heapObjectForWebGLType=type=>{type-=5120;if(type==1)return HEAPU8;if(type==4)return HEAP32;if(type==6)return HEAPF32;if(type==5||type==28922)return HEAPU32;return HEAPU16};var heapAccessShiftForWebGLHeap=heap=>31-Math.clz32(heap.BYTES_PER_ELEMENT);var emscriptenWebGLGetTexPixelData=(type,format,width,height,pixels,internalFormat)=>{var heap=heapObjectForWebGLType(type);var shift=heapAccessShiftForWebGLHeap(heap);var byteSize=1<<shift;var sizePerPixel=colorChannelsInGlTextureFormat(format)*byteSize;var bytes=computeUnpackAlignedImageSize(width,height,sizePerPixel,GL.unpackAlignment);return heap.subarray(pixels>>shift,pixels+bytes>>shift)};var _glReadPixels=(x,y,width,height,format,type,pixels)=>{var pixelData=emscriptenWebGLGetTexPixelData(type,format,width,height,pixels,format);if(!pixelData){GL.recordError(1280);return}GLctx.readPixels(x,y,width,height,format,type,pixelData)};_glReadPixels.sig="viiiiiip";var _emscripten_glReadPixels=_glReadPixels;var _glReleaseShaderCompiler=()=>{};_glReleaseShaderCompiler.sig="v";var _emscripten_glReleaseShaderCompiler=_glReleaseShaderCompiler;function _glRenderbufferStorage(x0,x1,x2,x3){GLctx.renderbufferStorage(x0,x1,x2,x3)}_glRenderbufferStorage.sig="viiii";var _emscripten_glRenderbufferStorage=_glRenderbufferStorage;var _glSampleCoverage=(value,invert)=>{GLctx.sampleCoverage(value,!!invert)};_glSampleCoverage.sig="vfi";var _emscripten_glSampleCoverage=_glSampleCoverage;function _glScissor(x0,x1,x2,x3){GLctx.scissor(x0,x1,x2,x3)}_glScissor.sig="viiii";var _emscripten_glScissor=_glScissor;var _glShaderBinary=(count,shaders,binaryformat,binary,length)=>{GL.recordError(1280)};_glShaderBinary.sig="vipipi";var _emscripten_glShaderBinary=_glShaderBinary;var _glShaderSource=(shader,count,string,length)=>{var source=GL.getSource(shader,count,string,length);GLctx.shaderSource(GL.shaders[shader],source)};_glShaderSource.sig="viipp";var _emscripten_glShaderSource=_glShaderSource;function _glStencilFunc(x0,x1,x2){GLctx.stencilFunc(x0,x1,x2)}_glStencilFunc.sig="viii";var _emscripten_glStencilFunc=_glStencilFunc;function _glStencilFuncSeparate(x0,x1,x2,x3){GLctx.stencilFuncSeparate(x0,x1,x2,x3)}_glStencilFuncSeparate.sig="viiii";var _emscripten_glStencilFuncSeparate=_glStencilFuncSeparate;function _glStencilMask(x0){GLctx.stencilMask(x0)}_glStencilMask.sig="vi";var _emscripten_glStencilMask=_glStencilMask;function _glStencilMaskSeparate(x0,x1){GLctx.stencilMaskSeparate(x0,x1)}_glStencilMaskSeparate.sig="vii";var _emscripten_glStencilMaskSeparate=_glStencilMaskSeparate;function _glStencilOp(x0,x1,x2){GLctx.stencilOp(x0,x1,x2)}_glStencilOp.sig="viii";var _emscripten_glStencilOp=_glStencilOp;function _glStencilOpSeparate(x0,x1,x2,x3){GLctx.stencilOpSeparate(x0,x1,x2,x3)}_glStencilOpSeparate.sig="viiii";var _emscripten_glStencilOpSeparate=_glStencilOpSeparate;var _glTexImage2D=(target,level,internalFormat,width,height,border,format,type,pixels)=>{GLctx.texImage2D(target,level,internalFormat,width,height,border,format,type,pixels?emscriptenWebGLGetTexPixelData(type,format,width,height,pixels,internalFormat):null)};_glTexImage2D.sig="viiiiiiiip";var _emscripten_glTexImage2D=_glTexImage2D;function _glTexParameterf(x0,x1,x2){GLctx.texParameterf(x0,x1,x2)}_glTexParameterf.sig="viif";var _emscripten_glTexParameterf=_glTexParameterf;var _glTexParameterfv=(target,pname,params)=>{var param=HEAPF32[params>>2];GLctx.texParameterf(target,pname,param)};_glTexParameterfv.sig="viip";var _emscripten_glTexParameterfv=_glTexParameterfv;function _glTexParameteri(x0,x1,x2){GLctx.texParameteri(x0,x1,x2)}_glTexParameteri.sig="viii";var _emscripten_glTexParameteri=_glTexParameteri;var _glTexParameteriv=(target,pname,params)=>{var param=HEAP32[params>>2];GLctx.texParameteri(target,pname,param)};_glTexParameteriv.sig="viip";var _emscripten_glTexParameteriv=_glTexParameteriv;var _glTexSubImage2D=(target,level,xoffset,yoffset,width,height,format,type,pixels)=>{var pixelData=null;if(pixels)pixelData=emscriptenWebGLGetTexPixelData(type,format,width,height,pixels,0);GLctx.texSubImage2D(target,level,xoffset,yoffset,width,height,format,type,pixelData)};_glTexSubImage2D.sig="viiiiiiiip";var _emscripten_glTexSubImage2D=_glTexSubImage2D;var _glUniform1f=(location,v0)=>{GLctx.uniform1f(webglGetUniformLocation(location),v0)};_glUniform1f.sig="vif";var _emscripten_glUniform1f=_glUniform1f;var miniTempWebGLFloatBuffers=[];var _glUniform1fv=(location,count,value)=>{if(count<=288){var view=miniTempWebGLFloatBuffers[count-1];for(var i=0;i<count;++i){view[i]=HEAPF32[value+4*i>>2]}}else{var view=HEAPF32.subarray(value>>2,value+count*4>>2)}GLctx.uniform1fv(webglGetUniformLocation(location),view)};_glUniform1fv.sig="viip";var _emscripten_glUniform1fv=_glUniform1fv;var _glUniform1i=(location,v0)=>{GLctx.uniform1i(webglGetUniformLocation(location),v0)};_glUniform1i.sig="vii";var _emscripten_glUniform1i=_glUniform1i;var miniTempWebGLIntBuffers=[];var _glUniform1iv=(location,count,value)=>{if(count<=288){var view=miniTempWebGLIntBuffers[count-1];for(var i=0;i<count;++i){view[i]=HEAP32[value+4*i>>2]}}else{var view=HEAP32.subarray(value>>2,value+count*4>>2)}GLctx.uniform1iv(webglGetUniformLocation(location),view)};_glUniform1iv.sig="viip";var _emscripten_glUniform1iv=_glUniform1iv;var _glUniform2f=(location,v0,v1)=>{GLctx.uniform2f(webglGetUniformLocation(location),v0,v1)};_glUniform2f.sig="viff";var _emscripten_glUniform2f=_glUniform2f;var _glUniform2fv=(location,count,value)=>{if(count<=144){var view=miniTempWebGLFloatBuffers[2*count-1];for(var i=0;i<2*count;i+=2){view[i]=HEAPF32[value+4*i>>2];view[i+1]=HEAPF32[value+(4*i+4)>>2]}}else{var view=HEAPF32.subarray(value>>2,value+count*8>>2)}GLctx.uniform2fv(webglGetUniformLocation(location),view)};_glUniform2fv.sig="viip";var _emscripten_glUniform2fv=_glUniform2fv;var _glUniform2i=(location,v0,v1)=>{GLctx.uniform2i(webglGetUniformLocation(location),v0,v1)};_glUniform2i.sig="viii";var _emscripten_glUniform2i=_glUniform2i;var _glUniform2iv=(location,count,value)=>{if(count<=144){var view=miniTempWebGLIntBuffers[2*count-1];for(var i=0;i<2*count;i+=2){view[i]=HEAP32[value+4*i>>2];view[i+1]=HEAP32[value+(4*i+4)>>2]}}else{var view=HEAP32.subarray(value>>2,value+count*8>>2)}GLctx.uniform2iv(webglGetUniformLocation(location),view)};_glUniform2iv.sig="viip";var _emscripten_glUniform2iv=_glUniform2iv;var _glUniform3f=(location,v0,v1,v2)=>{GLctx.uniform3f(webglGetUniformLocation(location),v0,v1,v2)};_glUniform3f.sig="vifff";var _emscripten_glUniform3f=_glUniform3f;var _glUniform3fv=(location,count,value)=>{if(count<=96){var view=miniTempWebGLFloatBuffers[3*count-1];for(var i=0;i<3*count;i+=3){view[i]=HEAPF32[value+4*i>>2];view[i+1]=HEAPF32[value+(4*i+4)>>2];view[i+2]=HEAPF32[value+(4*i+8)>>2]}}else{var view=HEAPF32.subarray(value>>2,value+count*12>>2)}GLctx.uniform3fv(webglGetUniformLocation(location),view)};_glUniform3fv.sig="viip";var _emscripten_glUniform3fv=_glUniform3fv;var _glUniform3i=(location,v0,v1,v2)=>{GLctx.uniform3i(webglGetUniformLocation(location),v0,v1,v2)};_glUniform3i.sig="viiii";var _emscripten_glUniform3i=_glUniform3i;var _glUniform3iv=(location,count,value)=>{if(count<=96){var view=miniTempWebGLIntBuffers[3*count-1];for(var i=0;i<3*count;i+=3){view[i]=HEAP32[value+4*i>>2];view[i+1]=HEAP32[value+(4*i+4)>>2];view[i+2]=HEAP32[value+(4*i+8)>>2]}}else{var view=HEAP32.subarray(value>>2,value+count*12>>2)}GLctx.uniform3iv(webglGetUniformLocation(location),view)};_glUniform3iv.sig="viip";var _emscripten_glUniform3iv=_glUniform3iv;var _glUniform4f=(location,v0,v1,v2,v3)=>{GLctx.uniform4f(webglGetUniformLocation(location),v0,v1,v2,v3)};_glUniform4f.sig="viffff";var _emscripten_glUniform4f=_glUniform4f;var _glUniform4fv=(location,count,value)=>{if(count<=72){var view=miniTempWebGLFloatBuffers[4*count-1];var heap=HEAPF32;value>>=2;for(var i=0;i<4*count;i+=4){var dst=value+i;view[i]=heap[dst];view[i+1]=heap[dst+1];view[i+2]=heap[dst+2];view[i+3]=heap[dst+3]}}else{var view=HEAPF32.subarray(value>>2,value+count*16>>2)}GLctx.uniform4fv(webglGetUniformLocation(location),view)};_glUniform4fv.sig="viip";var _emscripten_glUniform4fv=_glUniform4fv;var _glUniform4i=(location,v0,v1,v2,v3)=>{GLctx.uniform4i(webglGetUniformLocation(location),v0,v1,v2,v3)};_glUniform4i.sig="viiiii";var _emscripten_glUniform4i=_glUniform4i;var _glUniform4iv=(location,count,value)=>{if(count<=72){var view=miniTempWebGLIntBuffers[4*count-1];for(var i=0;i<4*count;i+=4){view[i]=HEAP32[value+4*i>>2];view[i+1]=HEAP32[value+(4*i+4)>>2];view[i+2]=HEAP32[value+(4*i+8)>>2];view[i+3]=HEAP32[value+(4*i+12)>>2]}}else{var view=HEAP32.subarray(value>>2,value+count*16>>2)}GLctx.uniform4iv(webglGetUniformLocation(location),view)};_glUniform4iv.sig="viip";var _emscripten_glUniform4iv=_glUniform4iv;var _glUniformMatrix2fv=(location,count,transpose,value)=>{if(count<=72){var view=miniTempWebGLFloatBuffers[4*count-1];for(var i=0;i<4*count;i+=4){view[i]=HEAPF32[value+4*i>>2];view[i+1]=HEAPF32[value+(4*i+4)>>2];view[i+2]=HEAPF32[value+(4*i+8)>>2];view[i+3]=HEAPF32[value+(4*i+12)>>2]}}else{var view=HEAPF32.subarray(value>>2,value+count*16>>2)}GLctx.uniformMatrix2fv(webglGetUniformLocation(location),!!transpose,view)};_glUniformMatrix2fv.sig="viiip";var _emscripten_glUniformMatrix2fv=_glUniformMatrix2fv;var _glUniformMatrix3fv=(location,count,transpose,value)=>{if(count<=32){var view=miniTempWebGLFloatBuffers[9*count-1];for(var i=0;i<9*count;i+=9){view[i]=HEAPF32[value+4*i>>2];view[i+1]=HEAPF32[value+(4*i+4)>>2];view[i+2]=HEAPF32[value+(4*i+8)>>2];view[i+3]=HEAPF32[value+(4*i+12)>>2];view[i+4]=HEAPF32[value+(4*i+16)>>2];view[i+5]=HEAPF32[value+(4*i+20)>>2];view[i+6]=HEAPF32[value+(4*i+24)>>2];view[i+7]=HEAPF32[value+(4*i+28)>>2];view[i+8]=HEAPF32[value+(4*i+32)>>2]}}else{var view=HEAPF32.subarray(value>>2,value+count*36>>2)}GLctx.uniformMatrix3fv(webglGetUniformLocation(location),!!transpose,view)};_glUniformMatrix3fv.sig="viiip";var _emscripten_glUniformMatrix3fv=_glUniformMatrix3fv;var _glUniformMatrix4fv=(location,count,transpose,value)=>{if(count<=18){var view=miniTempWebGLFloatBuffers[16*count-1];var heap=HEAPF32;value>>=2;for(var i=0;i<16*count;i+=16){var dst=value+i;view[i]=heap[dst];view[i+1]=heap[dst+1];view[i+2]=heap[dst+2];view[i+3]=heap[dst+3];view[i+4]=heap[dst+4];view[i+5]=heap[dst+5];view[i+6]=heap[dst+6];view[i+7]=heap[dst+7];view[i+8]=heap[dst+8];view[i+9]=heap[dst+9];view[i+10]=heap[dst+10];view[i+11]=heap[dst+11];view[i+12]=heap[dst+12];view[i+13]=heap[dst+13];view[i+14]=heap[dst+14];view[i+15]=heap[dst+15]}}else{var view=HEAPF32.subarray(value>>2,value+count*64>>2)}GLctx.uniformMatrix4fv(webglGetUniformLocation(location),!!transpose,view)};_glUniformMatrix4fv.sig="viiip";var _emscripten_glUniformMatrix4fv=_glUniformMatrix4fv;var _glUseProgram=program=>{program=GL.programs[program];GLctx.useProgram(program);GLctx.currentProgram=program};_glUseProgram.sig="vi";var _emscripten_glUseProgram=_glUseProgram;var _glValidateProgram=program=>{GLctx.validateProgram(GL.programs[program])};_glValidateProgram.sig="vi";var _emscripten_glValidateProgram=_glValidateProgram;function _glVertexAttrib1f(x0,x1){GLctx.vertexAttrib1f(x0,x1)}_glVertexAttrib1f.sig="vif";var _emscripten_glVertexAttrib1f=_glVertexAttrib1f;var _glVertexAttrib1fv=(index,v)=>{GLctx.vertexAttrib1f(index,HEAPF32[v>>2])};_glVertexAttrib1fv.sig="vip";var _emscripten_glVertexAttrib1fv=_glVertexAttrib1fv;function _glVertexAttrib2f(x0,x1,x2){GLctx.vertexAttrib2f(x0,x1,x2)}_glVertexAttrib2f.sig="viff";var _emscripten_glVertexAttrib2f=_glVertexAttrib2f;var _glVertexAttrib2fv=(index,v)=>{GLctx.vertexAttrib2f(index,HEAPF32[v>>2],HEAPF32[v+4>>2])};_glVertexAttrib2fv.sig="vip";var _emscripten_glVertexAttrib2fv=_glVertexAttrib2fv;function _glVertexAttrib3f(x0,x1,x2,x3){GLctx.vertexAttrib3f(x0,x1,x2,x3)}_glVertexAttrib3f.sig="vifff";var _emscripten_glVertexAttrib3f=_glVertexAttrib3f;var _glVertexAttrib3fv=(index,v)=>{GLctx.vertexAttrib3f(index,HEAPF32[v>>2],HEAPF32[v+4>>2],HEAPF32[v+8>>2])};_glVertexAttrib3fv.sig="vip";var _emscripten_glVertexAttrib3fv=_glVertexAttrib3fv;function _glVertexAttrib4f(x0,x1,x2,x3,x4){GLctx.vertexAttrib4f(x0,x1,x2,x3,x4)}_glVertexAttrib4f.sig="viffff";var _emscripten_glVertexAttrib4f=_glVertexAttrib4f;var _glVertexAttrib4fv=(index,v)=>{GLctx.vertexAttrib4f(index,HEAPF32[v>>2],HEAPF32[v+4>>2],HEAPF32[v+8>>2],HEAPF32[v+12>>2])};_glVertexAttrib4fv.sig="vip";var _emscripten_glVertexAttrib4fv=_glVertexAttrib4fv;var _glVertexAttribDivisor=(index,divisor)=>{GLctx.vertexAttribDivisor(index,divisor)};_glVertexAttribDivisor.sig="vii";var _glVertexAttribDivisorANGLE=_glVertexAttribDivisor;var _emscripten_glVertexAttribDivisorANGLE=_glVertexAttribDivisorANGLE;var _glVertexAttribPointer=(index,size,type,normalized,stride,ptr)=>{GLctx.vertexAttribPointer(index,size,type,!!normalized,stride,ptr)};_glVertexAttribPointer.sig="viiiiip";var _emscripten_glVertexAttribPointer=_glVertexAttribPointer;function _glViewport(x0,x1,x2,x3){GLctx.viewport(x0,x1,x2,x3)}_glViewport.sig="viiii";var _emscripten_glViewport=_glViewport;var _emscripten_is_main_browser_thread=()=>!ENVIRONMENT_IS_WORKER;var _emscripten_memcpy_js=(dest,src,num)=>HEAPU8.copyWithin(dest,src,src+num);_emscripten_memcpy_js.sig="vppp";var _emscripten_out=str=>out(UTF8ToString(str));_emscripten_out.sig="vp";function handleAllocatorInit(){Object.assign(HandleAllocator.prototype,{get(id){return this.allocated[id]},has(id){return this.allocated[id]!==undefined},allocate(handle){var id=this.freelist.pop()||this.allocated.length;this.allocated[id]=handle;return id},free(id){this.allocated[id]=undefined;this.freelist.push(id)}})}function HandleAllocator(){this.allocated=[undefined];this.freelist=[]}var promiseMap=new HandleAllocator;var makePromise=()=>{var promiseInfo={};promiseInfo.promise=new Promise((resolve,reject)=>{promiseInfo.reject=reject;promiseInfo.resolve=resolve});promiseInfo.id=promiseMap.allocate(promiseInfo);return promiseInfo};var _emscripten_promise_create=()=>makePromise().id;_emscripten_promise_create.sig="p";var _emscripten_promise_destroy=id=>{promiseMap.free(id)};_emscripten_promise_destroy.sig="vp";var getPromise=id=>promiseMap.get(id).promise;var _emscripten_promise_resolve=(id,result,value)=>{var info=promiseMap.get(id);switch(result){case 0:info.resolve(value);return;case 1:info.resolve(getPromise(value));return;case 2:info.resolve(getPromise(value));_emscripten_promise_destroy(value);return;case 3:info.reject(value);return}};_emscripten_promise_resolve.sig="vpip";var growMemory=size=>{var b=wasmMemory.buffer;var pages=(size-b.byteLength+65535)/65536;try{wasmMemory.grow(pages);updateMemoryViews();return 1}catch(e){}};var _emscripten_resize_heap=requestedSize=>{var oldSize=HEAPU8.length;requestedSize>>>=0;var maxHeapSize=getHeapMax();if(requestedSize>maxHeapSize){return false}var alignUp=(x,multiple)=>x+(multiple-x%multiple)%multiple;for(var cutDown=1;cutDown<=4;cutDown*=2){var overGrownHeapSize=oldSize*(1+.2/cutDown);overGrownHeapSize=Math.min(overGrownHeapSize,requestedSize+100663296);var newSize=Math.min(maxHeapSize,alignUp(Math.max(requestedSize,overGrownHeapSize),65536));var replacement=growMemory(newSize);if(replacement){return true}}return false};_emscripten_resize_heap.sig="ip";var Fetch={openDatabase(dbname,dbversion,onsuccess,onerror){try{var openRequest=indexedDB.open(dbname,dbversion)}catch(e){return onerror(e)}openRequest.onupgradeneeded=event=>{var db=event.target.result;if(db.objectStoreNames.contains("FILES")){db.deleteObjectStore("FILES")}db.createObjectStore("FILES")};openRequest.onsuccess=event=>onsuccess(event.target.result);openRequest.onerror=error=>onerror(error)},init(){Fetch.xhrs=new HandleAllocator;var onsuccess=db=>{Fetch.dbInstance=db;removeRunDependency("library_fetch_init")};var onerror=()=>{Fetch.dbInstance=false;removeRunDependency("library_fetch_init")};addRunDependency("library_fetch_init");Fetch.openDatabase("emscripten_filesystem",1,onsuccess,onerror)}};function fetchXHR(fetch,onsuccess,onerror,onprogress,onreadystatechange){var url=HEAPU32[fetch+8>>2];if(!url){onerror(fetch,0,"no url specified!");return}var url_=UTF8ToString(url);var fetch_attr=fetch+112;var requestMethod=UTF8ToString(fetch_attr+0);if(!requestMethod)requestMethod="GET";var timeoutMsecs=HEAPU32[fetch_attr+56>>2];var userName=HEAPU32[fetch_attr+68>>2];var password=HEAPU32[fetch_attr+72>>2];var requestHeaders=HEAPU32[fetch_attr+76>>2];var overriddenMimeType=HEAPU32[fetch_attr+80>>2];var dataPtr=HEAPU32[fetch_attr+84>>2];var dataLength=HEAPU32[fetch_attr+88>>2];var fetchAttributes=HEAPU32[fetch_attr+52>>2];var fetchAttrLoadToMemory=!!(fetchAttributes&1);var fetchAttrStreamData=!!(fetchAttributes&2);var fetchAttrSynchronous=!!(fetchAttributes&64);var userNameStr=userName?UTF8ToString(userName):undefined;var passwordStr=password?UTF8ToString(password):undefined;var xhr=new XMLHttpRequest;xhr.withCredentials=!!HEAPU8[fetch_attr+60>>0];xhr.open(requestMethod,url_,!fetchAttrSynchronous,userNameStr,passwordStr);if(!fetchAttrSynchronous)xhr.timeout=timeoutMsecs;xhr.url_=url_;xhr.responseType="arraybuffer";if(overriddenMimeType){var overriddenMimeTypeStr=UTF8ToString(overriddenMimeType);xhr.overrideMimeType(overriddenMimeTypeStr)}if(requestHeaders){for(;;){var key=HEAPU32[requestHeaders>>2];if(!key)break;var value=HEAPU32[requestHeaders+4>>2];if(!value)break;requestHeaders+=8;var keyStr=UTF8ToString(key);var valueStr=UTF8ToString(value);xhr.setRequestHeader(keyStr,valueStr)}}var id=Fetch.xhrs.allocate(xhr);HEAPU32[fetch>>2]=id;var data=dataPtr&&dataLength?HEAPU8.slice(dataPtr,dataPtr+dataLength):null;function saveResponseAndStatus(){var ptr=0;var ptrLen=0;if(xhr.response&&fetchAttrLoadToMemory&&HEAPU32[fetch+12>>2]===0){ptrLen=xhr.response.byteLength}if(ptrLen>0){ptr=_malloc(ptrLen);HEAPU8.set(new Uint8Array(xhr.response),ptr)}HEAPU32[fetch+12>>2]=ptr;writeI53ToI64(fetch+16,ptrLen);writeI53ToI64(fetch+24,0);var len=xhr.response?xhr.response.byteLength:0;if(len){writeI53ToI64(fetch+32,len)}HEAPU16[fetch+40>>1]=xhr.readyState;HEAPU16[fetch+42>>1]=xhr.status;if(xhr.statusText)stringToUTF8(xhr.statusText,fetch+44,64)}xhr.onload=e=>{if(!Fetch.xhrs.has(id)){return}saveResponseAndStatus();if(xhr.status>=200&&xhr.status<300){if(onsuccess)onsuccess(fetch,xhr,e)}else{if(onerror)onerror(fetch,xhr,e)}};xhr.onerror=e=>{if(!Fetch.xhrs.has(id)){return}saveResponseAndStatus();if(onerror)onerror(fetch,xhr,e)};xhr.ontimeout=e=>{if(!Fetch.xhrs.has(id)){return}if(onerror)onerror(fetch,xhr,e)};xhr.onprogress=e=>{if(!Fetch.xhrs.has(id)){return}var ptrLen=fetchAttrLoadToMemory&&fetchAttrStreamData&&xhr.response?xhr.response.byteLength:0;var ptr=0;if(ptrLen>0&&fetchAttrLoadToMemory&&fetchAttrStreamData){ptr=_malloc(ptrLen);HEAPU8.set(new Uint8Array(xhr.response),ptr)}HEAPU32[fetch+12>>2]=ptr;writeI53ToI64(fetch+16,ptrLen);writeI53ToI64(fetch+24,e.loaded-ptrLen);writeI53ToI64(fetch+32,e.total);HEAPU16[fetch+40>>1]=xhr.readyState;if(xhr.readyState>=3&&xhr.status===0&&e.loaded>0)xhr.status=200;HEAPU16[fetch+42>>1]=xhr.status;if(xhr.statusText)stringToUTF8(xhr.statusText,fetch+44,64);if(onprogress)onprogress(fetch,xhr,e);if(ptr){_free(ptr)}};xhr.onreadystatechange=e=>{if(!Fetch.xhrs.has(id)){runtimeKeepalivePop();return}HEAPU16[fetch+40>>1]=xhr.readyState;if(xhr.readyState>=2){HEAPU16[fetch+42>>1]=xhr.status}if(onreadystatechange)onreadystatechange(fetch,xhr,e)};try{xhr.send(data)}catch(e){if(onerror)onerror(fetch,xhr,e)}}function fetchCacheData(db,fetch,data,onsuccess,onerror){if(!db){onerror(fetch,0,"IndexedDB not available!");return}var fetch_attr=fetch+112;var destinationPath=HEAPU32[fetch_attr+64>>2];if(!destinationPath)destinationPath=HEAPU32[fetch+8>>2];var destinationPathStr=UTF8ToString(destinationPath);try{var transaction=db.transaction(["FILES"],"readwrite");var packages=transaction.objectStore("FILES");var putRequest=packages.put(data,destinationPathStr);putRequest.onsuccess=event=>{HEAPU16[fetch+40>>1]=4;HEAPU16[fetch+42>>1]=200;stringToUTF8("OK",fetch+44,64);onsuccess(fetch,0,destinationPathStr)};putRequest.onerror=error=>{HEAPU16[fetch+40>>1]=4;HEAPU16[fetch+42>>1]=413;stringToUTF8("Payload Too Large",fetch+44,64);onerror(fetch,0,error)}}catch(e){onerror(fetch,0,e)}}function fetchLoadCachedData(db,fetch,onsuccess,onerror){if(!db){onerror(fetch,0,"IndexedDB not available!");return}var fetch_attr=fetch+112;var path=HEAPU32[fetch_attr+64>>2];if(!path)path=HEAPU32[fetch+8>>2];var pathStr=UTF8ToString(path);try{var transaction=db.transaction(["FILES"],"readonly");var packages=transaction.objectStore("FILES");var getRequest=packages.get(pathStr);getRequest.onsuccess=event=>{if(event.target.result){var value=event.target.result;var len=value.byteLength||value.length;var ptr=_malloc(len);HEAPU8.set(new Uint8Array(value),ptr);HEAPU32[fetch+12>>2]=ptr;writeI53ToI64(fetch+16,len);writeI53ToI64(fetch+24,0);writeI53ToI64(fetch+32,len);HEAPU16[fetch+40>>1]=4;HEAPU16[fetch+42>>1]=200;stringToUTF8("OK",fetch+44,64);onsuccess(fetch,0,value)}else{HEAPU16[fetch+40>>1]=4;HEAPU16[fetch+42>>1]=404;stringToUTF8("Not Found",fetch+44,64);onerror(fetch,0,"no data")}};getRequest.onerror=error=>{HEAPU16[fetch+40>>1]=4;HEAPU16[fetch+42>>1]=404;stringToUTF8("Not Found",fetch+44,64);onerror(fetch,0,error)}}catch(e){onerror(fetch,0,e)}}function fetchDeleteCachedData(db,fetch,onsuccess,onerror){if(!db){onerror(fetch,0,"IndexedDB not available!");return}var fetch_attr=fetch+112;var path=HEAPU32[fetch_attr+64>>2];if(!path)path=HEAPU32[fetch+8>>2];var pathStr=UTF8ToString(path);try{var transaction=db.transaction(["FILES"],"readwrite");var packages=transaction.objectStore("FILES");var request=packages.delete(pathStr);request.onsuccess=event=>{var value=event.target.result;HEAPU32[fetch+12>>2]=0;writeI53ToI64(fetch+16,0);writeI53ToI64(fetch+24,0);writeI53ToI64(fetch+32,0);HEAPU16[fetch+40>>1]=4;HEAPU16[fetch+42>>1]=200;stringToUTF8("OK",fetch+44,64);onsuccess(fetch,0,value)};request.onerror=error=>{HEAPU16[fetch+40>>1]=4;HEAPU16[fetch+42>>1]=404;stringToUTF8("Not Found",fetch+44,64);onerror(fetch,0,error)}}catch(e){onerror(fetch,0,e)}}function _emscripten_start_fetch(fetch,successcb,errorcb,progresscb,readystatechangecb){runtimeKeepalivePush();var fetch_attr=fetch+112;var onsuccess=HEAPU32[fetch_attr+36>>2];var onerror=HEAPU32[fetch_attr+40>>2];var onprogress=HEAPU32[fetch_attr+44>>2];var onreadystatechange=HEAPU32[fetch_attr+48>>2];var fetchAttributes=HEAPU32[fetch_attr+52>>2];var fetchAttrSynchronous=!!(fetchAttributes&64);function doCallback(f){if(fetchAttrSynchronous){f()}else{callUserCallback(f)}}var reportSuccess=(fetch,xhr,e)=>{runtimeKeepalivePop();doCallback(()=>{if(onsuccess)getWasmTableEntry(onsuccess)(fetch);else if(successcb)successcb(fetch)})};var reportProgress=(fetch,xhr,e)=>{doCallback(()=>{if(onprogress)getWasmTableEntry(onprogress)(fetch);else if(progresscb)progresscb(fetch)})};var reportError=(fetch,xhr,e)=>{runtimeKeepalivePop();doCallback(()=>{if(onerror)getWasmTableEntry(onerror)(fetch);else if(errorcb)errorcb(fetch)})};var reportReadyStateChange=(fetch,xhr,e)=>{doCallback(()=>{if(onreadystatechange)getWasmTableEntry(onreadystatechange)(fetch);else if(readystatechangecb)readystatechangecb(fetch)})};var performUncachedXhr=(fetch,xhr,e)=>{fetchXHR(fetch,reportSuccess,reportError,reportProgress,reportReadyStateChange)};var cacheResultAndReportSuccess=(fetch,xhr,e)=>{var storeSuccess=(fetch,xhr,e)=>{runtimeKeepalivePop();doCallback(()=>{if(onsuccess)getWasmTableEntry(onsuccess)(fetch);else if(successcb)successcb(fetch)})};var storeError=(fetch,xhr,e)=>{runtimeKeepalivePop();doCallback(()=>{if(onsuccess)getWasmTableEntry(onsuccess)(fetch);else if(successcb)successcb(fetch)})};fetchCacheData(Fetch.dbInstance,fetch,xhr.response,storeSuccess,storeError)};var performCachedXhr=(fetch,xhr,e)=>{fetchXHR(fetch,cacheResultAndReportSuccess,reportError,reportProgress,reportReadyStateChange)};var requestMethod=UTF8ToString(fetch_attr+0);var fetchAttrReplace=!!(fetchAttributes&16);var fetchAttrPersistFile=!!(fetchAttributes&4);var fetchAttrNoDownload=!!(fetchAttributes&32);if(requestMethod==="EM_IDB_STORE"){var ptr=HEAPU32[fetch_attr+84>>2];var size=HEAPU32[fetch_attr+88>>2];fetchCacheData(Fetch.dbInstance,fetch,HEAPU8.slice(ptr,ptr+size),reportSuccess,reportError)}else if(requestMethod==="EM_IDB_DELETE"){fetchDeleteCachedData(Fetch.dbInstance,fetch,reportSuccess,reportError)}else if(!fetchAttrReplace){fetchLoadCachedData(Fetch.dbInstance,fetch,reportSuccess,fetchAttrNoDownload?reportError:fetchAttrPersistFile?performCachedXhr:performUncachedXhr)}else if(!fetchAttrNoDownload){fetchXHR(fetch,fetchAttrPersistFile?cacheResultAndReportSuccess:reportSuccess,reportError,reportProgress,reportReadyStateChange)}else{return 0}return fetch}_emscripten_start_fetch.sig="vp";var _emscripten_wget_data=(url,pbuffer,pnum,perror)=>{throw"Please compile your program with async support in order to use asynchronous operations like emscripten_wget_data"};_emscripten_wget_data.sig="vpppp";var getExecutableName=()=>thisProgram||"./this.program";var getEnvStrings=()=>{if(!getEnvStrings.strings){var lang=(typeof navigator=="object"&&navigator.languages&&navigator.languages[0]||"C").replace("-","_")+".UTF-8";var env={"USER":"web_user","LOGNAME":"web_user","PATH":"/","PWD":"/","HOME":"/home/web_user","LANG":lang,"_":getExecutableName()};for(var x in ENV){if(ENV[x]===undefined)delete env[x];else env[x]=ENV[x]}var strings=[];for(var x in env){strings.push(`${x}=${env[x]}`)}getEnvStrings.strings=strings}return getEnvStrings.strings};var stringToAscii=(str,buffer)=>{for(var i=0;i<str.length;++i){HEAP8[buffer++>>0]=str.charCodeAt(i)}HEAP8[buffer>>0]=0};var _environ_get=(__environ,environ_buf)=>{var bufSize=0;getEnvStrings().forEach((string,i)=>{var ptr=environ_buf+bufSize;HEAPU32[__environ+i*4>>2]=ptr;stringToAscii(string,ptr);bufSize+=string.length+1});return 0};_environ_get.sig="ipp";var _environ_sizes_get=(penviron_count,penviron_buf_size)=>{var strings=getEnvStrings();HEAPU32[penviron_count>>2]=strings.length;var bufSize=0;strings.forEach(string=>bufSize+=string.length+1);HEAPU32[penviron_buf_size>>2]=bufSize;return 0};_environ_sizes_get.sig="ipp";function _fd_close(fd){try{var stream=SYSCALLS.getStreamFromFD(fd);FS.close(stream);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_fd_close.sig="ii";function _fd_fdstat_get(fd,pbuf){try{var rightsBase=0;var rightsInheriting=0;var flags=0;{var stream=SYSCALLS.getStreamFromFD(fd);var type=stream.tty?2:FS.isDir(stream.mode)?3:FS.isLink(stream.mode)?7:4}HEAP8[pbuf>>0]=type;HEAP16[pbuf+2>>1]=flags;HEAP64[pbuf+8>>3]=BigInt(rightsBase);HEAP64[pbuf+16>>3]=BigInt(rightsInheriting);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_fd_fdstat_get.sig="iip";var doReadv=(stream,iov,iovcnt,offset)=>{var ret=0;for(var i=0;i<iovcnt;i++){var ptr=HEAPU32[iov>>2];var len=HEAPU32[iov+4>>2];iov+=8;var curr=FS.read(stream,HEAP8,ptr,len,offset);if(curr<0)return-1;ret+=curr;if(curr<len)break;if(typeof offset!=="undefined"){offset+=curr}}return ret};function _fd_pread(fd,iov,iovcnt,offset,pnum){offset=bigintToI53Checked(offset);try{if(isNaN(offset))return 61;var stream=SYSCALLS.getStreamFromFD(fd);var num=doReadv(stream,iov,iovcnt,offset);HEAPU32[pnum>>2]=num;return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_fd_pread.sig="iippjp";var doWritev=(stream,iov,iovcnt,offset)=>{var ret=0;for(var i=0;i<iovcnt;i++){var ptr=HEAPU32[iov>>2];var len=HEAPU32[iov+4>>2];iov+=8;var curr=FS.write(stream,HEAP8,ptr,len,offset);if(curr<0)return-1;ret+=curr;if(typeof offset!=="undefined"){offset+=curr}}return ret};function _fd_pwrite(fd,iov,iovcnt,offset,pnum){offset=bigintToI53Checked(offset);try{if(isNaN(offset))return 61;var stream=SYSCALLS.getStreamFromFD(fd);var num=doWritev(stream,iov,iovcnt,offset);HEAPU32[pnum>>2]=num;return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_fd_pwrite.sig="iippjp";function _fd_read(fd,iov,iovcnt,pnum){try{var stream=SYSCALLS.getStreamFromFD(fd);var num=doReadv(stream,iov,iovcnt);HEAPU32[pnum>>2]=num;return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_fd_read.sig="iippp";function _fd_seek(fd,offset,whence,newOffset){offset=bigintToI53Checked(offset);try{if(isNaN(offset))return 61;var stream=SYSCALLS.getStreamFromFD(fd);FS.llseek(stream,offset,whence);HEAP64[newOffset>>3]=BigInt(stream.position);if(stream.getdents&&offset===0&&whence===0)stream.getdents=null;return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_fd_seek.sig="iijip";function _fd_sync(fd){try{var stream=SYSCALLS.getStreamFromFD(fd);if(stream.stream_ops&&stream.stream_ops.fsync){return stream.stream_ops.fsync(stream)}return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_fd_sync.sig="ii";function _fd_write(fd,iov,iovcnt,pnum){try{var stream=SYSCALLS.getStreamFromFD(fd);var num=doWritev(stream,iov,iovcnt);HEAPU32[pnum>>2]=num;return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_fd_write.sig="iippp";var _getentropy=(buffer,size)=>{randomFill(HEAPU8.subarray(buffer,buffer+size));return 0};_getentropy.sig="ipp";var _getnameinfo=(sa,salen,node,nodelen,serv,servlen,flags)=>{var info=readSockaddr(sa,salen);if(info.errno){return-6}var port=info.port;var addr=info.addr;var overflowed=false;if(node&&nodelen){var lookup;if(flags&1||!(lookup=DNS.lookup_addr(addr))){if(flags&8){return-2}}else{addr=lookup}var numBytesWrittenExclNull=stringToUTF8(addr,node,nodelen);if(numBytesWrittenExclNull+1>=nodelen){overflowed=true}}if(serv&&servlen){port=""+port;var numBytesWrittenExclNull=stringToUTF8(port,serv,servlen);if(numBytesWrittenExclNull+1>=servlen){overflowed=true}}if(overflowed){return-12}return 0};_getnameinfo.sig="ipipipii";function _idamax_(){return wasmImports["idamax_"].apply(null,arguments)}_idamax_.stub=true;function _izamax_(){return wasmImports["izamax_"].apply(null,arguments)}_izamax_.stub=true;function _lsame_(){return wasmImports["lsame_"].apply(null,arguments)}_lsame_.stub=true;var arraySum=(array,index)=>{var sum=0;for(var i=0;i<=index;sum+=array[i++]){}return sum};var MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];var MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];var addDays=(date,days)=>{var newDate=new Date(date.getTime());while(days>0){var leap=isLeapYear(newDate.getFullYear());var currentMonth=newDate.getMonth();var daysInCurrentMonth=(leap?MONTH_DAYS_LEAP:MONTH_DAYS_REGULAR)[currentMonth];if(days>daysInCurrentMonth-newDate.getDate()){days-=daysInCurrentMonth-newDate.getDate()+1;newDate.setDate(1);if(currentMonth<11){newDate.setMonth(currentMonth+1)}else{newDate.setMonth(0);newDate.setFullYear(newDate.getFullYear()+1)}}else{newDate.setDate(newDate.getDate()+days);return newDate}}return newDate};var writeArrayToMemory=(array,buffer)=>{HEAP8.set(array,buffer)};var _strftime=(s,maxsize,format,tm)=>{var tm_zone=HEAPU32[tm+40>>2];var date={tm_sec:HEAP32[tm>>2],tm_min:HEAP32[tm+4>>2],tm_hour:HEAP32[tm+8>>2],tm_mday:HEAP32[tm+12>>2],tm_mon:HEAP32[tm+16>>2],tm_year:HEAP32[tm+20>>2],tm_wday:HEAP32[tm+24>>2],tm_yday:HEAP32[tm+28>>2],tm_isdst:HEAP32[tm+32>>2],tm_gmtoff:HEAP32[tm+36>>2],tm_zone:tm_zone?UTF8ToString(tm_zone):""};var pattern=UTF8ToString(format);var EXPANSION_RULES_1={"%c":"%a %b %d %H:%M:%S %Y","%D":"%m/%d/%y","%F":"%Y-%m-%d","%h":"%b","%r":"%I:%M:%S %p","%R":"%H:%M","%T":"%H:%M:%S","%x":"%m/%d/%y","%X":"%H:%M:%S","%Ec":"%c","%EC":"%C","%Ex":"%m/%d/%y","%EX":"%H:%M:%S","%Ey":"%y","%EY":"%Y","%Od":"%d","%Oe":"%e","%OH":"%H","%OI":"%I","%Om":"%m","%OM":"%M","%OS":"%S","%Ou":"%u","%OU":"%U","%OV":"%V","%Ow":"%w","%OW":"%W","%Oy":"%y"};for(var rule in EXPANSION_RULES_1){pattern=pattern.replace(new RegExp(rule,"g"),EXPANSION_RULES_1[rule])}var WEEKDAYS=["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"];var MONTHS=["January","February","March","April","May","June","July","August","September","October","November","December"];function leadingSomething(value,digits,character){var str=typeof value=="number"?value.toString():value||"";while(str.length<digits){str=character[0]+str}return str}function leadingNulls(value,digits){return leadingSomething(value,digits,"0")}function compareByDay(date1,date2){function sgn(value){return value<0?-1:value>0?1:0}var compare;if((compare=sgn(date1.getFullYear()-date2.getFullYear()))===0){if((compare=sgn(date1.getMonth()-date2.getMonth()))===0){compare=sgn(date1.getDate()-date2.getDate())}}return compare}function getFirstWeekStartDate(janFourth){switch(janFourth.getDay()){case 0:return new Date(janFourth.getFullYear()-1,11,29);case 1:return janFourth;case 2:return new Date(janFourth.getFullYear(),0,3);case 3:return new Date(janFourth.getFullYear(),0,2);case 4:return new Date(janFourth.getFullYear(),0,1);case 5:return new Date(janFourth.getFullYear()-1,11,31);case 6:return new Date(janFourth.getFullYear()-1,11,30)}}function getWeekBasedYear(date){var thisDate=addDays(new Date(date.tm_year+1900,0,1),date.tm_yday);var janFourthThisYear=new Date(thisDate.getFullYear(),0,4);var janFourthNextYear=new Date(thisDate.getFullYear()+1,0,4);var firstWeekStartThisYear=getFirstWeekStartDate(janFourthThisYear);var firstWeekStartNextYear=getFirstWeekStartDate(janFourthNextYear);if(compareByDay(firstWeekStartThisYear,thisDate)<=0){if(compareByDay(firstWeekStartNextYear,thisDate)<=0){return thisDate.getFullYear()+1}return thisDate.getFullYear()}return thisDate.getFullYear()-1}var EXPANSION_RULES_2={"%a":date=>WEEKDAYS[date.tm_wday].substring(0,3),"%A":date=>WEEKDAYS[date.tm_wday],"%b":date=>MONTHS[date.tm_mon].substring(0,3),"%B":date=>MONTHS[date.tm_mon],"%C":date=>{var year=date.tm_year+1900;return leadingNulls(year/100|0,2)},"%d":date=>leadingNulls(date.tm_mday,2),"%e":date=>leadingSomething(date.tm_mday,2," "),"%g":date=>getWeekBasedYear(date).toString().substring(2),"%G":date=>getWeekBasedYear(date),"%H":date=>leadingNulls(date.tm_hour,2),"%I":date=>{var twelveHour=date.tm_hour;if(twelveHour==0)twelveHour=12;else if(twelveHour>12)twelveHour-=12;return leadingNulls(twelveHour,2)},"%j":date=>leadingNulls(date.tm_mday+arraySum(isLeapYear(date.tm_year+1900)?MONTH_DAYS_LEAP:MONTH_DAYS_REGULAR,date.tm_mon-1),3),"%m":date=>leadingNulls(date.tm_mon+1,2),"%M":date=>leadingNulls(date.tm_min,2),"%n":()=>"\n","%p":date=>{if(date.tm_hour>=0&&date.tm_hour<12){return"AM"}return"PM"},"%S":date=>leadingNulls(date.tm_sec,2),"%t":()=>"\t","%u":date=>date.tm_wday||7,"%U":date=>{var days=date.tm_yday+7-date.tm_wday;return leadingNulls(Math.floor(days/7),2)},"%V":date=>{var val=Math.floor((date.tm_yday+7-(date.tm_wday+6)%7)/7);if((date.tm_wday+371-date.tm_yday-2)%7<=2){val++}if(!val){val=52;var dec31=(date.tm_wday+7-date.tm_yday-1)%7;if(dec31==4||dec31==5&&isLeapYear(date.tm_year%400-1)){val++}}else if(val==53){var jan1=(date.tm_wday+371-date.tm_yday)%7;if(jan1!=4&&(jan1!=3||!isLeapYear(date.tm_year)))val=1}return leadingNulls(val,2)},"%w":date=>date.tm_wday,"%W":date=>{var days=date.tm_yday+7-(date.tm_wday+6)%7;return leadingNulls(Math.floor(days/7),2)},"%y":date=>(date.tm_year+1900).toString().substring(2),"%Y":date=>date.tm_year+1900,"%z":date=>{var off=date.tm_gmtoff;var ahead=off>=0;off=Math.abs(off)/60;off=off/60*100+off%60;return(ahead?"+":"-")+String("0000"+off).slice(-4)},"%Z":date=>date.tm_zone,"%%":()=>"%"};pattern=pattern.replace(/%%/g,"\0\0");for(var rule in EXPANSION_RULES_2){if(pattern.includes(rule)){pattern=pattern.replace(new RegExp(rule,"g"),EXPANSION_RULES_2[rule](date))}}pattern=pattern.replace(/\0\0/g,"%");var bytes=intArrayFromString(pattern,false);if(bytes.length>maxsize){return 0}writeArrayToMemory(bytes,s);return bytes.length-1};_strftime.sig="ppppp";var _strftime_l=(s,maxsize,format,tm,loc)=>_strftime(s,maxsize,format,tm);_strftime_l.sig="pppppp";var _system=command=>{if(ENVIRONMENT_IS_NODE){if(!command)return 1;var cmdstr=UTF8ToString(command);if(!cmdstr.length)return 0;var cp=require("child_process");var ret=cp.spawnSync(cmdstr,[],{shell:true,stdio:"inherit"});var _W_EXITCODE=(ret,sig)=>ret<<8|sig;if(ret.status===null){var signalToNumber=sig=>{switch(sig){case"SIGHUP":return 1;case"SIGINT":return 2;case"SIGQUIT":return 3;case"SIGFPE":return 8;case"SIGKILL":return 9;case"SIGALRM":return 14;case"SIGTERM":return 15}return 2};return _W_EXITCODE(0,signalToNumber(ret.signal))}return _W_EXITCODE(ret.status,0)}if(!command)return 0;setErrNo(52);return-1};_system.sig="ip";function _zaxpy_(){return wasmImports["zaxpy_"].apply(null,arguments)}_zaxpy_.stub=true;function _zcopy_(){return wasmImports["zcopy_"].apply(null,arguments)}_zcopy_.stub=true;function _zdotc_(){return wasmImports["zdotc_"].apply(null,arguments)}_zdotc_.stub=true;function _zdotu_(){return wasmImports["zdotu_"].apply(null,arguments)}_zdotu_.stub=true;function _zdrot_(){return wasmImports["zdrot_"].apply(null,arguments)}_zdrot_.stub=true;function _zdscal_(){return wasmImports["zdscal_"].apply(null,arguments)}_zdscal_.stub=true;function _zgbmv_(){return wasmImports["zgbmv_"].apply(null,arguments)}_zgbmv_.stub=true;function _zgemm_(){return wasmImports["zgemm_"].apply(null,arguments)}_zgemm_.stub=true;function _zgemv_(){return wasmImports["zgemv_"].apply(null,arguments)}_zgemv_.stub=true;function _zgerc_(){return wasmImports["zgerc_"].apply(null,arguments)}_zgerc_.stub=true;function _zgeru_(){return wasmImports["zgeru_"].apply(null,arguments)}_zgeru_.stub=true;function _zhemv_(){return wasmImports["zhemv_"].apply(null,arguments)}_zhemv_.stub=true;function _zher2_(){return wasmImports["zher2_"].apply(null,arguments)}_zher2_.stub=true;function _zher2k_(){return wasmImports["zher2k_"].apply(null,arguments)}_zher2k_.stub=true;function _zher_(){return wasmImports["zher_"].apply(null,arguments)}_zher_.stub=true;function _zherk_(){return wasmImports["zherk_"].apply(null,arguments)}_zherk_.stub=true;function _zhpmv_(){return wasmImports["zhpmv_"].apply(null,arguments)}_zhpmv_.stub=true;function _zhpr2_(){return wasmImports["zhpr2_"].apply(null,arguments)}_zhpr2_.stub=true;function _zhpr_(){return wasmImports["zhpr_"].apply(null,arguments)}_zhpr_.stub=true;function _zscal_(){return wasmImports["zscal_"].apply(null,arguments)}_zscal_.stub=true;function _zspmv_(){return wasmImports["zspmv_"].apply(null,arguments)}_zspmv_.stub=true;function _zswap_(){return wasmImports["zswap_"].apply(null,arguments)}_zswap_.stub=true;function _ztbsv_(){return wasmImports["ztbsv_"].apply(null,arguments)}_ztbsv_.stub=true;function _ztpmv_(){return wasmImports["ztpmv_"].apply(null,arguments)}_ztpmv_.stub=true;function _ztpsv_(){return wasmImports["ztpsv_"].apply(null,arguments)}_ztpsv_.stub=true;function _ztrmm_(){return wasmImports["ztrmm_"].apply(null,arguments)}_ztrmm_.stub=true;function _ztrmv_(){return wasmImports["ztrmv_"].apply(null,arguments)}_ztrmv_.stub=true;function _ztrsm_(){return wasmImports["ztrsm_"].apply(null,arguments)}_ztrsm_.stub=true;function _ztrsv_(){return wasmImports["ztrsv_"].apply(null,arguments)}_ztrsv_.stub=true;var allocateUTF8=stringToNewUTF8;var allocateUTF8OnStack=stringToUTF8OnStack;var FS_unlink=path=>FS.unlink(path);var writeI53ToI64Clamped=(ptr,num)=>{if(num>0x8000000000000000){HEAPU32[ptr>>2]=4294967295;HEAPU32[ptr+4>>2]=2147483647}else if(num<-0x8000000000000000){HEAPU32[ptr>>2]=0;HEAPU32[ptr+4>>2]=2147483648}else{writeI53ToI64(ptr,num)}};var writeI53ToI64Signaling=(ptr,num)=>{if(num>0x8000000000000000||num<-0x8000000000000000){throw`RangeError: ${num}`}writeI53ToI64(ptr,num)};var writeI53ToU64Clamped=(ptr,num)=>{if(num>0x10000000000000000){HEAPU32[ptr>>2]=4294967295;HEAPU32[ptr+4>>2]=4294967295}else if(num<0){HEAPU32[ptr>>2]=0;HEAPU32[ptr+4>>2]=0}else{writeI53ToI64(ptr,num)}};var writeI53ToU64Signaling=(ptr,num)=>{if(num<0||num>0x10000000000000000){throw`RangeError: ${num}`}writeI53ToI64(ptr,num)};var readI53FromU64=ptr=>HEAPU32[ptr>>2]+HEAPU32[ptr+4>>2]*4294967296;var convertI32PairToI53=(lo,hi)=>(lo>>>0)+hi*4294967296;var convertI32PairToI53Checked=(lo,hi)=>hi+2097152>>>0<4194305-!!lo?(lo>>>0)+hi*4294967296:NaN;var convertU32PairToI53=(lo,hi)=>(lo>>>0)+(hi>>>0)*4294967296;var ptrToString=ptr=>{ptr>>>=0;return"0x"+ptr.toString(16).padStart(8,"0")};var _emscripten_notify_memory_growth=memoryIndex=>{updateMemoryViews()};_emscripten_notify_memory_growth.sig="vp";var ___asctime_r=(tmPtr,buf)=>{var date={tm_sec:HEAP32[tmPtr>>2],tm_min:HEAP32[tmPtr+4>>2],tm_hour:HEAP32[tmPtr+8>>2],tm_mday:HEAP32[tmPtr+12>>2],tm_mon:HEAP32[tmPtr+16>>2],tm_year:HEAP32[tmPtr+20>>2],tm_wday:HEAP32[tmPtr+24>>2]};var days=["Sun","Mon","Tue","Wed","Thu","Fri","Sat"];var months=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];var s=days[date.tm_wday]+" "+months[date.tm_mon]+(date.tm_mday<10?"  ":" ")+date.tm_mday+(date.tm_hour<10?" 0":" ")+date.tm_hour+(date.tm_min<10?":0":":")+date.tm_min+(date.tm_sec<10?":0":":")+date.tm_sec+" "+(1900+date.tm_year)+"\n";stringToUTF8(s,buf,26);return buf};___asctime_r.sig="ppp";var _strptime=(buf,format,tm)=>{var pattern=UTF8ToString(format);var SPECIAL_CHARS="\\!@#$^&*()+=-[]/{}|:<>?,.";for(var i=0,ii=SPECIAL_CHARS.length;i<ii;++i){pattern=pattern.replace(new RegExp("\\"+SPECIAL_CHARS[i],"g"),"\\"+SPECIAL_CHARS[i])}var EQUIVALENT_MATCHERS={"%A":"%a","%B":"%b","%c":"%a %b %d %H:%M:%S %Y","%D":"%m\\/%d\\/%y","%e":"%d","%F":"%Y-%m-%d","%h":"%b","%R":"%H\\:%M","%r":"%I\\:%M\\:%S\\s%p","%T":"%H\\:%M\\:%S","%x":"%m\\/%d\\/(?:%y|%Y)","%X":"%H\\:%M\\:%S"};for(var matcher in EQUIVALENT_MATCHERS){pattern=pattern.replace(matcher,EQUIVALENT_MATCHERS[matcher])}var DATE_PATTERNS={"%a":"(?:Sun(?:day)?)|(?:Mon(?:day)?)|(?:Tue(?:sday)?)|(?:Wed(?:nesday)?)|(?:Thu(?:rsday)?)|(?:Fri(?:day)?)|(?:Sat(?:urday)?)","%b":"(?:Jan(?:uary)?)|(?:Feb(?:ruary)?)|(?:Mar(?:ch)?)|(?:Apr(?:il)?)|May|(?:Jun(?:e)?)|(?:Jul(?:y)?)|(?:Aug(?:ust)?)|(?:Sep(?:tember)?)|(?:Oct(?:ober)?)|(?:Nov(?:ember)?)|(?:Dec(?:ember)?)","%C":"\\d\\d","%d":"0[1-9]|[1-9](?!\\d)|1\\d|2\\d|30|31","%H":"\\d(?!\\d)|[0,1]\\d|20|21|22|23","%I":"\\d(?!\\d)|0\\d|10|11|12","%j":"00[1-9]|0?[1-9](?!\\d)|0?[1-9]\\d(?!\\d)|[1,2]\\d\\d|3[0-6]\\d","%m":"0[1-9]|[1-9](?!\\d)|10|11|12","%M":"0\\d|\\d(?!\\d)|[1-5]\\d","%n":"\\s","%p":"AM|am|PM|pm|A\\.M\\.|a\\.m\\.|P\\.M\\.|p\\.m\\.","%S":"0\\d|\\d(?!\\d)|[1-5]\\d|60","%U":"0\\d|\\d(?!\\d)|[1-4]\\d|50|51|52|53","%W":"0\\d|\\d(?!\\d)|[1-4]\\d|50|51|52|53","%w":"[0-6]","%y":"\\d\\d","%Y":"\\d\\d\\d\\d","%%":"%","%t":"\\s"};var MONTH_NUMBERS={JAN:0,FEB:1,MAR:2,APR:3,MAY:4,JUN:5,JUL:6,AUG:7,SEP:8,OCT:9,NOV:10,DEC:11};var DAY_NUMBERS_SUN_FIRST={SUN:0,MON:1,TUE:2,WED:3,THU:4,FRI:5,SAT:6};var DAY_NUMBERS_MON_FIRST={MON:0,TUE:1,WED:2,THU:3,FRI:4,SAT:5,SUN:6};for(var datePattern in DATE_PATTERNS){pattern=pattern.replace(datePattern,"("+datePattern+DATE_PATTERNS[datePattern]+")")}var capture=[];for(var i=pattern.indexOf("%");i>=0;i=pattern.indexOf("%")){capture.push(pattern[i+1]);pattern=pattern.replace(new RegExp("\\%"+pattern[i+1],"g"),"")}var matches=new RegExp("^"+pattern,"i").exec(UTF8ToString(buf));function initDate(){function fixup(value,min,max){return typeof value!="number"||isNaN(value)?min:value>=min?value<=max?value:max:min}return{year:fixup(HEAP32[tm+20>>2]+1900,1970,9999),month:fixup(HEAP32[tm+16>>2],0,11),day:fixup(HEAP32[tm+12>>2],1,31),hour:fixup(HEAP32[tm+8>>2],0,23),min:fixup(HEAP32[tm+4>>2],0,59),sec:fixup(HEAP32[tm>>2],0,59)}}if(matches){var date=initDate();var value;var getMatch=symbol=>{var pos=capture.indexOf(symbol);if(pos>=0){return matches[pos+1]}return};if(value=getMatch("S")){date.sec=jstoi_q(value)}if(value=getMatch("M")){date.min=jstoi_q(value)}if(value=getMatch("H")){date.hour=jstoi_q(value)}else if(value=getMatch("I")){var hour=jstoi_q(value);if(value=getMatch("p")){hour+=value.toUpperCase()[0]==="P"?12:0}date.hour=hour}if(value=getMatch("Y")){date.year=jstoi_q(value)}else if(value=getMatch("y")){var year=jstoi_q(value);if(value=getMatch("C")){year+=jstoi_q(value)*100}else{year+=year<69?2e3:1900}date.year=year}if(value=getMatch("m")){date.month=jstoi_q(value)-1}else if(value=getMatch("b")){date.month=MONTH_NUMBERS[value.substring(0,3).toUpperCase()]||0}if(value=getMatch("d")){date.day=jstoi_q(value)}else if(value=getMatch("j")){var day=jstoi_q(value);var leapYear=isLeapYear(date.year);for(var month=0;month<12;++month){var daysUntilMonth=arraySum(leapYear?MONTH_DAYS_LEAP:MONTH_DAYS_REGULAR,month-1);if(day<=daysUntilMonth+(leapYear?MONTH_DAYS_LEAP:MONTH_DAYS_REGULAR)[month]){date.day=day-daysUntilMonth}}}else if(value=getMatch("a")){var weekDay=value.substring(0,3).toUpperCase();if(value=getMatch("U")){var weekDayNumber=DAY_NUMBERS_SUN_FIRST[weekDay];var weekNumber=jstoi_q(value);var janFirst=new Date(date.year,0,1);var endDate;if(janFirst.getDay()===0){endDate=addDays(janFirst,weekDayNumber+7*(weekNumber-1))}else{endDate=addDays(janFirst,7-janFirst.getDay()+weekDayNumber+7*(weekNumber-1))}date.day=endDate.getDate();date.month=endDate.getMonth()}else if(value=getMatch("W")){var weekDayNumber=DAY_NUMBERS_MON_FIRST[weekDay];var weekNumber=jstoi_q(value);var janFirst=new Date(date.year,0,1);var endDate;if(janFirst.getDay()===1){endDate=addDays(janFirst,weekDayNumber+7*(weekNumber-1))}else{endDate=addDays(janFirst,7-janFirst.getDay()+1+weekDayNumber+7*(weekNumber-1))}date.day=endDate.getDate();date.month=endDate.getMonth()}}var fullDate=new Date(date.year,date.month,date.day,date.hour,date.min,date.sec,0);HEAP32[tm>>2]=fullDate.getSeconds();HEAP32[tm+4>>2]=fullDate.getMinutes();HEAP32[tm+8>>2]=fullDate.getHours();HEAP32[tm+12>>2]=fullDate.getDate();HEAP32[tm+16>>2]=fullDate.getMonth();HEAP32[tm+20>>2]=fullDate.getFullYear()-1900;HEAP32[tm+24>>2]=fullDate.getDay();HEAP32[tm+28>>2]=arraySum(isLeapYear(fullDate.getFullYear())?MONTH_DAYS_LEAP:MONTH_DAYS_REGULAR,fullDate.getMonth()-1)+fullDate.getDate()-1;HEAP32[tm+32>>2]=0;return buf+intArrayFromString(matches[0]).length-1}return 0};_strptime.sig="pppp";var _strptime_l=(buf,format,tm,locale)=>_strptime(buf,format,tm);_strptime_l.sig="ppppp";var ERRNO_MESSAGES={0:"Success",1:"Arg list too long",2:"Permission denied",3:"Address already in use",4:"Address not available",5:"Address family not supported by protocol family",6:"No more processes",7:"Socket already connected",8:"Bad file number",9:"Trying to read unreadable message",10:"Mount device busy",11:"Operation canceled",12:"No children",13:"Connection aborted",14:"Connection refused",15:"Connection reset by peer",16:"File locking deadlock error",17:"Destination address required",18:"Math arg out of domain of func",19:"Quota exceeded",20:"File exists",21:"Bad address",22:"File too large",23:"Host is unreachable",24:"Identifier removed",25:"Illegal byte sequence",26:"Connection already in progress",27:"Interrupted system call",28:"Invalid argument",29:"I/O error",30:"Socket is already connected",31:"Is a directory",32:"Too many symbolic links",33:"Too many open files",34:"Too many links",35:"Message too long",36:"Multihop attempted",37:"File or path name too long",38:"Network interface is not configured",39:"Connection reset by network",40:"Network is unreachable",41:"Too many open files in system",42:"No buffer space available",43:"No such device",44:"No such file or directory",45:"Exec format error",46:"No record locks available",47:"The link has been severed",48:"Not enough core",49:"No message of desired type",50:"Protocol not available",51:"No space left on device",52:"Function not implemented",53:"Socket is not connected",54:"Not a directory",55:"Directory not empty",56:"State not recoverable",57:"Socket operation on non-socket",59:"Not a typewriter",60:"No such device or address",61:"Value too large for defined data type",62:"Previous owner died",63:"Not super-user",64:"Broken pipe",65:"Protocol error",66:"Unknown protocol",67:"Protocol wrong type for socket",68:"Math result not representable",69:"Read only file system",70:"Illegal seek",71:"No such process",72:"Stale file handle",73:"Connection timed out",74:"Text file busy",75:"Cross-device link",100:"Device not a stream",101:"Bad font file fmt",102:"Invalid slot",103:"Invalid request code",104:"No anode",105:"Block device required",106:"Channel number out of range",107:"Level 3 halted",108:"Level 3 reset",109:"Link number out of range",110:"Protocol driver not attached",111:"No CSI structure available",112:"Level 2 halted",113:"Invalid exchange",114:"Invalid request descriptor",115:"Exchange full",116:"No data (for no delay io)",117:"Timer expired",118:"Out of streams resources",119:"Machine is not on the network",120:"Package not installed",121:"The object is remote",122:"Advertise error",123:"Srmount error",124:"Communication error on send",125:"Cross mount point (not really error)",126:"Given log. name not unique",127:"f.d. invalid for this operation",128:"Remote address changed",129:"Can   access a needed shared lib",130:"Accessing a corrupted shared lib",131:".lib section in a.out corrupted",132:"Attempting to link in too many libs",133:"Attempting to exec a shared library",135:"Streams pipe error",136:"Too many users",137:"Socket type not supported",138:"Not supported",139:"Protocol family not supported",140:"Can't send after socket shutdown",141:"Too many references",142:"Host is down",148:"No medium (in tape drive)",156:"Level 2 not synchronized"};var getHostByName=name=>{var ret=_malloc(20);var nameBuf=stringToNewUTF8(name);HEAPU32[ret>>2]=nameBuf;var aliasesBuf=_malloc(4);HEAPU32[aliasesBuf>>2]=0;HEAPU32[ret+4>>2]=aliasesBuf;var afinet=2;HEAP32[ret+8>>2]=afinet;HEAP32[ret+12>>2]=4;var addrListBuf=_malloc(12);HEAPU32[addrListBuf>>2]=addrListBuf+8;HEAPU32[addrListBuf+4>>2]=0;HEAP32[addrListBuf+8>>2]=inetPton4(DNS.lookup_name(name));HEAPU32[ret+16>>2]=addrListBuf;return ret};var _gethostbyaddr=(addr,addrlen,type)=>{if(type!==2){setErrNo(5);return null}addr=HEAP32[addr>>2];var host=inetNtop4(addr);var lookup=DNS.lookup_addr(host);if(lookup){host=lookup}return getHostByName(host)};_gethostbyaddr.sig="ppii";var _gethostbyname=name=>getHostByName(UTF8ToString(name));_gethostbyname.sig="pp";var _gethostbyname_r=(name,ret,buf,buflen,out,err)=>{var data=_gethostbyname(name);_memcpy(ret,data,20);_free(data);HEAP32[err>>2]=0;HEAPU32[out>>2]=ret;return 0};_gethostbyname_r.sig="ipppppp";var _getaddrinfo=(node,service,hint,out)=>{var addrs=[];var canon=null;var addr=0;var port=0;var flags=0;var family=0;var type=0;var proto=0;var ai,last;function allocaddrinfo(family,type,proto,canon,addr,port){var sa,salen,ai;var errno;salen=family===10?28:16;addr=family===10?inetNtop6(addr):inetNtop4(addr);sa=_malloc(salen);errno=writeSockaddr(sa,family,addr,port);assert(!errno);ai=_malloc(32);HEAP32[ai+4>>2]=family;HEAP32[ai+8>>2]=type;HEAP32[ai+12>>2]=proto;HEAPU32[ai+24>>2]=canon;HEAPU32[ai+20>>2]=sa;if(family===10){HEAP32[ai+16>>2]=28}else{HEAP32[ai+16>>2]=16}HEAP32[ai+28>>2]=0;return ai}if(hint){flags=HEAP32[hint>>2];family=HEAP32[hint+4>>2];type=HEAP32[hint+8>>2];proto=HEAP32[hint+12>>2]}if(type&&!proto){proto=type===2?17:6}if(!type&&proto){type=proto===17?2:1}if(proto===0){proto=6}if(type===0){type=1}if(!node&&!service){return-2}if(flags&~(1|2|4|1024|8|16|32)){return-1}if(hint!==0&&HEAP32[hint>>2]&2&&!node){return-1}if(flags&32){return-2}if(type!==0&&type!==1&&type!==2){return-7}if(family!==0&&family!==2&&family!==10){return-6}if(service){service=UTF8ToString(service);port=parseInt(service,10);if(isNaN(port)){if(flags&1024){return-2}return-8}}if(!node){if(family===0){family=2}if((flags&1)===0){if(family===2){addr=_htonl(2130706433)}else{addr=[0,0,0,1]}}ai=allocaddrinfo(family,type,proto,null,addr,port);HEAPU32[out>>2]=ai;return 0}node=UTF8ToString(node);addr=inetPton4(node);if(addr!==null){if(family===0||family===2){family=2}else if(family===10&&flags&8){addr=[0,0,_htonl(65535),addr];family=10}else{return-2}}else{addr=inetPton6(node);if(addr!==null){if(family===0||family===10){family=10}else{return-2}}}if(addr!=null){ai=allocaddrinfo(family,type,proto,node,addr,port);HEAPU32[out>>2]=ai;return 0}if(flags&4){return-2}node=DNS.lookup_name(node);addr=inetPton4(node);if(family===0){family=2}else if(family===10){addr=[0,0,_htonl(65535),addr]}ai=allocaddrinfo(family,type,proto,null,addr,port);HEAPU32[out>>2]=ai;return 0};_getaddrinfo.sig="ipppp";var Protocols={list:[],map:{}};var _setprotoent=stayopen=>{function allocprotoent(name,proto,aliases){var nameBuf=_malloc(name.length+1);stringToAscii(name,nameBuf);var j=0;var length=aliases.length;var aliasListBuf=_malloc((length+1)*4);for(var i=0;i<length;i++,j+=4){var alias=aliases[i];var aliasBuf=_malloc(alias.length+1);stringToAscii(alias,aliasBuf);HEAPU32[aliasListBuf+j>>2]=aliasBuf}HEAPU32[aliasListBuf+j>>2]=0;var pe=_malloc(12);HEAPU32[pe>>2]=nameBuf;HEAPU32[pe+4>>2]=aliasListBuf;HEAP32[pe+8>>2]=proto;return pe}var list=Protocols.list;var map=Protocols.map;if(list.length===0){var entry=allocprotoent("tcp",6,["TCP"]);list.push(entry);map["tcp"]=map["6"]=entry;entry=allocprotoent("udp",17,["UDP"]);list.push(entry);map["udp"]=map["17"]=entry}_setprotoent.index=0};_setprotoent.sig="vi";var _endprotoent=()=>{};_endprotoent.sig="v";var _getprotoent=number=>{if(_setprotoent.index===Protocols.list.length){return 0}var result=Protocols.list[_setprotoent.index++];return result};_getprotoent.sig="p";var _getprotobyname=name=>{name=UTF8ToString(name);_setprotoent(true);var result=Protocols.map[name];return result};_getprotobyname.sig="pp";var _getprotobynumber=number=>{_setprotoent(true);var result=Protocols.map[number];return result};_getprotobynumber.sig="pi";var _emscripten_run_script=ptr=>{eval(UTF8ToString(ptr))};_emscripten_run_script.sig="vp";var _emscripten_run_script_int=ptr=>eval(UTF8ToString(ptr))|0;_emscripten_run_script_int.sig="ip";var _emscripten_run_script_string=ptr=>{var s=eval(UTF8ToString(ptr));if(s==null){return 0}s+="";var me=_emscripten_run_script_string;var len=lengthBytesUTF8(s);if(!me.bufferSize||me.bufferSize<len+1){if(me.bufferSize)_free(me.buffer);me.bufferSize=len+1;me.buffer=_malloc(me.bufferSize)}stringToUTF8(s,me.buffer,me.bufferSize);return me.buffer};_emscripten_run_script_string.sig="pp";var _emscripten_random=()=>Math.random();_emscripten_random.sig="f";function jsStackTrace(){var error=new Error;if(!error.stack){try{throw new Error}catch(e){error=e}if(!error.stack){return"(no stack trace available)"}}return error.stack.toString()}function getCallstack(flags){var callstack=jsStackTrace();var iThisFunc=callstack.lastIndexOf("_emscripten_log");var iThisFunc2=callstack.lastIndexOf("_emscripten_get_callstack");var iNextLine=callstack.indexOf("\n",Math.max(iThisFunc,iThisFunc2))+1;callstack=callstack.slice(iNextLine);if(flags&8&&typeof emscripten_source_map=="undefined"){warnOnce('Source map information is not available, emscripten_log with EM_LOG_C_STACK will be ignored. Build with "--pre-js $EMSCRIPTEN/src/emscripten-source-map.min.js" linker flag to add source map loading to code.');flags^=8;flags|=16}var lines=callstack.split("\n");callstack="";var newFirefoxRe=new RegExp("\\s*(.*?)@(.*?):([0-9]+):([0-9]+)");var firefoxRe=new RegExp("\\s*(.*?)@(.*):(.*)(:(.*))?");var chromeRe=new RegExp("\\s*at (.*?) \\((.*):(.*):(.*)\\)");for(var l in lines){var line=lines[l];var symbolName="";var file="";var lineno=0;var column=0;var parts=chromeRe.exec(line);if(parts&&parts.length==5){symbolName=parts[1];file=parts[2];lineno=parts[3];column=parts[4]}else{parts=newFirefoxRe.exec(line);if(!parts)parts=firefoxRe.exec(line);if(parts&&parts.length>=4){symbolName=parts[1];file=parts[2];lineno=parts[3];column=parts[4]|0}else{callstack+=line+"\n";continue}}var haveSourceMap=false;if(flags&8){var orig=emscripten_source_map.originalPositionFor({line:lineno,column:column});haveSourceMap=orig&&orig.source;if(haveSourceMap){if(flags&64){orig.source=orig.source.substring(orig.source.replace(/\\/g,"/").lastIndexOf("/")+1)}callstack+=`    at ${symbolName} (${orig.source}:${orig.line}:${orig.column})\n`}}if(flags&16||!haveSourceMap){if(flags&64){file=file.substring(file.replace(/\\/g,"/").lastIndexOf("/")+1)}callstack+=(haveSourceMap?`     = ${symbolName}`:`    at ${symbolName}`)+` (${file}:${lineno}:${column})\n`}}callstack=callstack.replace(/\s+$/,"");return callstack}function _emscripten_get_callstack(flags,str,maxbytes){var callstack=getCallstack(flags);if(!str||maxbytes<=0){return lengthBytesUTF8(callstack)+1}var bytesWrittenExcludingNull=stringToUTF8(callstack,str,maxbytes);return bytesWrittenExcludingNull+1}_emscripten_get_callstack.sig="iipi";var emscriptenLog=(flags,str)=>{if(flags&24){str=str.replace(/\s+$/,"");str+=(str.length>0?"\n":"")+getCallstack(flags)}if(flags&1){if(flags&4){console.error(str)}else if(flags&2){console.warn(str)}else if(flags&512){console.info(str)}else if(flags&256){console.debug(str)}else{console.log(str)}}else if(flags&6){err(str)}else{out(str)}};var reallyNegative=x=>x<0||x===0&&1/x===-Infinity;var reSign=(value,bits)=>{if(value<=0){return value}var half=bits<=32?Math.abs(1<<bits-1):Math.pow(2,bits-1);if(value>=half&&(bits<=32||value>half)){value=-2*half+value}return value};var unSign=(value,bits)=>{if(value>=0){return value}return bits<=32?2*Math.abs(1<<bits-1)+value:Math.pow(2,bits)+value};var strLen=ptr=>{var end=ptr;while(HEAPU8[end])++end;return end-ptr};var formatString=(format,varargs)=>{var textIndex=format;var argIndex=varargs;function prepVararg(ptr,type){if(type==="double"||type==="i64"){if(ptr&7){ptr+=4}}else{}return ptr}function getNextArg(type){var ret;argIndex=prepVararg(argIndex,type);if(type==="double"){ret=HEAPF64[argIndex>>3];argIndex+=8}else if(type=="i64"){ret=[HEAP32[argIndex>>2],HEAP32[argIndex+4>>2]];argIndex+=8}else{type="i32";ret=HEAP32[argIndex>>2];argIndex+=4}return ret}var ret=[];var curr,next,currArg;while(1){var startTextIndex=textIndex;curr=HEAP8[textIndex>>0];if(curr===0)break;next=HEAP8[textIndex+1>>0];if(curr==37){var flagAlwaysSigned=false;var flagLeftAlign=false;var flagAlternative=false;var flagZeroPad=false;var flagPadSign=false;flagsLoop:while(1){switch(next){case 43:flagAlwaysSigned=true;break;case 45:flagLeftAlign=true;break;case 35:flagAlternative=true;break;case 48:if(flagZeroPad){break flagsLoop}else{flagZeroPad=true;break}case 32:flagPadSign=true;break;default:break flagsLoop}textIndex++;next=HEAP8[textIndex+1>>0]}var width=0;if(next==42){width=getNextArg("i32");textIndex++;next=HEAP8[textIndex+1>>0]}else{while(next>=48&&next<=57){width=width*10+(next-48);textIndex++;next=HEAP8[textIndex+1>>0]}}var precisionSet=false,precision=-1;if(next==46){precision=0;precisionSet=true;textIndex++;next=HEAP8[textIndex+1>>0];if(next==42){precision=getNextArg("i32");textIndex++}else{while(1){var precisionChr=HEAP8[textIndex+1>>0];if(precisionChr<48||precisionChr>57)break;precision=precision*10+(precisionChr-48);textIndex++}}next=HEAP8[textIndex+1>>0]}if(precision<0){precision=6;precisionSet=false}var argSize;switch(String.fromCharCode(next)){case"h":var nextNext=HEAP8[textIndex+2>>0];if(nextNext==104){textIndex++;argSize=1}else{argSize=2}break;case"l":var nextNext=HEAP8[textIndex+2>>0];if(nextNext==108){textIndex++;argSize=8}else{argSize=4}break;case"L":case"q":case"j":argSize=8;break;case"z":case"t":case"I":argSize=4;break;default:argSize=null}if(argSize)textIndex++;next=HEAP8[textIndex+1>>0];switch(String.fromCharCode(next)){case"d":case"i":case"u":case"o":case"x":case"X":case"p":{var signed=next==100||next==105;argSize=argSize||4;currArg=getNextArg("i"+argSize*8);var argText;if(argSize==8){currArg=next==117?convertU32PairToI53(currArg[0],currArg[1]):convertI32PairToI53(currArg[0],currArg[1])}if(argSize<=4){var limit=Math.pow(256,argSize)-1;currArg=(signed?reSign:unSign)(currArg&limit,argSize*8)}var currAbsArg=Math.abs(currArg);var prefix="";if(next==100||next==105){argText=reSign(currArg,8*argSize).toString(10)}else if(next==117){argText=unSign(currArg,8*argSize).toString(10);currArg=Math.abs(currArg)}else if(next==111){argText=(flagAlternative?"0":"")+currAbsArg.toString(8)}else if(next==120||next==88){prefix=flagAlternative&&currArg!=0?"0x":"";if(currArg<0){currArg=-currArg;argText=(currAbsArg-1).toString(16);var buffer=[];for(var i=0;i<argText.length;i++){buffer.push((15-parseInt(argText[i],16)).toString(16))}argText=buffer.join("");while(argText.length<argSize*2)argText="f"+argText}else{argText=currAbsArg.toString(16)}if(next==88){prefix=prefix.toUpperCase();argText=argText.toUpperCase()}}else if(next==112){if(currAbsArg===0){argText="(nil)"}else{prefix="0x";argText=currAbsArg.toString(16)}}if(precisionSet){while(argText.length<precision){argText="0"+argText}}if(currArg>=0){if(flagAlwaysSigned){prefix="+"+prefix}else if(flagPadSign){prefix=" "+prefix}}if(argText.charAt(0)=="-"){prefix="-"+prefix;argText=argText.substr(1)}while(prefix.length+argText.length<width){if(flagLeftAlign){argText+=" "}else{if(flagZeroPad){argText="0"+argText}else{prefix=" "+prefix}}}argText=prefix+argText;argText.split("").forEach(function(chr){ret.push(chr.charCodeAt(0))});break}case"f":case"F":case"e":case"E":case"g":case"G":{currArg=getNextArg("double");var argText;if(isNaN(currArg)){argText="nan";flagZeroPad=false}else if(!isFinite(currArg)){argText=(currArg<0?"-":"")+"inf";flagZeroPad=false}else{var isGeneral=false;var effectivePrecision=Math.min(precision,20);if(next==103||next==71){isGeneral=true;precision=precision||1;var exponent=parseInt(currArg.toExponential(effectivePrecision).split("e")[1],10);if(precision>exponent&&exponent>=-4){next=(next==103?"f":"F").charCodeAt(0);precision-=exponent+1}else{next=(next==103?"e":"E").charCodeAt(0);precision--}effectivePrecision=Math.min(precision,20)}if(next==101||next==69){argText=currArg.toExponential(effectivePrecision);if(/[eE][-+]\d$/.test(argText)){argText=argText.slice(0,-1)+"0"+argText.slice(-1)}}else if(next==102||next==70){argText=currArg.toFixed(effectivePrecision);if(currArg===0&&reallyNegative(currArg)){argText="-"+argText}}var parts=argText.split("e");if(isGeneral&&!flagAlternative){while(parts[0].length>1&&parts[0].includes(".")&&(parts[0].slice(-1)=="0"||parts[0].slice(-1)==".")){parts[0]=parts[0].slice(0,-1)}}else{if(flagAlternative&&argText.indexOf(".")==-1)parts[0]+=".";while(precision>effectivePrecision++)parts[0]+="0"}argText=parts[0]+(parts.length>1?"e"+parts[1]:"");if(next==69)argText=argText.toUpperCase();if(currArg>=0){if(flagAlwaysSigned){argText="+"+argText}else if(flagPadSign){argText=" "+argText}}}while(argText.length<width){if(flagLeftAlign){argText+=" "}else{if(flagZeroPad&&(argText[0]=="-"||argText[0]=="+")){argText=argText[0]+"0"+argText.slice(1)}else{argText=(flagZeroPad?"0":" ")+argText}}}if(next<97)argText=argText.toUpperCase();argText.split("").forEach(function(chr){ret.push(chr.charCodeAt(0))});break}case"s":{var arg=getNextArg("i8*");var argLength=arg?strLen(arg):"(null)".length;if(precisionSet)argLength=Math.min(argLength,precision);if(!flagLeftAlign){while(argLength<width--){ret.push(32)}}if(arg){for(var i=0;i<argLength;i++){ret.push(HEAPU8[arg++>>0])}}else{ret=ret.concat(intArrayFromString("(null)".substr(0,argLength),true))}if(flagLeftAlign){while(argLength<width--){ret.push(32)}}break}case"c":{if(flagLeftAlign)ret.push(getNextArg("i8"));while(--width>0){ret.push(32)}if(!flagLeftAlign)ret.push(getNextArg("i8"));break}case"n":{var ptr=getNextArg("i32*");HEAP32[ptr>>2]=ret.length;break}case"%":{ret.push(curr);break}default:{for(var i=startTextIndex;i<textIndex+2;i++){ret.push(HEAP8[i>>0])}}}textIndex+=2}else{ret.push(curr);textIndex+=1}}return ret};var _emscripten_log=(flags,format,varargs)=>{var result=formatString(format,varargs);var str=UTF8ArrayToString(result,0);emscriptenLog(flags,str)};_emscripten_log.sig="vipp";var _emscripten_get_compiler_setting=name=>{throw"You must build with -sRETAIN_COMPILER_SETTINGS for getCompilerSetting or emscripten_get_compiler_setting to work"};_emscripten_get_compiler_setting.sig="pp";var _emscripten_has_asyncify=()=>0;_emscripten_has_asyncify.sig="i";function _emscripten_debugger(){debugger}_emscripten_debugger.sig="v";var _emscripten_print_double=(x,to,max)=>{var str=x+"";if(to)return stringToUTF8(str,to,max);else return lengthBytesUTF8(str)};_emscripten_print_double.sig="idpi";var convertFrameToPC=frame=>{abort("Cannot use convertFrameToPC (needed by __builtin_return_address) without -sUSE_OFFSET_CONVERTER");return 0};var _emscripten_return_address=level=>{var callstack=jsStackTrace().split("\n");if(callstack[0]=="Error"){callstack.shift()}var caller=callstack[level+3];return convertFrameToPC(caller)};_emscripten_return_address.sig="pi";var UNWIND_CACHE={};var saveInUnwindCache=callstack=>{callstack.forEach(frame=>{var pc=convertFrameToPC(frame);if(pc){UNWIND_CACHE[pc]=frame}})};function _emscripten_stack_snapshot(){var callstack=jsStackTrace().split("\n");if(callstack[0]=="Error"){callstack.shift()}saveInUnwindCache(callstack);UNWIND_CACHE.last_addr=convertFrameToPC(callstack[3]);UNWIND_CACHE.last_stack=callstack;return UNWIND_CACHE.last_addr}_emscripten_stack_snapshot.sig="p";var _emscripten_stack_unwind_buffer=(addr,buffer,count)=>{var stack;if(UNWIND_CACHE.last_addr==addr){stack=UNWIND_CACHE.last_stack}else{stack=jsStackTrace().split("\n");if(stack[0]=="Error"){stack.shift()}saveInUnwindCache(stack)}var offset=3;while(stack[offset]&&convertFrameToPC(stack[offset])!=addr){++offset}for(var i=0;i<count&&stack[i+offset];++i){HEAP32[buffer+i*4>>2]=convertFrameToPC(stack[i+offset])}return i};_emscripten_stack_unwind_buffer.sig="ippi";var _emscripten_pc_get_function=pc=>{abort("Cannot use emscripten_pc_get_function without -sUSE_OFFSET_CONVERTER");return 0};_emscripten_pc_get_function.sig="pp";var convertPCtoSourceLocation=pc=>{if(UNWIND_CACHE.last_get_source_pc==pc)return UNWIND_CACHE.last_source;var match;var source;if(!source){var frame=UNWIND_CACHE[pc];if(!frame)return null;if(match=/\((.*):(\d+):(\d+)\)$/.exec(frame)){source={file:match[1],line:match[2],column:match[3]}}else if(match=/@(.*):(\d+):(\d+)/.exec(frame)){source={file:match[1],line:match[2],column:match[3]}}}UNWIND_CACHE.last_get_source_pc=pc;UNWIND_CACHE.last_source=source;return source};var _emscripten_pc_get_file=pc=>{var result=convertPCtoSourceLocation(pc);if(!result)return 0;if(_emscripten_pc_get_file.ret)_free(_emscripten_pc_get_file.ret);_emscripten_pc_get_file.ret=stringToNewUTF8(result.file);return _emscripten_pc_get_file.ret};_emscripten_pc_get_file.sig="pp";var _emscripten_pc_get_line=pc=>{var result=convertPCtoSourceLocation(pc);return result?result.line:0};_emscripten_pc_get_line.sig="ip";var _emscripten_pc_get_column=pc=>{var result=convertPCtoSourceLocation(pc);return result?result.column||0:0};_emscripten_pc_get_column.sig="ip";var _emscripten_get_module_name=(buf,length)=>stringToUTF8(wasmBinaryFile,buf,length);_emscripten_get_module_name.sig="ppp";var _emscripten_asm_const_double=(code,sigPtr,argbuf)=>runEmAsmFunction(code,sigPtr,argbuf);_emscripten_asm_const_double.sig="dppp";var _emscripten_asm_const_ptr=(code,sigPtr,argbuf)=>runEmAsmFunction(code,sigPtr,argbuf);_emscripten_asm_const_ptr.sig="pppp";var runMainThreadEmAsm=(code,sigPtr,argbuf,sync)=>{var args=readEmAsmArgs(sigPtr,argbuf);return ASM_CONSTS[code].apply(null,args)};var _emscripten_asm_const_int_sync_on_main_thread=(code,sigPtr,argbuf)=>runMainThreadEmAsm(code,sigPtr,argbuf,1);_emscripten_asm_const_int_sync_on_main_thread.sig="ippp";var _emscripten_asm_const_ptr_sync_on_main_thread=(code,sigPtr,argbuf)=>runMainThreadEmAsm(code,sigPtr,argbuf,1);_emscripten_asm_const_ptr_sync_on_main_thread.sig="pppp";var _emscripten_asm_const_double_sync_on_main_thread=_emscripten_asm_const_int_sync_on_main_thread;_emscripten_asm_const_double_sync_on_main_thread.sig="dppp";var _emscripten_asm_const_async_on_main_thread=(code,sigPtr,argbuf)=>runMainThreadEmAsm(code,sigPtr,argbuf,0);_emscripten_asm_const_async_on_main_thread.sig="vppp";var jstoi_s=str=>Number(str);var __Unwind_Backtrace=(func,arg)=>{var trace=getCallstack();var parts=trace.split("\n");for(var i=0;i<parts.length;i++){var ret=getWasmTableEntry(func)(0,arg);if(ret!==0)return}};__Unwind_Backtrace.sig="ipp";var __Unwind_GetIPInfo=(context,ipBefore)=>abort("Unwind_GetIPInfo");__Unwind_GetIPInfo.sig="ppp";var __Unwind_FindEnclosingFunction=ip=>0;__Unwind_FindEnclosingFunction.sig="pp";var dynCall=(sig,ptr,args)=>{var rtn=getWasmTableEntry(ptr).apply(null,args);return rtn};var getDynCaller=(sig,ptr)=>{var argCache=[];return function(){argCache.length=0;Object.assign(argCache,arguments);return dynCall(sig,ptr,argCache)}};var _emscripten_exit_with_live_runtime=()=>{runtimeKeepalivePush();throw"unwind"};_emscripten_exit_with_live_runtime.sig="v";var _emscripten_force_exit=status=>{__emscripten_runtime_keepalive_clear();_exit(status)};_emscripten_force_exit.sig="vi";var _emscripten_outn=(str,len)=>out(UTF8ToString(str,len));_emscripten_outn.sig="vpp";var _emscripten_errn=(str,len)=>err(UTF8ToString(str,len));_emscripten_errn.sig="vpp";var _emscripten_throw_number=number=>{throw number};_emscripten_throw_number.sig="vd";var _emscripten_throw_string=str=>{throw UTF8ToString(str)};_emscripten_throw_string.sig="vp";var _emscripten_runtime_keepalive_push=runtimeKeepalivePush;_emscripten_runtime_keepalive_push.sig="v";var _emscripten_runtime_keepalive_pop=runtimeKeepalivePop;_emscripten_runtime_keepalive_pop.sig="v";var _emscripten_runtime_keepalive_check=keepRuntimeAlive;_emscripten_runtime_keepalive_check.sig="i";var ___global_base=1024;var POINTER_SIZE=4;function getNativeTypeSize(type){switch(type){case"i1":case"i8":case"u8":return 1;case"i16":case"u16":return 2;case"i32":case"u32":return 4;case"i64":case"u64":return 8;case"float":return 4;case"double":return 8;default:{if(type[type.length-1]==="*"){return POINTER_SIZE}if(type[0]==="i"){const bits=Number(type.substr(1));assert(bits%8===0,"getNativeTypeSize invalid bits "+bits+", type "+type);return bits/8}return 0}}}var STACK_SIZE=1048576;var STACK_ALIGN=16;var ASSERTIONS=0;var getCFunc=ident=>{var func=Module["_"+ident];return func};var ccall=(ident,returnType,argTypes,args,opts)=>{var toC={"string":str=>{var ret=0;if(str!==null&&str!==undefined&&str!==0){ret=stringToUTF8OnStack(str)}return ret},"array":arr=>{var ret=stackAlloc(arr.length);writeArrayToMemory(arr,ret);return ret}};function convertReturnValue(ret){if(returnType==="string"){return UTF8ToString(ret)}if(returnType==="boolean")return Boolean(ret);return ret}var func=getCFunc(ident);var cArgs=[];var stack=0;if(args){for(var i=0;i<args.length;i++){var converter=toC[argTypes[i]];if(converter){if(stack===0)stack=stackSave();cArgs[i]=converter(args[i])}else{cArgs[i]=args[i]}}}var ret=func.apply(null,cArgs);function onDone(ret){if(stack!==0)stackRestore(stack);return convertReturnValue(ret)}ret=onDone(ret);return ret};var cwrap=(ident,returnType,argTypes,opts)=>{var numericArgs=!argTypes||argTypes.every(type=>type==="number"||type==="boolean");var numericRet=returnType!=="string";if(numericRet&&numericArgs&&!opts){return getCFunc(ident)}return function(){return ccall(ident,returnType,argTypes,arguments,opts)}};var removeFunction=index=>{functionsInTableMap.delete(getWasmTableEntry(index));setWasmTableEntry(index,null);freeTableIndexes.push(index)};var _emscripten_math_cbrt=x=>Math.cbrt(x);_emscripten_math_cbrt.sig="dd";var _emscripten_math_pow=(x,y)=>Math.pow(x,y);_emscripten_math_pow.sig="ddd";var _emscripten_math_random=()=>Math.random();_emscripten_math_random.sig="d";var _emscripten_math_sign=x=>Math.sign(x);_emscripten_math_sign.sig="dd";var _emscripten_math_sqrt=x=>Math.sqrt(x);_emscripten_math_sqrt.sig="dd";var _emscripten_math_exp=x=>Math.exp(x);_emscripten_math_exp.sig="dd";var _emscripten_math_expm1=x=>Math.expm1(x);_emscripten_math_expm1.sig="dd";var _emscripten_math_fmod=(x,y)=>x%y;_emscripten_math_fmod.sig="ddd";var _emscripten_math_log=x=>Math.log(x);_emscripten_math_log.sig="dd";var _emscripten_math_log1p=x=>Math.log1p(x);_emscripten_math_log1p.sig="dd";var _emscripten_math_log10=x=>Math.log10(x);_emscripten_math_log10.sig="dd";var _emscripten_math_log2=x=>Math.log2(x);_emscripten_math_log2.sig="dd";var _emscripten_math_round=x=>Math.round(x);_emscripten_math_round.sig="dd";var _emscripten_math_acos=x=>Math.acos(x);_emscripten_math_acos.sig="dd";var _emscripten_math_acosh=x=>Math.acosh(x);_emscripten_math_acosh.sig="dd";var _emscripten_math_asin=x=>Math.asin(x);_emscripten_math_asin.sig="dd";var _emscripten_math_asinh=x=>Math.asinh(x);_emscripten_math_asinh.sig="dd";var _emscripten_math_atan=x=>Math.atan(x);_emscripten_math_atan.sig="dd";var _emscripten_math_atanh=x=>Math.atanh(x);_emscripten_math_atanh.sig="dd";var _emscripten_math_atan2=(y,x)=>Math.atan2(y,x);_emscripten_math_atan2.sig="ddd";var _emscripten_math_cos=x=>Math.cos(x);_emscripten_math_cos.sig="dd";var _emscripten_math_cosh=x=>Math.cosh(x);_emscripten_math_cosh.sig="dd";var _emscripten_math_hypot=(count,varargs)=>{var args=[];for(var i=0;i<count;++i){args.push(HEAPF64[varargs+i*8>>3])}return Math.hypot.apply(null,args)};_emscripten_math_hypot.sig="dip";var _emscripten_math_sin=x=>Math.sin(x);_emscripten_math_sin.sig="dd";var _emscripten_math_sinh=x=>Math.sinh(x);_emscripten_math_sinh.sig="dd";var _emscripten_math_tan=x=>Math.tan(x);_emscripten_math_tan.sig="dd";var _emscripten_math_tanh=x=>Math.tanh(x);_emscripten_math_tanh.sig="dd";function intArrayToString(array){var ret=[];for(var i=0;i<array.length;i++){var chr=array[i];if(chr>255){chr&=255}ret.push(String.fromCharCode(chr))}return ret.join("")}var AsciiToString=ptr=>{var str="";while(1){var ch=HEAPU8[ptr++>>0];if(!ch)return str;str+=String.fromCharCode(ch)}};var UTF16Decoder=typeof TextDecoder!="undefined"?new TextDecoder("utf-16le"):undefined;var UTF16ToString=(ptr,maxBytesToRead)=>{var endPtr=ptr;var idx=endPtr>>1;var maxIdx=idx+maxBytesToRead/2;while(!(idx>=maxIdx)&&HEAPU16[idx])++idx;endPtr=idx<<1;if(endPtr-ptr>32&&UTF16Decoder)return UTF16Decoder.decode(HEAPU8.subarray(ptr,endPtr));var str="";for(var i=0;!(i>=maxBytesToRead/2);++i){var codeUnit=HEAP16[ptr+i*2>>1];if(codeUnit==0)break;str+=String.fromCharCode(codeUnit)}return str};var stringToUTF16=(str,outPtr,maxBytesToWrite)=>{if(maxBytesToWrite===undefined){maxBytesToWrite=2147483647}if(maxBytesToWrite<2)return 0;maxBytesToWrite-=2;var startPtr=outPtr;var numCharsToWrite=maxBytesToWrite<str.length*2?maxBytesToWrite/2:str.length;for(var i=0;i<numCharsToWrite;++i){var codeUnit=str.charCodeAt(i);HEAP16[outPtr>>1]=codeUnit;outPtr+=2}HEAP16[outPtr>>1]=0;return outPtr-startPtr};var lengthBytesUTF16=str=>str.length*2;var UTF32ToString=(ptr,maxBytesToRead)=>{var i=0;var str="";while(!(i>=maxBytesToRead/4)){var utf32=HEAP32[ptr+i*4>>2];if(utf32==0)break;++i;if(utf32>=65536){var ch=utf32-65536;str+=String.fromCharCode(55296|ch>>10,56320|ch&1023)}else{str+=String.fromCharCode(utf32)}}return str};var stringToUTF32=(str,outPtr,maxBytesToWrite)=>{if(maxBytesToWrite===undefined){maxBytesToWrite=2147483647}if(maxBytesToWrite<4)return 0;var startPtr=outPtr;var endPtr=startPtr+maxBytesToWrite-4;for(var i=0;i<str.length;++i){var codeUnit=str.charCodeAt(i);if(codeUnit>=55296&&codeUnit<=57343){var trailSurrogate=str.charCodeAt(++i);codeUnit=65536+((codeUnit&1023)<<10)|trailSurrogate&1023}HEAP32[outPtr>>2]=codeUnit;outPtr+=4;if(outPtr+4>endPtr)break}HEAP32[outPtr>>2]=0;return outPtr-startPtr};var lengthBytesUTF32=str=>{var len=0;for(var i=0;i<str.length;++i){var codeUnit=str.charCodeAt(i);if(codeUnit>=55296&&codeUnit<=57343)++i;len+=4}return len};var JSEvents={inEventHandler:0,removeAllEventListeners(){for(var i=JSEvents.eventHandlers.length-1;i>=0;--i){JSEvents._removeHandler(i)}JSEvents.eventHandlers=[];JSEvents.deferredCalls=[]},registerRemoveEventListeners(){if(!JSEvents.removeEventListenersRegistered){__ATEXIT__.push(JSEvents.removeAllEventListeners);JSEvents.removeEventListenersRegistered=true}},deferredCalls:[],deferCall(targetFunction,precedence,argsList){function arraysHaveEqualContent(arrA,arrB){if(arrA.length!=arrB.length)return false;for(var i in arrA){if(arrA[i]!=arrB[i])return false}return true}for(var i in JSEvents.deferredCalls){var call=JSEvents.deferredCalls[i];if(call.targetFunction==targetFunction&&arraysHaveEqualContent(call.argsList,argsList)){return}}JSEvents.deferredCalls.push({targetFunction:targetFunction,precedence:precedence,argsList:argsList});JSEvents.deferredCalls.sort((x,y)=>x.precedence<y.precedence)},removeDeferredCalls(targetFunction){for(var i=0;i<JSEvents.deferredCalls.length;++i){if(JSEvents.deferredCalls[i].targetFunction==targetFunction){JSEvents.deferredCalls.splice(i,1);--i}}},canPerformEventHandlerRequests(){if(navigator.userActivation){return navigator.userActivation.isActive}return JSEvents.inEventHandler&&JSEvents.currentEventHandler.allowsDeferredCalls},runDeferredCalls(){if(!JSEvents.canPerformEventHandlerRequests()){return}for(var i=0;i<JSEvents.deferredCalls.length;++i){var call=JSEvents.deferredCalls[i];JSEvents.deferredCalls.splice(i,1);--i;call.targetFunction.apply(null,call.argsList)}},eventHandlers:[],removeAllHandlersOnTarget:(target,eventTypeString)=>{for(var i=0;i<JSEvents.eventHandlers.length;++i){if(JSEvents.eventHandlers[i].target==target&&(!eventTypeString||eventTypeString==JSEvents.eventHandlers[i].eventTypeString)){JSEvents._removeHandler(i--)}}},_removeHandler(i){var h=JSEvents.eventHandlers[i];h.target.removeEventListener(h.eventTypeString,h.eventListenerFunc,h.useCapture);JSEvents.eventHandlers.splice(i,1)},registerOrRemoveHandler(eventHandler){if(!eventHandler.target){return-4}var jsEventHandler=function jsEventHandler(event){++JSEvents.inEventHandler;JSEvents.currentEventHandler=eventHandler;JSEvents.runDeferredCalls();eventHandler.handlerFunc(event);JSEvents.runDeferredCalls();--JSEvents.inEventHandler};if(eventHandler.callbackfunc){eventHandler.eventListenerFunc=jsEventHandler;eventHandler.target.addEventListener(eventHandler.eventTypeString,jsEventHandler,eventHandler.useCapture);JSEvents.eventHandlers.push(eventHandler);JSEvents.registerRemoveEventListeners()}else{for(var i=0;i<JSEvents.eventHandlers.length;++i){if(JSEvents.eventHandlers[i].target==eventHandler.target&&JSEvents.eventHandlers[i].eventTypeString==eventHandler.eventTypeString){JSEvents._removeHandler(i--)}}}return 0},getNodeNameForTarget(target){if(!target)return"";if(target==window)return"#window";if(target==screen)return"#screen";return target&&target.nodeName?target.nodeName:""},fullscreenEnabled(){return document.fullscreenEnabled||document.webkitFullscreenEnabled}};var maybeCStringToJsString=cString=>cString>2?UTF8ToString(cString):cString;var specialHTMLTargets=[0,typeof document!="undefined"?document:0,typeof window!="undefined"?window:0];var findEventTarget=target=>{target=maybeCStringToJsString(target);var domElement=specialHTMLTargets[target]||(typeof document!="undefined"?document.querySelector(target):undefined);return domElement};var registerKeyEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.keyEvent)JSEvents.keyEvent=_malloc(176);var keyEventHandlerFunc=e=>{var keyEventData=JSEvents.keyEvent;HEAPF64[keyEventData>>3]=e.timeStamp;var idx=keyEventData>>2;HEAP32[idx+2]=e.location;HEAP32[idx+3]=e.ctrlKey;HEAP32[idx+4]=e.shiftKey;HEAP32[idx+5]=e.altKey;HEAP32[idx+6]=e.metaKey;HEAP32[idx+7]=e.repeat;HEAP32[idx+8]=e.charCode;HEAP32[idx+9]=e.keyCode;HEAP32[idx+10]=e.which;stringToUTF8(e.key||"",keyEventData+44,32);stringToUTF8(e.code||"",keyEventData+76,32);stringToUTF8(e.char||"",keyEventData+108,32);stringToUTF8(e.locale||"",keyEventData+140,32);if(getWasmTableEntry(callbackfunc)(eventTypeId,keyEventData,userData))e.preventDefault()};var eventHandler={target:findEventTarget(target),allowsDeferredCalls:true,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:keyEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var findCanvasEventTarget=target=>findEventTarget(target);var _emscripten_set_keypress_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerKeyEventCallback(target,userData,useCapture,callbackfunc,1,"keypress",targetThread);_emscripten_set_keypress_callback_on_thread.sig="ippipp";var _emscripten_set_keydown_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerKeyEventCallback(target,userData,useCapture,callbackfunc,2,"keydown",targetThread);_emscripten_set_keydown_callback_on_thread.sig="ippipp";var _emscripten_set_keyup_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerKeyEventCallback(target,userData,useCapture,callbackfunc,3,"keyup",targetThread);_emscripten_set_keyup_callback_on_thread.sig="ippipp";var getBoundingClientRect=e=>specialHTMLTargets.indexOf(e)<0?e.getBoundingClientRect():{"left":0,"top":0};var fillMouseEventData=(eventStruct,e,target)=>{HEAPF64[eventStruct>>3]=e.timeStamp;var idx=eventStruct>>2;HEAP32[idx+2]=e.screenX;HEAP32[idx+3]=e.screenY;HEAP32[idx+4]=e.clientX;HEAP32[idx+5]=e.clientY;HEAP32[idx+6]=e.ctrlKey;HEAP32[idx+7]=e.shiftKey;HEAP32[idx+8]=e.altKey;HEAP32[idx+9]=e.metaKey;HEAP16[idx*2+20]=e.button;HEAP16[idx*2+21]=e.buttons;HEAP32[idx+11]=e["movementX"];HEAP32[idx+12]=e["movementY"];var rect=getBoundingClientRect(target);HEAP32[idx+13]=e.clientX-rect.left;HEAP32[idx+14]=e.clientY-rect.top};var registerMouseEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.mouseEvent)JSEvents.mouseEvent=_malloc(72);target=findEventTarget(target);var mouseEventHandlerFunc=(e=event)=>{fillMouseEventData(JSEvents.mouseEvent,e,target);if(getWasmTableEntry(callbackfunc)(eventTypeId,JSEvents.mouseEvent,userData))e.preventDefault()};var eventHandler={target:target,allowsDeferredCalls:eventTypeString!="mousemove"&&eventTypeString!="mouseenter"&&eventTypeString!="mouseleave",eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:mouseEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_click_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,4,"click",targetThread);_emscripten_set_click_callback_on_thread.sig="ippipp";var _emscripten_set_mousedown_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,5,"mousedown",targetThread);_emscripten_set_mousedown_callback_on_thread.sig="ippipp";var _emscripten_set_mouseup_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,6,"mouseup",targetThread);_emscripten_set_mouseup_callback_on_thread.sig="ippipp";var _emscripten_set_dblclick_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,7,"dblclick",targetThread);_emscripten_set_dblclick_callback_on_thread.sig="ippipp";var _emscripten_set_mousemove_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,8,"mousemove",targetThread);_emscripten_set_mousemove_callback_on_thread.sig="ippipp";var _emscripten_set_mouseenter_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,33,"mouseenter",targetThread);_emscripten_set_mouseenter_callback_on_thread.sig="ippipp";var _emscripten_set_mouseleave_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,34,"mouseleave",targetThread);_emscripten_set_mouseleave_callback_on_thread.sig="ippipp";var _emscripten_set_mouseover_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,35,"mouseover",targetThread);_emscripten_set_mouseover_callback_on_thread.sig="ippipp";var _emscripten_set_mouseout_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerMouseEventCallback(target,userData,useCapture,callbackfunc,36,"mouseout",targetThread);_emscripten_set_mouseout_callback_on_thread.sig="ippipp";var _emscripten_get_mouse_status=mouseState=>{if(!JSEvents.mouseEvent)return-7;HEAP8.set(HEAP8.subarray(JSEvents.mouseEvent,JSEvents.mouseEvent+72),mouseState);return 0};_emscripten_get_mouse_status.sig="ip";var registerWheelEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.wheelEvent)JSEvents.wheelEvent=_malloc(104);var wheelHandlerFunc=(e=event)=>{var wheelEvent=JSEvents.wheelEvent;fillMouseEventData(wheelEvent,e,target);HEAPF64[wheelEvent+72>>3]=e["deltaX"];HEAPF64[wheelEvent+80>>3]=e["deltaY"];HEAPF64[wheelEvent+88>>3]=e["deltaZ"];HEAP32[wheelEvent+96>>2]=e["deltaMode"];if(getWasmTableEntry(callbackfunc)(eventTypeId,wheelEvent,userData))e.preventDefault()};var eventHandler={target:target,allowsDeferredCalls:true,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:wheelHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_wheel_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>{target=findEventTarget(target);if(!target)return-4;if(typeof target.onwheel!="undefined"){return registerWheelEventCallback(target,userData,useCapture,callbackfunc,9,"wheel",targetThread)}else{return-1}};_emscripten_set_wheel_callback_on_thread.sig="ippipp";var registerUiEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.uiEvent)JSEvents.uiEvent=_malloc(36);target=findEventTarget(target);var uiEventHandlerFunc=(e=event)=>{if(e.target!=target){return}var b=document.body;if(!b){return}var uiEvent=JSEvents.uiEvent;HEAP32[uiEvent>>2]=e.detail;HEAP32[uiEvent+4>>2]=b.clientWidth;HEAP32[uiEvent+8>>2]=b.clientHeight;HEAP32[uiEvent+12>>2]=innerWidth;HEAP32[uiEvent+16>>2]=innerHeight;HEAP32[uiEvent+20>>2]=outerWidth;HEAP32[uiEvent+24>>2]=outerHeight;HEAP32[uiEvent+28>>2]=pageXOffset;HEAP32[uiEvent+32>>2]=pageYOffset;if(getWasmTableEntry(callbackfunc)(eventTypeId,uiEvent,userData))e.preventDefault()};var eventHandler={target:target,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:uiEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_resize_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerUiEventCallback(target,userData,useCapture,callbackfunc,10,"resize",targetThread);_emscripten_set_resize_callback_on_thread.sig="ippipp";var _emscripten_set_scroll_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerUiEventCallback(target,userData,useCapture,callbackfunc,11,"scroll",targetThread);_emscripten_set_scroll_callback_on_thread.sig="ippipp";var registerFocusEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.focusEvent)JSEvents.focusEvent=_malloc(256);var focusEventHandlerFunc=(e=event)=>{var nodeName=JSEvents.getNodeNameForTarget(e.target);var id=e.target.id?e.target.id:"";var focusEvent=JSEvents.focusEvent;stringToUTF8(nodeName,focusEvent+0,128);stringToUTF8(id,focusEvent+128,128);if(getWasmTableEntry(callbackfunc)(eventTypeId,focusEvent,userData))e.preventDefault()};var eventHandler={target:findEventTarget(target),eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:focusEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_blur_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerFocusEventCallback(target,userData,useCapture,callbackfunc,12,"blur",targetThread);_emscripten_set_blur_callback_on_thread.sig="ippipp";var _emscripten_set_focus_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerFocusEventCallback(target,userData,useCapture,callbackfunc,13,"focus",targetThread);_emscripten_set_focus_callback_on_thread.sig="ippipp";var _emscripten_set_focusin_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerFocusEventCallback(target,userData,useCapture,callbackfunc,14,"focusin",targetThread);_emscripten_set_focusin_callback_on_thread.sig="ippipp";var _emscripten_set_focusout_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerFocusEventCallback(target,userData,useCapture,callbackfunc,15,"focusout",targetThread);_emscripten_set_focusout_callback_on_thread.sig="ippipp";var fillDeviceOrientationEventData=(eventStruct,e,target)=>{HEAPF64[eventStruct>>3]=e.alpha;HEAPF64[eventStruct+8>>3]=e.beta;HEAPF64[eventStruct+16>>3]=e.gamma;HEAP32[eventStruct+24>>2]=e.absolute};var registerDeviceOrientationEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.deviceOrientationEvent)JSEvents.deviceOrientationEvent=_malloc(32);var deviceOrientationEventHandlerFunc=(e=event)=>{fillDeviceOrientationEventData(JSEvents.deviceOrientationEvent,e,target);if(getWasmTableEntry(callbackfunc)(eventTypeId,JSEvents.deviceOrientationEvent,userData))e.preventDefault()};var eventHandler={target:findEventTarget(target),eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:deviceOrientationEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_deviceorientation_callback_on_thread=(userData,useCapture,callbackfunc,targetThread)=>registerDeviceOrientationEventCallback(2,userData,useCapture,callbackfunc,16,"deviceorientation",targetThread);_emscripten_set_deviceorientation_callback_on_thread.sig="ipipp";var _emscripten_get_deviceorientation_status=orientationState=>{if(!JSEvents.deviceOrientationEvent)return-7;HEAP32.set(HEAP32.subarray(JSEvents.deviceOrientationEvent,32),orientationState);return 0};_emscripten_get_deviceorientation_status.sig="ip";var fillDeviceMotionEventData=(eventStruct,e,target)=>{var supportedFields=0;var a=e["acceleration"];supportedFields|=a&&1;var ag=e["accelerationIncludingGravity"];supportedFields|=ag&&2;var rr=e["rotationRate"];supportedFields|=rr&&4;a=a||{};ag=ag||{};rr=rr||{};HEAPF64[eventStruct>>3]=a["x"];HEAPF64[eventStruct+8>>3]=a["y"];HEAPF64[eventStruct+16>>3]=a["z"];HEAPF64[eventStruct+24>>3]=ag["x"];HEAPF64[eventStruct+32>>3]=ag["y"];HEAPF64[eventStruct+40>>3]=ag["z"];HEAPF64[eventStruct+48>>3]=rr["alpha"];HEAPF64[eventStruct+56>>3]=rr["beta"];HEAPF64[eventStruct+64>>3]=rr["gamma"]};var registerDeviceMotionEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.deviceMotionEvent)JSEvents.deviceMotionEvent=_malloc(80);var deviceMotionEventHandlerFunc=(e=event)=>{fillDeviceMotionEventData(JSEvents.deviceMotionEvent,e,target);if(getWasmTableEntry(callbackfunc)(eventTypeId,JSEvents.deviceMotionEvent,userData))e.preventDefault()};var eventHandler={target:findEventTarget(target),eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:deviceMotionEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_devicemotion_callback_on_thread=(userData,useCapture,callbackfunc,targetThread)=>registerDeviceMotionEventCallback(2,userData,useCapture,callbackfunc,17,"devicemotion",targetThread);_emscripten_set_devicemotion_callback_on_thread.sig="ipipp";var _emscripten_get_devicemotion_status=motionState=>{if(!JSEvents.deviceMotionEvent)return-7;HEAP32.set(HEAP32.subarray(JSEvents.deviceMotionEvent,80),motionState);return 0};_emscripten_get_devicemotion_status.sig="ip";var screenOrientation=()=>{if(!screen)return undefined;return screen.orientation||screen.mozOrientation||screen.webkitOrientation||screen.msOrientation};var fillOrientationChangeEventData=eventStruct=>{var orientations=["portrait-primary","portrait-secondary","landscape-primary","landscape-secondary"];var orientations2=["portrait","portrait","landscape","landscape"];var orientationString=screenOrientation();var orientation=orientations.indexOf(orientationString);if(orientation==-1){orientation=orientations2.indexOf(orientationString)}HEAP32[eventStruct>>2]=1<<orientation;HEAP32[eventStruct+4>>2]=orientation};var registerOrientationChangeEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.orientationChangeEvent)JSEvents.orientationChangeEvent=_malloc(8);var orientationChangeEventHandlerFunc=(e=event)=>{var orientationChangeEvent=JSEvents.orientationChangeEvent;fillOrientationChangeEventData(orientationChangeEvent);if(getWasmTableEntry(callbackfunc)(eventTypeId,orientationChangeEvent,userData))e.preventDefault()};if(eventTypeString=="orientationchange"&&screen.mozOrientation!==undefined){eventTypeString="mozorientationchange"}var eventHandler={target:target,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:orientationChangeEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_orientationchange_callback_on_thread=(userData,useCapture,callbackfunc,targetThread)=>{if(!screen||!screen["addEventListener"])return-1;return registerOrientationChangeEventCallback(screen,userData,useCapture,callbackfunc,18,"orientationchange",targetThread)};_emscripten_set_orientationchange_callback_on_thread.sig="ipipp";var _emscripten_get_orientation_status=orientationChangeEvent=>{if(!screenOrientation()&&typeof orientation=="undefined")return-1;fillOrientationChangeEventData(orientationChangeEvent);return 0};_emscripten_get_orientation_status.sig="ip";var _emscripten_lock_orientation=allowedOrientations=>{var orientations=[];if(allowedOrientations&1)orientations.push("portrait-primary");if(allowedOrientations&2)orientations.push("portrait-secondary");if(allowedOrientations&4)orientations.push("landscape-primary");if(allowedOrientations&8)orientations.push("landscape-secondary");var succeeded;if(screen.lockOrientation){succeeded=screen.lockOrientation(orientations)}else if(screen.mozLockOrientation){succeeded=screen.mozLockOrientation(orientations)}else if(screen.webkitLockOrientation){succeeded=screen.webkitLockOrientation(orientations)}else if(screen.msLockOrientation){succeeded=screen.msLockOrientation(orientations)}else{return-1}if(succeeded){return 0}return-6};_emscripten_lock_orientation.sig="ii";var _emscripten_unlock_orientation=()=>{if(screen.unlockOrientation){screen.unlockOrientation()}else if(screen.mozUnlockOrientation){screen.mozUnlockOrientation()}else if(screen.webkitUnlockOrientation){screen.webkitUnlockOrientation()}else if(screen.msUnlockOrientation){screen.msUnlockOrientation()}else{return-1}return 0};_emscripten_unlock_orientation.sig="i";var fillFullscreenChangeEventData=eventStruct=>{var fullscreenElement=document.fullscreenElement||document.mozFullScreenElement||document.webkitFullscreenElement||document.msFullscreenElement;var isFullscreen=!!fullscreenElement;HEAP32[eventStruct>>2]=isFullscreen;HEAP32[eventStruct+4>>2]=JSEvents.fullscreenEnabled();var reportedElement=isFullscreen?fullscreenElement:JSEvents.previousFullscreenElement;var nodeName=JSEvents.getNodeNameForTarget(reportedElement);var id=reportedElement&&reportedElement.id?reportedElement.id:"";stringToUTF8(nodeName,eventStruct+8,128);stringToUTF8(id,eventStruct+136,128);HEAP32[eventStruct+264>>2]=reportedElement?reportedElement.clientWidth:0;HEAP32[eventStruct+268>>2]=reportedElement?reportedElement.clientHeight:0;HEAP32[eventStruct+272>>2]=screen.width;HEAP32[eventStruct+276>>2]=screen.height;if(isFullscreen){JSEvents.previousFullscreenElement=fullscreenElement}};var registerFullscreenChangeEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.fullscreenChangeEvent)JSEvents.fullscreenChangeEvent=_malloc(280);var fullscreenChangeEventhandlerFunc=(e=event)=>{var fullscreenChangeEvent=JSEvents.fullscreenChangeEvent;fillFullscreenChangeEventData(fullscreenChangeEvent);if(getWasmTableEntry(callbackfunc)(eventTypeId,fullscreenChangeEvent,userData))e.preventDefault()};var eventHandler={target:target,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:fullscreenChangeEventhandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_fullscreenchange_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>{if(!JSEvents.fullscreenEnabled())return-1;target=findEventTarget(target);if(!target)return-4;registerFullscreenChangeEventCallback(target,userData,useCapture,callbackfunc,19,"webkitfullscreenchange",targetThread);return registerFullscreenChangeEventCallback(target,userData,useCapture,callbackfunc,19,"fullscreenchange",targetThread)};_emscripten_set_fullscreenchange_callback_on_thread.sig="ippipp";var _emscripten_get_fullscreen_status=fullscreenStatus=>{if(!JSEvents.fullscreenEnabled())return-1;fillFullscreenChangeEventData(fullscreenStatus);return 0};_emscripten_get_fullscreen_status.sig="ip";var _emscripten_get_canvas_element_size=(target,width,height)=>{var canvas=findCanvasEventTarget(target);if(!canvas)return-4;HEAP32[width>>2]=canvas.width;HEAP32[height>>2]=canvas.height};_emscripten_get_canvas_element_size.sig="ippp";var getCanvasElementSize=target=>withStackSave(()=>{var w=stackAlloc(8);var h=w+4;var targetInt=stringToUTF8OnStack(target.id);var ret=_emscripten_get_canvas_element_size(targetInt,w,h);var size=[HEAP32[w>>2],HEAP32[h>>2]];return size});var _emscripten_set_canvas_element_size=(target,width,height)=>{var canvas=findCanvasEventTarget(target);if(!canvas)return-4;canvas.width=width;canvas.height=height;return 0};_emscripten_set_canvas_element_size.sig="ipii";var setCanvasElementSize=(target,width,height)=>{if(!target.controlTransferredOffscreen){target.width=width;target.height=height}else{withStackSave(()=>{var targetInt=stringToUTF8OnStack(target.id);_emscripten_set_canvas_element_size(targetInt,width,height)})}};var registerRestoreOldStyle=canvas=>{var canvasSize=getCanvasElementSize(canvas);var oldWidth=canvasSize[0];var oldHeight=canvasSize[1];var oldCssWidth=canvas.style.width;var oldCssHeight=canvas.style.height;var oldBackgroundColor=canvas.style.backgroundColor;var oldDocumentBackgroundColor=document.body.style.backgroundColor;var oldPaddingLeft=canvas.style.paddingLeft;var oldPaddingRight=canvas.style.paddingRight;var oldPaddingTop=canvas.style.paddingTop;var oldPaddingBottom=canvas.style.paddingBottom;var oldMarginLeft=canvas.style.marginLeft;var oldMarginRight=canvas.style.marginRight;var oldMarginTop=canvas.style.marginTop;var oldMarginBottom=canvas.style.marginBottom;var oldDocumentBodyMargin=document.body.style.margin;var oldDocumentOverflow=document.documentElement.style.overflow;var oldDocumentScroll=document.body.scroll;var oldImageRendering=canvas.style.imageRendering;function restoreOldStyle(){var fullscreenElement=document.fullscreenElement||document.webkitFullscreenElement;if(!fullscreenElement){document.removeEventListener("fullscreenchange",restoreOldStyle);document.removeEventListener("webkitfullscreenchange",restoreOldStyle);setCanvasElementSize(canvas,oldWidth,oldHeight);canvas.style.width=oldCssWidth;canvas.style.height=oldCssHeight;canvas.style.backgroundColor=oldBackgroundColor;if(!oldDocumentBackgroundColor)document.body.style.backgroundColor="white";document.body.style.backgroundColor=oldDocumentBackgroundColor;canvas.style.paddingLeft=oldPaddingLeft;canvas.style.paddingRight=oldPaddingRight;canvas.style.paddingTop=oldPaddingTop;canvas.style.paddingBottom=oldPaddingBottom;canvas.style.marginLeft=oldMarginLeft;canvas.style.marginRight=oldMarginRight;canvas.style.marginTop=oldMarginTop;canvas.style.marginBottom=oldMarginBottom;document.body.style.margin=oldDocumentBodyMargin;document.documentElement.style.overflow=oldDocumentOverflow;document.body.scroll=oldDocumentScroll;canvas.style.imageRendering=oldImageRendering;if(canvas.GLctxObject)canvas.GLctxObject.GLctx.viewport(0,0,oldWidth,oldHeight);if(currentFullscreenStrategy.canvasResizedCallback){getWasmTableEntry(currentFullscreenStrategy.canvasResizedCallback)(37,0,currentFullscreenStrategy.canvasResizedCallbackUserData)}}}document.addEventListener("fullscreenchange",restoreOldStyle);document.addEventListener("webkitfullscreenchange",restoreOldStyle);return restoreOldStyle};var setLetterbox=(element,topBottom,leftRight)=>{element.style.paddingLeft=element.style.paddingRight=leftRight+"px";element.style.paddingTop=element.style.paddingBottom=topBottom+"px"};var JSEvents_resizeCanvasForFullscreen=(target,strategy)=>{var restoreOldStyle=registerRestoreOldStyle(target);var cssWidth=strategy.softFullscreen?innerWidth:screen.width;var cssHeight=strategy.softFullscreen?innerHeight:screen.height;var rect=getBoundingClientRect(target);var windowedCssWidth=rect.width;var windowedCssHeight=rect.height;var canvasSize=getCanvasElementSize(target);var windowedRttWidth=canvasSize[0];var windowedRttHeight=canvasSize[1];if(strategy.scaleMode==3){setLetterbox(target,(cssHeight-windowedCssHeight)/2,(cssWidth-windowedCssWidth)/2);cssWidth=windowedCssWidth;cssHeight=windowedCssHeight}else if(strategy.scaleMode==2){if(cssWidth*windowedRttHeight<windowedRttWidth*cssHeight){var desiredCssHeight=windowedRttHeight*cssWidth/windowedRttWidth;setLetterbox(target,(cssHeight-desiredCssHeight)/2,0);cssHeight=desiredCssHeight}else{var desiredCssWidth=windowedRttWidth*cssHeight/windowedRttHeight;setLetterbox(target,0,(cssWidth-desiredCssWidth)/2);cssWidth=desiredCssWidth}}if(!target.style.backgroundColor)target.style.backgroundColor="black";if(!document.body.style.backgroundColor)document.body.style.backgroundColor="black";target.style.width=cssWidth+"px";target.style.height=cssHeight+"px";if(strategy.filteringMode==1){target.style.imageRendering="optimizeSpeed";target.style.imageRendering="-moz-crisp-edges";target.style.imageRendering="-o-crisp-edges";target.style.imageRendering="-webkit-optimize-contrast";target.style.imageRendering="optimize-contrast";target.style.imageRendering="crisp-edges";target.style.imageRendering="pixelated"}var dpiScale=strategy.canvasResolutionScaleMode==2?devicePixelRatio:1;if(strategy.canvasResolutionScaleMode!=0){var newWidth=cssWidth*dpiScale|0;var newHeight=cssHeight*dpiScale|0;setCanvasElementSize(target,newWidth,newHeight);if(target.GLctxObject)target.GLctxObject.GLctx.viewport(0,0,newWidth,newHeight)}return restoreOldStyle};var JSEvents_requestFullscreen=(target,strategy)=>{if(strategy.scaleMode!=0||strategy.canvasResolutionScaleMode!=0){JSEvents_resizeCanvasForFullscreen(target,strategy)}if(target.requestFullscreen){target.requestFullscreen()}else if(target.webkitRequestFullscreen){target.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT)}else{return JSEvents.fullscreenEnabled()?-3:-1}currentFullscreenStrategy=strategy;if(strategy.canvasResizedCallback){getWasmTableEntry(strategy.canvasResizedCallback)(37,0,strategy.canvasResizedCallbackUserData)}return 0};var hideEverythingExceptGivenElement=onlyVisibleElement=>{var child=onlyVisibleElement;var parent=child.parentNode;var hiddenElements=[];while(child!=document.body){var children=parent.children;for(var i=0;i<children.length;++i){if(children[i]!=child){hiddenElements.push({node:children[i],displayState:children[i].style.display});children[i].style.display="none"}}child=parent;parent=parent.parentNode}return hiddenElements};var restoreHiddenElements=hiddenElements=>{for(var i=0;i<hiddenElements.length;++i){hiddenElements[i].node.style.display=hiddenElements[i].displayState}};var currentFullscreenStrategy={};var restoreOldWindowedStyle=null;var softFullscreenResizeWebGLRenderTarget=()=>{var dpr=devicePixelRatio;var inHiDPIFullscreenMode=currentFullscreenStrategy.canvasResolutionScaleMode==2;var inAspectRatioFixedFullscreenMode=currentFullscreenStrategy.scaleMode==2;var inPixelPerfectFullscreenMode=currentFullscreenStrategy.canvasResolutionScaleMode!=0;var inCenteredWithoutScalingFullscreenMode=currentFullscreenStrategy.scaleMode==3;var screenWidth=inHiDPIFullscreenMode?Math.round(innerWidth*dpr):innerWidth;var screenHeight=inHiDPIFullscreenMode?Math.round(innerHeight*dpr):innerHeight;var w=screenWidth;var h=screenHeight;var canvas=currentFullscreenStrategy.target;var canvasSize=getCanvasElementSize(canvas);var x=canvasSize[0];var y=canvasSize[1];var topMargin;if(inAspectRatioFixedFullscreenMode){if(w*y<x*h)h=w*y/x|0;else if(w*y>x*h)w=h*x/y|0;topMargin=(screenHeight-h)/2|0}if(inPixelPerfectFullscreenMode){setCanvasElementSize(canvas,w,h);if(canvas.GLctxObject)canvas.GLctxObject.GLctx.viewport(0,0,w,h)}if(inHiDPIFullscreenMode){topMargin/=dpr;w/=dpr;h/=dpr;w=Math.round(w*1e4)/1e4;h=Math.round(h*1e4)/1e4;topMargin=Math.round(topMargin*1e4)/1e4}if(inCenteredWithoutScalingFullscreenMode){var t=(innerHeight-jstoi_q(canvas.style.height))/2;var b=(innerWidth-jstoi_q(canvas.style.width))/2;setLetterbox(canvas,t,b)}else{canvas.style.width=w+"px";canvas.style.height=h+"px";var b=(innerWidth-w)/2;setLetterbox(canvas,topMargin,b)}if(!inCenteredWithoutScalingFullscreenMode&&currentFullscreenStrategy.canvasResizedCallback){getWasmTableEntry(currentFullscreenStrategy.canvasResizedCallback)(37,0,currentFullscreenStrategy.canvasResizedCallbackUserData)}};var doRequestFullscreen=(target,strategy)=>{if(!JSEvents.fullscreenEnabled())return-1;target=findEventTarget(target);if(!target)return-4;if(!target.requestFullscreen&&!target.webkitRequestFullscreen){return-3}var canPerformRequests=JSEvents.canPerformEventHandlerRequests();if(!canPerformRequests){if(strategy.deferUntilInEventHandler){JSEvents.deferCall(JSEvents_requestFullscreen,1,[target,strategy]);return 1}return-2}return JSEvents_requestFullscreen(target,strategy)};var _emscripten_request_fullscreen=(target,deferUntilInEventHandler)=>{var strategy={scaleMode:0,canvasResolutionScaleMode:0,filteringMode:0,deferUntilInEventHandler:deferUntilInEventHandler,canvasResizedCallbackTargetThread:2};return doRequestFullscreen(target,strategy)};_emscripten_request_fullscreen.sig="ipi";var _emscripten_request_fullscreen_strategy=(target,deferUntilInEventHandler,fullscreenStrategy)=>{var strategy={scaleMode:HEAP32[fullscreenStrategy>>2],canvasResolutionScaleMode:HEAP32[fullscreenStrategy+4>>2],filteringMode:HEAP32[fullscreenStrategy+8>>2],deferUntilInEventHandler:deferUntilInEventHandler,canvasResizedCallback:HEAP32[fullscreenStrategy+12>>2],canvasResizedCallbackUserData:HEAP32[fullscreenStrategy+16>>2]};return doRequestFullscreen(target,strategy)};_emscripten_request_fullscreen_strategy.sig="ipip";var _emscripten_enter_soft_fullscreen=(target,fullscreenStrategy)=>{target=findEventTarget(target);if(!target)return-4;var strategy={scaleMode:HEAP32[fullscreenStrategy>>2],canvasResolutionScaleMode:HEAP32[fullscreenStrategy+4>>2],filteringMode:HEAP32[fullscreenStrategy+8>>2],canvasResizedCallback:HEAP32[fullscreenStrategy+12>>2],canvasResizedCallbackUserData:HEAP32[fullscreenStrategy+16>>2],target:target,softFullscreen:true};var restoreOldStyle=JSEvents_resizeCanvasForFullscreen(target,strategy);document.documentElement.style.overflow="hidden";document.body.scroll="no";document.body.style.margin="0px";var hiddenElements=hideEverythingExceptGivenElement(target);function restoreWindowedState(){restoreOldStyle();restoreHiddenElements(hiddenElements);removeEventListener("resize",softFullscreenResizeWebGLRenderTarget);if(strategy.canvasResizedCallback){getWasmTableEntry(strategy.canvasResizedCallback)(37,0,strategy.canvasResizedCallbackUserData)}currentFullscreenStrategy=0}restoreOldWindowedStyle=restoreWindowedState;currentFullscreenStrategy=strategy;addEventListener("resize",softFullscreenResizeWebGLRenderTarget);if(strategy.canvasResizedCallback){getWasmTableEntry(strategy.canvasResizedCallback)(37,0,strategy.canvasResizedCallbackUserData)}return 0};_emscripten_enter_soft_fullscreen.sig="ipp";var _emscripten_exit_soft_fullscreen=()=>{if(restoreOldWindowedStyle)restoreOldWindowedStyle();restoreOldWindowedStyle=null;return 0};_emscripten_exit_soft_fullscreen.sig="i";var _emscripten_exit_fullscreen=()=>{if(!JSEvents.fullscreenEnabled())return-1;JSEvents.removeDeferredCalls(JSEvents_requestFullscreen);var d=specialHTMLTargets[1];if(d.exitFullscreen){d.fullscreenElement&&d.exitFullscreen()}else if(d.webkitExitFullscreen){d.webkitFullscreenElement&&d.webkitExitFullscreen()}else{return-1}return 0};_emscripten_exit_fullscreen.sig="i";var fillPointerlockChangeEventData=eventStruct=>{var pointerLockElement=document.pointerLockElement||document.mozPointerLockElement||document.webkitPointerLockElement||document.msPointerLockElement;var isPointerlocked=!!pointerLockElement;HEAP32[eventStruct>>2]=isPointerlocked;var nodeName=JSEvents.getNodeNameForTarget(pointerLockElement);var id=pointerLockElement&&pointerLockElement.id?pointerLockElement.id:"";stringToUTF8(nodeName,eventStruct+4,128);stringToUTF8(id,eventStruct+132,128)};var registerPointerlockChangeEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.pointerlockChangeEvent)JSEvents.pointerlockChangeEvent=_malloc(260);var pointerlockChangeEventHandlerFunc=(e=event)=>{var pointerlockChangeEvent=JSEvents.pointerlockChangeEvent;fillPointerlockChangeEventData(pointerlockChangeEvent);if(getWasmTableEntry(callbackfunc)(eventTypeId,pointerlockChangeEvent,userData))e.preventDefault()};var eventHandler={target:target,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:pointerlockChangeEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_pointerlockchange_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>{if(!document||!document.body||!document.body.requestPointerLock&&!document.body.mozRequestPointerLock&&!document.body.webkitRequestPointerLock&&!document.body.msRequestPointerLock){return-1}target=findEventTarget(target);if(!target)return-4;registerPointerlockChangeEventCallback(target,userData,useCapture,callbackfunc,20,"mozpointerlockchange",targetThread);registerPointerlockChangeEventCallback(target,userData,useCapture,callbackfunc,20,"webkitpointerlockchange",targetThread);registerPointerlockChangeEventCallback(target,userData,useCapture,callbackfunc,20,"mspointerlockchange",targetThread);return registerPointerlockChangeEventCallback(target,userData,useCapture,callbackfunc,20,"pointerlockchange",targetThread)};_emscripten_set_pointerlockchange_callback_on_thread.sig="ippipp";var registerPointerlockErrorEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{var pointerlockErrorEventHandlerFunc=(e=event)=>{if(getWasmTableEntry(callbackfunc)(eventTypeId,0,userData))e.preventDefault()};var eventHandler={target:target,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:pointerlockErrorEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_pointerlockerror_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>{if(!document||!document.body.requestPointerLock&&!document.body.mozRequestPointerLock&&!document.body.webkitRequestPointerLock&&!document.body.msRequestPointerLock){return-1}target=findEventTarget(target);if(!target)return-4;registerPointerlockErrorEventCallback(target,userData,useCapture,callbackfunc,38,"mozpointerlockerror",targetThread);registerPointerlockErrorEventCallback(target,userData,useCapture,callbackfunc,38,"webkitpointerlockerror",targetThread);registerPointerlockErrorEventCallback(target,userData,useCapture,callbackfunc,38,"mspointerlockerror",targetThread);return registerPointerlockErrorEventCallback(target,userData,useCapture,callbackfunc,38,"pointerlockerror",targetThread)};_emscripten_set_pointerlockerror_callback_on_thread.sig="ippipp";var _emscripten_get_pointerlock_status=pointerlockStatus=>{if(pointerlockStatus)fillPointerlockChangeEventData(pointerlockStatus);if(!document.body||!document.body.requestPointerLock&&!document.body.mozRequestPointerLock&&!document.body.webkitRequestPointerLock&&!document.body.msRequestPointerLock){return-1}return 0};_emscripten_get_pointerlock_status.sig="ip";var requestPointerLock=target=>{if(target.requestPointerLock){target.requestPointerLock()}else{if(document.body.requestPointerLock){return-3}return-1}return 0};var _emscripten_request_pointerlock=(target,deferUntilInEventHandler)=>{target=findEventTarget(target);if(!target)return-4;if(!target.requestPointerLock){return-1}var canPerformRequests=JSEvents.canPerformEventHandlerRequests();if(!canPerformRequests){if(deferUntilInEventHandler){JSEvents.deferCall(requestPointerLock,2,[target]);return 1}return-2}return requestPointerLock(target)};_emscripten_request_pointerlock.sig="ipi";var _emscripten_exit_pointerlock=()=>{JSEvents.removeDeferredCalls(requestPointerLock);if(document.exitPointerLock){document.exitPointerLock()}else{return-1}return 0};_emscripten_exit_pointerlock.sig="i";var _emscripten_vibrate=msecs=>{if(!navigator.vibrate)return-1;navigator.vibrate(msecs);return 0};_emscripten_vibrate.sig="ii";var _emscripten_vibrate_pattern=(msecsArray,numEntries)=>{if(!navigator.vibrate)return-1;var vibrateList=[];for(var i=0;i<numEntries;++i){var msecs=HEAP32[msecsArray+i*4>>2];vibrateList.push(msecs)}navigator.vibrate(vibrateList);return 0};_emscripten_vibrate_pattern.sig="ipi";var fillVisibilityChangeEventData=eventStruct=>{var visibilityStates=["hidden","visible","prerender","unloaded"];var visibilityState=visibilityStates.indexOf(document.visibilityState);HEAP32[eventStruct>>2]=document.hidden;HEAP32[eventStruct+4>>2]=visibilityState};var registerVisibilityChangeEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.visibilityChangeEvent)JSEvents.visibilityChangeEvent=_malloc(8);var visibilityChangeEventHandlerFunc=(e=event)=>{var visibilityChangeEvent=JSEvents.visibilityChangeEvent;fillVisibilityChangeEventData(visibilityChangeEvent);if(getWasmTableEntry(callbackfunc)(eventTypeId,visibilityChangeEvent,userData))e.preventDefault()};var eventHandler={target:target,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:visibilityChangeEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_visibilitychange_callback_on_thread=(userData,useCapture,callbackfunc,targetThread)=>{if(!specialHTMLTargets[1]){return-4}return registerVisibilityChangeEventCallback(specialHTMLTargets[1],userData,useCapture,callbackfunc,21,"visibilitychange",targetThread)};_emscripten_set_visibilitychange_callback_on_thread.sig="ipipp";var _emscripten_get_visibility_status=visibilityStatus=>{if(typeof document.visibilityState=="undefined"&&typeof document.hidden=="undefined"){return-1}fillVisibilityChangeEventData(visibilityStatus);return 0};_emscripten_get_visibility_status.sig="ip";var registerTouchEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.touchEvent)JSEvents.touchEvent=_malloc(1696);target=findEventTarget(target);var touchEventHandlerFunc=e=>{var t,touches={},et=e.touches;for(var i=0;i<et.length;++i){t=et[i];t.isChanged=t.onTarget=0;touches[t.identifier]=t}for(var i=0;i<e.changedTouches.length;++i){t=e.changedTouches[i];t.isChanged=1;touches[t.identifier]=t}for(var i=0;i<e.targetTouches.length;++i){touches[e.targetTouches[i].identifier].onTarget=1}var touchEvent=JSEvents.touchEvent;HEAPF64[touchEvent>>3]=e.timeStamp;var idx=touchEvent>>2;HEAP32[idx+3]=e.ctrlKey;HEAP32[idx+4]=e.shiftKey;HEAP32[idx+5]=e.altKey;HEAP32[idx+6]=e.metaKey;idx+=7;var targetRect=getBoundingClientRect(target);var numTouches=0;for(var i in touches){t=touches[i];HEAP32[idx+0]=t.identifier;HEAP32[idx+1]=t.screenX;HEAP32[idx+2]=t.screenY;HEAP32[idx+3]=t.clientX;HEAP32[idx+4]=t.clientY;HEAP32[idx+5]=t.pageX;HEAP32[idx+6]=t.pageY;HEAP32[idx+7]=t.isChanged;HEAP32[idx+8]=t.onTarget;HEAP32[idx+9]=t.clientX-targetRect.left;HEAP32[idx+10]=t.clientY-targetRect.top;idx+=13;if(++numTouches>31){break}}HEAP32[touchEvent+8>>2]=numTouches;if(getWasmTableEntry(callbackfunc)(eventTypeId,touchEvent,userData))e.preventDefault()};var eventHandler={target:target,allowsDeferredCalls:eventTypeString=="touchstart"||eventTypeString=="touchend",eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:touchEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_touchstart_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerTouchEventCallback(target,userData,useCapture,callbackfunc,22,"touchstart",targetThread);_emscripten_set_touchstart_callback_on_thread.sig="ippipp";var _emscripten_set_touchend_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerTouchEventCallback(target,userData,useCapture,callbackfunc,23,"touchend",targetThread);_emscripten_set_touchend_callback_on_thread.sig="ippipp";var _emscripten_set_touchmove_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerTouchEventCallback(target,userData,useCapture,callbackfunc,24,"touchmove",targetThread);_emscripten_set_touchmove_callback_on_thread.sig="ippipp";var _emscripten_set_touchcancel_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>registerTouchEventCallback(target,userData,useCapture,callbackfunc,25,"touchcancel",targetThread);_emscripten_set_touchcancel_callback_on_thread.sig="ippipp";var fillGamepadEventData=(eventStruct,e)=>{HEAPF64[eventStruct>>3]=e.timestamp;for(var i=0;i<e.axes.length;++i){HEAPF64[eventStruct+i*8+16>>3]=e.axes[i]}for(var i=0;i<e.buttons.length;++i){if(typeof e.buttons[i]=="object"){HEAPF64[eventStruct+i*8+528>>3]=e.buttons[i].value}else{HEAPF64[eventStruct+i*8+528>>3]=e.buttons[i]}}for(var i=0;i<e.buttons.length;++i){if(typeof e.buttons[i]=="object"){HEAP32[eventStruct+i*4+1040>>2]=e.buttons[i].pressed}else{HEAP32[eventStruct+i*4+1040>>2]=e.buttons[i]==1}}HEAP32[eventStruct+1296>>2]=e.connected;HEAP32[eventStruct+1300>>2]=e.index;HEAP32[eventStruct+8>>2]=e.axes.length;HEAP32[eventStruct+12>>2]=e.buttons.length;stringToUTF8(e.id,eventStruct+1304,64);stringToUTF8(e.mapping,eventStruct+1368,64)};var registerGamepadEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.gamepadEvent)JSEvents.gamepadEvent=_malloc(1432);var gamepadEventHandlerFunc=(e=event)=>{var gamepadEvent=JSEvents.gamepadEvent;fillGamepadEventData(gamepadEvent,e["gamepad"]);if(getWasmTableEntry(callbackfunc)(eventTypeId,gamepadEvent,userData))e.preventDefault()};var eventHandler={target:findEventTarget(target),allowsDeferredCalls:true,eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:gamepadEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_gamepadconnected_callback_on_thread=(userData,useCapture,callbackfunc,targetThread)=>{if(!navigator.getGamepads&&!navigator.webkitGetGamepads)return-1;return registerGamepadEventCallback(2,userData,useCapture,callbackfunc,26,"gamepadconnected",targetThread)};_emscripten_set_gamepadconnected_callback_on_thread.sig="ipipp";var _emscripten_set_gamepaddisconnected_callback_on_thread=(userData,useCapture,callbackfunc,targetThread)=>{if(!navigator.getGamepads&&!navigator.webkitGetGamepads)return-1;return registerGamepadEventCallback(2,userData,useCapture,callbackfunc,27,"gamepaddisconnected",targetThread)};_emscripten_set_gamepaddisconnected_callback_on_thread.sig="ipipp";var _emscripten_sample_gamepad_data=()=>(JSEvents.lastGamepadState=navigator.getGamepads?navigator.getGamepads():navigator.webkitGetGamepads?navigator.webkitGetGamepads():null)?0:-1;_emscripten_sample_gamepad_data.sig="i";var _emscripten_get_num_gamepads=()=>JSEvents.lastGamepadState.length;_emscripten_get_num_gamepads.sig="i";var _emscripten_get_gamepad_status=(index,gamepadState)=>{if(index<0||index>=JSEvents.lastGamepadState.length)return-5;if(!JSEvents.lastGamepadState[index])return-7;fillGamepadEventData(gamepadState,JSEvents.lastGamepadState[index]);return 0};_emscripten_get_gamepad_status.sig="iip";var registerBeforeUnloadEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString)=>{var beforeUnloadEventHandlerFunc=(e=event)=>{var confirmationMessage=getWasmTableEntry(callbackfunc)(eventTypeId,0,userData);if(confirmationMessage){confirmationMessage=UTF8ToString(confirmationMessage)}if(confirmationMessage){e.preventDefault();e.returnValue=confirmationMessage;return confirmationMessage}};var eventHandler={target:findEventTarget(target),eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:beforeUnloadEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_beforeunload_callback_on_thread=(userData,callbackfunc,targetThread)=>{if(typeof onbeforeunload=="undefined")return-1;if(targetThread!==1)return-5;return registerBeforeUnloadEventCallback(2,userData,true,callbackfunc,28,"beforeunload")};_emscripten_set_beforeunload_callback_on_thread.sig="ippp";var fillBatteryEventData=(eventStruct,e)=>{HEAPF64[eventStruct>>3]=e.chargingTime;HEAPF64[eventStruct+8>>3]=e.dischargingTime;HEAPF64[eventStruct+16>>3]=e.level;HEAP32[eventStruct+24>>2]=e.charging};var battery=()=>navigator.battery||navigator.mozBattery||navigator.webkitBattery;var registerBatteryEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{if(!JSEvents.batteryEvent)JSEvents.batteryEvent=_malloc(32);var batteryEventHandlerFunc=(e=event)=>{var batteryEvent=JSEvents.batteryEvent;fillBatteryEventData(batteryEvent,battery());if(getWasmTableEntry(callbackfunc)(eventTypeId,batteryEvent,userData))e.preventDefault()};var eventHandler={target:findEventTarget(target),eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:batteryEventHandlerFunc,useCapture:useCapture};return JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_batterychargingchange_callback_on_thread=(userData,callbackfunc,targetThread)=>{if(!battery())return-1;return registerBatteryEventCallback(battery(),userData,true,callbackfunc,29,"chargingchange",targetThread)};_emscripten_set_batterychargingchange_callback_on_thread.sig="ippp";var _emscripten_set_batterylevelchange_callback_on_thread=(userData,callbackfunc,targetThread)=>{if(!battery())return-1;return registerBatteryEventCallback(battery(),userData,true,callbackfunc,30,"levelchange",targetThread)};_emscripten_set_batterylevelchange_callback_on_thread.sig="ippp";var _emscripten_get_battery_status=batteryState=>{if(!battery())return-1;fillBatteryEventData(batteryState,battery());return 0};_emscripten_get_battery_status.sig="ip";var _emscripten_set_element_css_size=(target,width,height)=>{target=findEventTarget(target);if(!target)return-4;target.style.width=width+"px";target.style.height=height+"px";return 0};_emscripten_set_element_css_size.sig="ipdd";var _emscripten_get_element_css_size=(target,width,height)=>{target=findEventTarget(target);if(!target)return-4;var rect=getBoundingClientRect(target);HEAPF64[width>>3]=rect.width;HEAPF64[height>>3]=rect.height;return 0};_emscripten_get_element_css_size.sig="ippp";var _emscripten_html5_remove_all_event_listeners=()=>JSEvents.removeAllEventListeners();_emscripten_html5_remove_all_event_listeners.sig="v";var _emscripten_request_animation_frame=(cb,userData)=>requestAnimationFrame(timeStamp=>getWasmTableEntry(cb)(timeStamp,userData));_emscripten_request_animation_frame.sig="ipp";var _emscripten_cancel_animation_frame=id=>cancelAnimationFrame(id);_emscripten_cancel_animation_frame.sig="vi";var _emscripten_request_animation_frame_loop=(cb,userData)=>{function tick(timeStamp){if(getWasmTableEntry(cb)(timeStamp,userData)){requestAnimationFrame(tick)}}return requestAnimationFrame(tick)};_emscripten_request_animation_frame_loop.sig="vpp";var _emscripten_performance_now=()=>performance.now();_emscripten_performance_now.sig="d";var _emscripten_get_device_pixel_ratio=()=>typeof devicePixelRatio=="number"&&devicePixelRatio||1;_emscripten_get_device_pixel_ratio.sig="d";var demangle=func=>func;var demangleAll=text=>{var regex=/\b_Z[\w\d_]+/g;return text.replace(regex,function(x){var y=demangle(x);return x===y?x:y+" ["+x+"]"})};function stackTrace(){var js=jsStackTrace();if(Module["extraStackTrace"])js+="\n"+Module["extraStackTrace"]();return demangleAll(js)}function _random_get(buf,buf_len){try{_getentropy(buf,buf_len);return 0}catch(e){if(typeof FS=="undefined"||!(e.name==="ErrnoError"))throw e;return e.errno}}_random_get.sig="ipp";var checkWasiClock=clock_id=>clock_id==0||clock_id==1||clock_id==2||clock_id==3;function _clock_time_get(clk_id,ignored_precision,ptime){ignored_precision=bigintToI53Checked(ignored_precision);if(!checkWasiClock(clk_id)){return 28}var now;if(clk_id===0){now=Date.now()}else if(nowIsMonotonic){now=_emscripten_get_now()}else{return 52}var nsec=Math.round(now*1e3*1e3);HEAP32[ptime>>2]=nsec>>>0;HEAP32[ptime+4>>2]=nsec/Math.pow(2,32)>>>0;return 0}_clock_time_get.sig="iijp";var _clock_res_get=(clk_id,pres)=>{if(!checkWasiClock(clk_id)){return 28}var nsec;if(clk_id===0){nsec=1e3*1e3}else if(nowIsMonotonic){nsec=_emscripten_get_now_res()}else{return 52}HEAP32[pres>>2]=nsec>>>0;HEAP32[pres+4>>2]=nsec/Math.pow(2,32)>>>0;return 0};_clock_res_get.sig="iip";var wasiRightsToMuslOFlags=rights=>{if(rights&2&&rights&64){return 2}if(rights&2){return 0}if(rights&64){return 1}throw new FS.ErrnoError(28)};var wasiOFlagsToMuslOFlags=oflags=>{var musl_oflags=0;if(oflags&1){musl_oflags|=64}if(oflags&8){musl_oflags|=512}if(oflags&2){musl_oflags|=65536}if(oflags&4){musl_oflags|=128}return musl_oflags};var createDyncallWrapper=sig=>{var sections=[];var prelude=[0,97,115,109,1,0,0,0];sections.push(prelude);var wrappersig=[sig[0].replace("j","i"),"i",sig.slice(1).replace(/j/g,"ii")].join("");var typeSectionBody=[3];generateFuncType(wrappersig,typeSectionBody);generateFuncType(sig,typeSectionBody);generateFuncType("vi",typeSectionBody);var typeSection=[1];uleb128Encode(typeSectionBody.length,typeSection);typeSection.push.apply(typeSection,typeSectionBody);sections.push(typeSection);var importSection=[2,15,2,1,101,1,116,1,112,0,0,1,101,1,114,0,2];sections.push(importSection);var functionSection=[3,2,1,0];sections.push(functionSection);var exportSection=[7,5,1,1,102,0,1];sections.push(exportSection);var convert_code=[];if(sig[0]==="j"){convert_code=[1,1,126]}else{convert_code.push(0)}function localGet(j){convert_code.push(32);uleb128Encode(j,convert_code)}var j=1;for(var i=1;i<sig.length;i++){if(sig[i]=="j"){localGet(j+1);convert_code.push(173,66,32,134);localGet(j);convert_code.push(172,132);j+=2}else{localGet(j);j++}}convert_code.push(32,0,17,1,0);if(sig[0]==="j"){convert_code.push(34);uleb128Encode(j,convert_code);convert_code.push(66,32,136,167,16,0);localGet(j);convert_code.push(167)}convert_code.push(11);var codeBody=[1];uleb128Encode(convert_code.length,codeBody);codeBody.push.apply(codeBody,convert_code);var codeSection=[10];uleb128Encode(codeBody.length,codeSection);codeSection.push.apply(codeSection,codeBody);sections.push(codeSection);var bytes=new Uint8Array([].concat.apply([],sections));var module=new WebAssembly.Module(bytes);var instance=new WebAssembly.Instance(module,{"e":{"t":wasmTable,"r":setTempRet0}});var wrappedFunc=instance.exports["f"];return wrappedFunc};var _emscripten_unwind_to_js_event_loop=()=>{throw"unwind"};_emscripten_unwind_to_js_event_loop.sig="v";var setImmediateWrapped=func=>{if(!setImmediateWrapped.mapping)setImmediateWrapped.mapping=[];var id=setImmediateWrapped.mapping.length;setImmediateWrapped.mapping[id]=setImmediate(()=>{setImmediateWrapped.mapping[id]=undefined;func()});return id};var clearImmediateWrapped=id=>{clearImmediate(setImmediateWrapped.mapping[id]);setImmediateWrapped.mapping[id]=undefined};var polyfillSetImmediate=()=>{};var _emscripten_set_immediate=(cb,userData)=>{runtimeKeepalivePush();return emSetImmediate(()=>{runtimeKeepalivePop();callUserCallback(()=>getWasmTableEntry(cb)(userData))})};_emscripten_set_immediate.sig="ipp";var _emscripten_clear_immediate=id=>{runtimeKeepalivePop();emClearImmediate(id)};_emscripten_clear_immediate.sig="vi";var _emscripten_set_immediate_loop=(cb,userData)=>{function tick(){callUserCallback(()=>{if(getWasmTableEntry(cb)(userData)){emSetImmediate(tick)}else{runtimeKeepalivePop()}})}runtimeKeepalivePush();emSetImmediate(tick)};_emscripten_set_immediate_loop.sig="vpp";var _emscripten_set_timeout=(cb,msecs,userData)=>safeSetTimeout(()=>getWasmTableEntry(cb)(userData),msecs);_emscripten_set_timeout.sig="ipdp";var _emscripten_clear_timeout=id=>clearTimeout(id);_emscripten_clear_timeout.sig="vi";var _emscripten_set_timeout_loop=(cb,msecs,userData)=>{function tick(){var t=_emscripten_get_now();var n=t+msecs;runtimeKeepalivePop();callUserCallback(()=>{if(getWasmTableEntry(cb)(t,userData)){runtimeKeepalivePush();setTimeout(tick,n-_emscripten_get_now())}})}runtimeKeepalivePush();return setTimeout(tick,0)};_emscripten_set_timeout_loop.sig="vpdp";var _emscripten_set_interval=(cb,msecs,userData)=>{runtimeKeepalivePush();return setInterval(()=>{callUserCallback(()=>getWasmTableEntry(cb)(userData))},msecs)};_emscripten_set_interval.sig="ipdp";var _emscripten_clear_interval=id=>{runtimeKeepalivePop();clearInterval(id)};_emscripten_clear_interval.sig="vi";var idsToPromises=(idBuf,size)=>{var promises=[];for(var i=0;i<size;i++){var id=HEAP32[idBuf+i*4>>2];promises[i]=getPromise(id)}return promises};var makePromiseCallback=(callback,userData)=>value=>{runtimeKeepalivePop();var stack=stackSave();var resultPtr=stackAlloc(POINTER_SIZE);HEAPU32[resultPtr>>2]=0;try{var result=getWasmTableEntry(callback)(resultPtr,userData,value);var resultVal=HEAPU32[resultPtr>>2]}catch(e){if(typeof e!=="number"){throw 0}throw e}finally{stackRestore(stack)}switch(result){case 0:return resultVal;case 1:return getPromise(resultVal);case 2:var ret=getPromise(resultVal);_emscripten_promise_destroy(resultVal);return ret;case 3:throw resultVal}};var _emscripten_promise_then=(id,onFulfilled,onRejected,userData)=>{runtimeKeepalivePush();var promise=getPromise(id);var newId=promiseMap.allocate({promise:promise.then(makePromiseCallback(onFulfilled,userData),makePromiseCallback(onRejected,userData))});return newId};_emscripten_promise_then.sig="ppppp";var _emscripten_promise_all=(idBuf,resultBuf,size)=>{var promises=idsToPromises(idBuf,size);var id=promiseMap.allocate({promise:Promise.all(promises).then(results=>{if(resultBuf){for(var i=0;i<size;i++){var result=results[i];HEAPU32[resultBuf+i*4>>2]=result}}return resultBuf})});return id};_emscripten_promise_all.sig="pppp";var setPromiseResult=(ptr,fulfill,value)=>{var result=fulfill?0:3;HEAP32[ptr>>2]=result;HEAPU32[ptr+4>>2]=value};var _emscripten_promise_all_settled=(idBuf,resultBuf,size)=>{var promises=idsToPromises(idBuf,size);var id=promiseMap.allocate({promise:Promise.allSettled(promises).then(results=>{if(resultBuf){var offset=resultBuf;for(var i=0;i<size;i++,offset+=8){if(results[i].status==="fulfilled"){setPromiseResult(offset,true,results[i].value)}else{setPromiseResult(offset,false,results[i].reason)}}}return resultBuf})});return id};_emscripten_promise_all_settled.sig="pppp";var _emscripten_promise_any=(idBuf,errorBuf,size)=>{var promises=idsToPromises(idBuf,size);var id=promiseMap.allocate({promise:Promise.any(promises).catch(err=>{if(errorBuf){for(var i=0;i<size;i++){HEAPU32[errorBuf+i*4>>2]=err.errors[i]}}throw errorBuf})});return id};_emscripten_promise_any.sig="pppp";var _emscripten_promise_race=(idBuf,size)=>{var promises=idsToPromises(idBuf,size);var id=promiseMap.allocate({promise:Promise.race(promises)});return id};_emscripten_promise_race.sig="ppp";var _emscripten_promise_await=(returnValuePtr,id)=>{abort("emscripten_promise_await is only available with ASYNCIFY")};_emscripten_promise_await.sig="vpp";var getExceptionMessageCommon=ptr=>withStackSave(()=>{var type_addr_addr=stackAlloc(4);var message_addr_addr=stackAlloc(4);___get_exception_message(ptr,type_addr_addr,message_addr_addr);var type_addr=HEAPU32[type_addr_addr>>2];var message_addr=HEAPU32[message_addr_addr>>2];var type=UTF8ToString(type_addr);_free(type_addr);var message;if(message_addr){message=UTF8ToString(message_addr);_free(message_addr)}return[type,message]});var getCppExceptionTag=()=>___cpp_exception;var getCppExceptionThrownObjectFromWebAssemblyException=ex=>{var unwind_header=ex.getArg(getCppExceptionTag(),0);return ___thrown_object_from_unwind_exception(unwind_header)};var incrementExceptionRefcount=ex=>{var ptr=getCppExceptionThrownObjectFromWebAssemblyException(ex);___cxa_increment_exception_refcount(ptr)};var decrementExceptionRefcount=ex=>{var ptr=getCppExceptionThrownObjectFromWebAssemblyException(ex);___cxa_decrement_exception_refcount(ptr)};var getExceptionMessage=ex=>{var ptr=getCppExceptionThrownObjectFromWebAssemblyException(ex);return getExceptionMessageCommon(ptr)};var _emscripten_run_preload_plugins=(file,onload,onerror)=>{runtimeKeepalivePush();var _file=UTF8ToString(file);var data=FS.analyzePath(_file);if(!data.exists)return-1;FS.createPreloadedFile(PATH.dirname(_file),PATH.basename(_file),new Uint8Array(data.object.contents),true,true,()=>{runtimeKeepalivePop();if(onload)getWasmTableEntry(onload)(file)},()=>{runtimeKeepalivePop();if(onerror)getWasmTableEntry(onerror)(file)},true);return 0};_emscripten_run_preload_plugins.sig="ippp";var _emscripten_run_preload_plugins_data=(data,size,suffix,arg,onload,onerror)=>{runtimeKeepalivePush();var _suffix=UTF8ToString(suffix);if(!Browser.asyncPrepareDataCounter)Browser.asyncPrepareDataCounter=0;var name="prepare_data_"+Browser.asyncPrepareDataCounter+++"."+_suffix;var cname=stringToNewUTF8(name);FS.createPreloadedFile("/",name,HEAPU8.subarray(data,data+size),true,true,()=>{runtimeKeepalivePop();if(onload)getWasmTableEntry(onload)(arg,cname)},()=>{runtimeKeepalivePop();if(onerror)getWasmTableEntry(onerror)(arg)},true)};_emscripten_run_preload_plugins_data.sig="vpipppp";var _emscripten_async_run_script=(script,millis)=>{safeSetTimeout(()=>_emscripten_run_script(script),millis)};_emscripten_async_run_script.sig="vpi";var _emscripten_async_load_script=(url,onload,onerror)=>{url=UTF8ToString(url);onload=getWasmTableEntry(onload);onerror=getWasmTableEntry(onerror);assert(runDependencies===0,"async_load_script must be run when no other dependencies are active");runtimeKeepalivePush();var loadDone=()=>{runtimeKeepalivePop();if(onload){if(runDependencies>0){dependenciesFulfilled=onload}else{onload()}}};var loadError=()=>{runtimeKeepalivePop();if(onerror)onerror()};if(ENVIRONMENT_IS_NODE){readAsync(url,data=>{eval(data);loadDone()},loadError,false);return}var script=document.createElement("script");script.onload=loadDone;script.onerror=loadError;script.src=url;document.body.appendChild(script)};_emscripten_async_load_script.sig="vppp";var _emscripten_get_main_loop_timing=(mode,value)=>{if(mode)HEAP32[mode>>2]=Browser.mainLoop.timingMode;if(value)HEAP32[value>>2]=Browser.mainLoop.timingValue};_emscripten_get_main_loop_timing.sig="vpp";var _emscripten_set_main_loop=(func,fps,simulateInfiniteLoop)=>{var browserIterationFunc=getWasmTableEntry(func);setMainLoop(browserIterationFunc,fps,simulateInfiniteLoop)};_emscripten_set_main_loop.sig="vpii";var _emscripten_set_main_loop_arg=(func,arg,fps,simulateInfiniteLoop)=>{var browserIterationFunc=()=>getWasmTableEntry(func)(arg);setMainLoop(browserIterationFunc,fps,simulateInfiniteLoop,arg)};_emscripten_set_main_loop_arg.sig="vppii";var _emscripten_cancel_main_loop=()=>{Browser.mainLoop.pause();Browser.mainLoop.func=null};_emscripten_cancel_main_loop.sig="v";var _emscripten_pause_main_loop=()=>{Browser.mainLoop.pause()};_emscripten_pause_main_loop.sig="v";var _emscripten_resume_main_loop=()=>{Browser.mainLoop.resume()};_emscripten_resume_main_loop.sig="v";var __emscripten_push_main_loop_blocker=(func,arg,name)=>{Browser.mainLoop.queue.push({func:()=>{getWasmTableEntry(func)(arg)},name:UTF8ToString(name),counted:true});Browser.mainLoop.updateStatus()};__emscripten_push_main_loop_blocker.sig="vppp";var __emscripten_push_uncounted_main_loop_blocker=(func,arg,name)=>{Browser.mainLoop.queue.push({func:()=>{getWasmTableEntry(func)(arg)},name:UTF8ToString(name),counted:false});Browser.mainLoop.updateStatus()};__emscripten_push_uncounted_main_loop_blocker.sig="vppp";var _emscripten_set_main_loop_expected_blockers=num=>{Browser.mainLoop.expectedBlockers=num;Browser.mainLoop.remainingBlockers=num;Browser.mainLoop.updateStatus()};_emscripten_set_main_loop_expected_blockers.sig="vi";var _emscripten_async_call=(func,arg,millis)=>{function wrapper(){getWasmTableEntry(func)(arg)}if(millis>=0||ENVIRONMENT_IS_NODE){safeSetTimeout(wrapper,millis)}else{Browser.safeRequestAnimationFrame(wrapper)}};_emscripten_async_call.sig="vppi";var _emscripten_get_window_title=()=>{var buflen=256;if(!_emscripten_get_window_title.buffer){_emscripten_get_window_title.buffer=_malloc(buflen)}stringToUTF8(document.title,_emscripten_get_window_title.buffer,buflen);return _emscripten_get_window_title.buffer};_emscripten_get_window_title.sig="p";var _emscripten_set_window_title=title=>document.title=UTF8ToString(title);_emscripten_set_window_title.sig="vp";var _emscripten_get_screen_size=(width,height)=>{HEAP32[width>>2]=screen.width;HEAP32[height>>2]=screen.height};_emscripten_get_screen_size.sig="vpp";var _emscripten_hide_mouse=()=>{var styleSheet=document.styleSheets[0];var rules=styleSheet.cssRules;for(var i=0;i<rules.length;i++){if(rules[i].cssText.substr(0,6)=="canvas"){styleSheet.deleteRule(i);i--}}styleSheet.insertRule("canvas.emscripten { border: 1px solid black; cursor: none; }",0)};_emscripten_hide_mouse.sig="v";var _emscripten_set_canvas_size=(width,height)=>{Browser.setCanvasSize(width,height)};_emscripten_set_canvas_size.sig="vii";var _emscripten_get_canvas_size=(width,height,isFullscreen)=>{var canvas=Module["canvas"];HEAP32[width>>2]=canvas.width;HEAP32[height>>2]=canvas.height;HEAP32[isFullscreen>>2]=Browser.isFullscreen?1:0};_emscripten_get_canvas_size.sig="vppp";var _emscripten_create_worker=url=>{url=UTF8ToString(url);var id=Browser.workers.length;var info={worker:new Worker(url),callbacks:[],awaited:0,buffer:0,bufferSize:0};info.worker.onmessage=function info_worker_onmessage(msg){if(ABORT)return;var info=Browser.workers[id];if(!info)return;var callbackId=msg.data["callbackId"];var callbackInfo=info.callbacks[callbackId];if(!callbackInfo)return;if(msg.data["finalResponse"]){info.awaited--;info.callbacks[callbackId]=null;runtimeKeepalivePop()}var data=msg.data["data"];if(data){if(!data.byteLength)data=new Uint8Array(data);if(!info.buffer||info.bufferSize<data.length){if(info.buffer)_free(info.buffer);info.bufferSize=data.length;info.buffer=_malloc(data.length)}HEAPU8.set(data,info.buffer);callbackInfo.func(info.buffer,data.length,callbackInfo.arg)}else{callbackInfo.func(0,0,callbackInfo.arg)}};Browser.workers.push(info);return id};_emscripten_create_worker.sig="ip";var _emscripten_destroy_worker=id=>{var info=Browser.workers[id];info.worker.terminate();if(info.buffer)_free(info.buffer);Browser.workers[id]=null};_emscripten_destroy_worker.sig="vi";var _emscripten_call_worker=(id,funcName,data,size,callback,arg)=>{funcName=UTF8ToString(funcName);var info=Browser.workers[id];var callbackId=-1;if(callback){runtimeKeepalivePush();callbackId=info.callbacks.length;info.callbacks.push({func:getWasmTableEntry(callback),arg:arg});info.awaited++}var transferObject={"funcName":funcName,"callbackId":callbackId,"data":data?new Uint8Array(HEAPU8.subarray(data,data+size)):0};if(data){info.worker.postMessage(transferObject,[transferObject.data.buffer])}else{info.worker.postMessage(transferObject)}};_emscripten_call_worker.sig="vippipp";var _emscripten_get_worker_queue_size=id=>{var info=Browser.workers[id];if(!info)return-1;return info.awaited};_emscripten_get_worker_queue_size.sig="ii";var _emscripten_get_preloaded_image_data=(path,w,h)=>{if((path|0)===path)path=UTF8ToString(path);path=PATH_FS.resolve(path);var canvas=preloadedImages[path];if(canvas){var ctx=canvas.getContext("2d");var image=ctx.getImageData(0,0,canvas.width,canvas.height);var buf=_malloc(canvas.width*canvas.height*4);HEAPU8.set(image.data,buf);HEAP32[w>>2]=canvas.width;HEAP32[h>>2]=canvas.height;return buf}return 0};_emscripten_get_preloaded_image_data.sig="pppp";var _emscripten_get_preloaded_image_data_from_FILE=(file,w,h)=>{var fd=_fileno(file);var stream=FS.getStream(fd);if(stream){return _emscripten_get_preloaded_image_data(stream.path,w,h)}return 0};_emscripten_get_preloaded_image_data_from_FILE.sig="pppp";var wget={wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle(){var handle=wget.nextWgetRequestHandle;wget.nextWgetRequestHandle++;return handle}};var FS_mkdirTree=(path,mode)=>FS.mkdirTree(path,mode);var _emscripten_async_wget=(url,file,onload,onerror)=>{runtimeKeepalivePush();var _url=UTF8ToString(url);var _file=UTF8ToString(file);_file=PATH_FS.resolve(_file);function doCallback(callback){if(callback){runtimeKeepalivePop();callUserCallback(function(){withStackSave(function(){getWasmTableEntry(callback)(stringToUTF8OnStack(_file))})})}}var destinationDirectory=PATH.dirname(_file);FS_createPreloadedFile(destinationDirectory,PATH.basename(_file),_url,true,true,function(){doCallback(onload)},function(){doCallback(onerror)},false,false,function(){try{FS_unlink(_file)}catch(e){}FS_mkdirTree(destinationDirectory)})};_emscripten_async_wget.sig="vpppp";var _emscripten_async_wget_data=(url,arg,onload,onerror)=>{runtimeKeepalivePush();asyncLoad(UTF8ToString(url),function(byteArray){runtimeKeepalivePop();callUserCallback(function(){var buffer=_malloc(byteArray.length);HEAPU8.set(byteArray,buffer);getWasmTableEntry(onload)(arg,buffer,byteArray.length);_free(buffer)})},function(){if(onerror){runtimeKeepalivePop();callUserCallback(function(){getWasmTableEntry(onerror)(arg)})}},true)};_emscripten_async_wget_data.sig="vpppp";var _emscripten_async_wget2=(url,file,request,param,arg,onload,onerror,onprogress)=>{runtimeKeepalivePush();var _url=UTF8ToString(url);var _file=UTF8ToString(file);_file=PATH_FS.resolve(_file);var _request=UTF8ToString(request);var _param=UTF8ToString(param);var index=_file.lastIndexOf("/");var http=new XMLHttpRequest;http.open(_request,_url,true);http.responseType="arraybuffer";var handle=wget.getNextWgetRequestHandle();var destinationDirectory=PATH.dirname(_file);http.onload=function http_onload(e){runtimeKeepalivePop();if(http.status>=200&&http.status<300){try{FS.unlink(_file)}catch(e){}FS.mkdirTree(destinationDirectory);FS.createDataFile(_file.substr(0,index),_file.substr(index+1),new Uint8Array(http.response),true,true,false);if(onload){withStackSave(function(){getWasmTableEntry(onload)(handle,arg,stringToUTF8OnStack(_file))})}}else{if(onerror)getWasmTableEntry(onerror)(handle,arg,http.status)}delete wget.wgetRequests[handle]};http.onerror=function http_onerror(e){runtimeKeepalivePop();if(onerror)getWasmTableEntry(onerror)(handle,arg,http.status);delete wget.wgetRequests[handle]};http.onprogress=function http_onprogress(e){if(e.lengthComputable||e.lengthComputable===undefined&&e.total!=0){var percentComplete=e.loaded/e.total*100;if(onprogress)getWasmTableEntry(onprogress)(handle,arg,percentComplete)}};http.onabort=function http_onabort(e){runtimeKeepalivePop();delete wget.wgetRequests[handle]};if(_request=="POST"){http.setRequestHeader("Content-type","application/x-www-form-urlencoded");http.send(_param)}else{http.send(null)}wget.wgetRequests[handle]=http;return handle};_emscripten_async_wget2.sig="ipppppppp";var _emscripten_async_wget2_data=(url,request,param,arg,free,onload,onerror,onprogress)=>{var _url=UTF8ToString(url);var _request=UTF8ToString(request);var _param=UTF8ToString(param);var http=new XMLHttpRequest;http.open(_request,_url,true);http.responseType="arraybuffer";var handle=wget.getNextWgetRequestHandle();function onerrorjs(){if(onerror){withStackSave(()=>{var statusText=0;if(http.statusText){statusText=stringToUTF8OnStack(http.statusText)}getWasmTableEntry(onerror)(handle,arg,http.status,statusText)})}}http.onload=function http_onload(e){if(http.status>=200&&http.status<300||http.status===0&&_url.substr(0,4).toLowerCase()!="http"){var byteArray=new Uint8Array(http.response);var buffer=_malloc(byteArray.length);HEAPU8.set(byteArray,buffer);if(onload)getWasmTableEntry(onload)(handle,arg,buffer,byteArray.length);if(free)_free(buffer)}else{onerrorjs()}delete wget.wgetRequests[handle]};http.onerror=function http_onerror(e){onerrorjs();delete wget.wgetRequests[handle]};http.onprogress=function http_onprogress(e){if(onprogress)getWasmTableEntry(onprogress)(handle,arg,e.loaded,e.lengthComputable||e.lengthComputable===undefined?e.total:0)};http.onabort=function http_onabort(e){delete wget.wgetRequests[handle]};if(_request=="POST"){http.setRequestHeader("Content-type","application/x-www-form-urlencoded");http.send(_param)}else{http.send(null)}wget.wgetRequests[handle]=http;return handle};_emscripten_async_wget2_data.sig="ippppippp";var _emscripten_async_wget2_abort=handle=>{var http=wget.wgetRequests[handle];if(http){http.abort()}};_emscripten_async_wget2_abort.sig="vi";var __dlsym_catchup_js=(handle,symbolIndex)=>{var lib=LDSO.loadedLibsByHandle[handle];var symDict=lib.exports;var symName=Object.keys(symDict)[symbolIndex];var sym=symDict[symName];var result=addFunction(sym,sym.sig);return result};__dlsym_catchup_js.sig="ppi";var _setNetworkCallback=(event,userData,callback)=>{function _callback(data){try{if(event==="error"){withStackSave(function(){var msg=stringToUTF8OnStack(data[2]);getWasmTableEntry(callback)(data[0],data[1],msg,userData)})}else{getWasmTableEntry(callback)(data,userData)}}catch(e){if(!(e instanceof ExitStatus)){if(e&&typeof e=="object"&&e.stack)err("exception thrown: "+[e,e.stack]);throw e}}}runtimeKeepalivePush();Module["websocket"]["on"](event,callback?_callback:null)};var _emscripten_set_socket_error_callback=(userData,callback)=>{_setNetworkCallback("error",userData,callback)};_emscripten_set_socket_error_callback.sig="vpp";var _emscripten_set_socket_open_callback=(userData,callback)=>{_setNetworkCallback("open",userData,callback)};_emscripten_set_socket_open_callback.sig="vpp";var _emscripten_set_socket_listen_callback=(userData,callback)=>{_setNetworkCallback("listen",userData,callback)};_emscripten_set_socket_listen_callback.sig="vpp";var _emscripten_set_socket_connection_callback=(userData,callback)=>{_setNetworkCallback("connection",userData,callback)};_emscripten_set_socket_connection_callback.sig="vpp";var _emscripten_set_socket_message_callback=(userData,callback)=>{_setNetworkCallback("message",userData,callback)};_emscripten_set_socket_message_callback.sig="vpp";var _emscripten_set_socket_close_callback=(userData,callback)=>{_setNetworkCallback("close",userData,callback)};_emscripten_set_socket_close_callback.sig="vpp";var _emscripten_webgl_enable_ANGLE_instanced_arrays=ctx=>webgl_enable_ANGLE_instanced_arrays(GL.contexts[ctx].GLctx);_emscripten_webgl_enable_ANGLE_instanced_arrays.sig="ii";var _emscripten_webgl_enable_OES_vertex_array_object=ctx=>webgl_enable_OES_vertex_array_object(GL.contexts[ctx].GLctx);_emscripten_webgl_enable_OES_vertex_array_object.sig="ii";var _emscripten_webgl_enable_WEBGL_draw_buffers=ctx=>webgl_enable_WEBGL_draw_buffers(GL.contexts[ctx].GLctx);_emscripten_webgl_enable_WEBGL_draw_buffers.sig="ii";var _emscripten_webgl_enable_WEBGL_multi_draw=ctx=>webgl_enable_WEBGL_multi_draw(GL.contexts[ctx].GLctx);_emscripten_webgl_enable_WEBGL_multi_draw.sig="ii";var _glVertexPointer=(size,type,stride,ptr)=>{throw"Legacy GL function (glVertexPointer) called. If you want legacy GL emulation, you need to compile with -sLEGACY_GL_EMULATION to enable legacy GL emulation."};_glVertexPointer.sig="viiip";var _glMatrixMode=()=>{throw"Legacy GL function (glMatrixMode) called. If you want legacy GL emulation, you need to compile with -sLEGACY_GL_EMULATION to enable legacy GL emulation."};_glMatrixMode.sig="vi";var _glBegin=()=>{throw"Legacy GL function (glBegin) called. If you want legacy GL emulation, you need to compile with -sLEGACY_GL_EMULATION to enable legacy GL emulation."};_glBegin.sig="vi";var _glLoadIdentity=()=>{throw"Legacy GL function (glLoadIdentity) called. If you want legacy GL emulation, you need to compile with -sLEGACY_GL_EMULATION to enable legacy GL emulation."};_glLoadIdentity.sig="v";var _glVertexAttribDivisorNV=_glVertexAttribDivisor;var _glDrawArraysInstancedNV=_glDrawArraysInstanced;var _glDrawElementsInstancedNV=_glDrawElementsInstanced;var _glVertexAttribDivisorEXT=_glVertexAttribDivisor;var _glDrawArraysInstancedEXT=_glDrawArraysInstanced;var _glDrawElementsInstancedEXT=_glDrawElementsInstanced;var _glVertexAttribDivisorARB=_glVertexAttribDivisor;var _glDrawArraysInstancedARB=_glDrawArraysInstanced;var _glDrawElementsInstancedARB=_glDrawElementsInstanced;var _glDrawBuffersEXT=_glDrawBuffers;var _glMultiDrawArraysWEBGL=(mode,firsts,counts,drawcount)=>{GLctx.multiDrawWebgl["multiDrawArraysWEBGL"](mode,HEAP32,firsts>>2,HEAP32,counts>>2,drawcount)};_glMultiDrawArraysWEBGL.sig="vippi";var _glMultiDrawArrays=_glMultiDrawArraysWEBGL;_glMultiDrawArrays.sig="vippi";var _glMultiDrawArraysANGLE=_glMultiDrawArraysWEBGL;var _glMultiDrawArraysInstancedWEBGL=(mode,firsts,counts,instanceCounts,drawcount)=>{GLctx.multiDrawWebgl["multiDrawArraysInstancedWEBGL"](mode,HEAP32,firsts>>2,HEAP32,counts>>2,HEAP32,instanceCounts>>2,drawcount)};_glMultiDrawArraysInstancedWEBGL.sig="viiiii";var _glMultiDrawArraysInstancedANGLE=_glMultiDrawArraysInstancedWEBGL;var _glMultiDrawElementsWEBGL=(mode,counts,type,offsets,drawcount)=>{GLctx.multiDrawWebgl["multiDrawElementsWEBGL"](mode,HEAP32,counts>>2,type,HEAP32,offsets>>2,drawcount)};_glMultiDrawElementsWEBGL.sig="vipipi";var _glMultiDrawElements=_glMultiDrawElementsWEBGL;_glMultiDrawElements.sig="vipipi";var _glMultiDrawElementsANGLE=_glMultiDrawElementsWEBGL;var _glMultiDrawElementsInstancedWEBGL=(mode,counts,type,offsets,instanceCounts,drawcount)=>{GLctx.multiDrawWebgl["multiDrawElementsInstancedWEBGL"](mode,HEAP32,counts>>2,type,HEAP32,offsets>>2,HEAP32,instanceCounts>>2,drawcount)};_glMultiDrawElementsInstancedWEBGL.sig="viiiiii";var _glMultiDrawElementsInstancedANGLE=_glMultiDrawElementsInstancedWEBGL;function _glClearDepth(x0){GLctx.clearDepth(x0)}_glClearDepth.sig="vd";function _glDepthRange(x0,x1){GLctx.depthRange(x0,x1)}_glDepthRange.sig="vdd";var _emscripten_glGenVertexArrays=_glGenVertexArrays;var _emscripten_glDeleteVertexArrays=_glDeleteVertexArrays;var _emscripten_glBindVertexArray=_glBindVertexArray;var _emscripten_glIsVertexArray=_glIsVertexArray;var _emscripten_glVertexPointer=_glVertexPointer;var _emscripten_glMatrixMode=_glMatrixMode;var _emscripten_glBegin=_glBegin;var _emscripten_glLoadIdentity=_glLoadIdentity;var _emscripten_glVertexAttribDivisor=_glVertexAttribDivisor;var _emscripten_glDrawArraysInstanced=_glDrawArraysInstanced;var _emscripten_glDrawElementsInstanced=_glDrawElementsInstanced;var _emscripten_glVertexAttribDivisorNV=_glVertexAttribDivisorNV;var _emscripten_glDrawArraysInstancedNV=_glDrawArraysInstancedNV;var _emscripten_glDrawElementsInstancedNV=_glDrawElementsInstancedNV;var _emscripten_glVertexAttribDivisorEXT=_glVertexAttribDivisorEXT;var _emscripten_glDrawArraysInstancedEXT=_glDrawArraysInstancedEXT;var _emscripten_glDrawElementsInstancedEXT=_glDrawElementsInstancedEXT;var _emscripten_glVertexAttribDivisorARB=_glVertexAttribDivisorARB;var _emscripten_glDrawArraysInstancedARB=_glDrawArraysInstancedARB;var _emscripten_glDrawElementsInstancedARB=_glDrawElementsInstancedARB;var _emscripten_glDrawBuffers=_glDrawBuffers;var _emscripten_glDrawBuffersEXT=_glDrawBuffersEXT;var _emscripten_glMultiDrawArrays=_glMultiDrawArrays;var _emscripten_glMultiDrawArraysANGLE=_glMultiDrawArraysANGLE;var _emscripten_glMultiDrawArraysWEBGL=_glMultiDrawArraysWEBGL;var _emscripten_glMultiDrawArraysInstancedANGLE=_glMultiDrawArraysInstancedANGLE;var _emscripten_glMultiDrawArraysInstancedWEBGL=_glMultiDrawArraysInstancedWEBGL;var _emscripten_glMultiDrawElements=_glMultiDrawElements;var _emscripten_glMultiDrawElementsANGLE=_glMultiDrawElementsANGLE;var _emscripten_glMultiDrawElementsWEBGL=_glMultiDrawElementsWEBGL;var _emscripten_glMultiDrawElementsInstancedANGLE=_glMultiDrawElementsInstancedANGLE;var _emscripten_glMultiDrawElementsInstancedWEBGL=_glMultiDrawElementsInstancedWEBGL;var _emscripten_glClearDepth=_glClearDepth;var _emscripten_glDepthRange=_glDepthRange;var writeGLArray=(arr,dst,dstLength,heapType)=>{var len=arr.length;var writeLength=dstLength<len?dstLength:len;var heap=heapType?HEAPF32:HEAP32;for(var i=0;i<writeLength;++i){heap[(dst>>2)+i]=arr[i]}return len};var _emscripten_webgl_init_context_attributes=attributes=>{var a=attributes>>2;for(var i=0;i<56>>2;++i){HEAP32[a+i]=0}HEAP32[a+(0>>2)]=HEAP32[a+(4>>2)]=HEAP32[a+(12>>2)]=HEAP32[a+(16>>2)]=HEAP32[a+(32>>2)]=HEAP32[a+(40>>2)]=1};_emscripten_webgl_init_context_attributes.sig="vp";var emscripten_webgl_power_preferences=["default","low-power","high-performance"];var _emscripten_webgl_do_create_context=(target,attributes)=>{var a=attributes>>2;var powerPreference=HEAP32[a+(24>>2)];var contextAttributes={"alpha":!!HEAP32[a+(0>>2)],"depth":!!HEAP32[a+(4>>2)],"stencil":!!HEAP32[a+(8>>2)],"antialias":!!HEAP32[a+(12>>2)],"premultipliedAlpha":!!HEAP32[a+(16>>2)],"preserveDrawingBuffer":!!HEAP32[a+(20>>2)],"powerPreference":emscripten_webgl_power_preferences[powerPreference],"failIfMajorPerformanceCaveat":!!HEAP32[a+(28>>2)],majorVersion:HEAP32[a+(32>>2)],minorVersion:HEAP32[a+(36>>2)],enableExtensionsByDefault:HEAP32[a+(40>>2)],explicitSwapControl:HEAP32[a+(44>>2)],proxyContextToMainThread:HEAP32[a+(48>>2)],renderViaOffscreenBackBuffer:HEAP32[a+(52>>2)]};var canvas=findCanvasEventTarget(target);if(!canvas){return 0}if(contextAttributes.explicitSwapControl){return 0}var contextHandle=GL.createContext(canvas,contextAttributes);return contextHandle};_emscripten_webgl_do_create_context.sig="ipp";var _emscripten_webgl_create_context=_emscripten_webgl_do_create_context;_emscripten_webgl_create_context.sig="ipp";var _emscripten_webgl_do_get_current_context=()=>GL.currentContext?GL.currentContext.handle:0;_emscripten_webgl_do_get_current_context.sig="i";var _emscripten_webgl_get_current_context=_emscripten_webgl_do_get_current_context;_emscripten_webgl_get_current_context.sig="i";var _emscripten_webgl_do_commit_frame=()=>{if(!GL.currentContext||!GL.currentContext.GLctx){return-3}if(!GL.currentContext.attributes.explicitSwapControl){return-3}return 0};_emscripten_webgl_do_commit_frame.sig="i";var _emscripten_webgl_commit_frame=_emscripten_webgl_do_commit_frame;_emscripten_webgl_commit_frame.sig="i";var _emscripten_webgl_make_context_current=contextHandle=>{var success=GL.makeContextCurrent(contextHandle);return success?0:-5};_emscripten_webgl_make_context_current.sig="ii";var _emscripten_webgl_get_drawing_buffer_size=(contextHandle,width,height)=>{var GLContext=GL.getContext(contextHandle);if(!GLContext||!GLContext.GLctx||!width||!height){return-5}HEAP32[width>>2]=GLContext.GLctx.drawingBufferWidth;HEAP32[height>>2]=GLContext.GLctx.drawingBufferHeight;return 0};_emscripten_webgl_get_drawing_buffer_size.sig="iipp";var _emscripten_webgl_get_context_attributes=(c,a)=>{if(!a)return-5;c=GL.contexts[c];if(!c)return-3;var t=c.GLctx;if(!t)return-3;t=t.getContextAttributes();HEAP32[a>>2]=t.alpha;HEAP32[a+4>>2]=t.depth;HEAP32[a+8>>2]=t.stencil;HEAP32[a+12>>2]=t.antialias;HEAP32[a+16>>2]=t.premultipliedAlpha;HEAP32[a+20>>2]=t.preserveDrawingBuffer;var power=t["powerPreference"]&&emscripten_webgl_power_preferences.indexOf(t["powerPreference"]);HEAP32[a+24>>2]=power;HEAP32[a+28>>2]=t.failIfMajorPerformanceCaveat;HEAP32[a+32>>2]=c.version;HEAP32[a+36>>2]=0;HEAP32[a+40>>2]=c.attributes.enableExtensionsByDefault;return 0};_emscripten_webgl_get_context_attributes.sig="iip";var _emscripten_webgl_destroy_context=contextHandle=>{if(GL.currentContext==contextHandle)GL.currentContext=0;GL.deleteContext(contextHandle)};_emscripten_webgl_destroy_context.sig="ii";var _emscripten_webgl_enable_extension=(contextHandle,extension)=>{var context=GL.getContext(contextHandle);var extString=UTF8ToString(extension);if(extString.startsWith("GL_"))extString=extString.substr(3);if(extString=="ANGLE_instanced_arrays")webgl_enable_ANGLE_instanced_arrays(GLctx);if(extString=="OES_vertex_array_object")webgl_enable_OES_vertex_array_object(GLctx);if(extString=="WEBGL_draw_buffers")webgl_enable_WEBGL_draw_buffers(GLctx);if(extString=="WEBGL_multi_draw")webgl_enable_WEBGL_multi_draw(GLctx);var ext=context.GLctx.getExtension(extString);return!!ext};_emscripten_webgl_enable_extension.sig="iip";var _emscripten_supports_offscreencanvas=()=>0;_emscripten_supports_offscreencanvas.sig="i";var registerWebGlEventCallback=(target,userData,useCapture,callbackfunc,eventTypeId,eventTypeString,targetThread)=>{var webGlEventHandlerFunc=(e=event)=>{if(getWasmTableEntry(callbackfunc)(eventTypeId,0,userData))e.preventDefault()};var eventHandler={target:findEventTarget(target),eventTypeString:eventTypeString,callbackfunc:callbackfunc,handlerFunc:webGlEventHandlerFunc,useCapture:useCapture};JSEvents.registerOrRemoveHandler(eventHandler)};var _emscripten_set_webglcontextlost_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>{registerWebGlEventCallback(target,userData,useCapture,callbackfunc,31,"webglcontextlost",targetThread);return 0};_emscripten_set_webglcontextlost_callback_on_thread.sig="ippipp";var _emscripten_set_webglcontextrestored_callback_on_thread=(target,userData,useCapture,callbackfunc,targetThread)=>{registerWebGlEventCallback(target,userData,useCapture,callbackfunc,32,"webglcontextrestored",targetThread);return 0};_emscripten_set_webglcontextrestored_callback_on_thread.sig="ippipp";var _emscripten_is_webgl_context_lost=contextHandle=>!GL.contexts[contextHandle]||GL.contexts[contextHandle].GLctx.isContextLost();_emscripten_is_webgl_context_lost.sig="ii";var _emscripten_webgl_get_supported_extensions=()=>stringToNewUTF8(GLctx.getSupportedExtensions().join(" "));_emscripten_webgl_get_supported_extensions.sig="p";var _emscripten_webgl_get_program_parameter_d=(program,param)=>GLctx.getProgramParameter(GL.programs[program],param);_emscripten_webgl_get_program_parameter_d.sig="dii";var _emscripten_webgl_get_program_info_log_utf8=program=>stringToNewUTF8(GLctx.getProgramInfoLog(GL.programs[program]));_emscripten_webgl_get_program_info_log_utf8.sig="pi";var _emscripten_webgl_get_shader_parameter_d=(shader,param)=>GLctx.getShaderParameter(GL.shaders[shader],param);_emscripten_webgl_get_shader_parameter_d.sig="dii";var _emscripten_webgl_get_shader_info_log_utf8=shader=>stringToNewUTF8(GLctx.getShaderInfoLog(GL.shaders[shader]));_emscripten_webgl_get_shader_info_log_utf8.sig="pi";var _emscripten_webgl_get_shader_source_utf8=shader=>stringToNewUTF8(GLctx.getShaderSource(GL.shaders[shader]));_emscripten_webgl_get_shader_source_utf8.sig="pi";var _emscripten_webgl_get_vertex_attrib_d=(index,param)=>GLctx.getVertexAttrib(index,param);_emscripten_webgl_get_vertex_attrib_d.sig="dii";var _emscripten_webgl_get_vertex_attrib_o=(index,param)=>{var obj=GLctx.getVertexAttrib(index,param);return obj&&obj.name};_emscripten_webgl_get_vertex_attrib_o.sig="iii";var _emscripten_webgl_get_vertex_attrib_v=(index,param,dst,dstLength,dstType)=>writeGLArray(GLctx.getVertexAttrib(index,param),dst,dstLength,dstType);_emscripten_webgl_get_vertex_attrib_v.sig="iiipii";var _emscripten_webgl_get_uniform_d=(program,location)=>GLctx.getUniform(GL.programs[program],webglGetUniformLocation(location));_emscripten_webgl_get_uniform_d.sig="dii";var _emscripten_webgl_get_uniform_v=(program,location,dst,dstLength,dstType)=>writeGLArray(GLctx.getUniform(GL.programs[program],webglGetUniformLocation(location)),dst,dstLength,dstType);_emscripten_webgl_get_uniform_v.sig="iiipii";var _emscripten_webgl_get_parameter_v=(param,dst,dstLength,dstType)=>writeGLArray(GLctx.getParameter(param),dst,dstLength,dstType);_emscripten_webgl_get_parameter_v.sig="iipii";var _emscripten_webgl_get_parameter_d=param=>GLctx.getParameter(param);_emscripten_webgl_get_parameter_d.sig="di";var _emscripten_webgl_get_parameter_o=param=>{var obj=GLctx.getParameter(param);return obj&&obj.name};_emscripten_webgl_get_parameter_o.sig="ii";var _emscripten_webgl_get_parameter_utf8=param=>stringToNewUTF8(GLctx.getParameter(param));_emscripten_webgl_get_parameter_utf8.sig="pi";var _emscripten_webgl_get_parameter_i64v=(param,dst)=>writeI53ToI64(dst,GLctx.getParameter(param));_emscripten_webgl_get_parameter_i64v.sig="vip";var _glutPostRedisplay=()=>{if(GLUT.displayFunc&&!GLUT.requestedAnimationFrame){GLUT.requestedAnimationFrame=true;Browser.requestAnimationFrame(function(){GLUT.requestedAnimationFrame=false;Browser.mainLoop.runIter(function(){getWasmTableEntry(GLUT.displayFunc)()})})}};_glutPostRedisplay.sig="v";var GLUT={initTime:null,idleFunc:null,displayFunc:null,keyboardFunc:null,keyboardUpFunc:null,specialFunc:null,specialUpFunc:null,reshapeFunc:null,motionFunc:null,passiveMotionFunc:null,mouseFunc:null,buttons:0,modifiers:0,initWindowWidth:256,initWindowHeight:256,initDisplayMode:18,windowX:0,windowY:0,windowWidth:0,windowHeight:0,requestedAnimationFrame:false,saveModifiers:event=>{GLUT.modifiers=0;if(event["shiftKey"])GLUT.modifiers+=1;if(event["ctrlKey"])GLUT.modifiers+=2;if(event["altKey"])GLUT.modifiers+=4},onMousemove:event=>{var lastX=Browser.mouseX;var lastY=Browser.mouseY;Browser.calculateMouseEvent(event);var newX=Browser.mouseX;var newY=Browser.mouseY;if(newX==lastX&&newY==lastY)return;if(GLUT.buttons==0&&event.target==Module["canvas"]&&GLUT.passiveMotionFunc){event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.passiveMotionFunc)(lastX,lastY)}else if(GLUT.buttons!=0&&GLUT.motionFunc){event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.motionFunc)(lastX,lastY)}},getSpecialKey:keycode=>{var key=null;switch(keycode){case 8:key=120;break;case 46:key=111;break;case 112:key=1;break;case 113:key=2;break;case 114:key=3;break;case 115:key=4;break;case 116:key=5;break;case 117:key=6;break;case 118:key=7;break;case 119:key=8;break;case 120:key=9;break;case 121:key=10;break;case 122:key=11;break;case 123:key=12;break;case 37:key=100;break;case 38:key=101;break;case 39:key=102;break;case 40:key=103;break;case 33:key=104;break;case 34:key=105;break;case 36:key=106;break;case 35:key=107;break;case 45:key=108;break;case 16:case 5:key=112;break;case 6:key=113;break;case 17:case 3:key=114;break;case 4:key=115;break;case 18:case 2:key=116;break;case 1:key=117;break}return key},getASCIIKey:event=>{if(event["ctrlKey"]||event["altKey"]||event["metaKey"])return null;var keycode=event["keyCode"];if(48<=keycode&&keycode<=57)return keycode;if(65<=keycode&&keycode<=90)return event["shiftKey"]?keycode:keycode+32;if(96<=keycode&&keycode<=105)return keycode-48;if(106<=keycode&&keycode<=111)return keycode-106+42;switch(keycode){case 9:case 13:case 27:case 32:case 61:return keycode}var s=event["shiftKey"];switch(keycode){case 186:return s?58:59;case 187:return s?43:61;case 188:return s?60:44;case 189:return s?95:45;case 190:return s?62:46;case 191:return s?63:47;case 219:return s?123:91;case 220:return s?124:47;case 221:return s?125:93;case 222:return s?34:39}return null},onKeydown:event=>{if(GLUT.specialFunc||GLUT.keyboardFunc){var key=GLUT.getSpecialKey(event["keyCode"]);if(key!==null){if(GLUT.specialFunc){event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.specialFunc)(key,Browser.mouseX,Browser.mouseY)}}else{key=GLUT.getASCIIKey(event);if(key!==null&&GLUT.keyboardFunc){event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.keyboardFunc)(key,Browser.mouseX,Browser.mouseY)}}}},onKeyup:event=>{if(GLUT.specialUpFunc||GLUT.keyboardUpFunc){var key=GLUT.getSpecialKey(event["keyCode"]);if(key!==null){if(GLUT.specialUpFunc){event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.specialUpFunc)(key,Browser.mouseX,Browser.mouseY)}}else{key=GLUT.getASCIIKey(event);if(key!==null&&GLUT.keyboardUpFunc){event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.keyboardUpFunc)(key,Browser.mouseX,Browser.mouseY)}}}},touchHandler:event=>{if(event.target!=Module["canvas"]){return}var touches=event.changedTouches,main=touches[0],type="";switch(event.type){case"touchstart":type="mousedown";break;case"touchmove":type="mousemove";break;case"touchend":type="mouseup";break;default:return}var simulatedEvent=document.createEvent("MouseEvent");simulatedEvent.initMouseEvent(type,true,true,window,1,main.screenX,main.screenY,main.clientX,main.clientY,false,false,false,false,0,null);main.target.dispatchEvent(simulatedEvent);event.preventDefault()},onMouseButtonDown:event=>{Browser.calculateMouseEvent(event);GLUT.buttons|=1<<event["button"];if(event.target==Module["canvas"]&&GLUT.mouseFunc){try{event.target.setCapture()}catch(e){}event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.mouseFunc)(event["button"],0,Browser.mouseX,Browser.mouseY)}},onMouseButtonUp:event=>{Browser.calculateMouseEvent(event);GLUT.buttons&=~(1<<event["button"]);if(GLUT.mouseFunc){event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.mouseFunc)(event["button"],1,Browser.mouseX,Browser.mouseY)}},onMouseWheel:event=>{Browser.calculateMouseEvent(event);var e=window.event||event;var delta=-Browser.getMouseWheelDelta(event);delta=delta==0?0:delta>0?Math.max(delta,1):Math.min(delta,-1);var button=3;if(delta<0){button=4}if(GLUT.mouseFunc){event.preventDefault();GLUT.saveModifiers(event);getWasmTableEntry(GLUT.mouseFunc)(button,0,Browser.mouseX,Browser.mouseY)}},onFullscreenEventChange:event=>{var width;var height;if(document["fullscreen"]||document["fullScreen"]||document["mozFullScreen"]||document["webkitIsFullScreen"]){width=screen["width"];height=screen["height"]}else{width=GLUT.windowWidth;height=GLUT.windowHeight;document.removeEventListener("fullscreenchange",GLUT.onFullscreenEventChange,true);document.removeEventListener("mozfullscreenchange",GLUT.onFullscreenEventChange,true);document.removeEventListener("webkitfullscreenchange",GLUT.onFullscreenEventChange,true)}Browser.setCanvasSize(width,height,true);if(GLUT.reshapeFunc){getWasmTableEntry(GLUT.reshapeFunc)(width,height)}_glutPostRedisplay()}};var _glutGetModifiers=()=>GLUT.modifiers;_glutGetModifiers.sig="i";var _glutInit=(argcp,argv)=>{GLUT.initTime=Date.now();var isTouchDevice="ontouchstart"in document.documentElement;if(isTouchDevice){window.addEventListener("touchmove",GLUT.touchHandler,true);window.addEventListener("touchstart",GLUT.touchHandler,true);window.addEventListener("touchend",GLUT.touchHandler,true)}window.addEventListener("keydown",GLUT.onKeydown,true);window.addEventListener("keyup",GLUT.onKeyup,true);window.addEventListener("mousemove",GLUT.onMousemove,true);window.addEventListener("mousedown",GLUT.onMouseButtonDown,true);window.addEventListener("mouseup",GLUT.onMouseButtonUp,true);window.addEventListener("mousewheel",GLUT.onMouseWheel,true);window.addEventListener("DOMMouseScroll",GLUT.onMouseWheel,true);Browser.resizeListeners.push(function(width,height){if(GLUT.reshapeFunc){getWasmTableEntry(GLUT.reshapeFunc)(width,height)}});__ATEXIT__.push(function(){if(isTouchDevice){window.removeEventListener("touchmove",GLUT.touchHandler,true);window.removeEventListener("touchstart",GLUT.touchHandler,true);window.removeEventListener("touchend",GLUT.touchHandler,true)}window.removeEventListener("keydown",GLUT.onKeydown,true);window.removeEventListener("keyup",GLUT.onKeyup,true);window.removeEventListener("mousemove",GLUT.onMousemove,true);window.removeEventListener("mousedown",GLUT.onMouseButtonDown,true);window.removeEventListener("mouseup",GLUT.onMouseButtonUp,true);window.removeEventListener("mousewheel",GLUT.onMouseWheel,true);window.removeEventListener("DOMMouseScroll",GLUT.onMouseWheel,true);Module["canvas"].width=Module["canvas"].height=1})};_glutInit.sig="vpp";var _glutInitWindowSize=(width,height)=>{Browser.setCanvasSize(GLUT.initWindowWidth=width,GLUT.initWindowHeight=height)};_glutInitWindowSize.sig="vii";var _glutInitWindowPosition=(x,y)=>{};_glutInitWindowPosition.sig="vii";var _glutGet=type=>{switch(type){case 100:return 0;case 101:return 0;case 102:return Module["canvas"].width;case 103:return Module["canvas"].height;case 200:return Module["canvas"].width;case 201:return Module["canvas"].height;case 500:return 0;case 501:return 0;case 502:return GLUT.initWindowWidth;case 503:return GLUT.initWindowHeight;case 700:var now=Date.now();return now-GLUT.initTime;case 105:return Module.ctx.getContextAttributes().stencil?8:0;case 106:return Module.ctx.getContextAttributes().depth?8:0;case 110:return Module.ctx.getContextAttributes().alpha?8:0;case 120:return Module.ctx.getContextAttributes().antialias?1:0;default:throw"glutGet("+type+") not implemented yet"}};_glutGet.sig="ii";var _glutIdleFunc=func=>{function callback(){if(GLUT.idleFunc){getWasmTableEntry(GLUT.idleFunc)();safeSetTimeout(callback,4)}}if(!GLUT.idleFunc){safeSetTimeout(callback,0)}GLUT.idleFunc=func};_glutIdleFunc.sig="vp";var _glutTimerFunc=(msec,func,value)=>safeSetTimeout(()=>getWasmTableEntry(func)(value),msec);_glutTimerFunc.sig="vipi";var _glutDisplayFunc=func=>{GLUT.displayFunc=func};_glutDisplayFunc.sig="vp";var _glutKeyboardFunc=func=>{GLUT.keyboardFunc=func};_glutKeyboardFunc.sig="vp";var _glutKeyboardUpFunc=func=>{GLUT.keyboardUpFunc=func};_glutKeyboardUpFunc.sig="vp";var _glutSpecialFunc=func=>{GLUT.specialFunc=func};_glutSpecialFunc.sig="vp";var _glutSpecialUpFunc=func=>{GLUT.specialUpFunc=func};_glutSpecialUpFunc.sig="vp";var _glutReshapeFunc=func=>{GLUT.reshapeFunc=func};_glutReshapeFunc.sig="vp";var _glutMotionFunc=func=>{GLUT.motionFunc=func};_glutMotionFunc.sig="vp";var _glutPassiveMotionFunc=func=>{GLUT.passiveMotionFunc=func};_glutPassiveMotionFunc.sig="vp";var _glutMouseFunc=func=>{GLUT.mouseFunc=func};_glutMouseFunc.sig="vp";var _glutSetCursor=cursor=>{var cursorStyle="auto";switch(cursor){case 0:break;case 1:break;case 2:cursorStyle="pointer";break;case 3:break;case 4:cursorStyle="help";break;case 5:break;case 6:break;case 7:cursorStyle="wait";break;case 8:cursorStyle="text";break;case 9:case 102:cursorStyle="crosshair";break;case 10:cursorStyle="ns-resize";break;case 11:cursorStyle="ew-resize";break;case 12:cursorStyle="n-resize";break;case 13:cursorStyle="s-resize";break;case 14:cursorStyle="w-resize";break;case 15:cursorStyle="e-resize";break;case 16:cursorStyle="nw-resize";break;case 17:cursorStyle="ne-resize";break;case 18:cursorStyle="se-resize";break;case 19:cursorStyle="sw-resize";break;case 100:break;case 101:cursorStyle="none";break;default:throw"glutSetCursor: Unknown cursor type: "+cursor}Module["canvas"].style.cursor=cursorStyle};_glutSetCursor.sig="vi";var _glutCreateWindow=name=>{var contextAttributes={antialias:(GLUT.initDisplayMode&128)!=0,depth:(GLUT.initDisplayMode&16)!=0,stencil:(GLUT.initDisplayMode&32)!=0,alpha:(GLUT.initDisplayMode&8)!=0};Module.ctx=Browser.createContext(Module["canvas"],true,true,contextAttributes);return Module.ctx?1:0};_glutCreateWindow.sig="ip";var _glutDestroyWindow=name=>{Module.ctx=Browser.destroyContext(Module["canvas"],true,true);return 1};_glutDestroyWindow.sig="vi";var _glutReshapeWindow=(width,height)=>{Browser.exitFullscreen();Browser.setCanvasSize(width,height,true);if(GLUT.reshapeFunc){getWasmTableEntry(GLUT.reshapeFunc)(width,height)}_glutPostRedisplay()};_glutReshapeWindow.sig="vii";var _glutPositionWindow=(x,y)=>{Browser.exitFullscreen();_glutPostRedisplay()};_glutPositionWindow.sig="vii";var _glutFullScreen=()=>{GLUT.windowX=0;GLUT.windowY=0;GLUT.windowWidth=Module["canvas"].width;GLUT.windowHeight=Module["canvas"].height;document.addEventListener("fullscreenchange",GLUT.onFullscreenEventChange,true);document.addEventListener("mozfullscreenchange",GLUT.onFullscreenEventChange,true);document.addEventListener("webkitfullscreenchange",GLUT.onFullscreenEventChange,true);Browser.requestFullscreen(false,false)};_glutFullScreen.sig="v";var _glutInitDisplayMode=mode=>GLUT.initDisplayMode=mode;_glutInitDisplayMode.sig="vi";var _glutSwapBuffers=()=>{};_glutSwapBuffers.sig="v";var _glutMainLoop=()=>{_glutReshapeWindow(Module["canvas"].width,Module["canvas"].height);_glutPostRedisplay();throw"unwind"};_glutMainLoop.sig="v";var _XOpenDisplay=name=>1;_XOpenDisplay.sig="pp";var _XCreateWindow=(display,parent,x,y,width,height,border_width,depth,class_,visual,valuemask,attributes)=>{Browser.setCanvasSize(width,height);return 2};_XCreateWindow.sig="pppiiiiiiippp";var _XChangeWindowAttributes=(display,window,valuemask,attributes)=>{};_XChangeWindowAttributes.sig="ipppp";var _XSetWMHints=(display,win,hints)=>{};_XSetWMHints.sig="ippp";var _XMapWindow=(display,win)=>{};_XMapWindow.sig="ipp";var _XStoreName=(display,win,name)=>{};_XStoreName.sig="ippp";var _XInternAtom=(display,name_,hmm)=>0;_XInternAtom.sig="pppi";var _XSendEvent=(display,win,propagate,event_mask,even_send)=>{};_XSendEvent.sig="ippipp";var _XPending=display=>0;_XPending.sig="ip";var EGL={errorCode:12288,defaultDisplayInitialized:false,currentContext:0,currentReadSurface:0,currentDrawSurface:0,contextAttributes:{alpha:false,depth:false,stencil:false,antialias:false},stringCache:{},setErrorCode(code){EGL.errorCode=code},chooseConfig(display,attribList,config,config_size,numConfigs){if(display!=62e3){EGL.setErrorCode(12296);return 0}if(attribList){for(;;){var param=HEAP32[attribList>>2];if(param==12321){var alphaSize=HEAP32[attribList+4>>2];EGL.contextAttributes.alpha=alphaSize>0}else if(param==12325){var depthSize=HEAP32[attribList+4>>2];EGL.contextAttributes.depth=depthSize>0}else if(param==12326){var stencilSize=HEAP32[attribList+4>>2];EGL.contextAttributes.stencil=stencilSize>0}else if(param==12337){var samples=HEAP32[attribList+4>>2];EGL.contextAttributes.antialias=samples>0}else if(param==12338){var samples=HEAP32[attribList+4>>2];EGL.contextAttributes.antialias=samples==1}else if(param==12544){var requestedPriority=HEAP32[attribList+4>>2];EGL.contextAttributes.lowLatency=requestedPriority!=12547}else if(param==12344){break}attribList+=8}}if((!config||!config_size)&&!numConfigs){EGL.setErrorCode(12300);return 0}if(numConfigs){HEAP32[numConfigs>>2]=1}if(config&&config_size>0){HEAPU32[config>>2]=62002}EGL.setErrorCode(12288);return 1}};var _eglGetDisplay=nativeDisplayType=>{EGL.setErrorCode(12288);return 62e3};_eglGetDisplay.sig="pi";var _eglInitialize=(display,majorVersion,minorVersion)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(majorVersion){HEAP32[majorVersion>>2]=1}if(minorVersion){HEAP32[minorVersion>>2]=4}EGL.defaultDisplayInitialized=true;EGL.setErrorCode(12288);return 1};_eglInitialize.sig="ippp";var _eglTerminate=display=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}EGL.currentContext=0;EGL.currentReadSurface=0;EGL.currentDrawSurface=0;EGL.defaultDisplayInitialized=false;EGL.setErrorCode(12288);return 1};_eglTerminate.sig="ip";var _eglGetConfigs=(display,configs,config_size,numConfigs)=>EGL.chooseConfig(display,0,configs,config_size,numConfigs);_eglGetConfigs.sig="ippip";var _eglChooseConfig=(display,attrib_list,configs,config_size,numConfigs)=>EGL.chooseConfig(display,attrib_list,configs,config_size,numConfigs);_eglChooseConfig.sig="ipppip";var _eglGetConfigAttrib=(display,config,attribute,value)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(config!=62002){EGL.setErrorCode(12293);return 0}if(!value){EGL.setErrorCode(12300);return 0}EGL.setErrorCode(12288);switch(attribute){case 12320:HEAP32[value>>2]=EGL.contextAttributes.alpha?32:24;return 1;case 12321:HEAP32[value>>2]=EGL.contextAttributes.alpha?8:0;return 1;case 12322:HEAP32[value>>2]=8;return 1;case 12323:HEAP32[value>>2]=8;return 1;case 12324:HEAP32[value>>2]=8;return 1;case 12325:HEAP32[value>>2]=EGL.contextAttributes.depth?24:0;return 1;case 12326:HEAP32[value>>2]=EGL.contextAttributes.stencil?8:0;return 1;case 12327:HEAP32[value>>2]=12344;return 1;case 12328:HEAP32[value>>2]=62002;return 1;case 12329:HEAP32[value>>2]=0;return 1;case 12330:HEAP32[value>>2]=4096;return 1;case 12331:HEAP32[value>>2]=16777216;return 1;case 12332:HEAP32[value>>2]=4096;return 1;case 12333:HEAP32[value>>2]=0;return 1;case 12334:HEAP32[value>>2]=0;return 1;case 12335:HEAP32[value>>2]=12344;return 1;case 12337:HEAP32[value>>2]=EGL.contextAttributes.antialias?4:0;return 1;case 12338:HEAP32[value>>2]=EGL.contextAttributes.antialias?1:0;return 1;case 12339:HEAP32[value>>2]=4;return 1;case 12340:HEAP32[value>>2]=12344;return 1;case 12341:case 12342:case 12343:HEAP32[value>>2]=-1;return 1;case 12345:case 12346:HEAP32[value>>2]=0;return 1;case 12347:HEAP32[value>>2]=0;return 1;case 12348:HEAP32[value>>2]=1;return 1;case 12349:case 12350:HEAP32[value>>2]=0;return 1;case 12351:HEAP32[value>>2]=12430;return 1;case 12352:HEAP32[value>>2]=4;return 1;case 12354:HEAP32[value>>2]=0;return 1;default:EGL.setErrorCode(12292);return 0}};_eglGetConfigAttrib.sig="ippip";var _eglCreateWindowSurface=(display,config,win,attrib_list)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(config!=62002){EGL.setErrorCode(12293);return 0}EGL.setErrorCode(12288);return 62006};_eglCreateWindowSurface.sig="pppip";var _eglDestroySurface=(display,surface)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(surface!=62006){EGL.setErrorCode(12301);return 1}if(EGL.currentReadSurface==surface){EGL.currentReadSurface=0}if(EGL.currentDrawSurface==surface){EGL.currentDrawSurface=0}EGL.setErrorCode(12288);return 1};_eglDestroySurface.sig="ipp";var _eglCreateContext=(display,config,hmm,contextAttribs)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}var glesContextVersion=1;for(;;){var param=HEAP32[contextAttribs>>2];if(param==12440){glesContextVersion=HEAP32[contextAttribs+4>>2]}else if(param==12344){break}else{EGL.setErrorCode(12292);return 0}contextAttribs+=8}if(glesContextVersion!=2){EGL.setErrorCode(12293);return 0}EGL.contextAttributes.majorVersion=glesContextVersion-1;EGL.contextAttributes.minorVersion=0;EGL.context=GL.createContext(Module["canvas"],EGL.contextAttributes);if(EGL.context!=0){EGL.setErrorCode(12288);GL.makeContextCurrent(EGL.context);Module.useWebGL=true;Browser.moduleContextCreatedCallbacks.forEach(function(callback){callback()});GL.makeContextCurrent(null);return 62004}else{EGL.setErrorCode(12297);return 0}};_eglCreateContext.sig="ppppp";var _eglDestroyContext=(display,context)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(context!=62004){EGL.setErrorCode(12294);return 0}GL.deleteContext(EGL.context);EGL.setErrorCode(12288);if(EGL.currentContext==context){EGL.currentContext=0}return 1};_eglDestroyContext.sig="ipp";var _eglQuerySurface=(display,surface,attribute,value)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(surface!=62006){EGL.setErrorCode(12301);return 0}if(!value){EGL.setErrorCode(12300);return 0}EGL.setErrorCode(12288);switch(attribute){case 12328:HEAP32[value>>2]=62002;return 1;case 12376:return 1;case 12375:HEAP32[value>>2]=Module["canvas"].width;return 1;case 12374:HEAP32[value>>2]=Module["canvas"].height;return 1;case 12432:HEAP32[value>>2]=-1;return 1;case 12433:HEAP32[value>>2]=-1;return 1;case 12434:HEAP32[value>>2]=-1;return 1;case 12422:HEAP32[value>>2]=12420;return 1;case 12441:HEAP32[value>>2]=12442;return 1;case 12435:HEAP32[value>>2]=12437;return 1;case 12416:case 12417:case 12418:case 12419:return 1;default:EGL.setErrorCode(12292);return 0}};_eglQuerySurface.sig="ippip";var _eglQueryContext=(display,context,attribute,value)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(context!=62004){EGL.setErrorCode(12294);return 0}if(!value){EGL.setErrorCode(12300);return 0}EGL.setErrorCode(12288);switch(attribute){case 12328:HEAP32[value>>2]=62002;return 1;case 12439:HEAP32[value>>2]=12448;return 1;case 12440:HEAP32[value>>2]=EGL.contextAttributes.majorVersion+1;return 1;case 12422:HEAP32[value>>2]=12420;return 1;default:EGL.setErrorCode(12292);return 0}};_eglQueryContext.sig="ippip";var _eglGetError=()=>EGL.errorCode;_eglGetError.sig="i";var _eglQueryString=(display,name)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}EGL.setErrorCode(12288);if(EGL.stringCache[name])return EGL.stringCache[name];var ret;switch(name){case 12371:ret=stringToNewUTF8("Emscripten");break;case 12372:ret=stringToNewUTF8("1.4 Emscripten EGL");break;case 12373:ret=stringToNewUTF8("");break;case 12429:ret=stringToNewUTF8("OpenGL_ES");break;default:EGL.setErrorCode(12300);return 0}EGL.stringCache[name]=ret;return ret};_eglQueryString.sig="ppi";var _eglBindAPI=api=>{if(api==12448){EGL.setErrorCode(12288);return 1}EGL.setErrorCode(12300);return 0};_eglBindAPI.sig="ii";var _eglQueryAPI=()=>{EGL.setErrorCode(12288);return 12448};_eglQueryAPI.sig="i";var _eglWaitClient=()=>{EGL.setErrorCode(12288);return 1};_eglWaitClient.sig="i";var _eglWaitNative=nativeEngineId=>{EGL.setErrorCode(12288);return 1};_eglWaitNative.sig="ii";var _eglWaitGL=_eglWaitClient;_eglWaitGL.sig="i";var _eglSwapInterval=(display,interval)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(interval==0)_emscripten_set_main_loop_timing(0,0);else _emscripten_set_main_loop_timing(1,interval);EGL.setErrorCode(12288);return 1};_eglSwapInterval.sig="ipi";var _eglMakeCurrent=(display,draw,read,context)=>{if(display!=62e3){EGL.setErrorCode(12296);return 0}if(context!=0&&context!=62004){EGL.setErrorCode(12294);return 0}if(read!=0&&read!=62006||draw!=0&&draw!=62006){EGL.setErrorCode(12301);return 0}GL.makeContextCurrent(context?EGL.context:null);EGL.currentContext=context;EGL.currentDrawSurface=draw;EGL.currentReadSurface=read;EGL.setErrorCode(12288);return 1};_eglMakeCurrent.sig="ipppp";var _eglGetCurrentContext=()=>EGL.currentContext;_eglGetCurrentContext.sig="p";var _eglGetCurrentSurface=readdraw=>{if(readdraw==12378){return EGL.currentReadSurface}else if(readdraw==12377){return EGL.currentDrawSurface}else{EGL.setErrorCode(12300);return 0}};_eglGetCurrentSurface.sig="pi";var _eglGetCurrentDisplay=()=>EGL.currentContext?62e3:0;_eglGetCurrentDisplay.sig="p";var _eglSwapBuffers=(dpy,surface)=>{if(!EGL.defaultDisplayInitialized){EGL.setErrorCode(12289)}else if(!Module.ctx){EGL.setErrorCode(12290)}else if(Module.ctx.isContextLost()){EGL.setErrorCode(12302)}else{EGL.setErrorCode(12288);return 1}return 0};_eglSwapBuffers.sig="ipp";var _eglReleaseThread=()=>{EGL.currentContext=0;EGL.currentReadSurface=0;EGL.currentDrawSurface=0;EGL.setErrorCode(12288);return 1};_eglReleaseThread.sig="i";var _uuid_clear=uu=>zeroMemory(uu,16);_uuid_clear.sig="vp";var _uuid_compare=(uu1,uu2)=>_memcmp(uu1,uu2,16);_uuid_compare.sig="ipp";var _uuid_copy=(dst,src)=>_memcpy(dst,src,16);_uuid_copy.sig="vpp";var _uuid_generate=out=>{var uuid=null;if(ENVIRONMENT_IS_NODE){try{var rb=require("crypto")["randomBytes"];uuid=rb(16)}catch(e){}}else if(ENVIRONMENT_IS_WEB&&typeof window.crypto!="undefined"&&typeof window.crypto.getRandomValues!="undefined"){uuid=new Uint8Array(16);window.crypto.getRandomValues(uuid)}if(!uuid){uuid=new Array(16);var d=(new Date).getTime();for(var i=0;i<16;i++){var r=(d+Math.random()*256)%256|0;d=d/256|0;uuid[i]=r}}uuid[6]=uuid[6]&15|64;uuid[8]=uuid[8]&63|128;writeArrayToMemory(uuid,out)};_uuid_generate.sig="vp";var _uuid_is_null=uu=>{for(var i=0;i<4;i++,uu=uu+4|0){var val=HEAP32[uu>>2];if(val){return 0}}return 1};_uuid_is_null.sig="ip";var _uuid_parse=(inp,uu)=>{inp=UTF8ToString(inp);if(inp.length===36){var i=0;var uuid=new Array(16);inp.toLowerCase().replace(/[0-9a-f]{2}/g,function(byte){if(i<16){uuid[i++]=parseInt(byte,16)}});if(i<16){return-1}writeArrayToMemory(uuid,uu);return 0}return-1};_uuid_parse.sig="ipp";var _uuid_unparse=(uu,out,upper)=>{var i=0;var uuid="xxxx-xx-xx-xx-xxxxxx".replace(/[x]/g,function(c){var r=upper?HEAPU8[uu+i>>0].toString(16).toUpperCase():HEAPU8[uu+i>>0].toString(16);r=r.length===1?"0"+r:r;i++;return r});stringToUTF8(uuid,out,37)};_uuid_unparse.sig="vpp";var _uuid_unparse_lower=(uu,out)=>{_uuid_unparse(uu,out)};_uuid_unparse_lower.sig="vpp";var _uuid_unparse_upper=(uu,out)=>{_uuid_unparse(uu,out,true)};_uuid_unparse_upper.sig="vpp";var _uuid_type=uu=>4;_uuid_type.sig="ip";var _uuid_variant=uu=>1;_uuid_variant.sig="ip";var GLEW={isLinaroFork:1,extensions:null,error:{0:null,1:null,2:null,3:null,4:null,5:null,6:null,7:null,8:null},version:{1:null,2:null,3:null,4:null},errorStringConstantFromCode(error){if(GLEW.isLinaroFork){switch(error){case 4:return"OpenGL ES lib expected, found OpenGL lib";case 5:return"OpenGL lib expected, found OpenGL ES lib";case 6:return"Missing EGL version";case 7:return"EGL 1.1 and up are supported";default:break}}switch(error){case 0:return"No error";case 1:return"Missing GL version";case 2:return"GL 1.1 and up are supported";case 3:return"GLX 1.2 and up are supported";default:return null}},errorString(error){if(!GLEW.error[error]){var string=GLEW.errorStringConstantFromCode(error);if(!string){string="Unknown error";error=8}GLEW.error[error]=stringToNewUTF8(string)}return GLEW.error[error]},versionStringConstantFromCode(name){switch(name){case 1:return"1.10.0";case 2:return"1";case 3:return"10";case 4:return"0";default:return null}},versionString(name){if(!GLEW.version[name]){var string=GLEW.versionStringConstantFromCode(name);if(!string)return 0;GLEW.version[name]=stringToNewUTF8(string)}return GLEW.version[name]},extensionIsSupported(name){if(!GLEW.extensions){GLEW.extensions=UTF8ToString(_glGetString(7939)).split(" ")}if(GLEW.extensions.includes(name))return 1;return GLEW.extensions.includes("GL_"+name)}};var _glewInit=()=>0;_glewInit.sig="i";var _glewIsSupported=name=>{var exts=UTF8ToString(name).split(" ");for(var i=0;i<exts.length;++i){if(!GLEW.extensionIsSupported(exts[i]))return 0}return 1};_glewIsSupported.sig="ip";var _glewGetExtension=name=>GLEW.extensionIsSupported(UTF8ToString(name));_glewGetExtension.sig="ip";var _glewGetErrorString=error=>GLEW.errorString(error);_glewGetErrorString.sig="pi";var _glewGetString=name=>GLEW.versionString(name);_glewGetString.sig="pi";var IDBStore={indexedDB(){if(typeof indexedDB!="undefined")return indexedDB;var ret=null;if(typeof window=="object")ret=window.indexedDB||window.mozIndexedDB||window.webkitIndexedDB||window.msIndexedDB;assert(ret,"IDBStore used, but indexedDB not supported");return ret},DB_VERSION:22,DB_STORE_NAME:"FILE_DATA",dbs:{},blobs:[0],getDB(name,callback){var db=IDBStore.dbs[name];if(db){return callback(null,db)}var req;try{req=IDBStore.indexedDB().open(name,IDBStore.DB_VERSION)}catch(e){return callback(e)}req.onupgradeneeded=e=>{var db=e.target.result;var transaction=e.target.transaction;var fileStore;if(db.objectStoreNames.contains(IDBStore.DB_STORE_NAME)){fileStore=transaction.objectStore(IDBStore.DB_STORE_NAME)}else{fileStore=db.createObjectStore(IDBStore.DB_STORE_NAME)}};req.onsuccess=()=>{db=req.result;IDBStore.dbs[name]=db;callback(null,db)};req.onerror=function(event){callback(event.target.error||"unknown error");event.preventDefault()}},getStore(dbName,type,callback){IDBStore.getDB(dbName,(error,db)=>{if(error)return callback(error);var transaction=db.transaction([IDBStore.DB_STORE_NAME],type);transaction.onerror=event=>{callback(event.target.error||"unknown error");event.preventDefault()};var store=transaction.objectStore(IDBStore.DB_STORE_NAME);callback(null,store)})},getFile(dbName,id,callback){IDBStore.getStore(dbName,"readonly",(err,store)=>{if(err)return callback(err);var req=store.get(id);req.onsuccess=event=>{var result=event.target.result;if(!result){return callback(`file ${id} not found`)}return callback(null,result)};req.onerror=error=>{callback(error)}})},setFile(dbName,id,data,callback){IDBStore.getStore(dbName,"readwrite",(err,store)=>{if(err)return callback(err);var req=store.put(data,id);req.onsuccess=event=>callback();req.onerror=error=>callback(error)})},deleteFile(dbName,id,callback){IDBStore.getStore(dbName,"readwrite",(err,store)=>{if(err)return callback(err);var req=store.delete(id);req.onsuccess=event=>callback();req.onerror=error=>callback(error)})},existsFile(dbName,id,callback){IDBStore.getStore(dbName,"readonly",(err,store)=>{if(err)return callback(err);var req=store.count(id);req.onsuccess=event=>callback(null,event.target.result>0);req.onerror=error=>callback(error)})},clearStore(dbName,callback){IDBStore.getStore(dbName,"readwrite",(err,store)=>{if(err)return callback(err);var req=store.clear();req.onsuccess=event=>callback();req.onerror=error=>callback(error)})}};var _emscripten_idb_async_load=(db,id,arg,onload,onerror)=>{runtimeKeepalivePush();IDBStore.getFile(UTF8ToString(db),UTF8ToString(id),(error,byteArray)=>{runtimeKeepalivePop();callUserCallback(()=>{if(error){if(onerror)getWasmTableEntry(onerror)(arg);return}var buffer=_malloc(byteArray.length);HEAPU8.set(byteArray,buffer);getWasmTableEntry(onload)(arg,buffer,byteArray.length);_free(buffer)})})};_emscripten_idb_async_load.sig="vppppp";var _emscripten_idb_async_store=(db,id,ptr,num,arg,onstore,onerror)=>{runtimeKeepalivePush();IDBStore.setFile(UTF8ToString(db),UTF8ToString(id),new Uint8Array(HEAPU8.subarray(ptr,ptr+num)),error=>{runtimeKeepalivePop();callUserCallback(()=>{if(error){if(onerror)getWasmTableEntry(onerror)(arg);return}if(onstore)getWasmTableEntry(onstore)(arg)})})};_emscripten_idb_async_store.sig="vpppippp";var _emscripten_idb_async_delete=(db,id,arg,ondelete,onerror)=>{runtimeKeepalivePush();IDBStore.deleteFile(UTF8ToString(db),UTF8ToString(id),error=>{runtimeKeepalivePop();callUserCallback(()=>{if(error){if(onerror)getWasmTableEntry(onerror)(arg);return}if(ondelete)getWasmTableEntry(ondelete)(arg)})})};_emscripten_idb_async_delete.sig="vppppp";var _emscripten_idb_async_exists=(db,id,arg,oncheck,onerror)=>{runtimeKeepalivePush();IDBStore.existsFile(UTF8ToString(db),UTF8ToString(id),(error,exists)=>{runtimeKeepalivePop();callUserCallback(()=>{if(error){if(onerror)getWasmTableEntry(onerror)(arg);return}if(oncheck)getWasmTableEntry(oncheck)(arg,exists)})})};_emscripten_idb_async_exists.sig="vppppp";var _emscripten_idb_async_clear=(db,arg,onclear,onerror)=>{runtimeKeepalivePush();IDBStore.clearStore(UTF8ToString(db),error=>{runtimeKeepalivePop();callUserCallback(()=>{if(error){if(onerror)getWasmTableEntry(onerror)(arg);return}if(onclear)getWasmTableEntry(onclear)(arg)})})};_emscripten_idb_async_clear.sig="vpppp";var _emscripten_idb_load=(db,id,pbuffer,pnum,perror)=>{throw"Please compile your program with async support in order to use synchronous operations like emscripten_idb_load, etc."};_emscripten_idb_load.sig="vppppp";var _emscripten_idb_store=(db,id,ptr,num,perror)=>{throw"Please compile your program with async support in order to use synchronous operations like emscripten_idb_store, etc."};_emscripten_idb_store.sig="vpppip";var _emscripten_idb_delete=(db,id,perror)=>{throw"Please compile your program with async support in order to use synchronous operations like emscripten_idb_delete, etc."};_emscripten_idb_delete.sig="vppp";var _emscripten_idb_exists=(db,id,pexists,perror)=>{throw"Please compile your program with async support in order to use synchronous operations like emscripten_idb_exists, etc."};_emscripten_idb_exists.sig="vpppp";var _emscripten_idb_clear=(db,perror)=>{throw"Please compile your program with async support in order to use synchronous operations like emscripten_idb_clear, etc."};_emscripten_idb_clear.sig="vpp";var runAndAbortIfError=func=>{try{return func()}catch(e){abort(e)}};var _emscripten_sleep=()=>{throw"Please compile your program with async support in order to use asynchronous operations like emscripten_sleep"};_emscripten_sleep.sig="vi";var _emscripten_scan_registers=func=>{throw"Please compile your program with async support in order to use asynchronous operations like emscripten_scan_registers"};_emscripten_scan_registers.sig="vp";function _emscripten_fiber_swap(oldFiber,newFiber){throw"Please compile your program with async support in order to use asynchronous operations like emscripten_fiber_swap"}_emscripten_fiber_swap.sig="vpp";var _SDL_GetTicks=()=>Date.now()-SDL.startTime|0;_SDL_GetTicks.sig="i";var _SDL_LockSurface=surf=>{var surfData=SDL.surfaces[surf];surfData.locked++;if(surfData.locked>1)return 0;if(!surfData.buffer){surfData.buffer=_malloc(surfData.width*surfData.height*4);HEAPU32[surf+20>>2]=surfData.buffer}HEAPU32[surf+20>>2]=surfData.buffer;if(surf==SDL.screen&&Module.screenIsReadOnly&&surfData.image)return 0;if(SDL.defaults.discardOnLock){if(!surfData.image){surfData.image=surfData.ctx.createImageData(surfData.width,surfData.height)}if(!SDL.defaults.opaqueFrontBuffer)return}else{surfData.image=surfData.ctx.getImageData(0,0,surfData.width,surfData.height)}if(surf==SDL.screen&&SDL.defaults.opaqueFrontBuffer){var data=surfData.image.data;var num=data.length;for(var i=0;i<num/4;i++){data[i*4+3]=255}}if(SDL.defaults.copyOnLock&&!SDL.defaults.discardOnLock){if(surfData.isFlagSet(2097152)){throw"CopyOnLock is not supported for SDL_LockSurface with SDL_HWPALETTE flag set"+(new Error).stack}else{HEAPU8.set(surfData.image.data,surfData.buffer)}}return 0};_SDL_LockSurface.sig="ip";var SDL_ttfContext=()=>SDL.ttfContext;var SDL_audio=()=>SDL.audio;var SDL={defaults:{width:320,height:200,copyOnLock:true,discardOnLock:false,opaqueFrontBuffer:true},version:null,surfaces:{},canvasPool:[],events:[],fonts:[null],audios:[null],rwops:[null],music:{audio:null,volume:1},mixerFrequency:22050,mixerFormat:32784,mixerNumChannels:2,mixerChunkSize:1024,channelMinimumNumber:0,GL:false,glAttributes:{0:3,1:3,2:2,3:0,4:0,5:1,6:16,7:0,8:0,9:0,10:0,11:0,12:0,13:0,14:0,15:1,16:0,17:0,18:0},keyboardState:null,keyboardMap:{},canRequestFullscreen:false,isRequestingFullscreen:false,textInput:false,startTime:null,initFlags:0,buttonState:0,modState:0,DOMButtons:[0,0,0],DOMEventToSDLEvent:{},TOUCH_DEFAULT_ID:0,eventHandler:null,eventHandlerContext:null,eventHandlerTemp:0,keyCodes:{16:1249,17:1248,18:1250,20:1081,33:1099,34:1102,35:1101,36:1098,37:1104,38:1106,39:1103,40:1105,44:316,45:1097,46:127,91:1251,93:1125,96:1122,97:1113,98:1114,99:1115,100:1116,101:1117,102:1118,103:1119,104:1120,105:1121,106:1109,107:1111,109:1110,110:1123,111:1108,112:1082,113:1083,114:1084,115:1085,116:1086,117:1087,118:1088,119:1089,120:1090,121:1091,122:1092,123:1093,124:1128,125:1129,126:1130,127:1131,128:1132,129:1133,130:1134,131:1135,132:1136,133:1137,134:1138,135:1139,144:1107,160:94,161:33,162:34,163:35,164:36,165:37,166:38,167:95,168:40,169:41,170:42,171:43,172:124,173:45,174:123,175:125,176:126,181:127,182:129,183:128,188:44,190:46,191:47,192:96,219:91,220:92,221:93,222:39,224:1251},scanCodes:{8:42,9:43,13:40,27:41,32:44,35:204,39:53,44:54,46:55,47:56,48:39,49:30,50:31,51:32,52:33,53:34,54:35,55:36,56:37,57:38,58:203,59:51,61:46,91:47,92:49,93:48,96:52,97:4,98:5,99:6,100:7,101:8,102:9,103:10,104:11,105:12,106:13,107:14,108:15,109:16,110:17,111:18,112:19,113:20,114:21,115:22,116:23,117:24,118:25,119:26,120:27,121:28,122:29,127:76,305:224,308:226,316:70},loadRect:rect=>({x:HEAP32[rect+0>>2],y:HEAP32[rect+4>>2],w:HEAP32[rect+8>>2],h:HEAP32[rect+12>>2]}),updateRect:(rect,r)=>{HEAP32[rect>>2]=r.x;HEAP32[rect+4>>2]=r.y;HEAP32[rect+8>>2]=r.w;HEAP32[rect+12>>2]=r.h},intersectionOfRects:(first,second)=>{var leftX=Math.max(first.x,second.x);var leftY=Math.max(first.y,second.y);var rightX=Math.min(first.x+first.w,second.x+second.w);var rightY=Math.min(first.y+first.h,second.y+second.h);return{x:leftX,y:leftY,w:Math.max(leftX,rightX)-leftX,h:Math.max(leftY,rightY)-leftY}},checkPixelFormat:fmt=>{},loadColorToCSSRGB:color=>{var rgba=HEAP32[color>>2];return"rgb("+(rgba&255)+","+(rgba>>8&255)+","+(rgba>>16&255)+")"},loadColorToCSSRGBA:color=>{var rgba=HEAP32[color>>2];return"rgba("+(rgba&255)+","+(rgba>>8&255)+","+(rgba>>16&255)+","+(rgba>>24&255)/255+")"},translateColorToCSSRGBA:rgba=>"rgba("+(rgba&255)+","+(rgba>>8&255)+","+(rgba>>16&255)+","+(rgba>>>24)/255+")",translateRGBAToCSSRGBA:(r,g,b,a)=>"rgba("+(r&255)+","+(g&255)+","+(b&255)+","+(a&255)/255+")",translateRGBAToColor:(r,g,b,a)=>r|g<<8|b<<16|a<<24,makeSurface:(width,height,flags,usePageCanvas,source,rmask,gmask,bmask,amask)=>{var is_SDL_HWSURFACE=flags&1;var is_SDL_HWPALETTE=flags&2097152;var is_SDL_OPENGL=flags&67108864;var surf=_malloc(60);var pixelFormat=_malloc(44);var bpp=is_SDL_HWPALETTE?1:4;var buffer=0;if(!is_SDL_HWSURFACE&&!is_SDL_OPENGL){buffer=_malloc(width*height*4)}HEAP32[surf>>2]=flags;HEAPU32[surf+4>>2]=pixelFormat;HEAP32[surf+8>>2]=width;HEAP32[surf+12>>2]=height;HEAP32[surf+16>>2]=width*bpp;HEAPU32[surf+20>>2]=buffer;HEAP32[surf+36>>2]=0;HEAP32[surf+40>>2]=0;HEAP32[surf+44>>2]=Module["canvas"].width;HEAP32[surf+48>>2]=Module["canvas"].height;HEAP32[surf+56>>2]=1;HEAP32[pixelFormat>>2]=-2042224636;HEAP32[pixelFormat+4>>2]=0;HEAP8[pixelFormat+8>>0]=bpp*8;HEAP8[pixelFormat+9>>0]=bpp;HEAP32[pixelFormat+12>>2]=rmask||255;HEAP32[pixelFormat+16>>2]=gmask||65280;HEAP32[pixelFormat+20>>2]=bmask||16711680;HEAP32[pixelFormat+24>>2]=amask||4278190080;SDL.GL=SDL.GL||is_SDL_OPENGL;var canvas;if(!usePageCanvas){if(SDL.canvasPool.length>0){canvas=SDL.canvasPool.pop()}else{canvas=document.createElement("canvas")}canvas.width=width;canvas.height=height}else{canvas=Module["canvas"]}var webGLContextAttributes={antialias:SDL.glAttributes[13]!=0&&SDL.glAttributes[14]>1,depth:SDL.glAttributes[6]>0,stencil:SDL.glAttributes[7]>0,alpha:SDL.glAttributes[3]>0};var ctx=Browser.createContext(canvas,is_SDL_OPENGL,usePageCanvas,webGLContextAttributes);SDL.surfaces[surf]={width:width,height:height,canvas:canvas,ctx:ctx,surf:surf,buffer:buffer,pixelFormat:pixelFormat,alpha:255,flags:flags,locked:0,usePageCanvas:usePageCanvas,source:source,isFlagSet:flag=>flags&flag};return surf},copyIndexedColorData:(surfData,rX,rY,rW,rH)=>{if(!surfData.colors){return}var fullWidth=Module["canvas"].width;var fullHeight=Module["canvas"].height;var startX=rX||0;var startY=rY||0;var endX=(rW||fullWidth-startX)+startX;var endY=(rH||fullHeight-startY)+startY;var buffer=surfData.buffer;if(!surfData.image.data32){surfData.image.data32=new Uint32Array(surfData.image.data.buffer)}var data32=surfData.image.data32;var colors32=surfData.colors32;for(var y=startY;y<endY;++y){var base=y*fullWidth;for(var x=startX;x<endX;++x){data32[base+x]=colors32[HEAPU8[buffer+base+x>>0]]}}},freeSurface:surf=>{var refcountPointer=surf+56;var refcount=HEAP32[refcountPointer>>2];if(refcount>1){HEAP32[refcountPointer>>2]=refcount-1;return}var info=SDL.surfaces[surf];if(!info.usePageCanvas&&info.canvas)SDL.canvasPool.push(info.canvas);if(info.buffer)_free(info.buffer);_free(info.pixelFormat);_free(surf);SDL.surfaces[surf]=null;if(surf===SDL.screen){SDL.screen=null}},blitSurface:(src,srcrect,dst,dstrect,scale)=>{var srcData=SDL.surfaces[src];var dstData=SDL.surfaces[dst];var sr,dr;if(srcrect){sr=SDL.loadRect(srcrect)}else{sr={x:0,y:0,w:srcData.width,h:srcData.height}}if(dstrect){dr=SDL.loadRect(dstrect)}else{dr={x:0,y:0,w:srcData.width,h:srcData.height}}if(dstData.clipRect){var widthScale=!scale||sr.w===0?1:sr.w/dr.w;var heightScale=!scale||sr.h===0?1:sr.h/dr.h;dr=SDL.intersectionOfRects(dstData.clipRect,dr);sr.w=dr.w*widthScale;sr.h=dr.h*heightScale;if(dstrect){SDL.updateRect(dstrect,dr)}}var blitw,blith;if(scale){blitw=dr.w;blith=dr.h}else{blitw=sr.w;blith=sr.h}if(sr.w===0||sr.h===0||blitw===0||blith===0){return 0}var oldAlpha=dstData.ctx.globalAlpha;dstData.ctx.globalAlpha=srcData.alpha/255;dstData.ctx.drawImage(srcData.canvas,sr.x,sr.y,sr.w,sr.h,dr.x,dr.y,blitw,blith);dstData.ctx.globalAlpha=oldAlpha;if(dst!=SDL.screen){warnOnce("WARNING: copying canvas data to memory for compatibility");_SDL_LockSurface(dst);dstData.locked--}return 0},downFingers:{},savedKeydown:null,receiveEvent:event=>{function unpressAllPressedKeys(){for(var code in SDL.keyboardMap){SDL.events.push({type:"keyup",keyCode:SDL.keyboardMap[code]})}}switch(event.type){case"touchstart":case"touchmove":{event.preventDefault();var touches=[];if(event.type==="touchstart"){for(var i=0;i<event.touches.length;i++){var touch=event.touches[i];if(SDL.downFingers[touch.identifier]!=true){SDL.downFingers[touch.identifier]=true;touches.push(touch)}}}else{touches=event.touches}var firstTouch=touches[0];if(firstTouch){if(event.type=="touchstart"){SDL.DOMButtons[0]=1}var mouseEventType;switch(event.type){case"touchstart":mouseEventType="mousedown";break;case"touchmove":mouseEventType="mousemove";break}var mouseEvent={type:mouseEventType,button:0,pageX:firstTouch.clientX,pageY:firstTouch.clientY};SDL.events.push(mouseEvent)}for(var i=0;i<touches.length;i++){var touch=touches[i];SDL.events.push({type:event.type,touch:touch})}break}case"touchend":{event.preventDefault();for(var i=0;i<event.changedTouches.length;i++){var touch=event.changedTouches[i];if(SDL.downFingers[touch.identifier]===true){delete SDL.downFingers[touch.identifier]}}var mouseEvent={type:"mouseup",button:0,pageX:event.changedTouches[0].clientX,pageY:event.changedTouches[0].clientY};SDL.DOMButtons[0]=0;SDL.events.push(mouseEvent);for(var i=0;i<event.changedTouches.length;i++){var touch=event.changedTouches[i];SDL.events.push({type:"touchend",touch:touch})}break}case"DOMMouseScroll":case"mousewheel":case"wheel":var delta=-Browser.getMouseWheelDelta(event);delta=delta==0?0:delta>0?Math.max(delta,1):Math.min(delta,-1);var button=delta>0?3:4;SDL.events.push({type:"mousedown",button:button,pageX:event.pageX,pageY:event.pageY});SDL.events.push({type:"mouseup",button:button,pageX:event.pageX,pageY:event.pageY});SDL.events.push({type:"wheel",deltaX:0,deltaY:delta});event.preventDefault();break;case"mousemove":if(SDL.DOMButtons[0]===1){SDL.events.push({type:"touchmove",touch:{identifier:0,deviceID:-1,pageX:event.pageX,pageY:event.pageY}})}if(Browser.pointerLock){if("mozMovementX"in event){event["movementX"]=event["mozMovementX"];event["movementY"]=event["mozMovementY"]}if(event["movementX"]==0&&event["movementY"]==0){event.preventDefault();return}}case"keydown":case"keyup":case"keypress":case"mousedown":case"mouseup":if(event.type!=="keydown"||!SDL_unicode()&&!SDL.textInput||(event.keyCode===8||event.keyCode===9)){event.preventDefault()}if(event.type=="mousedown"){SDL.DOMButtons[event.button]=1;SDL.events.push({type:"touchstart",touch:{identifier:0,deviceID:-1,pageX:event.pageX,pageY:event.pageY}})}else if(event.type=="mouseup"){if(!SDL.DOMButtons[event.button]){return}SDL.events.push({type:"touchend",touch:{identifier:0,deviceID:-1,pageX:event.pageX,pageY:event.pageY}});SDL.DOMButtons[event.button]=0}if(event.type==="keydown"||event.type==="mousedown"){SDL.canRequestFullscreen=true}else if(event.type==="keyup"||event.type==="mouseup"){if(SDL.isRequestingFullscreen){Module["requestFullscreen"](true,true);SDL.isRequestingFullscreen=false}SDL.canRequestFullscreen=false}if(event.type==="keypress"&&SDL.savedKeydown){SDL.savedKeydown.keypressCharCode=event.charCode;SDL.savedKeydown=null}else if(event.type==="keydown"){SDL.savedKeydown=event}if(event.type!=="keypress"||SDL.textInput){SDL.events.push(event)}break;case"mouseout":for(var i=0;i<3;i++){if(SDL.DOMButtons[i]){SDL.events.push({type:"mouseup",button:i,pageX:event.pageX,pageY:event.pageY});SDL.DOMButtons[i]=0}}event.preventDefault();break;case"focus":SDL.events.push(event);event.preventDefault();break;case"blur":SDL.events.push(event);unpressAllPressedKeys();event.preventDefault();break;case"visibilitychange":SDL.events.push({type:"visibilitychange",visible:!document.hidden});unpressAllPressedKeys();event.preventDefault();break;case"unload":if(Browser.mainLoop.runner){SDL.events.push(event);Browser.mainLoop.runner()}return;case"resize":SDL.events.push(event);if(event.preventDefault){event.preventDefault()}break}if(SDL.events.length>=1e4){err("SDL event queue full, dropping events");SDL.events=SDL.events.slice(0,1e4)}SDL.flushEventsToHandler();return},lookupKeyCodeForEvent:event=>{var code=event.keyCode;if(code>=65&&code<=90){code+=32}else{code=SDL.keyCodes[event.keyCode]||event.keyCode;if(event.location===2&&code>=(224|1<<10)&&code<=(227|1<<10)){code+=4}}return code},handleEvent:event=>{if(event.handled)return;event.handled=true;switch(event.type){case"touchstart":case"touchend":case"touchmove":{Browser.calculateMouseEvent(event);break}case"keydown":case"keyup":{var down=event.type==="keydown";var code=SDL.lookupKeyCodeForEvent(event);HEAP8[SDL.keyboardState+code>>0]=down;SDL.modState=(HEAP8[SDL.keyboardState+1248>>0]?64:0)|(HEAP8[SDL.keyboardState+1249>>0]?1:0)|(HEAP8[SDL.keyboardState+1250>>0]?256:0)|(HEAP8[SDL.keyboardState+1252>>0]?128:0)|(HEAP8[SDL.keyboardState+1253>>0]?2:0)|(HEAP8[SDL.keyboardState+1254>>0]?512:0);if(down){SDL.keyboardMap[code]=event.keyCode}else{delete SDL.keyboardMap[code]}break}case"mousedown":case"mouseup":if(event.type=="mousedown"){SDL.buttonState|=1<<event.button}else if(event.type=="mouseup"){SDL.buttonState&=~(1<<event.button)}case"mousemove":{Browser.calculateMouseEvent(event);break}}},flushEventsToHandler:()=>{if(!SDL.eventHandler)return;while(SDL.pollEvent(SDL.eventHandlerTemp)){getWasmTableEntry(SDL.eventHandler)(SDL.eventHandlerContext,SDL.eventHandlerTemp)}},pollEvent:ptr=>{if(SDL.initFlags&512&&SDL.joystickEventState){SDL.queryJoysticks()}if(ptr){while(SDL.events.length>0){if(SDL.makeCEvent(SDL.events.shift(),ptr)!==false)return 1}return 0}return SDL.events.length>0},makeCEvent:(event,ptr)=>{if(typeof event=="number"){_memcpy(ptr,event,28);_free(event);return}SDL.handleEvent(event);switch(event.type){case"keydown":case"keyup":{var down=event.type==="keydown";var key=SDL.lookupKeyCodeForEvent(event);var scan;if(key>=1024){scan=key-1024}else{scan=SDL.scanCodes[key]||key}HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP8[ptr+8>>0]=down?1:0;HEAP8[ptr+9>>0]=0;HEAP32[ptr+12>>2]=scan;HEAP32[ptr+16>>2]=key;HEAP16[ptr+20>>1]=SDL.modState;HEAP32[ptr+24>>2]=event.keypressCharCode||key;break}case"keypress":{HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];var cStr=intArrayFromString(String.fromCharCode(event.charCode));for(var i=0;i<cStr.length;++i){HEAP8[ptr+(8+i)>>0]=cStr[i]}break}case"mousedown":case"mouseup":case"mousemove":{if(event.type!="mousemove"){var down=event.type==="mousedown";HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP32[ptr+4>>2]=0;HEAP32[ptr+8>>2]=0;HEAP32[ptr+12>>2]=0;HEAP8[ptr+16>>0]=event.button+1;HEAP8[ptr+17>>0]=down?1:0;HEAP32[ptr+20>>2]=Browser.mouseX;HEAP32[ptr+24>>2]=Browser.mouseY}else{HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP32[ptr+4>>2]=0;HEAP32[ptr+8>>2]=0;HEAP32[ptr+12>>2]=0;HEAP32[ptr+16>>2]=SDL.buttonState;HEAP32[ptr+20>>2]=Browser.mouseX;HEAP32[ptr+24>>2]=Browser.mouseY;HEAP32[ptr+28>>2]=Browser.mouseMovementX;HEAP32[ptr+32>>2]=Browser.mouseMovementY}break}case"wheel":{HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP32[ptr+16>>2]=event.deltaX;HEAP32[ptr+20>>2]=event.deltaY;break}case"touchstart":case"touchend":case"touchmove":{var touch=event.touch;if(!Browser.touches[touch.identifier])break;var w=Module["canvas"].width;var h=Module["canvas"].height;var x=Browser.touches[touch.identifier].x/w;var y=Browser.touches[touch.identifier].y/h;var lx=Browser.lastTouches[touch.identifier].x/w;var ly=Browser.lastTouches[touch.identifier].y/h;var dx=x-lx;var dy=y-ly;if(touch["deviceID"]===undefined)touch.deviceID=SDL.TOUCH_DEFAULT_ID;if(dx===0&&dy===0&&event.type==="touchmove")return false;HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP32[ptr+4>>2]=_SDL_GetTicks();HEAP64[ptr+8>>3]=BigInt(touch.deviceID);HEAP64[ptr+16>>3]=BigInt(touch.identifier);HEAPF32[ptr+24>>2]=x;HEAPF32[ptr+28>>2]=y;HEAPF32[ptr+32>>2]=dx;HEAPF32[ptr+36>>2]=dy;if(touch.force!==undefined){HEAPF32[ptr+40>>2]=touch.force}else{HEAPF32[ptr+40>>2]=event.type=="touchend"?0:1}break}case"unload":{HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];break}case"resize":{HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP32[ptr+4>>2]=event.w;HEAP32[ptr+8>>2]=event.h;break}case"joystick_button_up":case"joystick_button_down":{var state=event.type==="joystick_button_up"?0:1;HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP8[ptr+4>>0]=event.index;HEAP8[ptr+5>>0]=event.button;HEAP8[ptr+6>>0]=state;break}case"joystick_axis_motion":{HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP8[ptr+4>>0]=event.index;HEAP8[ptr+5>>0]=event.axis;HEAP32[ptr+8>>2]=SDL.joystickAxisValueConversion(event.value);break}case"focus":{var SDL_WINDOWEVENT_FOCUS_GAINED=12;HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP32[ptr+4>>2]=0;HEAP8[ptr+8>>0]=SDL_WINDOWEVENT_FOCUS_GAINED;break}case"blur":{var SDL_WINDOWEVENT_FOCUS_LOST=13;HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP32[ptr+4>>2]=0;HEAP8[ptr+8>>0]=SDL_WINDOWEVENT_FOCUS_LOST;break}case"visibilitychange":{var SDL_WINDOWEVENT_SHOWN=1;var SDL_WINDOWEVENT_HIDDEN=2;var visibilityEventID=event.visible?SDL_WINDOWEVENT_SHOWN:SDL_WINDOWEVENT_HIDDEN;HEAP32[ptr>>2]=SDL.DOMEventToSDLEvent[event.type];HEAP32[ptr+4>>2]=0;HEAP8[ptr+8>>0]=visibilityEventID;break}default:throw"Unhandled SDL event: "+event.type}},makeFontString:(height,fontName)=>{if(fontName.charAt(0)!="'"&&fontName.charAt(0)!='"'){fontName='"'+fontName+'"'}return height+"px "+fontName+", serif"},estimateTextWidth:(fontData,text)=>{var h=fontData.size;var fontString=SDL.makeFontString(h,fontData.name);var tempCtx=SDL_ttfContext();tempCtx.font=fontString;var ret=tempCtx.measureText(text).width|0;return ret},allocateChannels:num=>{if(SDL.numChannels&&SDL.numChannels>=num&&num!=0)return;SDL.numChannels=num;SDL.channels=[];for(var i=0;i<num;i++){SDL.channels[i]={audio:null,volume:1}}},setGetVolume:(info,volume)=>{if(!info)return 0;var ret=info.volume*128;if(volume!=-1){info.volume=Math.min(Math.max(volume,0),128)/128;if(info.audio){try{info.audio.volume=info.volume;if(info.audio.webAudioGainNode)info.audio.webAudioGainNode["gain"]["value"]=info.volume}catch(e){err(`setGetVolume failed to set audio volume: ${e}`)}}}return ret},setPannerPosition:(info,x,y,z)=>{if(!info)return;if(info.audio){if(info.audio.webAudioPannerNode){info.audio.webAudioPannerNode["setPosition"](x,y,z)}}},playWebAudio:audio=>{if(!audio)return;if(audio.webAudioNode)return;if(!SDL.webAudioAvailable())return;try{var webAudio=audio.resource.webAudio;audio.paused=false;if(!webAudio.decodedBuffer){if(webAudio.onDecodeComplete===undefined)abort("Cannot play back audio object that was not loaded");webAudio.onDecodeComplete.push(()=>{if(!audio.paused)SDL.playWebAudio(audio)});return}audio.webAudioNode=SDL.audioContext["createBufferSource"]();audio.webAudioNode["buffer"]=webAudio.decodedBuffer;audio.webAudioNode["loop"]=audio.loop;audio.webAudioNode["onended"]=audio["onended"];audio.webAudioPannerNode=SDL.audioContext["createPanner"]();audio.webAudioPannerNode["setPosition"](0,0,-.5);audio.webAudioPannerNode["panningModel"]="equalpower";audio.webAudioGainNode=SDL.audioContext["createGain"]();audio.webAudioGainNode["gain"]["value"]=audio.volume;audio.webAudioNode["connect"](audio.webAudioPannerNode);audio.webAudioPannerNode["connect"](audio.webAudioGainNode);audio.webAudioGainNode["connect"](SDL.audioContext["destination"]);audio.webAudioNode["start"](0,audio.currentPosition);audio.startTime=SDL.audioContext["currentTime"]-audio.currentPosition}catch(e){err(`playWebAudio failed: ${e}`)}},pauseWebAudio:audio=>{if(!audio)return;if(audio.webAudioNode){try{audio.currentPosition=(SDL.audioContext["currentTime"]-audio.startTime)%audio.resource.webAudio.decodedBuffer.duration;audio.webAudioNode["onended"]=undefined;audio.webAudioNode.stop(0);audio.webAudioNode=undefined}catch(e){err(`pauseWebAudio failed: ${e}`)}}audio.paused=true},openAudioContext:()=>{if(!SDL.audioContext){if(typeof AudioContext!="undefined")SDL.audioContext=new AudioContext;else if(typeof webkitAudioContext!="undefined")SDL.audioContext=new webkitAudioContext}},webAudioAvailable:()=>!!SDL.audioContext,fillWebAudioBufferFromHeap:(heapPtr,sizeSamplesPerChannel,dstAudioBuffer)=>{var audio=SDL_audio();var numChannels=audio.channels;for(var c=0;c<numChannels;++c){var channelData=dstAudioBuffer["getChannelData"](c);if(channelData.length!=sizeSamplesPerChannel){throw"Web Audio output buffer length mismatch! Destination size: "+channelData.length+" samples vs expected "+sizeSamplesPerChannel+" samples!"}if(audio.format==32784){for(var j=0;j<sizeSamplesPerChannel;++j){channelData[j]=HEAP16[heapPtr+(j*numChannels+c)*2>>1]/32768}}else if(audio.format==8){for(var j=0;j<sizeSamplesPerChannel;++j){var v=HEAP8[heapPtr+(j*numChannels+c)>>0];channelData[j]=(v>=0?v-128:v+128)/128}}else if(audio.format==33056){for(var j=0;j<sizeSamplesPerChannel;++j){channelData[j]=HEAPF32[heapPtr+(j*numChannels+c)*4>>2]}}else{throw"Invalid SDL audio format "+audio.format+"!"}}},joystickEventState:1,lastJoystickState:{},joystickNamePool:{},recordJoystickState:(joystick,state)=>{var buttons=new Array(state.buttons.length);for(var i=0;i<state.buttons.length;i++){buttons[i]=SDL.getJoystickButtonState(state.buttons[i])}SDL.lastJoystickState[joystick]={buttons:buttons,axes:state.axes.slice(0),timestamp:state.timestamp,index:state.index,id:state.id}},getJoystickButtonState:button=>{if(typeof button=="object"){return button["pressed"]}return button>0},queryJoysticks:()=>{for(var joystick in SDL.lastJoystickState){var state=SDL.getGamepad(joystick-1);var prevState=SDL.lastJoystickState[joystick];if(typeof state=="undefined")return;if(state===null)return;if(typeof state.timestamp!="number"||state.timestamp!=prevState.timestamp||!state.timestamp){var i;for(i=0;i<state.buttons.length;i++){var buttonState=SDL.getJoystickButtonState(state.buttons[i]);if(buttonState!==prevState.buttons[i]){SDL.events.push({type:buttonState?"joystick_button_down":"joystick_button_up",joystick:joystick,index:joystick-1,button:i})}}for(i=0;i<state.axes.length;i++){if(state.axes[i]!==prevState.axes[i]){SDL.events.push({type:"joystick_axis_motion",joystick:joystick,index:joystick-1,axis:i,value:state.axes[i]})}}SDL.recordJoystickState(joystick,state)}}},joystickAxisValueConversion:value=>{value=Math.min(1,Math.max(value,-1));return Math.ceil((value+1)*32767.5-32768)},getGamepads:()=>{var fcn=navigator.getGamepads||navigator.webkitGamepads||navigator.mozGamepads||navigator.gamepads||navigator.webkitGetGamepads;if(fcn!==undefined){return fcn.apply(navigator)}return[]},getGamepad:deviceIndex=>{var gamepads=SDL.getGamepads();if(gamepads.length>deviceIndex&&deviceIndex>=0){return gamepads[deviceIndex]}return null}};var SDL_unicode=()=>SDL.unicode;var _SDL_Linked_Version=()=>{if(SDL.version===null){SDL.version=_malloc(3);HEAP8[SDL.version+0>>0]=1;HEAP8[SDL.version+1>>0]=3;HEAP8[SDL.version+2>>0]=0}return SDL.version};_SDL_Linked_Version.sig="p";var _SDL_Init=initFlags=>{SDL.startTime=Date.now();SDL.initFlags=initFlags;if(!Module["doNotCaptureKeyboard"]){var keyboardListeningElement=Module["keyboardListeningElement"]||document;keyboardListeningElement.addEventListener("keydown",SDL.receiveEvent);keyboardListeningElement.addEventListener("keyup",SDL.receiveEvent);keyboardListeningElement.addEventListener("keypress",SDL.receiveEvent);window.addEventListener("focus",SDL.receiveEvent);window.addEventListener("blur",SDL.receiveEvent);document.addEventListener("visibilitychange",SDL.receiveEvent)}window.addEventListener("unload",SDL.receiveEvent);SDL.keyboardState=_malloc(65536);zeroMemory(SDL.keyboardState,65536);SDL.DOMEventToSDLEvent["keydown"]=768;SDL.DOMEventToSDLEvent["keyup"]=769;SDL.DOMEventToSDLEvent["keypress"]=771;SDL.DOMEventToSDLEvent["mousedown"]=1025;SDL.DOMEventToSDLEvent["mouseup"]=1026;SDL.DOMEventToSDLEvent["mousemove"]=1024;SDL.DOMEventToSDLEvent["wheel"]=1027;SDL.DOMEventToSDLEvent["touchstart"]=1792;SDL.DOMEventToSDLEvent["touchend"]=1793;SDL.DOMEventToSDLEvent["touchmove"]=1794;SDL.DOMEventToSDLEvent["unload"]=256;SDL.DOMEventToSDLEvent["resize"]=28673;SDL.DOMEventToSDLEvent["visibilitychange"]=512;SDL.DOMEventToSDLEvent["focus"]=512;SDL.DOMEventToSDLEvent["blur"]=512;SDL.DOMEventToSDLEvent["joystick_axis_motion"]=1536;SDL.DOMEventToSDLEvent["joystick_button_down"]=1539;SDL.DOMEventToSDLEvent["joystick_button_up"]=1540;return 0};_SDL_Init.sig="ii";var _SDL_WasInit=flags=>{if(SDL.startTime===null){_SDL_Init(0)}return 1};_SDL_WasInit.sig="ii";var _SDL_GetVideoInfo=()=>{var ret=_malloc(20);zeroMemory(ret,3);HEAP32[ret+12>>2]=Module["canvas"].width;HEAP32[ret+16>>2]=Module["canvas"].height;return ret};_SDL_GetVideoInfo.sig="p";var _SDL_ListModes=(format,flags)=>-1;_SDL_ListModes.sig="ppi";var _SDL_VideoModeOK=(width,height,depth,flags)=>depth;_SDL_VideoModeOK.sig="iiiii";var _SDL_VideoDriverName=(buf,max_size)=>{if(SDL.startTime===null){return 0}var driverName=[101,109,115,99,114,105,112,116,101,110,95,115,100,108,95,100,114,105,118,101,114];var index=0;var size=driverName.length;if(max_size<=size){size=max_size-1}while(index<size){var value=driverName[index];HEAP8[buf+index>>0]=value;index++}HEAP8[buf+index>>0]=0;return buf};_SDL_VideoDriverName.sig="ppi";var _SDL_AudioDriverName=(buf,max_size)=>_SDL_VideoDriverName(buf,max_size);_SDL_AudioDriverName.sig="ppi";var _SDL_SetVideoMode=(width,height,depth,flags)=>{["touchstart","touchend","touchmove","mousedown","mouseup","mousemove","mousewheel","wheel","mouseout","DOMMouseScroll"].forEach(e=>Module["canvas"].addEventListener(e,SDL.receiveEvent,true));var canvas=Module["canvas"];if(width==0&&height==0){width=canvas.width;height=canvas.height}if(!SDL.addedResizeListener){SDL.addedResizeListener=true;Browser.resizeListeners.push((w,h)=>{if(!SDL.settingVideoMode){SDL.receiveEvent({type:"resize",w:w,h:h})}})}SDL.settingVideoMode=true;Browser.setCanvasSize(width,height);SDL.settingVideoMode=false;if(SDL.screen){SDL.freeSurface(SDL.screen);assert(!SDL.screen)}if(SDL.GL)flags=flags|67108864;SDL.screen=SDL.makeSurface(width,height,flags,true,"screen");return SDL.screen};_SDL_SetVideoMode.sig="piiii";var _SDL_GetVideoSurface=()=>SDL.screen;_SDL_GetVideoSurface.sig="p";var _SDL_AudioQuit=()=>{for(var i=0;i<SDL.numChannels;++i){var chan=SDL.channels[i];if(chan.audio){chan.audio.pause();chan.audio=undefined}}var audio=SDL.music.audio;if(audio)audio.pause();SDL.music.audio=undefined};_SDL_AudioQuit.sig="v";var _SDL_VideoQuit=()=>out("SDL_VideoQuit called (and ignored)");_SDL_VideoQuit.sig="v";var _SDL_QuitSubSystem=flags=>out("SDL_QuitSubSystem called (and ignored)");_SDL_QuitSubSystem.sig="vi";var _SDL_Quit=()=>{_SDL_AudioQuit();out("SDL_Quit called (and ignored)")};_SDL_Quit.sig="v";var _SDL_UnlockSurface=surf=>{assert(!SDL.GL);var surfData=SDL.surfaces[surf];if(!surfData.locked||--surfData.locked>0){return}if(surfData.isFlagSet(2097152)){SDL.copyIndexedColorData(surfData)}else if(!surfData.colors){var data=surfData.image.data;var buffer=surfData.buffer;assert(buffer%4==0,"Invalid buffer offset: "+buffer);var src=buffer>>2;var dst=0;var isScreen=surf==SDL.screen;var num;if(typeof CanvasPixelArray!="undefined"&&data instanceof CanvasPixelArray){num=data.length;while(dst<num){var val=HEAP32[src];data[dst]=val&255;data[dst+1]=val>>8&255;data[dst+2]=val>>16&255;data[dst+3]=isScreen?255:val>>24&255;src++;dst+=4}}else{var data32=new Uint32Array(data.buffer);if(isScreen&&SDL.defaults.opaqueFrontBuffer){num=data32.length;data32.set(HEAP32.subarray(src,src+num));var data8=new Uint8Array(data.buffer);var i=3;var j=i+4*num;if(num%8==0){while(i<j){data8[i]=255;i=i+4|0;data8[i]=255;i=i+4|0;data8[i]=255;i=i+4|0;data8[i]=255;i=i+4|0;data8[i]=255;i=i+4|0;data8[i]=255;i=i+4|0;data8[i]=255;i=i+4|0;data8[i]=255;i=i+4|0}}else{while(i<j){data8[i]=255;i=i+4|0}}}else{data32.set(HEAP32.subarray(src,src+data32.length))}}}else{var width=Module["canvas"].width;var height=Module["canvas"].height;var s=surfData.buffer;var data=surfData.image.data;var colors=surfData.colors;for(var y=0;y<height;y++){var base=y*width*4;for(var x=0;x<width;x++){var val=HEAPU8[s++>>0]*4;var start=base+x*4;data[start]=colors[val];data[start+1]=colors[val+1];data[start+2]=colors[val+2]}s+=width*3}}surfData.ctx.putImageData(surfData.image,0,0)};_SDL_UnlockSurface.sig="vp";var _SDL_Flip=surf=>{};_SDL_Flip.sig="ip";var _SDL_UpdateRect=(surf,x,y,w,h)=>{};_SDL_UpdateRect.sig="vpiiii";var _SDL_UpdateRects=(surf,numrects,rects)=>{};_SDL_UpdateRects.sig="vpip";var _SDL_Delay=delay=>{if(!ENVIRONMENT_IS_WORKER)abort("SDL_Delay called on the main thread! Potential infinite loop, quitting. (consider building with async support like ASYNCIFY)");var now=Date.now();while(Date.now()-now<delay){}};_SDL_Delay.sig="vi";var _SDL_WM_SetCaption=(title,icon)=>{if(title){_emscripten_set_window_title(title)}icon=icon&&UTF8ToString(icon)};_SDL_WM_SetCaption.sig="vpp";var _SDL_EnableKeyRepeat=(delay,interval)=>{};_SDL_EnableKeyRepeat.sig="iii";var _SDL_GetKeyboardState=numKeys=>{if(numKeys){HEAP32[numKeys>>2]=65536}return SDL.keyboardState};_SDL_GetKeyboardState.sig="pp";var _SDL_GetKeyState=()=>_SDL_GetKeyboardState(0);var _SDL_GetKeyName=key=>{if(!SDL.keyName){SDL.keyName=stringToNewUTF8("unknown key")}return SDL.keyName};_SDL_GetKeyName.sig="pi";var _SDL_GetModState=()=>SDL.modState;_SDL_GetModState.sig="i";var _SDL_GetMouseState=(x,y)=>{if(x)HEAP32[x>>2]=Browser.mouseX;if(y)HEAP32[y>>2]=Browser.mouseY;return SDL.buttonState};_SDL_GetMouseState.sig="ipp";var _SDL_WarpMouse=(x,y)=>{};_SDL_WarpMouse.sig="vii";var _SDL_ShowCursor=toggle=>{switch(toggle){case 0:if(Browser.isFullscreen){Module["canvas"].requestPointerLock();return 0}return 1;case 1:Module["canvas"].exitPointerLock();return 1;case-1:return!Browser.pointerLock;default:err(`SDL_ShowCursor called with unknown toggle parameter value: ${toggle}`);break}};_SDL_ShowCursor.sig="ii";var _SDL_GetError=()=>{if(!SDL.errorMessage){SDL.errorMessage=stringToNewUTF8("unknown SDL-emscripten error")}return SDL.errorMessage};_SDL_GetError.sig="p";var _SDL_SetError=(fmt,varargs)=>{};_SDL_SetError.sig="vpp";var _SDL_CreateRGBSurface=(flags,width,height,depth,rmask,gmask,bmask,amask)=>SDL.makeSurface(width,height,flags,false,"CreateRGBSurface",rmask,gmask,bmask,amask);_SDL_CreateRGBSurface.sig="piiiiiiii";var _SDL_CreateRGBSurfaceFrom=(pixels,width,height,depth,pitch,rmask,gmask,bmask,amask)=>{var surf=SDL.makeSurface(width,height,0,false,"CreateRGBSurfaceFrom",rmask,gmask,bmask,amask);if(depth!==32){err("TODO: Partially unimplemented SDL_CreateRGBSurfaceFrom called!");return surf}var data=SDL.surfaces[surf];var image=data.ctx.createImageData(width,height);var pitchOfDst=width*4;for(var row=0;row<height;++row){var baseOfSrc=row*pitch;var baseOfDst=row*pitchOfDst;for(var col=0;col<width*4;++col){image.data[baseOfDst+col]=HEAPU8[pixels+(baseOfDst+col)>>0]}}data.ctx.putImageData(image,0,0);return surf};_SDL_CreateRGBSurfaceFrom.sig="ppiiiiiiii";var _SDL_ConvertSurface=(surf,format,flags)=>{if(format){SDL.checkPixelFormat(format)}var oldData=SDL.surfaces[surf];var ret=SDL.makeSurface(oldData.width,oldData.height,oldData.flags,false,"copy:"+oldData.source);var newData=SDL.surfaces[ret];newData.ctx.globalCompositeOperation="copy";newData.ctx.drawImage(oldData.canvas,0,0);newData.ctx.globalCompositeOperation=oldData.ctx.globalCompositeOperation;return ret};_SDL_ConvertSurface.sig="pppi";var _SDL_DisplayFormatAlpha=surf=>_SDL_ConvertSurface(surf,0,0);_SDL_DisplayFormatAlpha.sig="pp";var _SDL_FreeSurface=surf=>{if(surf)SDL.freeSurface(surf)};_SDL_FreeSurface.sig="vp";var _SDL_UpperBlit=(src,srcrect,dst,dstrect)=>SDL.blitSurface(src,srcrect,dst,dstrect,false);_SDL_UpperBlit.sig="ipppp";var _SDL_UpperBlitScaled=(src,srcrect,dst,dstrect)=>SDL.blitSurface(src,srcrect,dst,dstrect,true);_SDL_UpperBlitScaled.sig="ipppp";var _SDL_LowerBlit=_SDL_UpperBlit;_SDL_LowerBlit.sig="ipppp";var _SDL_LowerBlitScaled=_SDL_UpperBlitScaled;_SDL_LowerBlitScaled.sig="ipppp";var _SDL_GetClipRect=(surf,rect)=>{assert(rect);var surfData=SDL.surfaces[surf];var r=surfData.clipRect||{x:0,y:0,w:surfData.width,h:surfData.height};SDL.updateRect(rect,r)};_SDL_GetClipRect.sig="vpp";var _SDL_SetClipRect=(surf,rect)=>{var surfData=SDL.surfaces[surf];if(rect){surfData.clipRect=SDL.intersectionOfRects({x:0,y:0,w:surfData.width,h:surfData.height},SDL.loadRect(rect))}else{delete surfData.clipRect}};_SDL_SetClipRect.sig="ipp";var _SDL_FillRect=(surf,rect,color)=>{var surfData=SDL.surfaces[surf];assert(!surfData.locked);if(surfData.isFlagSet(2097152)){color=surfData.colors32[color]}var r=rect?SDL.loadRect(rect):{x:0,y:0,w:surfData.width,h:surfData.height};if(surfData.clipRect){r=SDL.intersectionOfRects(surfData.clipRect,r);if(rect){SDL.updateRect(rect,r)}}surfData.ctx.save();surfData.ctx.fillStyle=SDL.translateColorToCSSRGBA(color);surfData.ctx.fillRect(r.x,r.y,r.w,r.h);surfData.ctx.restore();return 0};_SDL_FillRect.sig="ippi";var _zoomSurface=(src,x,y,smooth)=>{var srcData=SDL.surfaces[src];var w=srcData.width*x;var h=srcData.height*y;var ret=SDL.makeSurface(Math.abs(w),Math.abs(h),srcData.flags,false,"zoomSurface");var dstData=SDL.surfaces[ret];if(x>=0&&y>=0)dstData.ctx.drawImage(srcData.canvas,0,0,w,h);else{dstData.ctx.save();dstData.ctx.scale(x<0?-1:1,y<0?-1:1);dstData.ctx.drawImage(srcData.canvas,w<0?w:0,h<0?h:0,Math.abs(w),Math.abs(h));dstData.ctx.restore()}return ret};_zoomSurface.sig="ppddi";var _rotozoomSurface=(src,angle,zoom,smooth)=>{if(angle%360===0){return _zoomSurface(src,zoom,zoom,smooth)}var srcData=SDL.surfaces[src];var w=srcData.width*zoom;var h=srcData.height*zoom;var diagonal=Math.ceil(Math.sqrt(Math.pow(w,2)+Math.pow(h,2)));var ret=SDL.makeSurface(diagonal,diagonal,srcData.flags,false,"rotozoomSurface");var dstData=SDL.surfaces[ret];dstData.ctx.translate(diagonal/2,diagonal/2);dstData.ctx.rotate(-angle*Math.PI/180);dstData.ctx.drawImage(srcData.canvas,-w/2,-h/2,w,h);return ret};_rotozoomSurface.sig="ppddi";var _SDL_SetAlpha=(surf,flag,alpha)=>{var surfData=SDL.surfaces[surf];surfData.alpha=alpha;if(!(flag&65536)){surfData.alpha=255}};_SDL_SetAlpha.sig="ipii";var _SDL_SetColorKey=(surf,flag,key)=>{warnOnce("SDL_SetColorKey is a no-op for performance reasons");return 0};_SDL_SetColorKey.sig="ipii";var _SDL_PollEvent=ptr=>SDL.pollEvent(ptr);_SDL_PollEvent.sig="ip";var _SDL_PushEvent=ptr=>{var copy=_malloc(28);_memcpy(copy,ptr,28);SDL.events.push(copy);return 0};_SDL_PushEvent.sig="ip";var _SDL_PeepEvents=(events,requestedEventCount,action,from,to)=>{switch(action){case 2:{assert(requestedEventCount==1);var index=0;var retrievedEventCount=0;while(index<SDL.events.length&&retrievedEventCount<requestedEventCount){var event=SDL.events[index];var type=SDL.DOMEventToSDLEvent[event.type];if(from<=type&&type<=to){if(SDL.makeCEvent(event,events)===false){index++}else{SDL.events.splice(index,1);retrievedEventCount++}}else{index++}}return retrievedEventCount}default:throw"SDL_PeepEvents does not yet support that action: "+action}};_SDL_PeepEvents.sig="ipiiii";var _SDL_PumpEvents=()=>SDL.events.forEach(SDL.handleEvent);_SDL_PumpEvents.sig="v";var _emscripten_SDL_SetEventHandler=(handler,userdata)=>{SDL.eventHandler=handler;SDL.eventHandlerContext=userdata;if(!SDL.eventHandlerTemp)SDL.eventHandlerTemp=_malloc(28)};_emscripten_SDL_SetEventHandler.sig="vpp";var _SDL_SetColors=(surf,colors,firstColor,nColors)=>{var surfData=SDL.surfaces[surf];if(!surfData.colors){var buffer=new ArrayBuffer(256*4);surfData.colors=new Uint8Array(buffer);surfData.colors32=new Uint32Array(buffer)}for(var i=0;i<nColors;++i){var index=(firstColor+i)*4;surfData.colors[index]=HEAPU8[colors+i*4>>0];surfData.colors[index+1]=HEAPU8[colors+(i*4+1)>>0];surfData.colors[index+2]=HEAPU8[colors+(i*4+2)>>0];surfData.colors[index+3]=255}return 1};_SDL_SetColors.sig="ippii";var _SDL_SetPalette=(surf,flags,colors,firstColor,nColors)=>_SDL_SetColors(surf,colors,firstColor,nColors);_SDL_SetPalette.sig="ipipii";var _SDL_MapRGB=(fmt,r,g,b)=>{SDL.checkPixelFormat(fmt);return r&255|(g&255)<<8|(b&255)<<16|4278190080};_SDL_MapRGB.sig="ipiii";var _SDL_MapRGBA=(fmt,r,g,b,a)=>{SDL.checkPixelFormat(fmt);return r&255|(g&255)<<8|(b&255)<<16|(a&255)<<24};_SDL_MapRGBA.sig="ipiiii";var _SDL_GetRGB=(pixel,fmt,r,g,b)=>{SDL.checkPixelFormat(fmt);if(r){HEAP8[r>>0]=pixel&255}if(g){HEAP8[g>>0]=pixel>>8&255}if(b){HEAP8[b>>0]=pixel>>16&255}};_SDL_GetRGB.sig="vipppp";var _SDL_GetRGBA=(pixel,fmt,r,g,b,a)=>{SDL.checkPixelFormat(fmt);if(r){HEAP8[r>>0]=pixel&255}if(g){HEAP8[g>>0]=pixel>>8&255}if(b){HEAP8[b>>0]=pixel>>16&255}if(a){HEAP8[a>>0]=pixel>>24&255}};_SDL_GetRGBA.sig="vippppp";var _SDL_GetAppState=()=>{var state=0;if(Browser.pointerLock){state|=1}if(document.hasFocus()){state|=2}state|=4;return state};_SDL_GetAppState.sig="i";var _SDL_WM_GrabInput=()=>{};_SDL_WM_GrabInput.sig="ii";var _SDL_WM_ToggleFullScreen=surf=>{if(Browser.exitFullscreen()){return 1}if(!SDL.canRequestFullscreen){return 0}SDL.isRequestingFullscreen=true;return 1};_SDL_WM_ToggleFullScreen.sig="ip";var _IMG_Init=flags=>flags;_IMG_Init.sig="ii";var _SDL_FreeRW=rwopsID=>{SDL.rwops[rwopsID]=null;while(SDL.rwops.length>0&&SDL.rwops[SDL.rwops.length-1]===null){SDL.rwops.pop()}};_SDL_FreeRW.sig="vp";var _IMG_Load_RW=(rwopsID,freeSrc)=>{try{var cleanup=()=>{if(rwops&&freeSrc)_SDL_FreeRW(rwopsID)};var addCleanup=func=>{var old=cleanup;cleanup=()=>{old();func()}};var callStbImage=(func,params)=>withStackSave(()=>{var x=stackAlloc(4);var y=stackAlloc(4);var comp=stackAlloc(4);var data=Module["_"+func].apply(null,params.concat([x,y,comp,0]));if(!data)return null;addCleanup(()=>Module["_stbi_image_free"](data));return{rawData:true,data:data,width:HEAP32[x>>2],height:HEAP32[y>>2],size:HEAP32[x>>2]*HEAP32[y>>2]*HEAP32[comp>>2],bpp:HEAP32[comp>>2]}});var rwops=SDL.rwops[rwopsID];if(rwops===undefined){return 0}var raw;var filename=rwops.filename;if(filename===undefined){warnOnce("Only file names that have been preloaded are supported for IMG_Load_RW. Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js), or package files with --use-preload-plugins");return 0}if(!raw){filename=PATH_FS.resolve(filename);raw=preloadedImages[filename];if(!raw){if(raw===null)err("Trying to reuse preloaded image, but freePreloadedMediaOnUse is set!");warnOnce("Cannot find preloaded image "+filename);warnOnce("Cannot find preloaded image "+filename+". Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js), or package files with --use-preload-plugins");return 0}else if(Module["freePreloadedMediaOnUse"]){preloadedImages[filename]=null}}var surf=SDL.makeSurface(raw.width,raw.height,0,false,"load:"+filename);var surfData=SDL.surfaces[surf];surfData.ctx.globalCompositeOperation="copy";if(!raw.rawData){surfData.ctx.drawImage(raw,0,0,raw.width,raw.height,0,0,raw.width,raw.height)}else{var imageData=surfData.ctx.getImageData(0,0,surfData.width,surfData.height);if(raw.bpp==4){imageData.data.set(HEAPU8.subarray(raw.data,raw.data+raw.size))}else if(raw.bpp==3){var pixels=raw.size/3;var data=imageData.data;var sourcePtr=raw.data;var destPtr=0;for(var i=0;i<pixels;i++){data[destPtr++]=HEAPU8[sourcePtr++>>0];data[destPtr++]=HEAPU8[sourcePtr++>>0];data[destPtr++]=HEAPU8[sourcePtr++>>0];data[destPtr++]=255}}else if(raw.bpp==2){var pixels=raw.size;var data=imageData.data;var sourcePtr=raw.data;var destPtr=0;for(var i=0;i<pixels;i++){var gray=HEAPU8[sourcePtr++>>0];var alpha=HEAPU8[sourcePtr++>>0];data[destPtr++]=gray;data[destPtr++]=gray;data[destPtr++]=gray;data[destPtr++]=alpha}}else if(raw.bpp==1){var pixels=raw.size;var data=imageData.data;var sourcePtr=raw.data;var destPtr=0;for(var i=0;i<pixels;i++){var value=HEAPU8[sourcePtr++>>0];data[destPtr++]=value;data[destPtr++]=value;data[destPtr++]=value;data[destPtr++]=255}}else{err(`cannot handle bpp ${raw.bpp}`);return 0}surfData.ctx.putImageData(imageData,0,0)}surfData.ctx.globalCompositeOperation="source-over";_SDL_LockSurface(surf);surfData.locked--;if(SDL.GL){surfData.canvas=surfData.ctx=null}return surf}finally{cleanup()}};_IMG_Load_RW.sig="ppi";var _SDL_LoadBMP_RW=_IMG_Load_RW;_SDL_LoadBMP_RW.sig="ppi";var _SDL_RWFromFile=(_name,mode)=>{var id=SDL.rwops.length;var filename=UTF8ToString(_name);SDL.rwops.push({filename:filename,mimetype:Browser.getMimetype(filename)});return id};_SDL_RWFromFile.sig="ppp";var _IMG_Load=filename=>{var rwops=_SDL_RWFromFile(filename,0);var result=_IMG_Load_RW(rwops,1);return result};_IMG_Load.sig="pp";var _IMG_Quit=()=>out("IMG_Quit called (and ignored)");_IMG_Quit.sig="v";var _SDL_OpenAudio=(desired,obtained)=>{try{SDL.audio={freq:HEAPU32[desired>>2],format:HEAPU16[desired+4>>1],channels:HEAPU8[desired+6>>0],samples:HEAPU16[desired+8>>1],callback:HEAPU32[desired+16>>2],userdata:HEAPU32[desired+20>>2],paused:true,timer:null};if(SDL.audio.format==8){SDL.audio.silence=128}else if(SDL.audio.format==32784){SDL.audio.silence=0}else if(SDL.audio.format==33056){SDL.audio.silence=0}else{throw"Invalid SDL audio format "+SDL.audio.format+"!"}if(SDL.audio.freq<=0){throw"Unsupported sound frequency "+SDL.audio.freq+"!"}else if(SDL.audio.freq<=22050){SDL.audio.freq=22050}else if(SDL.audio.freq<=32e3){SDL.audio.freq=32e3}else if(SDL.audio.freq<=44100){SDL.audio.freq=44100}else if(SDL.audio.freq<=48e3){SDL.audio.freq=48e3}else if(SDL.audio.freq<=96e3){SDL.audio.freq=96e3}else{throw`Unsupported sound frequency ${SDL.audio.freq}!`}if(SDL.audio.channels==0){SDL.audio.channels=1}else if(SDL.audio.channels<0||SDL.audio.channels>32){throw`Unsupported number of audio channels for SDL audio: ${SDL.audio.channels}!`}else if(SDL.audio.channels!=1&&SDL.audio.channels!=2){out(`Warning: Using untested number of audio channels ${SDL.audio.channels}`)}if(SDL.audio.samples<128||SDL.audio.samples>524288){throw`Unsupported audio callback buffer size ${SDL.audio.samples}!`}else if((SDL.audio.samples&SDL.audio.samples-1)!=0){throw`Audio callback buffer size ${SDL.audio.samples} must be a power-of-two!`}var totalSamples=SDL.audio.samples*SDL.audio.channels;if(SDL.audio.format==8){SDL.audio.bytesPerSample=1}else if(SDL.audio.format==32784){SDL.audio.bytesPerSample=2}else if(SDL.audio.format==33056){SDL.audio.bytesPerSample=4}else{throw`Invalid SDL audio format ${SDL.audio.format}!`}SDL.audio.bufferSize=totalSamples*SDL.audio.bytesPerSample;SDL.audio.bufferDurationSecs=SDL.audio.bufferSize/SDL.audio.bytesPerSample/SDL.audio.channels/SDL.audio.freq;SDL.audio.bufferingDelay=50/1e3;SDL.audio.buffer=_malloc(SDL.audio.bufferSize);SDL.audio.numSimultaneouslyQueuedBuffers=Module["SDL_numSimultaneouslyQueuedBuffers"]||5;SDL.audio.queueNewAudioData=()=>{if(!SDL.audio)return;for(var i=0;i<SDL.audio.numSimultaneouslyQueuedBuffers;++i){var secsUntilNextPlayStart=SDL.audio.nextPlayTime-SDL.audioContext["currentTime"];if(secsUntilNextPlayStart>=SDL.audio.bufferingDelay+SDL.audio.bufferDurationSecs*SDL.audio.numSimultaneouslyQueuedBuffers)return;getWasmTableEntry(SDL.audio.callback)(SDL.audio.userdata,SDL.audio.buffer,SDL.audio.bufferSize);SDL.audio.pushAudio(SDL.audio.buffer,SDL.audio.bufferSize)}};SDL.audio.caller=()=>{if(!SDL.audio)return;--SDL.audio.numAudioTimersPending;SDL.audio.queueNewAudioData();var secsUntilNextPlayStart=SDL.audio.nextPlayTime-SDL.audioContext["currentTime"];var preemptBufferFeedSecs=SDL.audio.bufferDurationSecs/2;if(SDL.audio.numAudioTimersPending<SDL.audio.numSimultaneouslyQueuedBuffers){++SDL.audio.numAudioTimersPending;SDL.audio.timer=safeSetTimeout(SDL.audio.caller,Math.max(0,1e3*(secsUntilNextPlayStart-preemptBufferFeedSecs)));if(SDL.audio.numAudioTimersPending<SDL.audio.numSimultaneouslyQueuedBuffers){++SDL.audio.numAudioTimersPending;safeSetTimeout(SDL.audio.caller,1)}}};SDL.audio.audioOutput=new Audio;SDL.openAudioContext();if(!SDL.audioContext)throw"Web Audio API is not available!";autoResumeAudioContext(SDL.audioContext);SDL.audio.nextPlayTime=0;SDL.audio.pushAudio=function(ptr,sizeBytes){try{if(SDL.audio.paused)return;var sizeSamples=sizeBytes/SDL.audio.bytesPerSample;var sizeSamplesPerChannel=sizeSamples/SDL.audio.channels;if(sizeSamplesPerChannel!=SDL.audio.samples){throw"Received mismatching audio buffer size!"}var source=SDL.audioContext["createBufferSource"]();var soundBuffer=SDL.audioContext["createBuffer"](SDL.audio.channels,sizeSamplesPerChannel,SDL.audio.freq);source["connect"](SDL.audioContext["destination"]);SDL.fillWebAudioBufferFromHeap(ptr,sizeSamplesPerChannel,soundBuffer);source["buffer"]=soundBuffer;var curtime=SDL.audioContext["currentTime"];var playtime=Math.max(curtime+SDL.audio.bufferingDelay,SDL.audio.nextPlayTime);if(typeof source["start"]!="undefined"){source["start"](playtime)}else if(typeof source["noteOn"]!="undefined"){source["noteOn"](playtime)}SDL.audio.nextPlayTime=playtime+SDL.audio.bufferDurationSecs}catch(e){err(`Web Audio API error playing back audio: ${e.toString()}`)}};if(obtained){HEAP32[obtained>>2]=SDL.audio.freq;HEAP16[obtained+4>>1]=SDL.audio.format;HEAP8[obtained+6>>0]=SDL.audio.channels;HEAP8[obtained+7>>0]=SDL.audio.silence;HEAP16[obtained+8>>1]=SDL.audio.samples;HEAPU32[obtained+16>>2]=SDL.audio.callback;HEAPU32[obtained+20>>2]=SDL.audio.userdata}SDL.allocateChannels(32)}catch(e){err(`Initializing SDL audio threw an exception: "${e.toString()}"! Continuing without audio`);SDL.audio=null;SDL.allocateChannels(0);if(obtained){HEAP32[obtained>>2]=0;HEAP16[obtained+4>>1]=0;HEAP8[obtained+6>>0]=0;HEAP8[obtained+7>>0]=0;HEAP16[obtained+8>>1]=0;HEAPU32[obtained+16>>2]=0;HEAPU32[obtained+20>>2]=0}}if(!SDL.audio){return-1}return 0};_SDL_OpenAudio.sig="ipp";var _SDL_PauseAudio=pauseOn=>{if(!SDL.audio){return}if(pauseOn){if(SDL.audio.timer!==undefined){clearTimeout(SDL.audio.timer);SDL.audio.numAudioTimersPending=0;SDL.audio.timer=undefined}}else if(!SDL.audio.timer){SDL.audio.numAudioTimersPending=1;SDL.audio.timer=safeSetTimeout(SDL.audio.caller,1)}SDL.audio.paused=pauseOn};_SDL_PauseAudio.sig="vi";var _SDL_CloseAudio=()=>{if(SDL.audio){if(SDL.audio.callbackRemover){SDL.audio.callbackRemover();SDL.audio.callbackRemover=null}_SDL_PauseAudio(1);_free(SDL.audio.buffer);SDL.audio=null;SDL.allocateChannels(0)}};_SDL_CloseAudio.sig="v";var _SDL_LockAudio=()=>{};_SDL_LockAudio.sig="v";var _SDL_UnlockAudio=()=>{};_SDL_UnlockAudio.sig="v";var _SDL_CreateMutex=()=>0;_SDL_CreateMutex.sig="p";var _SDL_mutexP=mutex=>0;_SDL_mutexP.sig="ip";var _SDL_mutexV=mutex=>0;_SDL_mutexV.sig="ip";var _SDL_DestroyMutex=mutex=>{};_SDL_DestroyMutex.sig="vp";var _SDL_CreateCond=()=>0;_SDL_CreateCond.sig="p";var _SDL_CondSignal=cond=>{};_SDL_CondSignal.sig="ip";var _SDL_CondWait=(cond,mutex)=>{};_SDL_CondWait.sig="ipp";var _SDL_DestroyCond=cond=>{};_SDL_DestroyCond.sig="vp";var _SDL_StartTextInput=()=>{SDL.textInput=true};_SDL_StartTextInput.sig="v";var _SDL_StopTextInput=()=>{SDL.textInput=false};_SDL_StopTextInput.sig="v";var _Mix_Init=flags=>{if(!flags)return 0;return 8};_Mix_Init.sig="ii";var _Mix_Quit=()=>{};_Mix_Quit.sig="v";var _Mix_OpenAudio=(frequency,format,channels,chunksize)=>{SDL.openAudioContext();autoResumeAudioContext(SDL.audioContext);SDL.allocateChannels(32);SDL.mixerFrequency=frequency;SDL.mixerFormat=format;SDL.mixerNumChannels=channels;SDL.mixerChunkSize=chunksize;return 0};_Mix_OpenAudio.sig="iiiii";var _Mix_CloseAudio=_SDL_CloseAudio;_Mix_CloseAudio.sig="v";var _Mix_AllocateChannels=num=>{SDL.allocateChannels(num);return num};_Mix_AllocateChannels.sig="ii";var _Mix_ChannelFinished=func=>{SDL.channelFinished=func};_Mix_ChannelFinished.sig="vp";var _Mix_Volume=(channel,volume)=>{if(channel==-1){for(var i=0;i<SDL.numChannels-1;i++){_Mix_Volume(i,volume)}return _Mix_Volume(SDL.numChannels-1,volume)}return SDL.setGetVolume(SDL.channels[channel],volume)};_Mix_Volume.sig="iii";var _Mix_SetPanning=(channel,left,right)=>{left/=255;right/=255;SDL.setPannerPosition(SDL.channels[channel],right-left,0,.1);return 1};_Mix_SetPanning.sig="iiii";var _Mix_LoadWAV_RW=(rwopsID,freesrc)=>{var rwops=SDL.rwops[rwopsID];if(rwops===undefined)return 0;var filename="";var audio;var webAudio;var bytes;if(rwops.filename!==undefined){filename=PATH_FS.resolve(rwops.filename);var raw=preloadedAudios[filename];if(!raw){if(raw===null)err("Trying to reuse preloaded audio, but freePreloadedMediaOnUse is set!");if(!Module.noAudioDecoding)warnOnce("Cannot find preloaded audio "+filename);try{bytes=FS.readFile(filename)}catch(e){err(`Couldn't find file for: ${filename}`);return 0}}if(Module["freePreloadedMediaOnUse"]){preloadedAudios[filename]=null}audio=raw}else if(rwops.bytes!==undefined){if(SDL.webAudioAvailable())bytes=HEAPU8.buffer.slice(rwops.bytes,rwops.bytes+rwops.count);else bytes=HEAPU8.subarray(rwops.bytes,rwops.bytes+rwops.count)}else{return 0}var arrayBuffer=bytes?bytes.buffer||bytes:bytes;var canPlayWithWebAudio=Module["SDL_canPlayWithWebAudio"]===undefined||Module["SDL_canPlayWithWebAudio"](filename,arrayBuffer);if(bytes!==undefined&&SDL.webAudioAvailable()&&canPlayWithWebAudio){audio=undefined;webAudio={};webAudio.onDecodeComplete=[];var onDecodeComplete=data=>{webAudio.decodedBuffer=data;webAudio.onDecodeComplete.forEach(e=>e());webAudio.onDecodeComplete=undefined};SDL.audioContext["decodeAudioData"](arrayBuffer,onDecodeComplete)}else if(audio===undefined&&bytes){var blob=new Blob([bytes],{type:rwops.mimetype});var url=URL.createObjectURL(blob);audio=new Audio;audio.src=url;audio.mozAudioChannelType="content"}var id=SDL.audios.length;SDL.audios.push({source:filename,audio:audio,webAudio:webAudio});return id};_Mix_LoadWAV_RW.sig="ppi";var _Mix_LoadWAV=filename=>{var rwops=_SDL_RWFromFile(filename,0);var result=_Mix_LoadWAV_RW(rwops,0);_SDL_FreeRW(rwops);return result};_Mix_LoadWAV.sig="pp";var _Mix_QuickLoad_RAW=(mem,len)=>{var audio;var webAudio;var numSamples=len>>1;var buffer=new Float32Array(numSamples);for(var i=0;i<numSamples;++i){buffer[i]=HEAP16[mem+i*2>>1]/32768}if(SDL.webAudioAvailable()){webAudio={};webAudio.decodedBuffer=buffer}else{audio=new Audio;audio.mozAudioChannelType="content";audio.numChannels=SDL.mixerNumChannels;audio.frequency=SDL.mixerFrequency}var id=SDL.audios.length;SDL.audios.push({source:"",audio:audio,webAudio:webAudio,buffer:buffer});return id};_Mix_QuickLoad_RAW.sig="ppi";var _Mix_FreeChunk=id=>{SDL.audios[id]=null};_Mix_FreeChunk.sig="vp";var _Mix_ReserveChannels=num=>{SDL.channelMinimumNumber=num};_Mix_ReserveChannels.sig="ii";var _Mix_PlayChannelTimed=(channel,id,loops,ticks)=>{assert(ticks==-1);var info=SDL.audios[id];if(!info)return-1;if(!info.audio&&!info.webAudio)return-1;if(channel==-1){for(var i=SDL.channelMinimumNumber;i<SDL.numChannels;i++){if(!SDL.channels[i].audio){channel=i;break}}if(channel==-1){err(`All ${SDL.numChannels}  channels in use!`);return-1}}var channelInfo=SDL.channels[channel];var audio;if(info.webAudio){audio={};audio.resource=info;audio.paused=false;audio.currentPosition=0;audio.play=function(){SDL.playWebAudio(this)};audio.pause=function(){SDL.pauseWebAudio(this)}}else{audio=info.audio.cloneNode(true);audio.numChannels=info.audio.numChannels;audio.frequency=info.audio.frequency}audio["onended"]=function(){if(channelInfo.audio==this){channelInfo.audio.paused=true;channelInfo.audio=null}if(SDL.channelFinished)getWasmTableEntry(SDL.channelFinished)(channel)};channelInfo.audio=audio;audio.loop=loops!=0;audio.volume=channelInfo.volume;audio.play();return channel};_Mix_PlayChannelTimed.sig="iipii";var _Mix_FadingChannel=channel=>0;_Mix_FadingChannel.sig="ii";var _Mix_HaltChannel=channel=>{function halt(channel){var info=SDL.channels[channel];if(info.audio){info.audio.pause();info.audio=null}if(SDL.channelFinished){getWasmTableEntry(SDL.channelFinished)(channel)}}if(channel!=-1){halt(channel)}else{for(var i=0;i<SDL.channels.length;++i)halt(i)}return 0};_Mix_HaltChannel.sig="ii";var _Mix_HaltMusic=()=>{var audio=SDL.music.audio;if(audio){audio.src=audio.src;audio.currentPosition=0;audio.pause()}SDL.music.audio=null;if(SDL.hookMusicFinished){getWasmTableEntry(SDL.hookMusicFinished)()}return 0};_Mix_HaltMusic.sig="i";var _Mix_HookMusicFinished=func=>{SDL.hookMusicFinished=func;if(SDL.music.audio){SDL.music.audio["onended"]=_Mix_HaltMusic}};_Mix_HookMusicFinished.sig="vp";var _Mix_VolumeMusic=volume=>SDL.setGetVolume(SDL.music,volume);_Mix_VolumeMusic.sig="ii";var _Mix_LoadMUS_RW=_Mix_LoadWAV_RW;_Mix_LoadMUS_RW.sig="pp";var _Mix_LoadMUS=filename=>{var rwops=_SDL_RWFromFile(filename,0);var result=_Mix_LoadMUS_RW(rwops,0);_SDL_FreeRW(rwops);return result};_Mix_LoadMUS.sig="pp";var _Mix_FreeMusic=_Mix_FreeChunk;_Mix_FreeMusic.sig="vp";var _Mix_PlayMusic=(id,loops)=>{if(SDL.music.audio){if(!SDL.music.audio.paused)err(`Music is already playing. ${SDL.music.source}`);SDL.music.audio.pause()}var info=SDL.audios[id];var audio;if(info.webAudio){audio={};audio.resource=info;audio.paused=false;audio.currentPosition=0;audio.play=function(){SDL.playWebAudio(this)};audio.pause=function(){SDL.pauseWebAudio(this)}}else if(info.audio){audio=info.audio}audio["onended"]=function(){if(SDL.music.audio==this)_Mix_HaltMusic()};audio.loop=loops!=0&&loops!=1;audio.volume=SDL.music.volume;SDL.music.audio=audio;audio.play();return 0};_Mix_PlayMusic.sig="ipi";var _Mix_PauseMusic=()=>{var audio=SDL.music.audio;if(audio)audio.pause()};_Mix_PauseMusic.sig="v";var _Mix_ResumeMusic=()=>{var audio=SDL.music.audio;if(audio)audio.play()};_Mix_ResumeMusic.sig="v";var _Mix_FadeInMusicPos=_Mix_PlayMusic;_Mix_FadeInMusicPos.sig="ipiid";var _Mix_FadeOutMusic=_Mix_HaltMusic;_Mix_FadeOutMusic.sig="ii";var _Mix_PlayingMusic=()=>SDL.music.audio&&!SDL.music.audio.paused?1:0;_Mix_PlayingMusic.sig="i";var _Mix_Playing=channel=>{if(channel===-1){var count=0;for(var i=0;i<SDL.channels.length;i++){count+=_Mix_Playing(i)}return count}var info=SDL.channels[channel];if(info&&info.audio&&!info.audio.paused){return 1}return 0};_Mix_Playing.sig="ii";var _Mix_Pause=channel=>{if(channel===-1){for(var i=0;i<SDL.channels.length;i++){_Mix_Pause(i)}return}var info=SDL.channels[channel];if(info&&info.audio){info.audio.pause()}else{}};_Mix_Pause.sig="vi";var _Mix_Paused=channel=>{if(channel===-1){var pausedCount=0;for(var i=0;i<SDL.channels.length;i++){pausedCount+=_Mix_Paused(i)}return pausedCount}var info=SDL.channels[channel];if(info&&info.audio&&info.audio.paused){return 1}return 0};_Mix_Paused.sig="ii";var _Mix_PausedMusic=()=>SDL.music.audio&&SDL.music.audio.paused?1:0;_Mix_PausedMusic.sig="i";var _Mix_Resume=channel=>{if(channel===-1){for(var i=0;i<SDL.channels.length;i++){_Mix_Resume(i)}return}var info=SDL.channels[channel];if(info&&info.audio)info.audio.play()};_Mix_Resume.sig="vi";var _TTF_Init=()=>{try{var offscreenCanvas=new OffscreenCanvas(0,0);SDL.ttfContext=offscreenCanvas.getContext("2d");if(typeof SDL.ttfContext.measureText!="function"){throw"bad context"}}catch(ex){var canvas=document.createElement("canvas");SDL.ttfContext=canvas.getContext("2d")}return 0};_TTF_Init.sig="i";var _TTF_OpenFont=(name,size)=>{name=PATH.normalize(UTF8ToString(name));var id=SDL.fonts.length;SDL.fonts.push({name:name,size:size});return id};_TTF_OpenFont.sig="ppi";var _TTF_CloseFont=font=>{SDL.fonts[font]=null};_TTF_CloseFont.sig="vp";var _TTF_RenderText_Solid=(font,text,color)=>{text=UTF8ToString(text)||" ";var fontData=SDL.fonts[font];var w=SDL.estimateTextWidth(fontData,text);var h=fontData.size;color=SDL.loadColorToCSSRGB(color);var fontString=SDL.makeFontString(h,fontData.name);var surf=SDL.makeSurface(w,h,0,false,"text:"+text);var surfData=SDL.surfaces[surf];surfData.ctx.save();surfData.ctx.fillStyle=color;surfData.ctx.font=fontString;surfData.ctx.textBaseline="bottom";surfData.ctx.fillText(text,0,h|0);surfData.ctx.restore();return surf};_TTF_RenderText_Solid.sig="pppp";var _TTF_RenderText_Blended=_TTF_RenderText_Solid;_TTF_RenderText_Blended.sig="pppp";var _TTF_RenderText_Shaded=_TTF_RenderText_Solid;_TTF_RenderText_Shaded.sig="ppppp";var _TTF_RenderUTF8_Solid=_TTF_RenderText_Solid;_TTF_RenderUTF8_Solid.sig="pppp";var _TTF_SizeText=(font,text,w,h)=>{var fontData=SDL.fonts[font];if(w){HEAP32[w>>2]=SDL.estimateTextWidth(fontData,UTF8ToString(text))}if(h){HEAP32[h>>2]=fontData.size}return 0};_TTF_SizeText.sig="ipppp";var _TTF_SizeUTF8=_TTF_SizeText;_TTF_SizeUTF8.sig="ipppp";var _TTF_GlyphMetrics=(font,ch,minx,maxx,miny,maxy,advance)=>{var fontData=SDL.fonts[font];var width=SDL.estimateTextWidth(fontData,String.fromCharCode(ch));if(advance){HEAP32[advance>>2]=width}if(minx){HEAP32[minx>>2]=0}if(maxx){HEAP32[maxx>>2]=width}if(miny){HEAP32[miny>>2]=0}if(maxy){HEAP32[maxy>>2]=fontData.size}};_TTF_GlyphMetrics.sig="ipippppp";var _TTF_FontAscent=font=>{var fontData=SDL.fonts[font];return fontData.size*.98|0};_TTF_FontAscent.sig="ip";var _TTF_FontDescent=font=>{var fontData=SDL.fonts[font];return fontData.size*.02|0};_TTF_FontDescent.sig="ip";var _TTF_FontHeight=font=>{var fontData=SDL.fonts[font];return fontData.size};_TTF_FontHeight.sig="ip";var _TTF_FontLineSkip=_TTF_FontHeight;_TTF_FontLineSkip.sig="ip";var _TTF_Quit=()=>out("TTF_Quit called (and ignored)");_TTF_Quit.sig="v";var SDL_gfx={drawRectangle:(surf,x1,y1,x2,y2,action,cssColor)=>{x1=x1<<16>>16;y1=y1<<16>>16;x2=x2<<16>>16;y2=y2<<16>>16;var surfData=SDL.surfaces[surf];assert(!surfData.locked);var x=x1<x2?x1:x2;var y=y1<y2?y1:y2;var w=Math.abs(x2-x1);var h=Math.abs(y2-y1);surfData.ctx.save();surfData.ctx[action+"Style"]=cssColor;surfData.ctx[action+"Rect"](x,y,w,h);surfData.ctx.restore()},drawLine:(surf,x1,y1,x2,y2,cssColor)=>{x1=x1<<16>>16;y1=y1<<16>>16;x2=x2<<16>>16;y2=y2<<16>>16;var surfData=SDL.surfaces[surf];assert(!surfData.locked);surfData.ctx.save();surfData.ctx.strokeStyle=cssColor;surfData.ctx.beginPath();surfData.ctx.moveTo(x1,y1);surfData.ctx.lineTo(x2,y2);surfData.ctx.stroke();surfData.ctx.restore()},drawEllipse:(surf,x,y,rx,ry,action,cssColor)=>{x=x<<16>>16;y=y<<16>>16;rx=rx<<16>>16;ry=ry<<16>>16;var surfData=SDL.surfaces[surf];assert(!surfData.locked);surfData.ctx.save();surfData.ctx.beginPath();surfData.ctx.translate(x,y);surfData.ctx.scale(rx,ry);surfData.ctx.arc(0,0,1,0,2*Math.PI);surfData.ctx.restore();surfData.ctx.save();surfData.ctx[action+"Style"]=cssColor;surfData.ctx[action]();surfData.ctx.restore()},translateColorToCSSRGBA:rgba=>`rgba(${rgba>>>24},${rgba>>16&255},${rgba>>8&255},${rgba&255})`};var _boxColor=(surf,x1,y1,x2,y2,color)=>SDL_gfx.drawRectangle(surf,x1,y1,x2,y2,"fill",SDL_gfx.translateColorToCSSRGBA(color));_boxColor.sig="ipiiiii";var _boxRGBA=(surf,x1,y1,x2,y2,r,g,b,a)=>SDL_gfx.drawRectangle(surf,x1,y1,x2,y2,"fill",SDL.translateRGBAToCSSRGBA(r,g,b,a));_boxRGBA.sig="ipiiiiiiii";var _rectangleColor=(surf,x1,y1,x2,y2,color)=>SDL_gfx.drawRectangle(surf,x1,y1,x2,y2,"stroke",SDL_gfx.translateColorToCSSRGBA(color));_rectangleColor.sig="ipiiiii";var _rectangleRGBA=(surf,x1,y1,x2,y2,r,g,b,a)=>SDL_gfx.drawRectangle(surf,x1,y1,x2,y2,"stroke",SDL.translateRGBAToCSSRGBA(r,g,b,a));_rectangleRGBA.sig="ipiiiiiiii";var _ellipseColor=(surf,x,y,rx,ry,color)=>SDL_gfx.drawEllipse(surf,x,y,rx,ry,"stroke",SDL_gfx.translateColorToCSSRGBA(color));_ellipseColor.sig="ipiiiii";var _ellipseRGBA=(surf,x,y,rx,ry,r,g,b,a)=>SDL_gfx.drawEllipse(surf,x,y,rx,ry,"stroke",SDL.translateRGBAToCSSRGBA(r,g,b,a));_ellipseRGBA.sig="ipiiiiiiii";var _filledEllipseColor=(surf,x,y,rx,ry,color)=>SDL_gfx.drawEllipse(surf,x,y,rx,ry,"fill",SDL_gfx.translateColorToCSSRGBA(color));_filledEllipseColor.sig="ipiiiii";var _filledEllipseRGBA=(surf,x,y,rx,ry,r,g,b,a)=>SDL_gfx.drawEllipse(surf,x,y,rx,ry,"fill",SDL.translateRGBAToCSSRGBA(r,g,b,a));_filledEllipseRGBA.sig="ipiiiiiiii";var _lineColor=(surf,x1,y1,x2,y2,color)=>SDL_gfx.drawLine(surf,x1,y1,x2,y2,SDL_gfx.translateColorToCSSRGBA(color));_lineColor.sig="ipiiiii";var _lineRGBA=(surf,x1,y1,x2,y2,r,g,b,a)=>SDL_gfx.drawLine(surf,x1,y1,x2,y2,SDL.translateRGBAToCSSRGBA(r,g,b,a));_lineRGBA.sig="ipiiiiiiii";var _pixelRGBA=(surf,x1,y1,r,g,b,a)=>_boxRGBA(surf,x1,y1,x1,y1,r,g,b,a);_pixelRGBA.sig="ipiiiiii";var _SDL_GL_SetAttribute=(attr,value)=>{if(!(attr in SDL.glAttributes)){abort("Unknown SDL GL attribute ("+attr+"). Please check if your SDL version is supported.")}SDL.glAttributes[attr]=value};_SDL_GL_SetAttribute.sig="iii";var _SDL_GL_GetAttribute=(attr,value)=>{if(!(attr in SDL.glAttributes)){abort("Unknown SDL GL attribute ("+attr+"). Please check if your SDL version is supported.")}if(value)HEAP32[value>>2]=SDL.glAttributes[attr];return 0};_SDL_GL_GetAttribute.sig="iip";var _SDL_GL_SwapBuffers=()=>{if(Browser.doSwapBuffers)Browser.doSwapBuffers()};_SDL_GL_SwapBuffers.sig="v";var _SDL_GL_ExtensionSupported=extension=>Module.ctx.getExtension(extension)|0;_SDL_GL_ExtensionSupported.sig="ip";var _SDL_DestroyWindow=window=>{};_SDL_DestroyWindow.sig="vp";var _SDL_DestroyRenderer=renderer=>{};_SDL_DestroyRenderer.sig="vp";var _SDL_GetWindowFlags=window=>{if(Browser.isFullscreen){return 1}return 0};_SDL_GetWindowFlags.sig="ip";var _SDL_GL_SwapWindow=window=>{};_SDL_GL_SwapWindow.sig="vp";var _SDL_GL_MakeCurrent=(window,context)=>{};_SDL_GL_MakeCurrent.sig="ipp";var _SDL_GL_DeleteContext=context=>{};_SDL_GL_DeleteContext.sig="vp";var _SDL_GL_GetSwapInterval=()=>{if(Browser.mainLoop.timingMode==1)return Browser.mainLoop.timingValue;else return 0};_SDL_GL_GetSwapInterval.sig="i";var _SDL_GL_SetSwapInterval=state=>{_emscripten_set_main_loop_timing(1,state)};_SDL_GL_SetSwapInterval.sig="ii";var _SDL_SetWindowTitle=(window,title)=>{if(title)document.title=UTF8ToString(title)};_SDL_SetWindowTitle.sig="vpp";var _SDL_GetWindowSize=(window,width,height)=>{var w=Module["canvas"].width;var h=Module["canvas"].height;if(width)HEAP32[width>>2]=w;if(height)HEAP32[height>>2]=h};_SDL_GetWindowSize.sig="vppp";var _SDL_LogSetOutputFunction=(callback,userdata)=>{};_SDL_LogSetOutputFunction.sig="vpp";var _SDL_SetWindowFullscreen=(window,fullscreen)=>{if(Browser.isFullscreen){Module["canvas"].exitFullscreen();return 1}return 0};_SDL_SetWindowFullscreen.sig="ipi";var _SDL_ClearError=()=>{};_SDL_ClearError.sig="v";var _SDL_SetGamma=(r,g,b)=>-1;_SDL_SetGamma.sig="ifff";var _SDL_SetGammaRamp=(redTable,greenTable,blueTable)=>-1;_SDL_SetGammaRamp.sig="ippp";var _SDL_NumJoysticks=()=>{var count=0;var gamepads=SDL.getGamepads();for(var i=0;i<gamepads.length;i++){if(gamepads[i]!==undefined)count++}return count};_SDL_NumJoysticks.sig="i";var _SDL_JoystickName=deviceIndex=>{var gamepad=SDL.getGamepad(deviceIndex);if(gamepad){var name=gamepad.id;if(SDL.joystickNamePool.hasOwnProperty(name)){return SDL.joystickNamePool[name]}return SDL.joystickNamePool[name]=stringToNewUTF8(name)}return 0};_SDL_JoystickName.sig="pi";var _SDL_JoystickOpen=deviceIndex=>{var gamepad=SDL.getGamepad(deviceIndex);if(gamepad){var joystick=deviceIndex+1;SDL.recordJoystickState(joystick,gamepad);return joystick}return 0};_SDL_JoystickOpen.sig="pi";var _SDL_JoystickOpened=deviceIndex=>SDL.lastJoystickState.hasOwnProperty(deviceIndex+1)?1:0;_SDL_JoystickOpened.sig="ii";var _SDL_JoystickIndex=joystick=>joystick-1;_SDL_JoystickIndex.sig="ip";var _SDL_JoystickNumAxes=joystick=>{var gamepad=SDL.getGamepad(joystick-1);if(gamepad){return gamepad.axes.length}return 0};_SDL_JoystickNumAxes.sig="ip";var _SDL_JoystickNumBalls=joystick=>0;_SDL_JoystickNumBalls.sig="ip";var _SDL_JoystickNumHats=joystick=>0;_SDL_JoystickNumHats.sig="ip";var _SDL_JoystickNumButtons=joystick=>{var gamepad=SDL.getGamepad(joystick-1);if(gamepad){return gamepad.buttons.length}return 0};_SDL_JoystickNumButtons.sig="ip";var _SDL_JoystickUpdate=()=>SDL.queryJoysticks();_SDL_JoystickUpdate.sig="v";var _SDL_JoystickEventState=state=>{if(state<0){return SDL.joystickEventState}return SDL.joystickEventState=state};_SDL_JoystickEventState.sig="ii";var _SDL_JoystickGetAxis=(joystick,axis)=>{var gamepad=SDL.getGamepad(joystick-1);if(gamepad&&gamepad.axes.length>axis){return SDL.joystickAxisValueConversion(gamepad.axes[axis])}return 0};_SDL_JoystickGetAxis.sig="ipi";var _SDL_JoystickGetHat=(joystick,hat)=>0;_SDL_JoystickGetHat.sig="ipi";var _SDL_JoystickGetBall=(joystick,ball,dxptr,dyptr)=>-1;_SDL_JoystickGetBall.sig="ipipp";var _SDL_JoystickGetButton=(joystick,button)=>{var gamepad=SDL.getGamepad(joystick-1);if(gamepad&&gamepad.buttons.length>button){return SDL.getJoystickButtonState(gamepad.buttons[button])?1:0}return 0};_SDL_JoystickGetButton.sig="ipi";var _SDL_JoystickClose=joystick=>{delete SDL.lastJoystickState[joystick]};_SDL_JoystickClose.sig="vp";var _SDL_InitSubSystem=flags=>0;_SDL_InitSubSystem.sig="ii";var _SDL_RWFromConstMem=(mem,size)=>{var id=SDL.rwops.length;SDL.rwops.push({bytes:mem,count:size});return id};_SDL_RWFromConstMem.sig="ppi";var _SDL_RWFromMem=_SDL_RWFromConstMem;_SDL_RWFromMem.sig="ppi";var _SDL_GetNumAudioDrivers=()=>1;_SDL_GetNumAudioDrivers.sig="i";var _SDL_GetCurrentAudioDriver=()=>stringToNewUTF8("Emscripten Audio");_SDL_GetCurrentAudioDriver.sig="p";var _SDL_GetScancodeFromKey=key=>SDL.scanCodes[key];_SDL_GetScancodeFromKey.sig="ii";var _SDL_GetAudioDriver=index=>_SDL_GetCurrentAudioDriver();_SDL_GetAudioDriver.sig="pi";var _SDL_EnableUNICODE=on=>{var ret=SDL.unicode||0;SDL.unicode=on;return ret};_SDL_EnableUNICODE.sig="ii";var _SDL_AddTimer=(interval,callback,param)=>safeSetTimeout(()=>getWasmTableEntry(callback)(interval,param),interval);_SDL_AddTimer.sig="iipp";var _SDL_RemoveTimer=id=>{clearTimeout(id);return true};_SDL_RemoveTimer.sig="ii";var _SDL_CreateThread=(fs,data,pfnBeginThread,pfnEndThread)=>{throw"SDL threads cannot be supported in the web platform because they assume shared state. See emscripten_create_worker etc. for a message-passing concurrency model that does let you run code in another thread."};_SDL_CreateThread.sig="ppp";var _SDL_WaitThread=(thread,status)=>{throw"SDL_WaitThread"};_SDL_WaitThread.sig="vpp";var _SDL_GetThreadID=thread=>{throw"SDL_GetThreadID"};_SDL_GetThreadID.sig="pp";var _SDL_ThreadID=()=>0;_SDL_ThreadID.sig="p";var _SDL_AllocRW=()=>{throw"SDL_AllocRW: TODO"};_SDL_AllocRW.sig="p";var _SDL_CondBroadcast=cond=>{throw"SDL_CondBroadcast: TODO"};_SDL_CondBroadcast.sig="ip";var _SDL_CondWaitTimeout=(cond,mutex,ms)=>{throw"SDL_CondWaitTimeout: TODO"};_SDL_CondWaitTimeout.sig="ippi";var _SDL_WM_IconifyWindow=()=>{throw"SDL_WM_IconifyWindow TODO"};_SDL_WM_IconifyWindow.sig="i";var _Mix_SetPostMix=(func,arg)=>warnOnce("Mix_SetPostMix: TODO");_Mix_SetPostMix.sig="vpp";var _Mix_VolumeChunk=(chunk,volume)=>{throw"Mix_VolumeChunk: TODO"};_Mix_VolumeChunk.sig="ipi";var _Mix_SetPosition=(channel,angle,distance)=>{throw"Mix_SetPosition: TODO"};_Mix_SetPosition.sig="iiii";var _Mix_QuerySpec=(frequency,format,channels)=>{throw"Mix_QuerySpec: TODO"};_Mix_QuerySpec.sig="ippp";var _Mix_FadeInChannelTimed=(channel,chunk,loop,ms,ticks)=>{throw"Mix_FadeInChannelTimed"};_Mix_FadeInChannelTimed.sig="iipiii";var _Mix_FadeOutChannel=()=>{throw"Mix_FadeOutChannel"};_Mix_FadeOutChannel.sig="iii";var _Mix_Linked_Version=()=>{throw"Mix_Linked_Version: TODO"};_Mix_Linked_Version.sig="p";var _SDL_SaveBMP_RW=(surface,dst,freedst)=>{throw"SDL_SaveBMP_RW: TODO"};_SDL_SaveBMP_RW.sig="ippi";var _SDL_WM_SetIcon=(icon,mask)=>{};_SDL_WM_SetIcon.sig="vpp";var _SDL_HasRDTSC=()=>0;_SDL_HasRDTSC.sig="i";var _SDL_HasMMX=()=>0;_SDL_HasMMX.sig="i";var _SDL_HasMMXExt=()=>0;_SDL_HasMMXExt.sig="i";var _SDL_Has3DNow=()=>0;_SDL_Has3DNow.sig="i";var _SDL_Has3DNowExt=()=>0;_SDL_Has3DNowExt.sig="i";var _SDL_HasSSE=()=>0;_SDL_HasSSE.sig="i";var _SDL_HasSSE2=()=>0;_SDL_HasSSE2.sig="i";var _SDL_HasAltiVec=()=>0;_SDL_HasAltiVec.sig="i";var ALLOC_NORMAL=0;var ALLOC_STACK=1;var allocate=(slab,allocator)=>{var ret;if(allocator==ALLOC_STACK){ret=stackAlloc(slab.length)}else{ret=_malloc(slab.length)}if(!slab.subarray&&!slab.slice){slab=new Uint8Array(slab)}HEAPU8.set(slab,ret);return ret};var writeStringToMemory=(string,buffer,dontAddNull)=>{warnOnce("writeStringToMemory is deprecated and should not be called! Use stringToUTF8() instead!");var lastChar,end;if(dontAddNull){end=buffer+lengthBytesUTF8(string);lastChar=HEAP8[end]}stringToUTF8(string,buffer,Infinity);if(dontAddNull)HEAP8[end]=lastChar};var writeAsciiToMemory=(str,buffer,dontAddNull)=>{for(var i=0;i<str.length;++i){HEAP8[buffer++>>0]=str.charCodeAt(i)}if(!dontAddNull)HEAP8[buffer>>0]=0};Module["requestFullscreen"]=(lockPointer,resizeCanvas)=>Browser.requestFullscreen(lockPointer,resizeCanvas);Module["requestAnimationFrame"]=func=>Browser.requestAnimationFrame(func);Module["setCanvasSize"]=(width,height,noUpdates)=>Browser.setCanvasSize(width,height,noUpdates);Module["pauseMainLoop"]=()=>Browser.mainLoop.pause();Module["resumeMainLoop"]=()=>Browser.mainLoop.resume();Module["getUserMedia"]=()=>Browser.getUserMedia();Module["createContext"]=(canvas,useWebGL,setInModule,webGLContextAttributes)=>Browser.createContext(canvas,useWebGL,setInModule,webGLContextAttributes);var preloadedImages={};var preloadedAudios={};var FSNode=function(parent,name,mode,rdev){if(!parent){parent=this}this.parent=parent;this.mount=parent.mount;this.mounted=null;this.id=FS.nextInode++;this.name=name;this.mode=mode;this.node_ops={};this.stream_ops={};this.rdev=rdev};var readMode=292|73;var writeMode=146;Object.defineProperties(FSNode.prototype,{read:{get:function(){return(this.mode&readMode)===readMode},set:function(val){val?this.mode|=readMode:this.mode&=~readMode}},write:{get:function(){return(this.mode&writeMode)===writeMode},set:function(val){val?this.mode|=writeMode:this.mode&=~writeMode}},isFolder:{get:function(){return FS.isDir(this.mode)}},isDevice:{get:function(){return FS.isChrdev(this.mode)}}});FS.FSNode=FSNode;FS.createPreloadedFile=FS_createPreloadedFile;FS.staticInit();Module["FS_createPath"]=FS.createPath;Module["FS_createDataFile"]=FS.createDataFile;Module["FS_createPreloadedFile"]=FS.createPreloadedFile;Module["FS_unlink"]=FS.unlink;Module["FS_createLazyFile"]=FS.createLazyFile;Module["FS_createDevice"]=FS.createDevice;if(ENVIRONMENT_IS_NODE){NODEFS.staticInit()}ERRNO_CODES={"EPERM":63,"ENOENT":44,"ESRCH":71,"EINTR":27,"EIO":29,"ENXIO":60,"E2BIG":1,"ENOEXEC":45,"EBADF":8,"ECHILD":12,"EAGAIN":6,"EWOULDBLOCK":6,"ENOMEM":48,"EACCES":2,"EFAULT":21,"ENOTBLK":105,"EBUSY":10,"EEXIST":20,"EXDEV":75,"ENODEV":43,"ENOTDIR":54,"EISDIR":31,"EINVAL":28,"ENFILE":41,"EMFILE":33,"ENOTTY":59,"ETXTBSY":74,"EFBIG":22,"ENOSPC":51,"ESPIPE":70,"EROFS":69,"EMLINK":34,"EPIPE":64,"EDOM":18,"ERANGE":68,"ENOMSG":49,"EIDRM":24,"ECHRNG":106,"EL2NSYNC":156,"EL3HLT":107,"EL3RST":108,"ELNRNG":109,"EUNATCH":110,"ENOCSI":111,"EL2HLT":112,"EDEADLK":16,"ENOLCK":46,"EBADE":113,"EBADR":114,"EXFULL":115,"ENOANO":104,"EBADRQC":103,"EBADSLT":102,"EDEADLOCK":16,"EBFONT":101,"ENOSTR":100,"ENODATA":116,"ETIME":117,"ENOSR":118,"ENONET":119,"ENOPKG":120,"EREMOTE":121,"ENOLINK":47,"EADV":122,"ESRMNT":123,"ECOMM":124,"EPROTO":65,"EMULTIHOP":36,"EDOTDOT":125,"EBADMSG":9,"ENOTUNIQ":126,"EBADFD":127,"EREMCHG":128,"ELIBACC":129,"ELIBBAD":130,"ELIBSCN":131,"ELIBMAX":132,"ELIBEXEC":133,"ENOSYS":52,"ENOTEMPTY":55,"ENAMETOOLONG":37,"ELOOP":32,"EOPNOTSUPP":138,"EPFNOSUPPORT":139,"ECONNRESET":15,"ENOBUFS":42,"EAFNOSUPPORT":5,"EPROTOTYPE":67,"ENOTSOCK":57,"ENOPROTOOPT":50,"ESHUTDOWN":140,"ECONNREFUSED":14,"EADDRINUSE":3,"ECONNABORTED":13,"ENETUNREACH":40,"ENETDOWN":38,"ETIMEDOUT":73,"EHOSTDOWN":142,"EHOSTUNREACH":23,"EINPROGRESS":26,"EALREADY":7,"EDESTADDRREQ":17,"EMSGSIZE":35,"EPROTONOSUPPORT":66,"ESOCKTNOSUPPORT":137,"EADDRNOTAVAIL":4,"ENETRESET":39,"EISCONN":30,"ENOTCONN":53,"ETOOMANYREFS":141,"EUSERS":136,"EDQUOT":19,"ESTALE":72,"ENOTSUP":138,"ENOMEDIUM":148,"EILSEQ":25,"EOVERFLOW":61,"ECANCELED":11,"ENOTRECOVERABLE":56,"EOWNERDEAD":62,"ESTRPIPE":135};registerWasmPlugin();var GLctx;for(var i=0;i<32;++i)tempFixedLengthArray.push(new Array(i));var miniTempWebGLFloatBuffersStorage=new Float32Array(288);for(var i=0;i<288;++i){miniTempWebGLFloatBuffers[i]=miniTempWebGLFloatBuffersStorage.subarray(0,i+1)}var miniTempWebGLIntBuffersStorage=new Int32Array(288);for(var i=0;i<288;++i){miniTempWebGLIntBuffers[i]=miniTempWebGLIntBuffersStorage.subarray(0,i+1)}handleAllocatorInit();Fetch.init();var emSetImmediate;var emClearImmediate;if(typeof setImmediate!="undefined"){emSetImmediate=setImmediateWrapped;emClearImmediate=clearImmediateWrapped}else if(typeof addEventListener=="function"){var __setImmediate_id_counter=0;var __setImmediate_queue=[];var __setImmediate_message_id="_si";var __setImmediate_cb=e=>{if(e.data===__setImmediate_message_id){e.stopPropagation();__setImmediate_queue.shift()();++__setImmediate_id_counter}};addEventListener("message",__setImmediate_cb,true);emSetImmediate=func=>{postMessage(__setImmediate_message_id,"*");return __setImmediate_id_counter+__setImmediate_queue.push(func)-1};emClearImmediate=id=>{var index=id-__setImmediate_id_counter;if(index>=0&&index<__setImmediate_queue.length)__setImmediate_queue[index]=()=>{}}}var wasmImports={IMG_Init:_IMG_Init,IMG_Load:_IMG_Load,IMG_Load_RW:_IMG_Load_RW,IMG_Quit:_IMG_Quit,Mix_AllocateChannels:_Mix_AllocateChannels,Mix_ChannelFinished:_Mix_ChannelFinished,Mix_CloseAudio:_Mix_CloseAudio,Mix_FadeInChannelTimed:_Mix_FadeInChannelTimed,Mix_FadeInMusicPos:_Mix_FadeInMusicPos,Mix_FadeOutChannel:_Mix_FadeOutChannel,Mix_FadeOutMusic:_Mix_FadeOutMusic,Mix_FadingChannel:_Mix_FadingChannel,Mix_FreeChunk:_Mix_FreeChunk,Mix_FreeMusic:_Mix_FreeMusic,Mix_HaltChannel:_Mix_HaltChannel,Mix_HaltMusic:_Mix_HaltMusic,Mix_HookMusicFinished:_Mix_HookMusicFinished,Mix_Init:_Mix_Init,Mix_Linked_Version:_Mix_Linked_Version,Mix_LoadMUS:_Mix_LoadMUS,Mix_LoadMUS_RW:_Mix_LoadMUS_RW,Mix_LoadWAV:_Mix_LoadWAV,Mix_LoadWAV_RW:_Mix_LoadWAV_RW,Mix_OpenAudio:_Mix_OpenAudio,Mix_Pause:_Mix_Pause,Mix_PauseMusic:_Mix_PauseMusic,Mix_Paused:_Mix_Paused,Mix_PausedMusic:_Mix_PausedMusic,Mix_PlayChannelTimed:_Mix_PlayChannelTimed,Mix_PlayMusic:_Mix_PlayMusic,Mix_Playing:_Mix_Playing,Mix_PlayingMusic:_Mix_PlayingMusic,Mix_QuerySpec:_Mix_QuerySpec,Mix_QuickLoad_RAW:_Mix_QuickLoad_RAW,Mix_Quit:_Mix_Quit,Mix_ReserveChannels:_Mix_ReserveChannels,Mix_Resume:_Mix_Resume,Mix_ResumeMusic:_Mix_ResumeMusic,Mix_SetPanning:_Mix_SetPanning,Mix_SetPosition:_Mix_SetPosition,Mix_SetPostMix:_Mix_SetPostMix,Mix_Volume:_Mix_Volume,Mix_VolumeChunk:_Mix_VolumeChunk,Mix_VolumeMusic:_Mix_VolumeMusic,SDL_AddTimer:_SDL_AddTimer,SDL_AllocRW:_SDL_AllocRW,SDL_AudioDriverName:_SDL_AudioDriverName,SDL_AudioQuit:_SDL_AudioQuit,SDL_ClearError:_SDL_ClearError,SDL_CloseAudio:_SDL_CloseAudio,SDL_CondBroadcast:_SDL_CondBroadcast,SDL_CondSignal:_SDL_CondSignal,SDL_CondWait:_SDL_CondWait,SDL_CondWaitTimeout:_SDL_CondWaitTimeout,SDL_ConvertSurface:_SDL_ConvertSurface,SDL_CreateCond:_SDL_CreateCond,SDL_CreateMutex:_SDL_CreateMutex,SDL_CreateRGBSurface:_SDL_CreateRGBSurface,SDL_CreateRGBSurfaceFrom:_SDL_CreateRGBSurfaceFrom,SDL_CreateThread:_SDL_CreateThread,SDL_Delay:_SDL_Delay,SDL_DestroyCond:_SDL_DestroyCond,SDL_DestroyMutex:_SDL_DestroyMutex,SDL_DestroyRenderer:_SDL_DestroyRenderer,SDL_DestroyWindow:_SDL_DestroyWindow,SDL_DisplayFormatAlpha:_SDL_DisplayFormatAlpha,SDL_EnableKeyRepeat:_SDL_EnableKeyRepeat,SDL_EnableUNICODE:_SDL_EnableUNICODE,SDL_FillRect:_SDL_FillRect,SDL_Flip:_SDL_Flip,SDL_FreeRW:_SDL_FreeRW,SDL_FreeSurface:_SDL_FreeSurface,SDL_GL_DeleteContext:_SDL_GL_DeleteContext,SDL_GL_ExtensionSupported:_SDL_GL_ExtensionSupported,SDL_GL_GetAttribute:_SDL_GL_GetAttribute,SDL_GL_GetSwapInterval:_SDL_GL_GetSwapInterval,SDL_GL_MakeCurrent:_SDL_GL_MakeCurrent,SDL_GL_SetAttribute:_SDL_GL_SetAttribute,SDL_GL_SetSwapInterval:_SDL_GL_SetSwapInterval,SDL_GL_SwapBuffers:_SDL_GL_SwapBuffers,SDL_GL_SwapWindow:_SDL_GL_SwapWindow,SDL_GetAppState:_SDL_GetAppState,SDL_GetAudioDriver:_SDL_GetAudioDriver,SDL_GetClipRect:_SDL_GetClipRect,SDL_GetCurrentAudioDriver:_SDL_GetCurrentAudioDriver,SDL_GetError:_SDL_GetError,SDL_GetKeyName:_SDL_GetKeyName,SDL_GetKeyState:_SDL_GetKeyState,SDL_GetKeyboardState:_SDL_GetKeyboardState,SDL_GetModState:_SDL_GetModState,SDL_GetMouseState:_SDL_GetMouseState,SDL_GetNumAudioDrivers:_SDL_GetNumAudioDrivers,SDL_GetRGB:_SDL_GetRGB,SDL_GetRGBA:_SDL_GetRGBA,SDL_GetScancodeFromKey:_SDL_GetScancodeFromKey,SDL_GetThreadID:_SDL_GetThreadID,SDL_GetTicks:_SDL_GetTicks,SDL_GetVideoInfo:_SDL_GetVideoInfo,SDL_GetVideoSurface:_SDL_GetVideoSurface,SDL_GetWindowFlags:_SDL_GetWindowFlags,SDL_GetWindowSize:_SDL_GetWindowSize,SDL_Has3DNow:_SDL_Has3DNow,SDL_Has3DNowExt:_SDL_Has3DNowExt,SDL_HasAltiVec:_SDL_HasAltiVec,SDL_HasMMX:_SDL_HasMMX,SDL_HasMMXExt:_SDL_HasMMXExt,SDL_HasRDTSC:_SDL_HasRDTSC,SDL_HasSSE:_SDL_HasSSE,SDL_HasSSE2:_SDL_HasSSE2,SDL_Init:_SDL_Init,SDL_InitSubSystem:_SDL_InitSubSystem,SDL_JoystickClose:_SDL_JoystickClose,SDL_JoystickEventState:_SDL_JoystickEventState,SDL_JoystickGetAxis:_SDL_JoystickGetAxis,SDL_JoystickGetBall:_SDL_JoystickGetBall,SDL_JoystickGetButton:_SDL_JoystickGetButton,SDL_JoystickGetHat:_SDL_JoystickGetHat,SDL_JoystickIndex:_SDL_JoystickIndex,SDL_JoystickName:_SDL_JoystickName,SDL_JoystickNumAxes:_SDL_JoystickNumAxes,SDL_JoystickNumBalls:_SDL_JoystickNumBalls,SDL_JoystickNumButtons:_SDL_JoystickNumButtons,SDL_JoystickNumHats:_SDL_JoystickNumHats,SDL_JoystickOpen:_SDL_JoystickOpen,SDL_JoystickOpened:_SDL_JoystickOpened,SDL_JoystickUpdate:_SDL_JoystickUpdate,SDL_Linked_Version:_SDL_Linked_Version,SDL_ListModes:_SDL_ListModes,SDL_LoadBMP_RW:_SDL_LoadBMP_RW,SDL_LockAudio:_SDL_LockAudio,SDL_LockSurface:_SDL_LockSurface,SDL_LogSetOutputFunction:_SDL_LogSetOutputFunction,SDL_LowerBlit:_SDL_LowerBlit,SDL_LowerBlitScaled:_SDL_LowerBlitScaled,SDL_MapRGB:_SDL_MapRGB,SDL_MapRGBA:_SDL_MapRGBA,SDL_NumJoysticks:_SDL_NumJoysticks,SDL_OpenAudio:_SDL_OpenAudio,SDL_PauseAudio:_SDL_PauseAudio,SDL_PeepEvents:_SDL_PeepEvents,SDL_PollEvent:_SDL_PollEvent,SDL_PumpEvents:_SDL_PumpEvents,SDL_PushEvent:_SDL_PushEvent,SDL_Quit:_SDL_Quit,SDL_QuitSubSystem:_SDL_QuitSubSystem,SDL_RWFromConstMem:_SDL_RWFromConstMem,SDL_RWFromFile:_SDL_RWFromFile,SDL_RWFromMem:_SDL_RWFromMem,SDL_RemoveTimer:_SDL_RemoveTimer,SDL_SaveBMP_RW:_SDL_SaveBMP_RW,SDL_SetAlpha:_SDL_SetAlpha,SDL_SetClipRect:_SDL_SetClipRect,SDL_SetColorKey:_SDL_SetColorKey,SDL_SetColors:_SDL_SetColors,SDL_SetError:_SDL_SetError,SDL_SetGamma:_SDL_SetGamma,SDL_SetGammaRamp:_SDL_SetGammaRamp,SDL_SetPalette:_SDL_SetPalette,SDL_SetVideoMode:_SDL_SetVideoMode,SDL_SetWindowFullscreen:_SDL_SetWindowFullscreen,SDL_SetWindowTitle:_SDL_SetWindowTitle,SDL_ShowCursor:_SDL_ShowCursor,SDL_StartTextInput:_SDL_StartTextInput,SDL_StopTextInput:_SDL_StopTextInput,SDL_ThreadID:_SDL_ThreadID,SDL_UnlockAudio:_SDL_UnlockAudio,SDL_UnlockSurface:_SDL_UnlockSurface,SDL_UpdateRect:_SDL_UpdateRect,SDL_UpdateRects:_SDL_UpdateRects,SDL_UpperBlit:_SDL_UpperBlit,SDL_UpperBlitScaled:_SDL_UpperBlitScaled,SDL_VideoDriverName:_SDL_VideoDriverName,SDL_VideoModeOK:_SDL_VideoModeOK,SDL_VideoQuit:_SDL_VideoQuit,SDL_WM_GrabInput:_SDL_WM_GrabInput,SDL_WM_IconifyWindow:_SDL_WM_IconifyWindow,SDL_WM_SetCaption:_SDL_WM_SetCaption,SDL_WM_SetIcon:_SDL_WM_SetIcon,SDL_WM_ToggleFullScreen:_SDL_WM_ToggleFullScreen,SDL_WaitThread:_SDL_WaitThread,SDL_WarpMouse:_SDL_WarpMouse,SDL_WasInit:_SDL_WasInit,SDL_mutexP:_SDL_mutexP,SDL_mutexV:_SDL_mutexV,TTF_CloseFont:_TTF_CloseFont,TTF_FontAscent:_TTF_FontAscent,TTF_FontDescent:_TTF_FontDescent,TTF_FontHeight:_TTF_FontHeight,TTF_FontLineSkip:_TTF_FontLineSkip,TTF_GlyphMetrics:_TTF_GlyphMetrics,TTF_Init:_TTF_Init,TTF_OpenFont:_TTF_OpenFont,TTF_Quit:_TTF_Quit,TTF_RenderText_Blended:_TTF_RenderText_Blended,TTF_RenderText_Shaded:_TTF_RenderText_Shaded,TTF_RenderText_Solid:_TTF_RenderText_Solid,TTF_RenderUTF8_Solid:_TTF_RenderUTF8_Solid,TTF_SizeText:_TTF_SizeText,TTF_SizeUTF8:_TTF_SizeUTF8,XChangeWindowAttributes:_XChangeWindowAttributes,XCreateWindow:_XCreateWindow,XInternAtom:_XInternAtom,XMapWindow:_XMapWindow,XOpenDisplay:_XOpenDisplay,XPending:_XPending,XSendEvent:_XSendEvent,XSetWMHints:_XSetWMHints,XStoreName:_XStoreName,_QQclX20:__QQclX20,_QQclX31:__QQclX31,_QQclX32:__QQclX32,_QQclX3253544147:__QQclX3253544147,_QQclX41:__QQclX41,_QQclX414C4C:__QQclX414C4C,_QQclX416C6C:__QQclX416C6C,_QQclX42:__QQclX42,_QQclX4252:__QQclX4252,_QQclX425244:__QQclX425244,_QQclX4261636B77617264:__QQclX4261636B77617264,_QQclX42617365:__QQclX42617365,_QQclX43:__QQclX43,_QQclX436F6C756D6E77697365:__QQclX436F6C756D6E77697365,_QQclX436F6E6A205472616E73:__QQclX436F6E6A205472616E73,_QQclX436F6E6A7567617465205472616E73706F7365:__QQclX436F6E6A7567617465205472616E73706F7365,_QQclX436F6E6A7567617465207472616E73706F7365:__QQclX436F6E6A7567617465207472616E73706F7365,_QQclX44:__QQclX44,_QQclX444242435344:__QQclX444242435344,_QQclX444244534443:__QQclX444244534443,_QQclX444244535152:__QQclX444244535152,_QQclX444449534E41:__QQclX444449534E41,_QQclX444742425244:__QQclX444742425244,_QQclX444742434F4E:__QQclX444742434F4E,_QQclX444742455155:__QQclX444742455155,_QQclX44474245515542:__QQclX44474245515542,_QQclX4447424D5620:__QQclX4447424D5620,_QQclX444742524653:__QQclX444742524653,_QQclX444742535620:__QQclX444742535620,_QQclX444742535658:__QQclX444742535658,_QQclX444742544632:__QQclX444742544632,_QQclX444742545246:__QQclX444742545246,_QQclX444742545253:__QQclX444742545253,_QQclX44474542414B:__QQclX44474542414B,_QQclX44474542414C:__QQclX44474542414C,_QQclX444745424432:__QQclX444745424432,_QQclX444745425244:__QQclX444745425244,_QQclX444745434F4E:__QQclX444745434F4E,_QQclX444745455155:__QQclX444745455155,_QQclX44474545515542:__QQclX44474545515542,_QQclX444745455320:__QQclX444745455320,_QQclX444745455358:__QQclX444745455358,_QQclX444745455620:__QQclX444745455620,_QQclX444745455658:__QQclX444745455658,_QQclX444745475320:__QQclX444745475320,_QQclX444745475620:__QQclX444745475620,_QQclX444745484432:__QQclX444745484432,_QQclX444745485244:__QQclX444745485244,_QQclX4447454A5356:__QQclX4447454A5356,_QQclX4447454C5132:__QQclX4447454C5132,_QQclX4447454C5146:__QQclX4447454C5146,_QQclX4447454C5320:__QQclX4447454C5320,_QQclX4447454C5344:__QQclX4447454C5344,_QQclX4447454C5353:__QQclX4447454C5353,_QQclX4447454C5358:__QQclX4447454C5358,_QQclX4447454C5359:__QQclX4447454C5359,_QQclX4447454D4D20:__QQclX4447454D4D20,_QQclX4447454D515254:__QQclX4447454D515254,_QQclX4447454D5620:__QQclX4447454D5620,_QQclX444745514C32:__QQclX444745514C32,_QQclX444745514C46:__QQclX444745514C46,_QQclX444745515033:__QQclX444745515033,_QQclX444745515046:__QQclX444745515046,_QQclX444745515232:__QQclX444745515232,_QQclX44474551523250:__QQclX44474551523250,_QQclX444745515246:__QQclX444745515246,_QQclX44474551524650:__QQclX44474551524650,_QQclX444745515254:__QQclX444745515254,_QQclX44474551525432:__QQclX44474551525432,_QQclX44474551525433:__QQclX44474551525433,_QQclX444745522020:__QQclX444745522020,_QQclX444745524653:__QQclX444745524653,_QQclX444745525132:__QQclX444745525132,_QQclX444745525146:__QQclX444745525146,_QQclX444745534444:__QQclX444745534444,_QQclX444745535620:__QQclX444745535620,_QQclX444745535644:__QQclX444745535644,_QQclX44474553564A:__QQclX44474553564A,_QQclX444745535658:__QQclX444745535658,_QQclX444745544632:__QQclX444745544632,_QQclX444745545246:__QQclX444745545246,_QQclX44474554524632:__QQclX44474554524632,_QQclX444745545249:__QQclX444745545249,_QQclX444745545253:__QQclX444745545253,_QQclX44474742414B:__QQclX44474742414B,_QQclX44474742414C:__QQclX44474742414C,_QQclX444747455320:__QQclX444747455320,_QQclX444747455358:__QQclX444747455358,_QQclX444747455620:__QQclX444747455620,_QQclX444747455658:__QQclX444747455658,_QQclX444747474C4D:__QQclX444747474C4D,_QQclX444747485244:__QQclX444747485244,_QQclX4447474C5345:__QQclX4447474C5345,_QQclX444747515246:__QQclX444747515246,_QQclX444747525146:__QQclX444747525146,_QQclX444747535644:__QQclX444747535644,_QQclX444747535650:__QQclX444747535650,_QQclX444753564A30:__QQclX444753564A30,_QQclX444753564A31:__QQclX444753564A31,_QQclX444754434F4E:__QQclX444754434F4E,_QQclX444754524653:__QQclX444754524653,_QQclX444754535620:__QQclX444754535620,_QQclX444754535658:__QQclX444754535658,_QQclX444754545246:__QQclX444754545246,_QQclX444754545253:__QQclX444754545253,_QQclX44484745515A:__QQclX44484745515A,_QQclX44485345494E:__QQclX44485345494E,_QQclX444853455152:__QQclX444853455152,_QQclX444C41454430:__QQclX444C41454430,_QQclX444C41454431:__QQclX444C41454431,_QQclX444C41454432:__QQclX444C41454432,_QQclX444C41454433:__QQclX444C41454433,_QQclX444C41454437:__QQclX444C41454437,_QQclX444C41454438:__QQclX444C41454438,_QQclX444C41454439:__QQclX444C41454439,_QQclX444C41454441:__QQclX444C41454441,_QQclX444C41475446:__QQclX444C41475446,_QQclX444C41475453:__QQclX444C41475453,_QQclX444C414C5330:__QQclX444C414C5330,_QQclX444C414C5341:__QQclX444C414C5341,_QQclX444C414C5344:__QQclX444C414C5344,_QQclX444C41515230:__QQclX444C41515230,_QQclX444C41515233:__QQclX444C41515233,_QQclX444C41515234:__QQclX444C41515234,_QQclX444C41525A42:__QQclX444C41525A42,_QQclX444C41525A54:__QQclX444C41525A54,_QQclX444C4153434C:__QQclX444C4153434C,_QQclX444C41534430:__QQclX444C41534430,_QQclX444C41534431:__QQclX444C41534431,_QQclX444C41534432:__QQclX444C41534432,_QQclX444C41534433:__QQclX444C41534433,_QQclX444C41534436:__QQclX444C41534436,_QQclX444C41534437:__QQclX444C41534437,_QQclX444C41534438:__QQclX444C41534438,_QQclX444C41534441:__QQclX444C41534441,_QQclX444C41534451:__QQclX444C41534451,_QQclX444C41535131:__QQclX444C41535131,_QQclX444C41535132:__QQclX444C41535132,_QQclX444C41535220:__QQclX444C41535220,_QQclX444C41535254:__QQclX444C41535254,_QQclX444C41544253:__QQclX444C41544253,_QQclX444C41545053:__QQclX444C41545053,_QQclX444C41545253:__QQclX444C41545253,_QQclX444C41555532:__QQclX444C41555532,_QQclX444C4155554D:__QQclX444C4155554D,_QQclX444F50475452:__QQclX444F50475452,_QQclX444F504D5452:__QQclX444F504D5452,_QQclX444F52435344:__QQclX444F52435344,_QQclX444F5247324C:__QQclX444F5247324C,_QQclX444F52473252:__QQclX444F52473252,_QQclX444F52474252:__QQclX444F52474252,_QQclX444F52474852:__QQclX444F52474852,_QQclX444F52474C32:__QQclX444F52474C32,_QQclX444F52474C51:__QQclX444F52474C51,_QQclX444F5247514C:__QQclX444F5247514C,_QQclX444F52475152:__QQclX444F52475152,_QQclX444F52475232:__QQclX444F52475232,_QQclX444F52475251:__QQclX444F52475251,_QQclX444F52475452:__QQclX444F52475452,_QQclX444F524D324C:__QQclX444F524D324C,_QQclX444F524D3252:__QQclX444F524D3252,_QQclX444F524D4252:__QQclX444F524D4252,_QQclX444F524D4852:__QQclX444F524D4852,_QQclX444F524D4C32:__QQclX444F524D4C32,_QQclX444F524D4C51:__QQclX444F524D4C51,_QQclX444F524D514C:__QQclX444F524D514C,_QQclX444F524D5152:__QQclX444F524D5152,_QQclX444F524D5232:__QQclX444F524D5232,_QQclX444F524D5233:__QQclX444F524D5233,_QQclX444F524D5251:__QQclX444F524D5251,_QQclX444F524D525A:__QQclX444F524D525A,_QQclX444F524D5452:__QQclX444F524D5452,_QQclX445042434F4E:__QQclX445042434F4E,_QQclX445042455155:__QQclX445042455155,_QQclX445042524653:__QQclX445042524653,_QQclX445042535446:__QQclX445042535446,_QQclX445042535620:__QQclX445042535620,_QQclX445042535658:__QQclX445042535658,_QQclX445042544632:__QQclX445042544632,_QQclX445042545246:__QQclX445042545246,_QQclX445042545253:__QQclX445042545253,_QQclX445046545246:__QQclX445046545246,_QQclX445046545249:__QQclX445046545249,_QQclX445046545253:__QQclX445046545253,_QQclX44504F434F4E:__QQclX44504F434F4E,_QQclX44504F455155:__QQclX44504F455155,_QQclX44504F45515542:__QQclX44504F45515542,_QQclX44504F524653:__QQclX44504F524653,_QQclX44504F535620:__QQclX44504F535620,_QQclX44504F535658:__QQclX44504F535658,_QQclX44504F544632:__QQclX44504F544632,_QQclX44504F545246:__QQclX44504F545246,_QQclX44504F54524632:__QQclX44504F54524632,_QQclX44504F545249:__QQclX44504F545249,_QQclX44504F545253:__QQclX44504F545253,_QQclX445050434F4E:__QQclX445050434F4E,_QQclX445050455155:__QQclX445050455155,_QQclX445050524653:__QQclX445050524653,_QQclX445050535620:__QQclX445050535620,_QQclX445050535658:__QQclX445050535658,_QQclX445050545246:__QQclX445050545246,_QQclX445050545249:__QQclX445050545249,_QQclX445050545253:__QQclX445050545253,_QQclX445053544632:__QQclX445053544632,_QQclX445053545246:__QQclX445053545246,_QQclX445054434F4E:__QQclX445054434F4E,_QQclX445054455152:__QQclX445054455152,_QQclX445054524653:__QQclX445054524653,_QQclX445054535620:__QQclX445054535620,_QQclX445054535658:__QQclX445054535658,_QQclX445054545246:__QQclX445054545246,_QQclX445054545253:__QQclX445054545253,_QQclX445342455620:__QQclX445342455620,_QQclX445342455644:__QQclX445342455644,_QQclX445342455658:__QQclX445342455658,_QQclX445342475354:__QQclX445342475354,_QQclX4453424756:__QQclX4453424756,_QQclX445342475644:__QQclX445342475644,_QQclX445342475658:__QQclX445342475658,_QQclX4453424D5620:__QQclX4453424D5620,_QQclX445342545244:__QQclX445342545244,_QQclX445346524B20:__QQclX445346524B20,_QQclX445350434F4E:__QQclX445350434F4E,_QQclX445350455620:__QQclX445350455620,_QQclX445350455644:__QQclX445350455644,_QQclX445350455658:__QQclX445350455658,_QQclX445350475354:__QQclX445350475354,_QQclX445350475620:__QQclX445350475620,_QQclX445350475644:__QQclX445350475644,_QQclX445350475658:__QQclX445350475658,_QQclX4453504D5620:__QQclX4453504D5620,_QQclX445350522020:__QQclX445350522020,_QQclX445350523220:__QQclX445350523220,_QQclX445350524653:__QQclX445350524653,_QQclX445350535620:__QQclX445350535620,_QQclX445350535658:__QQclX445350535658,_QQclX445350545244:__QQclX445350545244,_QQclX445350545246:__QQclX445350545246,_QQclX445350545249:__QQclX445350545249,_QQclX445350545253:__QQclX445350545253,_QQclX44535445425A:__QQclX44535445425A,_QQclX445354454443:__QQclX445354454443,_QQclX44535445494E:__QQclX44535445494E,_QQclX445354454D52:__QQclX445354454D52,_QQclX445354455152:__QQclX445354455152,_QQclX445354455246:__QQclX445354455246,_QQclX445354455620:__QQclX445354455620,_QQclX445354455644:__QQclX445354455644,_QQclX445354455652:__QQclX445354455652,_QQclX445354455658:__QQclX445354455658,_QQclX445359434F4E:__QQclX445359434F4E,_QQclX445359434F4E56:__QQclX445359434F4E56,_QQclX44535945515542:__QQclX44535945515542,_QQclX445359455620:__QQclX445359455620,_QQclX445359455644:__QQclX445359455644,_QQclX445359455652:__QQclX445359455652,_QQclX445359455658:__QQclX445359455658,_QQclX445359475332:__QQclX445359475332,_QQclX445359475354:__QQclX445359475354,_QQclX445359475620:__QQclX445359475620,_QQclX445359475644:__QQclX445359475644,_QQclX445359475658:__QQclX445359475658,_QQclX4453594D4D20:__QQclX4453594D4D20,_QQclX4453594D5620:__QQclX4453594D5620,_QQclX445359522020:__QQclX445359522020,_QQclX445359523220:__QQclX445359523220,_QQclX44535952324B:__QQclX44535952324B,_QQclX445359524653:__QQclX445359524653,_QQclX445359524B20:__QQclX445359524B20,_QQclX445359535620:__QQclX445359535620,_QQclX445359535658:__QQclX445359535658,_QQclX445359544432:__QQclX445359544432,_QQclX445359544632:__QQclX445359544632,_QQclX445359545244:__QQclX445359545244,_QQclX445359545246:__QQclX445359545246,_QQclX445359545249:__QQclX445359545249,_QQclX44535954524932:__QQclX44535954524932,_QQclX4453595452493258:__QQclX4453595452493258,_QQclX445359545253:__QQclX445359545253,_QQclX44535954525332:__QQclX44535954525332,_QQclX445442434F4E:__QQclX445442434F4E,_QQclX4454424D5620:__QQclX4454424D5620,_QQclX445442524653:__QQclX445442524653,_QQclX445442535620:__QQclX445442535620,_QQclX445442545253:__QQclX445442545253,_QQclX445446534D20:__QQclX445446534D20,_QQclX445446545249:__QQclX445446545249,_QQclX445446545450:__QQclX445446545450,_QQclX445446545452:__QQclX445446545452,_QQclX445447455643:__QQclX445447455643,_QQclX445447455843:__QQclX445447455843,_QQclX44544753454E:__QQclX44544753454E,_QQclX445447534A41:__QQclX445447534A41,_QQclX445447534E41:__QQclX445447534E41,_QQclX445447535932:__QQclX445447535932,_QQclX44544753594C:__QQclX44544753594C,_QQclX445450434F4E:__QQclX445450434F4E,_QQclX4454504D515254:__QQclX4454504D515254,_QQclX4454504D5620:__QQclX4454504D5620,_QQclX445450515254:__QQclX445450515254,_QQclX44545051525432:__QQclX44545051525432,_QQclX445450524653:__QQclX445450524653,_QQclX445450535620:__QQclX445450535620,_QQclX445450545249:__QQclX445450545249,_QQclX445450545253:__QQclX445450545253,_QQclX445450545446:__QQclX445450545446,_QQclX445450545452:__QQclX445450545452,_QQclX445452434F4E:__QQclX445452434F4E,_QQclX445452455643:__QQclX445452455643,_QQclX44545245564333:__QQclX44545245564333,_QQclX445452455843:__QQclX445452455843,_QQclX4454524D4D20:__QQclX4454524D4D20,_QQclX4454524D5620:__QQclX4454524D5620,_QQclX445452524653:__QQclX445452524653,_QQclX44545253454E:__QQclX44545253454E,_QQclX445452534D20:__QQclX445452534D20,_QQclX445452534E41:__QQclX445452534E41,_QQclX445452535620:__QQclX445452535620,_QQclX44545253594C:__QQclX44545253594C,_QQclX445452544932:__QQclX445452544932,_QQclX445452545249:__QQclX445452545249,_QQclX445452545253:__QQclX445452545253,_QQclX445452545446:__QQclX445452545446,_QQclX445452545450:__QQclX445452545450,_QQclX44545A525146:__QQclX44545A525146,_QQclX44545A525A46:__QQclX44545A525A46,_QQclX45:__QQclX45,_QQclX45425A:__QQclX45425A,_QQclX455053:__QQclX455053,_QQclX455643:__QQclX455643,_QQclX455843:__QQclX455843,_QQclX457073696C6F6E:__QQclX457073696C6F6E,_QQclX46:__QQclX46,_QQclX466F7277617264:__QQclX466F7277617264,_QQclX46756C6C:__QQclX46756C6C,_QQclX47:__QQclX47,_QQclX4742:__QQclX4742,_QQclX4742324244:__QQclX4742324244,_QQclX4745:__QQclX4745,_QQclX4745324742:__QQclX4745324742,_QQclX47454C5146:__QQclX47454C5146,_QQclX4745515246:__QQclX4745515246,_QQclX4747:__QQclX4747,_QQclX4747484433:__QQclX4747484433,_QQclX4747485244:__QQclX4747485244,_QQclX475354:__QQclX475354,_QQclX48:__QQclX48,_QQclX4842325354:__QQclX4842325354,_QQclX484433:__QQclX484433,_QQclX4845:__QQclX4845,_QQclX4845324842:__QQclX4845324842,_QQclX4852:__QQclX4852,_QQclX485244:__QQclX485244,_QQclX4853455152:__QQclX4853455152,_QQclX49:__QQclX49,_QQclX4A:__QQclX4A,_QQclX4C:__QQclX4C,_QQclX4C20:__QQclX4C20,_QQclX4C41:__QQclX4C41,_QQclX4C414F5248:__QQclX4C414F5248,_QQclX4C415152:__QQclX4C415152,_QQclX4C43:__QQclX4C43,_QQclX4C454654:__QQclX4C454654,_QQclX4C4E:__QQclX4C4E,_QQclX4C51:__QQclX4C51,_QQclX4C5120:__QQclX4C5120,_QQclX4C5146:__QQclX4C5146,_QQclX4C54:__QQclX4C54,_QQclX4C656674:__QQclX4C656674,_QQclX4C6F776572:__QQclX4C6F776572,_QQclX4D:__QQclX4D,_QQclX4D6178:__QQclX4D6178,_QQclX4E:__QQclX4E,_QQclX4E4F205452414E53504F5345:__QQclX4E4F205452414E53504F5345,_QQclX4E4F4E2D554E4954:__QQclX4E4F4E2D554E4954,_QQclX4E6F2051:__QQclX4E6F2051,_QQclX4E6F205472:__QQclX4E6F205472,_QQclX4E6F205472616E73:__QQclX4E6F205472616E73,_QQclX4E6F205472616E73706F7365:__QQclX4E6F205472616E73706F7365,_QQclX4E6F205544:__QQclX4E6F205544,_QQclX4E6F207472616E73706F7365:__QQclX4E6F207472616E73706F7365,_QQclX4E6F5472616E73:__QQclX4E6F5472616E73,_QQclX4E6F55:__QQclX4E6F55,_QQclX4E6F56:__QQclX4E6F56,_QQclX4E6F5F5472:__QQclX4E6F5F5472,_QQclX4E6F6E20756E6974:__QQclX4E6F6E20756E6974,_QQclX4E6F6E2D756E6974:__QQclX4E6F6E2D756E6974,_QQclX4E6F6E756E6974:__QQclX4E6F6E756E6974,_QQclX4F:__QQclX4F,_QQclX4F52:__QQclX4F52,_QQclX4F766572666C6F77:__QQclX4F766572666C6F77,_QQclX4F766572666C6F77207468726573686F6C64:__QQclX4F766572666C6F77207468726573686F6C64,_QQclX50:__QQclX50,_QQclX5042:__QQclX5042,_QQclX504C4E:__QQclX504C4E,_QQclX504F:__QQclX504F,_QQclX505245434953494F4E:__QQclX505245434953494F4E,_QQclX507265636973696F6E:__QQclX507265636973696F6E,_QQclX51:__QQclX51,_QQclX514C:__QQclX514C,_QQclX514C43:__QQclX514C43,_QQclX514C46:__QQclX514C46,_QQclX514C54:__QQclX514C54,_QQclX515033524B:__QQclX515033524B,_QQclX5152:__QQclX5152,_QQclX515220:__QQclX515220,_QQclX515246:__QQclX515246,_QQclX52:__QQclX52,_QQclX5249474854:__QQclX5249474854,_QQclX5251:__QQclX5251,_QQclX525146:__QQclX525146,_QQclX5269676874:__QQclX5269676874,_QQclX526F7777697365:__QQclX526F7777697365,_QQclX53:__QQclX53,_QQclX53414645204D494E494D554D:__QQclX53414645204D494E494D554D,_QQclX534146454D494E:__QQclX534146454D494E,_QQclX5342325354:__QQclX5342325354,_QQclX5354:__QQclX5354,_QQclX5356:__QQclX5356,_QQclX5359:__QQclX5359,_QQclX5359325342:__QQclX5359325342,_QQclX53594C:__QQclX53594C,_QQclX5361664D696E:__QQclX5361664D696E,_QQclX53616665204D696E696D756D:__QQclX53616665204D696E696D756D,_QQclX53616665206D696E696D756D:__QQclX53616665206D696E696D756D,_QQclX536166654D696E696D756D:__QQclX536166654D696E696D756D,_QQclX54:__QQclX54,_QQclX5452:__QQclX5452,_QQclX545244:__QQclX545244,_QQclX545246:__QQclX545246,_QQclX545249:__QQclX545249,_QQclX545253:__QQclX545253,_QQclX5472616E73:__QQclX5472616E73,_QQclX5472616E73706F7365:__QQclX5472616E73706F7365,_QQclX55:__QQclX55,_QQclX554E:__QQclX554E,_QQclX554E4954:__QQclX554E4954,_QQclX55554D:__QQclX55554D,_QQclX556E6974:__QQclX556E6974,_QQclX5570706572:__QQclX5570706572,_QQclX56:__QQclX56,_QQclX57:__QQclX57,_QQclX58:__QQclX58,_QQclX59:__QQclX59,_QQclX5A:__QQclX5A,_QQclX5A4244535152:__QQclX5A4244535152,_QQclX5A4742434F4E:__QQclX5A4742434F4E,_QQclX5A4742455155:__QQclX5A4742455155,_QQclX5A47424D5620:__QQclX5A47424D5620,_QQclX5A4742524653:__QQclX5A4742524653,_QQclX5A4742535620:__QQclX5A4742535620,_QQclX5A4742535658:__QQclX5A4742535658,_QQclX5A4742544632:__QQclX5A4742544632,_QQclX5A4742545246:__QQclX5A4742545246,_QQclX5A4742545253:__QQclX5A4742545253,_QQclX5A474542414B:__QQclX5A474542414B,_QQclX5A474542414C:__QQclX5A474542414C,_QQclX5A4745424432:__QQclX5A4745424432,_QQclX5A4745425244:__QQclX5A4745425244,_QQclX5A4745434F4E:__QQclX5A4745434F4E,_QQclX5A4745455155:__QQclX5A4745455155,_QQclX5A4745455320:__QQclX5A4745455320,_QQclX5A4745455620:__QQclX5A4745455620,_QQclX5A4745455658:__QQclX5A4745455658,_QQclX5A4745484432:__QQclX5A4745484432,_QQclX5A4745485244:__QQclX5A4745485244,_QQclX5A47454C5132:__QQclX5A47454C5132,_QQclX5A47454C5146:__QQclX5A47454C5146,_QQclX5A47454C5320:__QQclX5A47454C5320,_QQclX5A47454C5344:__QQclX5A47454C5344,_QQclX5A47454D4D20:__QQclX5A47454D4D20,_QQclX5A47454D5620:__QQclX5A47454D5620,_QQclX5A4745515033:__QQclX5A4745515033,_QQclX5A4745515232:__QQclX5A4745515232,_QQclX5A4745515246:__QQclX5A4745515246,_QQclX5A4745524320:__QQclX5A4745524320,_QQclX5A4745524653:__QQclX5A4745524653,_QQclX5A4745525520:__QQclX5A4745525520,_QQclX5A4745534444:__QQclX5A4745534444,_QQclX5A4745535620:__QQclX5A4745535620,_QQclX5A4745535644:__QQclX5A4745535644,_QQclX5A4745535658:__QQclX5A4745535658,_QQclX5A4745544632:__QQclX5A4745544632,_QQclX5A4745545246:__QQclX5A4745545246,_QQclX5A474554524632:__QQclX5A474554524632,_QQclX5A4745545249:__QQclX5A4745545249,_QQclX5A4745545253:__QQclX5A4745545253,_QQclX5A474742414B:__QQclX5A474742414B,_QQclX5A474742414C:__QQclX5A474742414C,_QQclX5A4747455320:__QQclX5A4747455320,_QQclX5A4747455620:__QQclX5A4747455620,_QQclX5A4747485244:__QQclX5A4747485244,_QQclX5A4754434F4E:__QQclX5A4754434F4E,_QQclX5A4754524653:__QQclX5A4754524653,_QQclX5A4754535620:__QQclX5A4754535620,_QQclX5A4754535658:__QQclX5A4754535658,_QQclX5A4754545246:__QQclX5A4754545246,_QQclX5A4754545253:__QQclX5A4754545253,_QQclX5A48424D5620:__QQclX5A48424D5620,_QQclX5A4845434F4E:__QQclX5A4845434F4E,_QQclX5A4845455620:__QQclX5A4845455620,_QQclX5A4845455644:__QQclX5A4845455644,_QQclX5A48454D4D20:__QQclX5A48454D4D20,_QQclX5A48454D5620:__QQclX5A48454D5620,_QQclX5A4845522020:__QQclX5A4845522020,_QQclX5A4845523220:__QQclX5A4845523220,_QQclX5A484552324B:__QQclX5A484552324B,_QQclX5A4845524B20:__QQclX5A4845524B20,_QQclX5A4845544432:__QQclX5A4845544432,_QQclX5A4845544632:__QQclX5A4845544632,_QQclX5A4845545244:__QQclX5A4845545244,_QQclX5A4845545246:__QQclX5A4845545246,_QQclX5A4845545249:__QQclX5A4845545249,_QQclX5A4845545253:__QQclX5A4845545253,_QQclX5A484745515A:__QQclX5A484745515A,_QQclX5A4850434F4E:__QQclX5A4850434F4E,_QQclX5A4850455620:__QQclX5A4850455620,_QQclX5A48504D5620:__QQclX5A48504D5620,_QQclX5A4850522020:__QQclX5A4850522020,_QQclX5A4850523220:__QQclX5A4850523220,_QQclX5A4850545244:__QQclX5A4850545244,_QQclX5A4850545246:__QQclX5A4850545246,_QQclX5A4850545249:__QQclX5A4850545249,_QQclX5A4850545253:__QQclX5A4850545253,_QQclX5A4853455152:__QQclX5A4853455152,_QQclX5A4C41454430:__QQclX5A4C41454430,_QQclX5A4C41454437:__QQclX5A4C41454437,_QQclX5A4C41454438:__QQclX5A4C41454438,_QQclX5A4C414C5330:__QQclX5A4C414C5330,_QQclX5A4C414C5341:__QQclX5A4C414C5341,_QQclX5A4C414C5344:__QQclX5A4C414C5344,_QQclX5A4C41515230:__QQclX5A4C41515230,_QQclX5A4C41515233:__QQclX5A4C41515233,_QQclX5A4C41515234:__QQclX5A4C41515234,_QQclX5A4C4153434C:__QQclX5A4C4153434C,_QQclX5A4C41535220:__QQclX5A4C41535220,_QQclX5A4C41544253:__QQclX5A4C41544253,_QQclX5A4C41545053:__QQclX5A4C41545053,_QQclX5A4C41545253:__QQclX5A4C41545253,_QQclX5A4C41555532:__QQclX5A4C41555532,_QQclX5A4C4155554D:__QQclX5A4C4155554D,_QQclX5A5042544632:__QQclX5A5042544632,_QQclX5A5042545246:__QQclX5A5042545246,_QQclX5A504F434F4E:__QQclX5A504F434F4E,_QQclX5A504F455155:__QQclX5A504F455155,_QQclX5A504F524653:__QQclX5A504F524653,_QQclX5A504F535620:__QQclX5A504F535620,_QQclX5A504F535658:__QQclX5A504F535658,_QQclX5A504F544632:__QQclX5A504F544632,_QQclX5A504F545246:__QQclX5A504F545246,_QQclX5A504F54524632:__QQclX5A504F54524632,_QQclX5A504F545249:__QQclX5A504F545249,_QQclX5A504F545253:__QQclX5A504F545253,_QQclX5A5050434F4E:__QQclX5A5050434F4E,_QQclX5A5050545246:__QQclX5A5050545246,_QQclX5A5050545249:__QQclX5A5050545249,_QQclX5A5050545253:__QQclX5A5050545253,_QQclX5A5053544632:__QQclX5A5053544632,_QQclX5A5053545246:__QQclX5A5053545246,_QQclX5A5350434F4E:__QQclX5A5350434F4E,_QQclX5A53504D5620:__QQclX5A53504D5620,_QQclX5A5350522020:__QQclX5A5350522020,_QQclX5A5350545246:__QQclX5A5350545246,_QQclX5A5350545249:__QQclX5A5350545249,_QQclX5A5350545253:__QQclX5A5350545253,_QQclX5A5354454443:__QQclX5A5354454443,_QQclX5A5354455152:__QQclX5A5354455152,_QQclX5A5359434F4E:__QQclX5A5359434F4E,_QQclX5A53594D4D20:__QQclX5A53594D4D20,_QQclX5A53594D5620:__QQclX5A53594D5620,_QQclX5A5359522020:__QQclX5A5359522020,_QQclX5A535952324B:__QQclX5A535952324B,_QQclX5A5359524B20:__QQclX5A5359524B20,_QQclX5A5359544632:__QQclX5A5359544632,_QQclX5A5359545246:__QQclX5A5359545246,_QQclX5A5359545249:__QQclX5A5359545249,_QQclX5A5359545253:__QQclX5A5359545253,_QQclX5A54424D5620:__QQclX5A54424D5620,_QQclX5A5442535620:__QQclX5A5442535620,_QQclX5A5447455643:__QQclX5A5447455643,_QQclX5A5447455843:__QQclX5A5447455843,_QQclX5A544753454E:__QQclX5A544753454E,_QQclX5A5447535932:__QQclX5A5447535932,_QQclX5A544753594C:__QQclX5A544753594C,_QQclX5A5450434F4E:__QQclX5A5450434F4E,_QQclX5A54504D5620:__QQclX5A54504D5620,_QQclX5A5450535620:__QQclX5A5450535620,_QQclX5A5450545249:__QQclX5A5450545249,_QQclX5A5450545253:__QQclX5A5450545253,_QQclX5A5452434F4E:__QQclX5A5452434F4E,_QQclX5A5452455643:__QQclX5A5452455643,_QQclX5A545245564333:__QQclX5A545245564333,_QQclX5A5452455843:__QQclX5A5452455843,_QQclX5A54524D4D20:__QQclX5A54524D4D20,_QQclX5A54524D5620:__QQclX5A54524D5620,_QQclX5A545253454E:__QQclX5A545253454E,_QQclX5A5452534D20:__QQclX5A5452534D20,_QQclX5A5452534E41:__QQclX5A5452534E41,_QQclX5A5452535620:__QQclX5A5452535620,_QQclX5A545253594C:__QQclX5A545253594C,_QQclX5A5452544932:__QQclX5A5452544932,_QQclX5A5452545249:__QQclX5A5452545249,_QQclX5A5452545253:__QQclX5A5452545253,_QQclX5A554E47324C:__QQclX5A554E47324C,_QQclX5A554E473252:__QQclX5A554E473252,_QQclX5A554E474252:__QQclX5A554E474252,_QQclX5A554E474852:__QQclX5A554E474852,_QQclX5A554E474C32:__QQclX5A554E474C32,_QQclX5A554E474C51:__QQclX5A554E474C51,_QQclX5A554E47514C:__QQclX5A554E47514C,_QQclX5A554E475152:__QQclX5A554E475152,_QQclX5A554E475232:__QQclX5A554E475232,_QQclX5A554E475251:__QQclX5A554E475251,_QQclX5A554E475452:__QQclX5A554E475452,_QQclX5A554E4D324C:__QQclX5A554E4D324C,_QQclX5A554E4D3252:__QQclX5A554E4D3252,_QQclX5A554E4D4252:__QQclX5A554E4D4252,_QQclX5A554E4D4852:__QQclX5A554E4D4852,_QQclX5A554E4D4C32:__QQclX5A554E4D4C32,_QQclX5A554E4D4C51:__QQclX5A554E4D4C51,_QQclX5A554E4D514C:__QQclX5A554E4D514C,_QQclX5A554E4D5152:__QQclX5A554E4D5152,_QQclX5A554E4D5452:__QQclX5A554E4D5452,_QQclX5A5550475452:__QQclX5A5550475452,_QQclX63:__QQclX63,_QQclX6E:__QQclX6E,_QQclX74:__QQclX74,_QQclX784F52424442:__QQclX784F52424442,_QQclXd508bd4b36136b084c68941b4b791b1d:__QQclXd508bd4b36136b084c68941b4b791b1d,_Unwind_Backtrace:__Unwind_Backtrace,_Unwind_FindEnclosingFunction:__Unwind_FindEnclosingFunction,_Unwind_GetIPInfo:__Unwind_GetIPInfo,__asctime_r:___asctime_r,__assert_fail:___assert_fail,__c_longjmp:___c_longjmp,__call_sighandler:___call_sighandler,__cpp_exception:___cpp_exception,__global_base:___global_base,__heap_base:___heap_base,__indirect_function_table:wasmTable,__memory_base:___memory_base,__stack_high:___stack_high,__stack_low:___stack_low,__stack_pointer:___stack_pointer,__syscall__newselect:___syscall__newselect,__syscall_accept4:___syscall_accept4,__syscall_bind:___syscall_bind,__syscall_chdir:___syscall_chdir,__syscall_chmod:___syscall_chmod,__syscall_connect:___syscall_connect,__syscall_dup:___syscall_dup,__syscall_dup3:___syscall_dup3,__syscall_faccessat:___syscall_faccessat,__syscall_fadvise64:___syscall_fadvise64,__syscall_fallocate:___syscall_fallocate,__syscall_fchdir:___syscall_fchdir,__syscall_fchmod:___syscall_fchmod,__syscall_fchmodat:___syscall_fchmodat,__syscall_fchown32:___syscall_fchown32,__syscall_fchownat:___syscall_fchownat,__syscall_fcntl64:___syscall_fcntl64,__syscall_fdatasync:___syscall_fdatasync,__syscall_fstat64:___syscall_fstat64,__syscall_fstatfs64:___syscall_fstatfs64,__syscall_ftruncate64:___syscall_ftruncate64,__syscall_getcwd:___syscall_getcwd,__syscall_getdents64:___syscall_getdents64,__syscall_getpeername:___syscall_getpeername,__syscall_getsockname:___syscall_getsockname,__syscall_getsockopt:___syscall_getsockopt,__syscall_ioctl:___syscall_ioctl,__syscall_listen:___syscall_listen,__syscall_lstat64:___syscall_lstat64,__syscall_mkdirat:___syscall_mkdirat,__syscall_mknodat:___syscall_mknodat,__syscall_newfstatat:___syscall_newfstatat,__syscall_openat:___syscall_openat,__syscall_pipe:___syscall_pipe,__syscall_poll:___syscall_poll,__syscall_readlinkat:___syscall_readlinkat,__syscall_recvfrom:___syscall_recvfrom,__syscall_recvmsg:___syscall_recvmsg,__syscall_renameat:___syscall_renameat,__syscall_rmdir:___syscall_rmdir,__syscall_sendmsg:___syscall_sendmsg,__syscall_sendto:___syscall_sendto,__syscall_socket:___syscall_socket,__syscall_stat64:___syscall_stat64,__syscall_statfs64:___syscall_statfs64,__syscall_symlink:___syscall_symlink,__syscall_symlinkat:___syscall_symlinkat,__syscall_truncate64:___syscall_truncate64,__syscall_unlinkat:___syscall_unlinkat,__syscall_utimensat:___syscall_utimensat,__table_base:___table_base,_dlopen_js:__dlopen_js,_dlsym_catchup_js:__dlsym_catchup_js,_dlsym_js:__dlsym_js,_emscripten_dlopen_js:__emscripten_dlopen_js,_emscripten_fetch_free:__emscripten_fetch_free,_emscripten_fetch_get_response_headers:__emscripten_fetch_get_response_headers,_emscripten_fetch_get_response_headers_length:__emscripten_fetch_get_response_headers_length,_emscripten_fs_load_embedded_files:__emscripten_fs_load_embedded_files,_emscripten_get_now_is_monotonic:__emscripten_get_now_is_monotonic,_emscripten_get_progname:__emscripten_get_progname,_emscripten_push_main_loop_blocker:__emscripten_push_main_loop_blocker,_emscripten_push_uncounted_main_loop_blocker:__emscripten_push_uncounted_main_loop_blocker,_emscripten_runtime_keepalive_clear:__emscripten_runtime_keepalive_clear,_emscripten_set_offscreencanvas_size:__emscripten_set_offscreencanvas_size,_glGenObject:__glGenObject,_glGetActiveAttribOrUniform:__glGetActiveAttribOrUniform,_gmtime_js:__gmtime_js,_localtime_js:__localtime_js,_mktime_js:__mktime_js,_mmap_js:__mmap_js,_msync_js:__msync_js,_munmap_js:__munmap_js,_setitimer_js:__setitimer_js,_timegm_js:__timegm_js,_tzset_js:__tzset_js,abort:_abort,alBuffer3f:_alBuffer3f,alBuffer3i:_alBuffer3i,alBufferData:_alBufferData,alBufferf:_alBufferf,alBufferfv:_alBufferfv,alBufferi:_alBufferi,alBufferiv:_alBufferiv,alDeleteBuffers:_alDeleteBuffers,alDeleteSources:_alDeleteSources,alDisable:_alDisable,alDistanceModel:_alDistanceModel,alDopplerFactor:_alDopplerFactor,alDopplerVelocity:_alDopplerVelocity,alEnable:_alEnable,alGenBuffers:_alGenBuffers,alGenSources:_alGenSources,alGetBoolean:_alGetBoolean,alGetBooleanv:_alGetBooleanv,alGetBuffer3f:_alGetBuffer3f,alGetBuffer3i:_alGetBuffer3i,alGetBufferf:_alGetBufferf,alGetBufferfv:_alGetBufferfv,alGetBufferi:_alGetBufferi,alGetBufferiv:_alGetBufferiv,alGetDouble:_alGetDouble,alGetDoublev:_alGetDoublev,alGetEnumValue:_alGetEnumValue,alGetError:_alGetError,alGetFloat:_alGetFloat,alGetFloatv:_alGetFloatv,alGetInteger:_alGetInteger,alGetIntegerv:_alGetIntegerv,alGetListener3f:_alGetListener3f,alGetListener3i:_alGetListener3i,alGetListenerf:_alGetListenerf,alGetListenerfv:_alGetListenerfv,alGetListeneri:_alGetListeneri,alGetListeneriv:_alGetListeneriv,alGetSource3f:_alGetSource3f,alGetSource3i:_alGetSource3i,alGetSourcef:_alGetSourcef,alGetSourcefv:_alGetSourcefv,alGetSourcei:_alGetSourcei,alGetSourceiv:_alGetSourceiv,alGetString:_alGetString,alIsBuffer:_alIsBuffer,alIsEnabled:_alIsEnabled,alIsExtensionPresent:_alIsExtensionPresent,alIsSource:_alIsSource,alListener3f:_alListener3f,alListener3i:_alListener3i,alListenerf:_alListenerf,alListenerfv:_alListenerfv,alListeneri:_alListeneri,alListeneriv:_alListeneriv,alSource3f:_alSource3f,alSource3i:_alSource3i,alSourcePause:_alSourcePause,alSourcePausev:_alSourcePausev,alSourcePlay:_alSourcePlay,alSourcePlayv:_alSourcePlayv,alSourceQueueBuffers:_alSourceQueueBuffers,alSourceRewind:_alSourceRewind,alSourceRewindv:_alSourceRewindv,alSourceStop:_alSourceStop,alSourceStopv:_alSourceStopv,alSourceUnqueueBuffers:_alSourceUnqueueBuffers,alSourcef:_alSourcef,alSourcefv:_alSourcefv,alSourcei:_alSourcei,alSourceiv:_alSourceiv,alSpeedOfSound:_alSpeedOfSound,alcCaptureCloseDevice:_alcCaptureCloseDevice,alcCaptureOpenDevice:_alcCaptureOpenDevice,alcCaptureSamples:_alcCaptureSamples,alcCaptureStart:_alcCaptureStart,alcCaptureStop:_alcCaptureStop,alcCloseDevice:_alcCloseDevice,alcCreateContext:_alcCreateContext,alcDestroyContext:_alcDestroyContext,alcGetContextsDevice:_alcGetContextsDevice,alcGetCurrentContext:_alcGetCurrentContext,alcGetEnumValue:_alcGetEnumValue,alcGetError:_alcGetError,alcGetIntegerv:_alcGetIntegerv,alcGetString:_alcGetString,alcIsExtensionPresent:_alcIsExtensionPresent,alcMakeContextCurrent:_alcMakeContextCurrent,alcOpenDevice:_alcOpenDevice,alcProcessContext:_alcProcessContext,alcSuspendContext:_alcSuspendContext,boxColor:_boxColor,boxRGBA:_boxRGBA,clock_res_get:_clock_res_get,clock_time_get:_clock_time_get,dasum_:_dasum_,daxpy_:_daxpy_,dcopy_:_dcopy_,ddot_:_ddot_,dgbmv_:_dgbmv_,dgemm_:_dgemm_,dgemv_:_dgemv_,dger_:_dger_,dnrm2_:_dnrm2_,drot_:_drot_,drotg_:_drotg_,drotm_:_drotm_,dsbmv_:_dsbmv_,dscal_:_dscal_,dspmv_:_dspmv_,dspr2_:_dspr2_,dspr_:_dspr_,dswap_:_dswap_,dsymm_:_dsymm_,dsymv_:_dsymv_,dsyr2_:_dsyr2_,dsyr2k_:_dsyr2k_,dsyr_:_dsyr_,dsyrk_:_dsyrk_,dtbmv_:_dtbmv_,dtbsv_:_dtbsv_,dtpmv_:_dtpmv_,dtpsv_:_dtpsv_,dtrmm_:_dtrmm_,dtrmv_:_dtrmv_,dtrsm_:_dtrsm_,dtrsv_:_dtrsv_,dzasum_:_dzasum_,dznrm2_:_dznrm2_,eglBindAPI:_eglBindAPI,eglChooseConfig:_eglChooseConfig,eglCreateContext:_eglCreateContext,eglCreateWindowSurface:_eglCreateWindowSurface,eglDestroyContext:_eglDestroyContext,eglDestroySurface:_eglDestroySurface,eglGetConfigAttrib:_eglGetConfigAttrib,eglGetConfigs:_eglGetConfigs,eglGetCurrentContext:_eglGetCurrentContext,eglGetCurrentDisplay:_eglGetCurrentDisplay,eglGetCurrentSurface:_eglGetCurrentSurface,eglGetDisplay:_eglGetDisplay,eglGetError:_eglGetError,eglInitialize:_eglInitialize,eglMakeCurrent:_eglMakeCurrent,eglQueryAPI:_eglQueryAPI,eglQueryContext:_eglQueryContext,eglQueryString:_eglQueryString,eglQuerySurface:_eglQuerySurface,eglReleaseThread:_eglReleaseThread,eglSwapBuffers:_eglSwapBuffers,eglSwapInterval:_eglSwapInterval,eglTerminate:_eglTerminate,eglWaitClient:_eglWaitClient,eglWaitGL:_eglWaitGL,eglWaitNative:_eglWaitNative,ellipseColor:_ellipseColor,ellipseRGBA:_ellipseRGBA,emscripten_SDL_SetEventHandler:_emscripten_SDL_SetEventHandler,emscripten_alcDevicePauseSOFT:_emscripten_alcDevicePauseSOFT,emscripten_alcDeviceResumeSOFT:_emscripten_alcDeviceResumeSOFT,emscripten_alcGetStringiSOFT:_emscripten_alcGetStringiSOFT,emscripten_alcResetDeviceSOFT:_emscripten_alcResetDeviceSOFT,emscripten_asm_const_async_on_main_thread:_emscripten_asm_const_async_on_main_thread,emscripten_asm_const_double:_emscripten_asm_const_double,emscripten_asm_const_double_sync_on_main_thread:_emscripten_asm_const_double_sync_on_main_thread,emscripten_asm_const_int:_emscripten_asm_const_int,emscripten_asm_const_int_sync_on_main_thread:_emscripten_asm_const_int_sync_on_main_thread,emscripten_asm_const_ptr:_emscripten_asm_const_ptr,emscripten_asm_const_ptr_sync_on_main_thread:_emscripten_asm_const_ptr_sync_on_main_thread,emscripten_async_call:_emscripten_async_call,emscripten_async_load_script:_emscripten_async_load_script,emscripten_async_run_script:_emscripten_async_run_script,emscripten_async_wget:_emscripten_async_wget,emscripten_async_wget2:_emscripten_async_wget2,emscripten_async_wget2_abort:_emscripten_async_wget2_abort,emscripten_async_wget2_data:_emscripten_async_wget2_data,emscripten_async_wget_data:_emscripten_async_wget_data,emscripten_call_worker:_emscripten_call_worker,emscripten_cancel_animation_frame:_emscripten_cancel_animation_frame,emscripten_cancel_main_loop:_emscripten_cancel_main_loop,emscripten_clear_immediate:_emscripten_clear_immediate,emscripten_clear_interval:_emscripten_clear_interval,emscripten_clear_timeout:_emscripten_clear_timeout,emscripten_console_error:_emscripten_console_error,emscripten_console_log:_emscripten_console_log,emscripten_console_warn:_emscripten_console_warn,emscripten_create_worker:_emscripten_create_worker,emscripten_date_now:_emscripten_date_now,emscripten_debugger:_emscripten_debugger,emscripten_destroy_worker:_emscripten_destroy_worker,emscripten_enter_soft_fullscreen:_emscripten_enter_soft_fullscreen,emscripten_err:_emscripten_err,emscripten_errn:_emscripten_errn,emscripten_exit_fullscreen:_emscripten_exit_fullscreen,emscripten_exit_pointerlock:_emscripten_exit_pointerlock,emscripten_exit_soft_fullscreen:_emscripten_exit_soft_fullscreen,emscripten_exit_with_live_runtime:_emscripten_exit_with_live_runtime,emscripten_fiber_swap:_emscripten_fiber_swap,emscripten_force_exit:_emscripten_force_exit,emscripten_get_battery_status:_emscripten_get_battery_status,emscripten_get_callstack:_emscripten_get_callstack,emscripten_get_canvas_element_size:_emscripten_get_canvas_element_size,emscripten_get_canvas_size:_emscripten_get_canvas_size,emscripten_get_compiler_setting:_emscripten_get_compiler_setting,emscripten_get_device_pixel_ratio:_emscripten_get_device_pixel_ratio,emscripten_get_devicemotion_status:_emscripten_get_devicemotion_status,emscripten_get_deviceorientation_status:_emscripten_get_deviceorientation_status,emscripten_get_element_css_size:_emscripten_get_element_css_size,emscripten_get_fullscreen_status:_emscripten_get_fullscreen_status,emscripten_get_gamepad_status:_emscripten_get_gamepad_status,emscripten_get_heap_max:_emscripten_get_heap_max,emscripten_get_main_loop_timing:_emscripten_get_main_loop_timing,emscripten_get_module_name:_emscripten_get_module_name,emscripten_get_mouse_status:_emscripten_get_mouse_status,emscripten_get_now:_emscripten_get_now,emscripten_get_now_res:_emscripten_get_now_res,emscripten_get_num_gamepads:_emscripten_get_num_gamepads,emscripten_get_orientation_status:_emscripten_get_orientation_status,emscripten_get_pointerlock_status:_emscripten_get_pointerlock_status,emscripten_get_preloaded_image_data:_emscripten_get_preloaded_image_data,emscripten_get_preloaded_image_data_from_FILE:_emscripten_get_preloaded_image_data_from_FILE,emscripten_get_screen_size:_emscripten_get_screen_size,emscripten_get_visibility_status:_emscripten_get_visibility_status,emscripten_get_window_title:_emscripten_get_window_title,emscripten_get_worker_queue_size:_emscripten_get_worker_queue_size,emscripten_glActiveTexture:_emscripten_glActiveTexture,emscripten_glAttachShader:_emscripten_glAttachShader,emscripten_glBegin:_emscripten_glBegin,emscripten_glBeginQueryEXT:_emscripten_glBeginQueryEXT,emscripten_glBindAttribLocation:_emscripten_glBindAttribLocation,emscripten_glBindBuffer:_emscripten_glBindBuffer,emscripten_glBindFramebuffer:_emscripten_glBindFramebuffer,emscripten_glBindRenderbuffer:_emscripten_glBindRenderbuffer,emscripten_glBindTexture:_emscripten_glBindTexture,emscripten_glBindVertexArray:_emscripten_glBindVertexArray,emscripten_glBindVertexArrayOES:_emscripten_glBindVertexArrayOES,emscripten_glBlendColor:_emscripten_glBlendColor,emscripten_glBlendEquation:_emscripten_glBlendEquation,emscripten_glBlendEquationSeparate:_emscripten_glBlendEquationSeparate,emscripten_glBlendFunc:_emscripten_glBlendFunc,emscripten_glBlendFuncSeparate:_emscripten_glBlendFuncSeparate,emscripten_glBufferData:_emscripten_glBufferData,emscripten_glBufferSubData:_emscripten_glBufferSubData,emscripten_glCheckFramebufferStatus:_emscripten_glCheckFramebufferStatus,emscripten_glClear:_emscripten_glClear,emscripten_glClearColor:_emscripten_glClearColor,emscripten_glClearDepth:_emscripten_glClearDepth,emscripten_glClearDepthf:_emscripten_glClearDepthf,emscripten_glClearStencil:_emscripten_glClearStencil,emscripten_glColorMask:_emscripten_glColorMask,emscripten_glCompileShader:_emscripten_glCompileShader,emscripten_glCompressedTexImage2D:_emscripten_glCompressedTexImage2D,emscripten_glCompressedTexSubImage2D:_emscripten_glCompressedTexSubImage2D,emscripten_glCopyTexImage2D:_emscripten_glCopyTexImage2D,emscripten_glCopyTexSubImage2D:_emscripten_glCopyTexSubImage2D,emscripten_glCreateProgram:_emscripten_glCreateProgram,emscripten_glCreateShader:_emscripten_glCreateShader,emscripten_glCullFace:_emscripten_glCullFace,emscripten_glDeleteBuffers:_emscripten_glDeleteBuffers,emscripten_glDeleteFramebuffers:_emscripten_glDeleteFramebuffers,emscripten_glDeleteProgram:_emscripten_glDeleteProgram,emscripten_glDeleteQueriesEXT:_emscripten_glDeleteQueriesEXT,emscripten_glDeleteRenderbuffers:_emscripten_glDeleteRenderbuffers,emscripten_glDeleteShader:_emscripten_glDeleteShader,emscripten_glDeleteTextures:_emscripten_glDeleteTextures,emscripten_glDeleteVertexArrays:_emscripten_glDeleteVertexArrays,emscripten_glDeleteVertexArraysOES:_emscripten_glDeleteVertexArraysOES,emscripten_glDepthFunc:_emscripten_glDepthFunc,emscripten_glDepthMask:_emscripten_glDepthMask,emscripten_glDepthRange:_emscripten_glDepthRange,emscripten_glDepthRangef:_emscripten_glDepthRangef,emscripten_glDetachShader:_emscripten_glDetachShader,emscripten_glDisable:_emscripten_glDisable,emscripten_glDisableVertexAttribArray:_emscripten_glDisableVertexAttribArray,emscripten_glDrawArrays:_emscripten_glDrawArrays,emscripten_glDrawArraysInstanced:_emscripten_glDrawArraysInstanced,emscripten_glDrawArraysInstancedANGLE:_emscripten_glDrawArraysInstancedANGLE,emscripten_glDrawArraysInstancedARB:_emscripten_glDrawArraysInstancedARB,emscripten_glDrawArraysInstancedEXT:_emscripten_glDrawArraysInstancedEXT,emscripten_glDrawArraysInstancedNV:_emscripten_glDrawArraysInstancedNV,emscripten_glDrawBuffers:_emscripten_glDrawBuffers,emscripten_glDrawBuffersEXT:_emscripten_glDrawBuffersEXT,emscripten_glDrawBuffersWEBGL:_emscripten_glDrawBuffersWEBGL,emscripten_glDrawElements:_emscripten_glDrawElements,emscripten_glDrawElementsInstanced:_emscripten_glDrawElementsInstanced,emscripten_glDrawElementsInstancedANGLE:_emscripten_glDrawElementsInstancedANGLE,emscripten_glDrawElementsInstancedARB:_emscripten_glDrawElementsInstancedARB,emscripten_glDrawElementsInstancedEXT:_emscripten_glDrawElementsInstancedEXT,emscripten_glDrawElementsInstancedNV:_emscripten_glDrawElementsInstancedNV,emscripten_glEnable:_emscripten_glEnable,emscripten_glEnableVertexAttribArray:_emscripten_glEnableVertexAttribArray,emscripten_glEndQueryEXT:_emscripten_glEndQueryEXT,emscripten_glFinish:_emscripten_glFinish,emscripten_glFlush:_emscripten_glFlush,emscripten_glFramebufferRenderbuffer:_emscripten_glFramebufferRenderbuffer,emscripten_glFramebufferTexture2D:_emscripten_glFramebufferTexture2D,emscripten_glFrontFace:_emscripten_glFrontFace,emscripten_glGenBuffers:_emscripten_glGenBuffers,emscripten_glGenFramebuffers:_emscripten_glGenFramebuffers,emscripten_glGenQueriesEXT:_emscripten_glGenQueriesEXT,emscripten_glGenRenderbuffers:_emscripten_glGenRenderbuffers,emscripten_glGenTextures:_emscripten_glGenTextures,emscripten_glGenVertexArrays:_emscripten_glGenVertexArrays,emscripten_glGenVertexArraysOES:_emscripten_glGenVertexArraysOES,emscripten_glGenerateMipmap:_emscripten_glGenerateMipmap,emscripten_glGetActiveAttrib:_emscripten_glGetActiveAttrib,emscripten_glGetActiveUniform:_emscripten_glGetActiveUniform,emscripten_glGetAttachedShaders:_emscripten_glGetAttachedShaders,emscripten_glGetAttribLocation:_emscripten_glGetAttribLocation,emscripten_glGetBooleanv:_emscripten_glGetBooleanv,emscripten_glGetBufferParameteriv:_emscripten_glGetBufferParameteriv,emscripten_glGetError:_emscripten_glGetError,emscripten_glGetFloatv:_emscripten_glGetFloatv,emscripten_glGetFramebufferAttachmentParameteriv:_emscripten_glGetFramebufferAttachmentParameteriv,emscripten_glGetIntegerv:_emscripten_glGetIntegerv,emscripten_glGetProgramInfoLog:_emscripten_glGetProgramInfoLog,emscripten_glGetProgramiv:_emscripten_glGetProgramiv,emscripten_glGetQueryObjecti64vEXT:_emscripten_glGetQueryObjecti64vEXT,emscripten_glGetQueryObjectivEXT:_emscripten_glGetQueryObjectivEXT,emscripten_glGetQueryObjectui64vEXT:_emscripten_glGetQueryObjectui64vEXT,emscripten_glGetQueryObjectuivEXT:_emscripten_glGetQueryObjectuivEXT,emscripten_glGetQueryivEXT:_emscripten_glGetQueryivEXT,emscripten_glGetRenderbufferParameteriv:_emscripten_glGetRenderbufferParameteriv,emscripten_glGetShaderInfoLog:_emscripten_glGetShaderInfoLog,emscripten_glGetShaderPrecisionFormat:_emscripten_glGetShaderPrecisionFormat,emscripten_glGetShaderSource:_emscripten_glGetShaderSource,emscripten_glGetShaderiv:_emscripten_glGetShaderiv,emscripten_glGetString:_emscripten_glGetString,emscripten_glGetTexParameterfv:_emscripten_glGetTexParameterfv,emscripten_glGetTexParameteriv:_emscripten_glGetTexParameteriv,emscripten_glGetUniformLocation:_emscripten_glGetUniformLocation,emscripten_glGetUniformfv:_emscripten_glGetUniformfv,emscripten_glGetUniformiv:_emscripten_glGetUniformiv,emscripten_glGetVertexAttribPointerv:_emscripten_glGetVertexAttribPointerv,emscripten_glGetVertexAttribfv:_emscripten_glGetVertexAttribfv,emscripten_glGetVertexAttribiv:_emscripten_glGetVertexAttribiv,emscripten_glHint:_emscripten_glHint,emscripten_glIsBuffer:_emscripten_glIsBuffer,emscripten_glIsEnabled:_emscripten_glIsEnabled,emscripten_glIsFramebuffer:_emscripten_glIsFramebuffer,emscripten_glIsProgram:_emscripten_glIsProgram,emscripten_glIsQueryEXT:_emscripten_glIsQueryEXT,emscripten_glIsRenderbuffer:_emscripten_glIsRenderbuffer,emscripten_glIsShader:_emscripten_glIsShader,emscripten_glIsTexture:_emscripten_glIsTexture,emscripten_glIsVertexArray:_emscripten_glIsVertexArray,emscripten_glIsVertexArrayOES:_emscripten_glIsVertexArrayOES,emscripten_glLineWidth:_emscripten_glLineWidth,emscripten_glLinkProgram:_emscripten_glLinkProgram,emscripten_glLoadIdentity:_emscripten_glLoadIdentity,emscripten_glMatrixMode:_emscripten_glMatrixMode,emscripten_glMultiDrawArrays:_emscripten_glMultiDrawArrays,emscripten_glMultiDrawArraysANGLE:_emscripten_glMultiDrawArraysANGLE,emscripten_glMultiDrawArraysInstancedANGLE:_emscripten_glMultiDrawArraysInstancedANGLE,emscripten_glMultiDrawArraysInstancedWEBGL:_emscripten_glMultiDrawArraysInstancedWEBGL,emscripten_glMultiDrawArraysWEBGL:_emscripten_glMultiDrawArraysWEBGL,emscripten_glMultiDrawElements:_emscripten_glMultiDrawElements,emscripten_glMultiDrawElementsANGLE:_emscripten_glMultiDrawElementsANGLE,emscripten_glMultiDrawElementsInstancedANGLE:_emscripten_glMultiDrawElementsInstancedANGLE,emscripten_glMultiDrawElementsInstancedWEBGL:_emscripten_glMultiDrawElementsInstancedWEBGL,emscripten_glMultiDrawElementsWEBGL:_emscripten_glMultiDrawElementsWEBGL,emscripten_glPixelStorei:_emscripten_glPixelStorei,emscripten_glPolygonOffset:_emscripten_glPolygonOffset,emscripten_glQueryCounterEXT:_emscripten_glQueryCounterEXT,emscripten_glReadPixels:_emscripten_glReadPixels,emscripten_glReleaseShaderCompiler:_emscripten_glReleaseShaderCompiler,emscripten_glRenderbufferStorage:_emscripten_glRenderbufferStorage,emscripten_glSampleCoverage:_emscripten_glSampleCoverage,emscripten_glScissor:_emscripten_glScissor,emscripten_glShaderBinary:_emscripten_glShaderBinary,emscripten_glShaderSource:_emscripten_glShaderSource,emscripten_glStencilFunc:_emscripten_glStencilFunc,emscripten_glStencilFuncSeparate:_emscripten_glStencilFuncSeparate,emscripten_glStencilMask:_emscripten_glStencilMask,emscripten_glStencilMaskSeparate:_emscripten_glStencilMaskSeparate,emscripten_glStencilOp:_emscripten_glStencilOp,emscripten_glStencilOpSeparate:_emscripten_glStencilOpSeparate,emscripten_glTexImage2D:_emscripten_glTexImage2D,emscripten_glTexParameterf:_emscripten_glTexParameterf,emscripten_glTexParameterfv:_emscripten_glTexParameterfv,emscripten_glTexParameteri:_emscripten_glTexParameteri,emscripten_glTexParameteriv:_emscripten_glTexParameteriv,emscripten_glTexSubImage2D:_emscripten_glTexSubImage2D,emscripten_glUniform1f:_emscripten_glUniform1f,emscripten_glUniform1fv:_emscripten_glUniform1fv,emscripten_glUniform1i:_emscripten_glUniform1i,emscripten_glUniform1iv:_emscripten_glUniform1iv,emscripten_glUniform2f:_emscripten_glUniform2f,emscripten_glUniform2fv:_emscripten_glUniform2fv,emscripten_glUniform2i:_emscripten_glUniform2i,emscripten_glUniform2iv:_emscripten_glUniform2iv,emscripten_glUniform3f:_emscripten_glUniform3f,emscripten_glUniform3fv:_emscripten_glUniform3fv,emscripten_glUniform3i:_emscripten_glUniform3i,emscripten_glUniform3iv:_emscripten_glUniform3iv,emscripten_glUniform4f:_emscripten_glUniform4f,emscripten_glUniform4fv:_emscripten_glUniform4fv,emscripten_glUniform4i:_emscripten_glUniform4i,emscripten_glUniform4iv:_emscripten_glUniform4iv,emscripten_glUniformMatrix2fv:_emscripten_glUniformMatrix2fv,emscripten_glUniformMatrix3fv:_emscripten_glUniformMatrix3fv,emscripten_glUniformMatrix4fv:_emscripten_glUniformMatrix4fv,emscripten_glUseProgram:_emscripten_glUseProgram,emscripten_glValidateProgram:_emscripten_glValidateProgram,emscripten_glVertexAttrib1f:_emscripten_glVertexAttrib1f,emscripten_glVertexAttrib1fv:_emscripten_glVertexAttrib1fv,emscripten_glVertexAttrib2f:_emscripten_glVertexAttrib2f,emscripten_glVertexAttrib2fv:_emscripten_glVertexAttrib2fv,emscripten_glVertexAttrib3f:_emscripten_glVertexAttrib3f,emscripten_glVertexAttrib3fv:_emscripten_glVertexAttrib3fv,emscripten_glVertexAttrib4f:_emscripten_glVertexAttrib4f,emscripten_glVertexAttrib4fv:_emscripten_glVertexAttrib4fv,emscripten_glVertexAttribDivisor:_emscripten_glVertexAttribDivisor,emscripten_glVertexAttribDivisorANGLE:_emscripten_glVertexAttribDivisorANGLE,emscripten_glVertexAttribDivisorARB:_emscripten_glVertexAttribDivisorARB,emscripten_glVertexAttribDivisorEXT:_emscripten_glVertexAttribDivisorEXT,emscripten_glVertexAttribDivisorNV:_emscripten_glVertexAttribDivisorNV,emscripten_glVertexAttribPointer:_emscripten_glVertexAttribPointer,emscripten_glVertexPointer:_emscripten_glVertexPointer,emscripten_glViewport:_emscripten_glViewport,emscripten_has_asyncify:_emscripten_has_asyncify,emscripten_hide_mouse:_emscripten_hide_mouse,emscripten_html5_remove_all_event_listeners:_emscripten_html5_remove_all_event_listeners,emscripten_idb_async_clear:_emscripten_idb_async_clear,emscripten_idb_async_delete:_emscripten_idb_async_delete,emscripten_idb_async_exists:_emscripten_idb_async_exists,emscripten_idb_async_load:_emscripten_idb_async_load,emscripten_idb_async_store:_emscripten_idb_async_store,emscripten_idb_clear:_emscripten_idb_clear,emscripten_idb_delete:_emscripten_idb_delete,emscripten_idb_exists:_emscripten_idb_exists,emscripten_idb_load:_emscripten_idb_load,emscripten_idb_store:_emscripten_idb_store,emscripten_is_main_browser_thread:_emscripten_is_main_browser_thread,emscripten_is_webgl_context_lost:_emscripten_is_webgl_context_lost,emscripten_lock_orientation:_emscripten_lock_orientation,emscripten_log:_emscripten_log,emscripten_math_acos:_emscripten_math_acos,emscripten_math_acosh:_emscripten_math_acosh,emscripten_math_asin:_emscripten_math_asin,emscripten_math_asinh:_emscripten_math_asinh,emscripten_math_atan:_emscripten_math_atan,emscripten_math_atan2:_emscripten_math_atan2,emscripten_math_atanh:_emscripten_math_atanh,emscripten_math_cbrt:_emscripten_math_cbrt,emscripten_math_cos:_emscripten_math_cos,emscripten_math_cosh:_emscripten_math_cosh,emscripten_math_exp:_emscripten_math_exp,emscripten_math_expm1:_emscripten_math_expm1,emscripten_math_fmod:_emscripten_math_fmod,emscripten_math_hypot:_emscripten_math_hypot,emscripten_math_log:_emscripten_math_log,emscripten_math_log10:_emscripten_math_log10,emscripten_math_log1p:_emscripten_math_log1p,emscripten_math_log2:_emscripten_math_log2,emscripten_math_pow:_emscripten_math_pow,emscripten_math_random:_emscripten_math_random,emscripten_math_round:_emscripten_math_round,emscripten_math_sign:_emscripten_math_sign,emscripten_math_sin:_emscripten_math_sin,emscripten_math_sinh:_emscripten_math_sinh,emscripten_math_sqrt:_emscripten_math_sqrt,emscripten_math_tan:_emscripten_math_tan,emscripten_math_tanh:_emscripten_math_tanh,emscripten_memcpy_js:_emscripten_memcpy_js,emscripten_notify_memory_growth:_emscripten_notify_memory_growth,emscripten_out:_emscripten_out,emscripten_outn:_emscripten_outn,emscripten_pause_main_loop:_emscripten_pause_main_loop,emscripten_pc_get_column:_emscripten_pc_get_column,emscripten_pc_get_file:_emscripten_pc_get_file,emscripten_pc_get_function:_emscripten_pc_get_function,emscripten_pc_get_line:_emscripten_pc_get_line,emscripten_performance_now:_emscripten_performance_now,emscripten_print_double:_emscripten_print_double,emscripten_promise_all:_emscripten_promise_all,emscripten_promise_all_settled:_emscripten_promise_all_settled,emscripten_promise_any:_emscripten_promise_any,emscripten_promise_await:_emscripten_promise_await,emscripten_promise_create:_emscripten_promise_create,emscripten_promise_destroy:_emscripten_promise_destroy,emscripten_promise_race:_emscripten_promise_race,emscripten_promise_resolve:_emscripten_promise_resolve,emscripten_promise_then:_emscripten_promise_then,emscripten_random:_emscripten_random,emscripten_request_animation_frame:_emscripten_request_animation_frame,emscripten_request_animation_frame_loop:_emscripten_request_animation_frame_loop,emscripten_request_fullscreen:_emscripten_request_fullscreen,emscripten_request_fullscreen_strategy:_emscripten_request_fullscreen_strategy,emscripten_request_pointerlock:_emscripten_request_pointerlock,emscripten_resize_heap:_emscripten_resize_heap,emscripten_resume_main_loop:_emscripten_resume_main_loop,emscripten_return_address:_emscripten_return_address,emscripten_run_preload_plugins:_emscripten_run_preload_plugins,emscripten_run_preload_plugins_data:_emscripten_run_preload_plugins_data,emscripten_run_script:_emscripten_run_script,emscripten_run_script_int:_emscripten_run_script_int,emscripten_run_script_string:_emscripten_run_script_string,emscripten_runtime_keepalive_check:_emscripten_runtime_keepalive_check,emscripten_runtime_keepalive_pop:_emscripten_runtime_keepalive_pop,emscripten_runtime_keepalive_push:_emscripten_runtime_keepalive_push,emscripten_sample_gamepad_data:_emscripten_sample_gamepad_data,emscripten_scan_registers:_emscripten_scan_registers,emscripten_set_batterychargingchange_callback_on_thread:_emscripten_set_batterychargingchange_callback_on_thread,emscripten_set_batterylevelchange_callback_on_thread:_emscripten_set_batterylevelchange_callback_on_thread,emscripten_set_beforeunload_callback_on_thread:_emscripten_set_beforeunload_callback_on_thread,emscripten_set_blur_callback_on_thread:_emscripten_set_blur_callback_on_thread,emscripten_set_canvas_element_size:_emscripten_set_canvas_element_size,emscripten_set_canvas_size:_emscripten_set_canvas_size,emscripten_set_click_callback_on_thread:_emscripten_set_click_callback_on_thread,emscripten_set_dblclick_callback_on_thread:_emscripten_set_dblclick_callback_on_thread,emscripten_set_devicemotion_callback_on_thread:_emscripten_set_devicemotion_callback_on_thread,emscripten_set_deviceorientation_callback_on_thread:_emscripten_set_deviceorientation_callback_on_thread,emscripten_set_element_css_size:_emscripten_set_element_css_size,emscripten_set_focus_callback_on_thread:_emscripten_set_focus_callback_on_thread,emscripten_set_focusin_callback_on_thread:_emscripten_set_focusin_callback_on_thread,emscripten_set_focusout_callback_on_thread:_emscripten_set_focusout_callback_on_thread,emscripten_set_fullscreenchange_callback_on_thread:_emscripten_set_fullscreenchange_callback_on_thread,emscripten_set_gamepadconnected_callback_on_thread:_emscripten_set_gamepadconnected_callback_on_thread,emscripten_set_gamepaddisconnected_callback_on_thread:_emscripten_set_gamepaddisconnected_callback_on_thread,emscripten_set_immediate:_emscripten_set_immediate,emscripten_set_immediate_loop:_emscripten_set_immediate_loop,emscripten_set_interval:_emscripten_set_interval,emscripten_set_keydown_callback_on_thread:_emscripten_set_keydown_callback_on_thread,emscripten_set_keypress_callback_on_thread:_emscripten_set_keypress_callback_on_thread,emscripten_set_keyup_callback_on_thread:_emscripten_set_keyup_callback_on_thread,emscripten_set_main_loop:_emscripten_set_main_loop,emscripten_set_main_loop_arg:_emscripten_set_main_loop_arg,emscripten_set_main_loop_expected_blockers:_emscripten_set_main_loop_expected_blockers,emscripten_set_main_loop_timing:_emscripten_set_main_loop_timing,emscripten_set_mousedown_callback_on_thread:_emscripten_set_mousedown_callback_on_thread,emscripten_set_mouseenter_callback_on_thread:_emscripten_set_mouseenter_callback_on_thread,emscripten_set_mouseleave_callback_on_thread:_emscripten_set_mouseleave_callback_on_thread,emscripten_set_mousemove_callback_on_thread:_emscripten_set_mousemove_callback_on_thread,emscripten_set_mouseout_callback_on_thread:_emscripten_set_mouseout_callback_on_thread,emscripten_set_mouseover_callback_on_thread:_emscripten_set_mouseover_callback_on_thread,emscripten_set_mouseup_callback_on_thread:_emscripten_set_mouseup_callback_on_thread,emscripten_set_orientationchange_callback_on_thread:_emscripten_set_orientationchange_callback_on_thread,emscripten_set_pointerlockchange_callback_on_thread:_emscripten_set_pointerlockchange_callback_on_thread,emscripten_set_pointerlockerror_callback_on_thread:_emscripten_set_pointerlockerror_callback_on_thread,emscripten_set_resize_callback_on_thread:_emscripten_set_resize_callback_on_thread,emscripten_set_scroll_callback_on_thread:_emscripten_set_scroll_callback_on_thread,emscripten_set_socket_close_callback:_emscripten_set_socket_close_callback,emscripten_set_socket_connection_callback:_emscripten_set_socket_connection_callback,emscripten_set_socket_error_callback:_emscripten_set_socket_error_callback,emscripten_set_socket_listen_callback:_emscripten_set_socket_listen_callback,emscripten_set_socket_message_callback:_emscripten_set_socket_message_callback,emscripten_set_socket_open_callback:_emscripten_set_socket_open_callback,emscripten_set_timeout:_emscripten_set_timeout,emscripten_set_timeout_loop:_emscripten_set_timeout_loop,emscripten_set_touchcancel_callback_on_thread:_emscripten_set_touchcancel_callback_on_thread,emscripten_set_touchend_callback_on_thread:_emscripten_set_touchend_callback_on_thread,emscripten_set_touchmove_callback_on_thread:_emscripten_set_touchmove_callback_on_thread,emscripten_set_touchstart_callback_on_thread:_emscripten_set_touchstart_callback_on_thread,emscripten_set_visibilitychange_callback_on_thread:_emscripten_set_visibilitychange_callback_on_thread,emscripten_set_webglcontextlost_callback_on_thread:_emscripten_set_webglcontextlost_callback_on_thread,emscripten_set_webglcontextrestored_callback_on_thread:_emscripten_set_webglcontextrestored_callback_on_thread,emscripten_set_wheel_callback_on_thread:_emscripten_set_wheel_callback_on_thread,emscripten_set_window_title:_emscripten_set_window_title,emscripten_sleep:_emscripten_sleep,emscripten_stack_snapshot:_emscripten_stack_snapshot,emscripten_stack_unwind_buffer:_emscripten_stack_unwind_buffer,emscripten_start_fetch:_emscripten_start_fetch,emscripten_supports_offscreencanvas:_emscripten_supports_offscreencanvas,emscripten_throw_number:_emscripten_throw_number,emscripten_throw_string:_emscripten_throw_string,emscripten_unlock_orientation:_emscripten_unlock_orientation,emscripten_unwind_to_js_event_loop:_emscripten_unwind_to_js_event_loop,emscripten_vibrate:_emscripten_vibrate,emscripten_vibrate_pattern:_emscripten_vibrate_pattern,emscripten_webgl_commit_frame:_emscripten_webgl_commit_frame,emscripten_webgl_create_context:_emscripten_webgl_create_context,emscripten_webgl_destroy_context:_emscripten_webgl_destroy_context,emscripten_webgl_do_commit_frame:_emscripten_webgl_do_commit_frame,emscripten_webgl_do_create_context:_emscripten_webgl_do_create_context,emscripten_webgl_do_get_current_context:_emscripten_webgl_do_get_current_context,emscripten_webgl_enable_ANGLE_instanced_arrays:_emscripten_webgl_enable_ANGLE_instanced_arrays,emscripten_webgl_enable_OES_vertex_array_object:_emscripten_webgl_enable_OES_vertex_array_object,emscripten_webgl_enable_WEBGL_draw_buffers:_emscripten_webgl_enable_WEBGL_draw_buffers,emscripten_webgl_enable_WEBGL_multi_draw:_emscripten_webgl_enable_WEBGL_multi_draw,emscripten_webgl_enable_extension:_emscripten_webgl_enable_extension,emscripten_webgl_get_context_attributes:_emscripten_webgl_get_context_attributes,emscripten_webgl_get_current_context:_emscripten_webgl_get_current_context,emscripten_webgl_get_drawing_buffer_size:_emscripten_webgl_get_drawing_buffer_size,emscripten_webgl_get_parameter_d:_emscripten_webgl_get_parameter_d,emscripten_webgl_get_parameter_i64v:_emscripten_webgl_get_parameter_i64v,emscripten_webgl_get_parameter_o:_emscripten_webgl_get_parameter_o,emscripten_webgl_get_parameter_utf8:_emscripten_webgl_get_parameter_utf8,emscripten_webgl_get_parameter_v:_emscripten_webgl_get_parameter_v,emscripten_webgl_get_program_info_log_utf8:_emscripten_webgl_get_program_info_log_utf8,emscripten_webgl_get_program_parameter_d:_emscripten_webgl_get_program_parameter_d,emscripten_webgl_get_shader_info_log_utf8:_emscripten_webgl_get_shader_info_log_utf8,emscripten_webgl_get_shader_parameter_d:_emscripten_webgl_get_shader_parameter_d,emscripten_webgl_get_shader_source_utf8:_emscripten_webgl_get_shader_source_utf8,emscripten_webgl_get_supported_extensions:_emscripten_webgl_get_supported_extensions,emscripten_webgl_get_uniform_d:_emscripten_webgl_get_uniform_d,emscripten_webgl_get_uniform_v:_emscripten_webgl_get_uniform_v,emscripten_webgl_get_vertex_attrib_d:_emscripten_webgl_get_vertex_attrib_d,emscripten_webgl_get_vertex_attrib_o:_emscripten_webgl_get_vertex_attrib_o,emscripten_webgl_get_vertex_attrib_v:_emscripten_webgl_get_vertex_attrib_v,emscripten_webgl_init_context_attributes:_emscripten_webgl_init_context_attributes,emscripten_webgl_make_context_current:_emscripten_webgl_make_context_current,emscripten_wget_data:_emscripten_wget_data,endprotoent:_endprotoent,environ_get:_environ_get,environ_sizes_get:_environ_sizes_get,exit:_exit,fd_close:_fd_close,fd_fdstat_get:_fd_fdstat_get,fd_pread:_fd_pread,fd_pwrite:_fd_pwrite,fd_read:_fd_read,fd_seek:_fd_seek,fd_sync:_fd_sync,fd_write:_fd_write,filledEllipseColor:_filledEllipseColor,filledEllipseRGBA:_filledEllipseRGBA,getaddrinfo:_getaddrinfo,getentropy:_getentropy,gethostbyaddr:_gethostbyaddr,gethostbyname:_gethostbyname,gethostbyname_r:_gethostbyname_r,getnameinfo:_getnameinfo,getprotobyname:_getprotobyname,getprotobynumber:_getprotobynumber,getprotoent:_getprotoent,glActiveTexture:_glActiveTexture,glAttachShader:_glAttachShader,glBegin:_glBegin,glBeginQueryEXT:_glBeginQueryEXT,glBindAttribLocation:_glBindAttribLocation,glBindBuffer:_glBindBuffer,glBindFramebuffer:_glBindFramebuffer,glBindRenderbuffer:_glBindRenderbuffer,glBindTexture:_glBindTexture,glBindVertexArray:_glBindVertexArray,glBindVertexArrayOES:_glBindVertexArrayOES,glBlendColor:_glBlendColor,glBlendEquation:_glBlendEquation,glBlendEquationSeparate:_glBlendEquationSeparate,glBlendFunc:_glBlendFunc,glBlendFuncSeparate:_glBlendFuncSeparate,glBufferData:_glBufferData,glBufferSubData:_glBufferSubData,glCheckFramebufferStatus:_glCheckFramebufferStatus,glClear:_glClear,glClearColor:_glClearColor,glClearDepth:_glClearDepth,glClearDepthf:_glClearDepthf,glClearStencil:_glClearStencil,glColorMask:_glColorMask,glCompileShader:_glCompileShader,glCompressedTexImage2D:_glCompressedTexImage2D,glCompressedTexSubImage2D:_glCompressedTexSubImage2D,glCopyTexImage2D:_glCopyTexImage2D,glCopyTexSubImage2D:_glCopyTexSubImage2D,glCreateProgram:_glCreateProgram,glCreateShader:_glCreateShader,glCullFace:_glCullFace,glDeleteBuffers:_glDeleteBuffers,glDeleteFramebuffers:_glDeleteFramebuffers,glDeleteProgram:_glDeleteProgram,glDeleteQueriesEXT:_glDeleteQueriesEXT,glDeleteRenderbuffers:_glDeleteRenderbuffers,glDeleteShader:_glDeleteShader,glDeleteTextures:_glDeleteTextures,glDeleteVertexArrays:_glDeleteVertexArrays,glDeleteVertexArraysOES:_glDeleteVertexArraysOES,glDepthFunc:_glDepthFunc,glDepthMask:_glDepthMask,glDepthRange:_glDepthRange,glDepthRangef:_glDepthRangef,glDetachShader:_glDetachShader,glDisable:_glDisable,glDisableVertexAttribArray:_glDisableVertexAttribArray,glDrawArrays:_glDrawArrays,glDrawArraysInstanced:_glDrawArraysInstanced,glDrawArraysInstancedANGLE:_glDrawArraysInstancedANGLE,glDrawArraysInstancedARB:_glDrawArraysInstancedARB,glDrawArraysInstancedEXT:_glDrawArraysInstancedEXT,glDrawArraysInstancedNV:_glDrawArraysInstancedNV,glDrawBuffers:_glDrawBuffers,glDrawBuffersEXT:_glDrawBuffersEXT,glDrawBuffersWEBGL:_glDrawBuffersWEBGL,glDrawElements:_glDrawElements,glDrawElementsInstanced:_glDrawElementsInstanced,glDrawElementsInstancedANGLE:_glDrawElementsInstancedANGLE,glDrawElementsInstancedARB:_glDrawElementsInstancedARB,glDrawElementsInstancedEXT:_glDrawElementsInstancedEXT,glDrawElementsInstancedNV:_glDrawElementsInstancedNV,glEnable:_glEnable,glEnableVertexAttribArray:_glEnableVertexAttribArray,glEndQueryEXT:_glEndQueryEXT,glFinish:_glFinish,glFlush:_glFlush,glFramebufferRenderbuffer:_glFramebufferRenderbuffer,glFramebufferTexture2D:_glFramebufferTexture2D,glFrontFace:_glFrontFace,glGenBuffers:_glGenBuffers,glGenFramebuffers:_glGenFramebuffers,glGenQueriesEXT:_glGenQueriesEXT,glGenRenderbuffers:_glGenRenderbuffers,glGenTextures:_glGenTextures,glGenVertexArrays:_glGenVertexArrays,glGenVertexArraysOES:_glGenVertexArraysOES,glGenerateMipmap:_glGenerateMipmap,glGetActiveAttrib:_glGetActiveAttrib,glGetActiveUniform:_glGetActiveUniform,glGetAttachedShaders:_glGetAttachedShaders,glGetAttribLocation:_glGetAttribLocation,glGetBooleanv:_glGetBooleanv,glGetBufferParameteriv:_glGetBufferParameteriv,glGetError:_glGetError,glGetFloatv:_glGetFloatv,glGetFramebufferAttachmentParameteriv:_glGetFramebufferAttachmentParameteriv,glGetIntegerv:_glGetIntegerv,glGetProgramInfoLog:_glGetProgramInfoLog,glGetProgramiv:_glGetProgramiv,glGetQueryObjecti64vEXT:_glGetQueryObjecti64vEXT,glGetQueryObjectivEXT:_glGetQueryObjectivEXT,glGetQueryObjectui64vEXT:_glGetQueryObjectui64vEXT,glGetQueryObjectuivEXT:_glGetQueryObjectuivEXT,glGetQueryivEXT:_glGetQueryivEXT,glGetRenderbufferParameteriv:_glGetRenderbufferParameteriv,glGetShaderInfoLog:_glGetShaderInfoLog,glGetShaderPrecisionFormat:_glGetShaderPrecisionFormat,glGetShaderSource:_glGetShaderSource,glGetShaderiv:_glGetShaderiv,glGetString:_glGetString,glGetTexParameterfv:_glGetTexParameterfv,glGetTexParameteriv:_glGetTexParameteriv,glGetUniformLocation:_glGetUniformLocation,glGetUniformfv:_glGetUniformfv,glGetUniformiv:_glGetUniformiv,glGetVertexAttribPointerv:_glGetVertexAttribPointerv,glGetVertexAttribfv:_glGetVertexAttribfv,glGetVertexAttribiv:_glGetVertexAttribiv,glHint:_glHint,glIsBuffer:_glIsBuffer,glIsEnabled:_glIsEnabled,glIsFramebuffer:_glIsFramebuffer,glIsProgram:_glIsProgram,glIsQueryEXT:_glIsQueryEXT,glIsRenderbuffer:_glIsRenderbuffer,glIsShader:_glIsShader,glIsTexture:_glIsTexture,glIsVertexArray:_glIsVertexArray,glIsVertexArrayOES:_glIsVertexArrayOES,glLineWidth:_glLineWidth,glLinkProgram:_glLinkProgram,glLoadIdentity:_glLoadIdentity,glMatrixMode:_glMatrixMode,glMultiDrawArrays:_glMultiDrawArrays,glMultiDrawArraysANGLE:_glMultiDrawArraysANGLE,glMultiDrawArraysInstancedANGLE:_glMultiDrawArraysInstancedANGLE,glMultiDrawArraysInstancedWEBGL:_glMultiDrawArraysInstancedWEBGL,glMultiDrawArraysWEBGL:_glMultiDrawArraysWEBGL,glMultiDrawElements:_glMultiDrawElements,glMultiDrawElementsANGLE:_glMultiDrawElementsANGLE,glMultiDrawElementsInstancedANGLE:_glMultiDrawElementsInstancedANGLE,glMultiDrawElementsInstancedWEBGL:_glMultiDrawElementsInstancedWEBGL,glMultiDrawElementsWEBGL:_glMultiDrawElementsWEBGL,glPixelStorei:_glPixelStorei,glPolygonOffset:_glPolygonOffset,glQueryCounterEXT:_glQueryCounterEXT,glReadPixels:_glReadPixels,glReleaseShaderCompiler:_glReleaseShaderCompiler,glRenderbufferStorage:_glRenderbufferStorage,glSampleCoverage:_glSampleCoverage,glScissor:_glScissor,glShaderBinary:_glShaderBinary,glShaderSource:_glShaderSource,glStencilFunc:_glStencilFunc,glStencilFuncSeparate:_glStencilFuncSeparate,glStencilMask:_glStencilMask,glStencilMaskSeparate:_glStencilMaskSeparate,glStencilOp:_glStencilOp,glStencilOpSeparate:_glStencilOpSeparate,glTexImage2D:_glTexImage2D,glTexParameterf:_glTexParameterf,glTexParameterfv:_glTexParameterfv,glTexParameteri:_glTexParameteri,glTexParameteriv:_glTexParameteriv,glTexSubImage2D:_glTexSubImage2D,glUniform1f:_glUniform1f,glUniform1fv:_glUniform1fv,glUniform1i:_glUniform1i,glUniform1iv:_glUniform1iv,glUniform2f:_glUniform2f,glUniform2fv:_glUniform2fv,glUniform2i:_glUniform2i,glUniform2iv:_glUniform2iv,glUniform3f:_glUniform3f,glUniform3fv:_glUniform3fv,glUniform3i:_glUniform3i,glUniform3iv:_glUniform3iv,glUniform4f:_glUniform4f,glUniform4fv:_glUniform4fv,glUniform4i:_glUniform4i,glUniform4iv:_glUniform4iv,glUniformMatrix2fv:_glUniformMatrix2fv,glUniformMatrix3fv:_glUniformMatrix3fv,glUniformMatrix4fv:_glUniformMatrix4fv,glUseProgram:_glUseProgram,glValidateProgram:_glValidateProgram,glVertexAttrib1f:_glVertexAttrib1f,glVertexAttrib1fv:_glVertexAttrib1fv,glVertexAttrib2f:_glVertexAttrib2f,glVertexAttrib2fv:_glVertexAttrib2fv,glVertexAttrib3f:_glVertexAttrib3f,glVertexAttrib3fv:_glVertexAttrib3fv,glVertexAttrib4f:_glVertexAttrib4f,glVertexAttrib4fv:_glVertexAttrib4fv,glVertexAttribDivisor:_glVertexAttribDivisor,glVertexAttribDivisorANGLE:_glVertexAttribDivisorANGLE,glVertexAttribDivisorARB:_glVertexAttribDivisorARB,glVertexAttribDivisorEXT:_glVertexAttribDivisorEXT,glVertexAttribDivisorNV:_glVertexAttribDivisorNV,glVertexAttribPointer:_glVertexAttribPointer,glVertexPointer:_glVertexPointer,glViewport:_glViewport,glewGetErrorString:_glewGetErrorString,glewGetExtension:_glewGetExtension,glewGetString:_glewGetString,glewInit:_glewInit,glewIsSupported:_glewIsSupported,glutCreateWindow:_glutCreateWindow,glutDestroyWindow:_glutDestroyWindow,glutDisplayFunc:_glutDisplayFunc,glutFullScreen:_glutFullScreen,glutGet:_glutGet,glutGetModifiers:_glutGetModifiers,glutIdleFunc:_glutIdleFunc,glutInit:_glutInit,glutInitDisplayMode:_glutInitDisplayMode,glutInitWindowPosition:_glutInitWindowPosition,glutInitWindowSize:_glutInitWindowSize,glutKeyboardFunc:_glutKeyboardFunc,glutKeyboardUpFunc:_glutKeyboardUpFunc,glutMainLoop:_glutMainLoop,glutMotionFunc:_glutMotionFunc,glutMouseFunc:_glutMouseFunc,glutPassiveMotionFunc:_glutPassiveMotionFunc,glutPositionWindow:_glutPositionWindow,glutPostRedisplay:_glutPostRedisplay,glutReshapeFunc:_glutReshapeFunc,glutReshapeWindow:_glutReshapeWindow,glutSetCursor:_glutSetCursor,glutSpecialFunc:_glutSpecialFunc,glutSpecialUpFunc:_glutSpecialUpFunc,glutSwapBuffers:_glutSwapBuffers,glutTimerFunc:_glutTimerFunc,idamax_:_idamax_,izamax_:_izamax_,lineColor:_lineColor,lineRGBA:_lineRGBA,lsame_:_lsame_,memory:wasmMemory,pixelRGBA:_pixelRGBA,proc_exit:_proc_exit,random_get:_random_get,rectangleColor:_rectangleColor,rectangleRGBA:_rectangleRGBA,rotozoomSurface:_rotozoomSurface,setNetworkCallback:_setNetworkCallback,setprotoent:_setprotoent,strftime:_strftime,strftime_l:_strftime_l,strptime:_strptime,strptime_l:_strptime_l,system:_system,uuid_clear:_uuid_clear,uuid_compare:_uuid_compare,uuid_copy:_uuid_copy,uuid_generate:_uuid_generate,uuid_is_null:_uuid_is_null,uuid_parse:_uuid_parse,uuid_type:_uuid_type,uuid_unparse:_uuid_unparse,uuid_unparse_lower:_uuid_unparse_lower,uuid_unparse_upper:_uuid_unparse_upper,uuid_variant:_uuid_variant,zaxpy_:_zaxpy_,zcopy_:_zcopy_,zdotc_:_zdotc_,zdotu_:_zdotu_,zdrot_:_zdrot_,zdscal_:_zdscal_,zgbmv_:_zgbmv_,zgemm_:_zgemm_,zgemv_:_zgemv_,zgerc_:_zgerc_,zgeru_:_zgeru_,zhemv_:_zhemv_,zher2_:_zher2_,zher2k_:_zher2k_,zher_:_zher_,zherk_:_zherk_,zhpmv_:_zhpmv_,zhpr2_:_zhpr2_,zhpr_:_zhpr_,zoomSurface:_zoomSurface,zscal_:_zscal_,zspmv_:_zspmv_,zswap_:_zswap_,ztbsv_:_ztbsv_,ztpmv_:_ztpmv_,ztpsv_:_ztpsv_,ztrmm_:_ztrmm_,ztrmv_:_ztrmv_,ztrsm_:_ztrsm_,ztrsv_:_ztrsv_};var wasmExports=createWasm();var _stderr=Module["_stderr"]=8283696;var __ZTISt18bad_variant_access=Module["__ZTISt18bad_variant_access"]=8294368;var __ZTVSt18bad_variant_access=Module["__ZTVSt18bad_variant_access"]=8294348;var __ZTVSt9exception=Module["__ZTVSt9exception"]=8300916;var _environ=Module["_environ"]=9381620;var __ZTISt19bad_optional_access=Module["__ZTISt19bad_optional_access"]=8292416;var __ZTVSt19bad_optional_access=Module["__ZTVSt19bad_optional_access"]=8292396;var _stdin=Module["_stdin"]=8283848;var _R_running_as_main_program=Module["_R_running_as_main_program"]=9343160;var _R_PPStackTop=Module["_R_PPStackTop"]=8444280;var _R_RestoreHistory=Module["_R_RestoreHistory"]=8449152;var _R_NilValue=Module["_R_NilValue"]=8444296;var _R_NaInt=Module["_R_NaInt"]=8448784;var _R_TrueValue=Module["_R_TrueValue"]=8444240;var _R_LogicalNAValue=Module["_R_LogicalNAValue"]=8444248;var _R_NamesSymbol=Module["_R_NamesSymbol"]=8448832;var _R_ClassSymbol=Module["_R_ClassSymbol"]=8448920;var _R_UnboundValue=Module["_R_UnboundValue"]=8448764;var _R_Home=Module["_R_Home"]=8448768;var _R_SeedsSymbol=Module["_R_SeedsSymbol"]=8448992;var _R_GlobalEnv=Module["_R_GlobalEnv"]=8448712;var _R_MissingArg=Module["_R_MissingArg"]=8448776;var _N01_kind=Module["_N01_kind"]=8265080;var _User_norm_fun=Module["_User_norm_fun"]=8403012;var _R_BaseEnv=Module["_R_BaseEnv"]=8448724;var _User_unif_init=Module["_User_unif_init"]=8403008;var _R_NaString=Module["_R_NaString"]=8449036;var _mbcslocale=Module["_mbcslocale"]=8444196;var _R_FunTab=Module["_R_FunTab"]=8171088;var _R_NaReal=Module["_R_NaReal"]=8448864;var _R_DimNamesSymbol=Module["_R_DimNamesSymbol"]=8448924;var _R_PosInf=Module["_R_PosInf"]=8448848;var _R_compact_realseq_class=Module["_R_compact_realseq_class"]=8409608;var _R_compact_intseq_class=Module["_R_compact_intseq_class"]=8409604;var _R_print=Module["_R_print"]=8451168;var _OutDec=Module["_OutDec"]=8170820;var _R_Bracket2Symbol=Module["_R_Bracket2Symbol"]=8448912;var _R_DotsSymbol=Module["_R_DotsSymbol"]=8448936;var _R_DimSymbol=Module["_R_DimSymbol"]=8448928;var _R_FalseValue=Module["_R_FalseValue"]=8444244;var _R_NaN=Module["_R_NaN"]=8448840;var _R_NegInf=Module["_R_NegInf"]=8448856;var _R_TspSymbol=Module["_R_TspSymbol"]=8449012;var _R_CurrentExpression=Module["_R_CurrentExpression"]=8448884;var _R_BaseSymbol=Module["_R_BaseSymbol"]=8448904;var _R_BlankString=Module["_R_BlankString"]=8449040;var _R_RowNamesSymbol=Module["_R_RowNamesSymbol"]=8448988;var _R_MethodsNamespace=Module["_R_MethodsNamespace"]=8449164;var _R_AsCharacterSymbol=Module["_R_AsCharacterSymbol"]=8448892;var _R_CStackDir=Module["_R_CStackDir"]=8170800;var _R_CStackStart=Module["_R_CStackStart"]=8170796;var _R_CStackLimit=Module["_R_CStackLimit"]=8170792;var _R_LevelsSymbol=Module["_R_LevelsSymbol"]=8448956;var _R_BaseNamespace=Module["_R_BaseNamespace"]=8448752;var _R_GlobalContext=Module["_R_GlobalContext"]=8444600;var _R_EmptyEnv=Module["_R_EmptyEnv"]=8448872;var _R_NameSymbol=Module["_R_NameSymbol"]=8448968;var _R_Visible=Module["_R_Visible"]=8444288;var _R_MB_CUR_MAX=Module["_R_MB_CUR_MAX"]=8444204;var _utf8locale=Module["_utf8locale"]=8444192;var _known_to_be_latin1=Module["_known_to_be_latin1"]=8444232;var _R_ParseError=Module["_R_ParseError"]=8443632;var _R_Outputfile=Module["_R_Outputfile"]=8443588;var _R_Consolefile=Module["_R_Consolefile"]=8443584;var _R_TempDir=Module["_R_TempDir"]=8443592;var _R_interrupts_suspended=Module["_R_interrupts_suspended"]=8443520;var _R_BCNodeStackTop=Module["_R_BCNodeStackTop"]=8448728;var _R_Srcref=Module["_R_Srcref"]=8448880;var _R_OldCStackLimit=Module["_R_OldCStackLimit"]=8443564;var _R_InBCInterpreter=Module["_R_InBCInterpreter"]=8448772;var _R_SrcrefSymbol=Module["_R_SrcrefSymbol"]=8449112;var _R_BraceSymbol=Module["_R_BraceSymbol"]=8448908;var _R_tzname=Module["_R_tzname"]=8265372;var _baseRegisterIndex=Module["_baseRegisterIndex"]=8166256;var _R_NamespaceRegistry=Module["_R_NamespaceRegistry"]=8448876;var _R_DeviceSymbol=Module["_R_DeviceSymbol"]=8448756;var _R_Interactive=Module["_R_Interactive"]=8170804;var _ptr_R_EditFile=Module["_ptr_R_EditFile"]=9343180;var _R_ParseErrorMsg=Module["_R_ParseErrorMsg"]=8443648;var _R_DirtyImage=Module["_R_DirtyImage"]=8444164;var _R_QuoteSymbol=Module["_R_QuoteSymbol"]=8448984;var _R_DoubleColonSymbol=Module["_R_DoubleColonSymbol"]=8448940;var _R_dot_Generic=Module["_R_dot_Generic"]=8449032;var _R_dot_Method=Module["_R_dot_Method"]=8449020;var _R_dot_packageName=Module["_R_dot_packageName"]=8449024;var _R_interrupts_pending=Module["_R_interrupts_pending"]=8443524;var _R_SrcfileSymbol=Module["_R_SrcfileSymbol"]=8449108;var _R_TripleColonSymbol=Module["_R_TripleColonSymbol"]=8449008;var _R_dot_defined=Module["_R_dot_defined"]=8449016;var _R_dot_target=Module["_R_dot_target"]=8449028;var _R_BlankScalarString=Module["_R_BlankScalarString"]=8449044;var _R_num_math_threads=Module["_R_num_math_threads"]=8170880;var _R_max_num_math_threads=Module["_R_max_num_math_threads"]=8170884;var _R_DollarSymbol=Module["_R_DollarSymbol"]=8448932;var _Rf_yychar=Module["_Rf_yychar"]=8434412;var _yylloc=Module["_yylloc"]=8434416;var _Rf_yylval=Module["_Rf_yylval"]=8434452;var _R_FunctionSymbol=Module["_R_FunctionSymbol"]=8448952;var _Rf_yynerrs=Module["_Rf_yynerrs"]=8434512;var _R_ParseContext=Module["_R_ParseContext"]=8443904;var _R_ParseContextLast=Module["_R_ParseContextLast"]=8444160;var _R_BracketSymbol=Module["_R_BracketSymbol"]=8448916;var _R_AtsignSymbol=Module["_R_AtsignSymbol"]=8448896;var _R_ParseContextLine=Module["_R_ParseContextLine"]=8449140;var _R_PPStackSize=Module["_R_PPStackSize"]=8170768;var _R_PPStack=Module["_R_PPStack"]=8449124;var _R_NaRmSymbol=Module["_R_NaRmSymbol"]=8448964;var _R_AccuracyInfo=Module["_R_AccuracyInfo"]=8449168;var _R_LastvalueSymbol=Module["_R_LastvalueSymbol"]=8444292;var _R_NoEcho=Module["_R_NoEcho"]=8443576;var _DLLbuf=Module["_DLLbuf"]=8444608;var _DLLbufp=Module["_DLLbufp"]=8448708;var _R_SignalHandlers=Module["_R_SignalHandlers"]=8170904;var _R_GUIType=Module["_R_GUIType"]=8170828;var _R_ignore_SIGPIPE=Module["_R_ignore_SIGPIPE"]=8448716;var _R_isForkedChild=Module["_R_isForkedChild"]=8444212;var _max_contour_segments=Module["_max_contour_segments"]=8170892;var _R_baseSymbol=Module["_R_baseSymbol"]=8448900;var _R_DropSymbol=Module["_R_DropSymbol"]=8448944;var _R_EvalSymbol=Module["_R_EvalSymbol"]=8448948;var _R_ModeSymbol=Module["_R_ModeSymbol"]=8448960;var _R_NamespaceEnvSymbol=Module["_R_NamespaceEnvSymbol"]=8448972;var _R_PackageSymbol=Module["_R_PackageSymbol"]=8448976;var _R_PreviousSymbol=Module["_R_PreviousSymbol"]=8448980;var _R_SortListSymbol=Module["_R_SortListSymbol"]=8448996;var _R_SourceSymbol=Module["_R_SourceSymbol"]=8449e3;var _R_SpecSymbol=Module["_R_SpecSymbol"]=8449004;var _R_HistoryFile=Module["_R_HistoryFile"]=8449144;var _R_HistorySize=Module["_R_HistorySize"]=8449148;var _R_BCNodeStackEnd=Module["_R_BCNodeStackEnd"]=8449156;var _RestoreAction=Module["_RestoreAction"]=8206432;var _SaveAction=Module["_SaveAction"]=8206428;var __occidental_hershey_glyphs=Module["__occidental_hershey_glyphs"]=8225408;var __oriental_hershey_glyphs=Module["__oriental_hershey_glyphs"]=8243008;var __hershey_font_info=Module["__hershey_font_info"]=8211808;var __hershey_accented_char_info=Module["__hershey_accented_char_info"]=385360;var __hershey_typeface_info=Module["__hershey_typeface_info"]=385536;var _R_InputHandlers=Module["_R_InputHandlers"]=8265108;var _Rg_PolledEvents=Module["_Rg_PolledEvents"]=8265120;var _R_PolledEvents=Module["_R_PolledEvents"]=8265112;var _stdout=Module["_stdout"]=8284e3;var _R_wait_usec=Module["_R_wait_usec"]=8265116;var _Rg_wait_usec=Module["_Rg_wait_usec"]=9337008;var _ptr_R_ProcessEvents=Module["_ptr_R_ProcessEvents"]=9347308;var _ptr_R_Suicide=Module["_ptr_R_Suicide"]=9343112;var _ptr_R_ShowMessage=Module["_ptr_R_ShowMessage"]=9343116;var _ptr_R_ReadConsole=Module["_ptr_R_ReadConsole"]=9343120;var _ptr_R_WriteConsole=Module["_ptr_R_WriteConsole"]=9343124;var _ptr_R_WriteConsoleEx=Module["_ptr_R_WriteConsoleEx"]=9343128;var _ptr_R_ResetConsole=Module["_ptr_R_ResetConsole"]=9343132;var _ptr_R_FlushConsole=Module["_ptr_R_FlushConsole"]=9343136;var _ptr_R_ClearerrConsole=Module["_ptr_R_ClearerrConsole"]=9343140;var _ptr_R_Busy=Module["_ptr_R_Busy"]=9343144;var _ptr_R_CleanUp=Module["_ptr_R_CleanUp"]=9343148;var _ptr_R_ShowFiles=Module["_ptr_R_ShowFiles"]=9343152;var _ptr_R_ChooseFile=Module["_ptr_R_ChooseFile"]=9343156;var _ptr_R_loadhistory=Module["_ptr_R_loadhistory"]=9343168;var _ptr_R_savehistory=Module["_ptr_R_savehistory"]=9343172;var _ptr_R_addhistory=Module["_ptr_R_addhistory"]=9343176;var _R_timeout_handler=Module["_R_timeout_handler"]=9343184;var _R_timeout_val=Module["_R_timeout_val"]=9343188;var _ptr_do_dataviewer=Module["_ptr_do_dataviewer"]=9343192;var _ptr_R_EditFiles=Module["_ptr_R_EditFiles"]=9347296;var _ptr_do_selectlist=Module["_ptr_do_selectlist"]=9347300;var _ptr_do_dataentry=Module["_ptr_do_dataentry"]=9347304;var _BZ2_crc32Table=Module["_BZ2_crc32Table"]=8266336;var _BZ2_rNums=Module["_BZ2_rNums"]=8267360;var _z_errmsg=Module["_z_errmsg"]=8269600;var __length_code=Module["__length_code"]=547360;var __dist_code=Module["__dist_code"]=546848;var _deflate_copyright=Module["_deflate_copyright"]=542016;var _inflate_copyright=Module["_inflate_copyright"]=546544;var ___emscripten_embedded_file_data=Module["___emscripten_embedded_file_data"]=7738312;var _af_script_classes=Module["_af_script_classes"]=8270224;var _af_blue_stringsets=Module["_af_blue_stringsets"]=7742448;var _af_blue_strings=Module["_af_blue_strings"]=7741680;var _af_style_classes=Module["_af_style_classes"]=8270320;var _af_writing_system_classes=Module["_af_writing_system_classes"]=8270192;var _af_arab_dflt_style_class=Module["_af_arab_dflt_style_class"]=7742824;var _af_arab_script_class=Module["_af_arab_script_class"]=8269640;var _af_arab_uniranges=Module["_af_arab_uniranges"]=7743808;var _af_cyrl_script_class=Module["_af_cyrl_script_class"]=8269660;var _af_cyrl_uniranges=Module["_af_cyrl_uniranges"]=7743872;var _af_deva_script_class=Module["_af_deva_script_class"]=8269680;var _af_deva_uniranges=Module["_af_deva_uniranges"]=7743920;var _af_grek_script_class=Module["_af_grek_script_class"]=8269700;var _af_grek_uniranges=Module["_af_grek_uniranges"]=7743968;var _af_hebr_script_class=Module["_af_hebr_script_class"]=8269720;var _af_hebr_uniranges=Module["_af_hebr_uniranges"]=7744e3;var _af_latn_script_class=Module["_af_latn_script_class"]=8269740;var _af_latn_uniranges=Module["_af_latn_uniranges"]=7744032;var _af_none_script_class=Module["_af_none_script_class"]=8269760;var _af_none_uniranges=Module["_af_none_uniranges"]=7744224;var _af_telu_script_class=Module["_af_telu_script_class"]=8269780;var _af_telu_uniranges=Module["_af_telu_uniranges"]=7744240;var _af_thai_script_class=Module["_af_thai_script_class"]=8269800;var _af_thai_uniranges=Module["_af_thai_uniranges"]=7744256;var _af_beng_script_class=Module["_af_beng_script_class"]=8269820;var _af_beng_uniranges=Module["_af_beng_uniranges"]=7744272;var _af_gujr_script_class=Module["_af_gujr_script_class"]=8269840;var _af_gujr_uniranges=Module["_af_gujr_uniranges"]=7744288;var _af_guru_script_class=Module["_af_guru_script_class"]=8269860;var _af_guru_uniranges=Module["_af_guru_uniranges"]=7744304;var _af_knda_script_class=Module["_af_knda_script_class"]=8269880;var _af_knda_uniranges=Module["_af_knda_uniranges"]=7744320;var _af_limb_script_class=Module["_af_limb_script_class"]=8269900;var _af_limb_uniranges=Module["_af_limb_uniranges"]=7744336;var _af_mlym_script_class=Module["_af_mlym_script_class"]=8269920;var _af_mlym_uniranges=Module["_af_mlym_uniranges"]=7744352;var _af_orya_script_class=Module["_af_orya_script_class"]=8269940;var _af_orya_uniranges=Module["_af_orya_uniranges"]=7744368;var _af_sinh_script_class=Module["_af_sinh_script_class"]=8269960;var _af_sinh_uniranges=Module["_af_sinh_uniranges"]=7744384;var _af_sund_script_class=Module["_af_sund_script_class"]=8269980;var _af_sund_uniranges=Module["_af_sund_uniranges"]=7744400;var _af_sylo_script_class=Module["_af_sylo_script_class"]=827e4;var _af_sylo_uniranges=Module["_af_sylo_uniranges"]=7744416;var _af_taml_script_class=Module["_af_taml_script_class"]=8270020;var _af_taml_uniranges=Module["_af_taml_uniranges"]=7744432;var _af_tibt_script_class=Module["_af_tibt_script_class"]=8270040;var _af_tibt_uniranges=Module["_af_tibt_uniranges"]=7744448;var _af_hani_script_class=Module["_af_hani_script_class"]=8270060;var _af_hani_uniranges=Module["_af_hani_uniranges"]=7744464;var _af_cyrl_c2cp_style_class=Module["_af_cyrl_c2cp_style_class"]=7742844;var _af_cyrl_c2sc_style_class=Module["_af_cyrl_c2sc_style_class"]=7742864;var _af_cyrl_ordn_style_class=Module["_af_cyrl_ordn_style_class"]=7742884;var _af_cyrl_pcap_style_class=Module["_af_cyrl_pcap_style_class"]=7742904;var _af_cyrl_sinf_style_class=Module["_af_cyrl_sinf_style_class"]=7742924;var _af_cyrl_smcp_style_class=Module["_af_cyrl_smcp_style_class"]=7742944;var _af_cyrl_subs_style_class=Module["_af_cyrl_subs_style_class"]=7742964;var _af_cyrl_sups_style_class=Module["_af_cyrl_sups_style_class"]=7742984;var _af_cyrl_titl_style_class=Module["_af_cyrl_titl_style_class"]=7743004;var _af_cyrl_dflt_style_class=Module["_af_cyrl_dflt_style_class"]=7743024;var _af_grek_c2cp_style_class=Module["_af_grek_c2cp_style_class"]=7743044;var _af_grek_c2sc_style_class=Module["_af_grek_c2sc_style_class"]=7743064;var _af_grek_ordn_style_class=Module["_af_grek_ordn_style_class"]=7743084;var _af_grek_pcap_style_class=Module["_af_grek_pcap_style_class"]=7743104;var _af_grek_sinf_style_class=Module["_af_grek_sinf_style_class"]=7743124;var _af_grek_smcp_style_class=Module["_af_grek_smcp_style_class"]=7743144;var _af_grek_subs_style_class=Module["_af_grek_subs_style_class"]=7743164;var _af_grek_sups_style_class=Module["_af_grek_sups_style_class"]=7743184;var _af_grek_titl_style_class=Module["_af_grek_titl_style_class"]=7743204;var _af_grek_dflt_style_class=Module["_af_grek_dflt_style_class"]=7743224;var _af_hebr_dflt_style_class=Module["_af_hebr_dflt_style_class"]=7743244;var _af_latn_c2cp_style_class=Module["_af_latn_c2cp_style_class"]=7743264;var _af_latn_c2sc_style_class=Module["_af_latn_c2sc_style_class"]=7743284;var _af_latn_ordn_style_class=Module["_af_latn_ordn_style_class"]=7743304;var _af_latn_pcap_style_class=Module["_af_latn_pcap_style_class"]=7743324;var _af_latn_sinf_style_class=Module["_af_latn_sinf_style_class"]=7743344;var _af_latn_smcp_style_class=Module["_af_latn_smcp_style_class"]=7743364;var _af_latn_subs_style_class=Module["_af_latn_subs_style_class"]=7743384;var _af_latn_sups_style_class=Module["_af_latn_sups_style_class"]=7743404;var _af_latn_titl_style_class=Module["_af_latn_titl_style_class"]=7743424;var _af_latn_dflt_style_class=Module["_af_latn_dflt_style_class"]=7743444;var _af_deva_dflt_style_class=Module["_af_deva_dflt_style_class"]=7743464;var _af_none_dflt_style_class=Module["_af_none_dflt_style_class"]=7743484;var _af_telu_dflt_style_class=Module["_af_telu_dflt_style_class"]=7743504;var _af_thai_dflt_style_class=Module["_af_thai_dflt_style_class"]=7743524;var _af_beng_dflt_style_class=Module["_af_beng_dflt_style_class"]=7743544;var _af_gujr_dflt_style_class=Module["_af_gujr_dflt_style_class"]=7743564;var _af_guru_dflt_style_class=Module["_af_guru_dflt_style_class"]=7743584;var _af_knda_dflt_style_class=Module["_af_knda_dflt_style_class"]=7743604;var _af_limb_dflt_style_class=Module["_af_limb_dflt_style_class"]=7743624;var _af_mlym_dflt_style_class=Module["_af_mlym_dflt_style_class"]=7743644;var _af_orya_dflt_style_class=Module["_af_orya_dflt_style_class"]=7743664;var _af_sinh_dflt_style_class=Module["_af_sinh_dflt_style_class"]=7743684;var _af_sund_dflt_style_class=Module["_af_sund_dflt_style_class"]=7743704;var _af_sylo_dflt_style_class=Module["_af_sylo_dflt_style_class"]=7743724;var _af_taml_dflt_style_class=Module["_af_taml_dflt_style_class"]=7743744;var _af_tibt_dflt_style_class=Module["_af_tibt_dflt_style_class"]=7743764;var _af_hani_dflt_style_class=Module["_af_hani_dflt_style_class"]=7743784;var _af_dummy_writing_system_class=Module["_af_dummy_writing_system_class"]=8270080;var _af_latin_writing_system_class=Module["_af_latin_writing_system_class"]=8270108;var _af_cjk_writing_system_class=Module["_af_cjk_writing_system_class"]=8270136;var _af_indic_writing_system_class=Module["_af_indic_writing_system_class"]=8270164;var _af_autofitter_interface=Module["_af_autofitter_interface"]=8270520;var _autofit_module_class=Module["_autofit_module_class"]=8270536;var _bdf_driver_class=Module["_bdf_driver_class"]=8270600;var _cff_cmap_unicode_class_rec=Module["_cff_cmap_unicode_class_rec"]=8272248;var _cff_cmap_encoding_class_rec=Module["_cff_cmap_encoding_class_rec"]=8272208;var _cff_driver_class=Module["_cff_driver_class"]=8272112;var _ft_bitmap_glyph_class=Module["_ft_bitmap_glyph_class"]=8274092;var _ft_outline_glyph_class=Module["_ft_outline_glyph_class"]=8274124;var _tt_driver_class=Module["_tt_driver_class"]=8276548;var _t1_driver_class=Module["_t1_driver_class"]=8276768;var _t1cid_driver_class=Module["_t1cid_driver_class"]=8278668;var _pfr_driver_class=Module["_pfr_driver_class"]=8274448;var _t42_driver_class=Module["_t42_driver_class"]=8280684;var _winfnt_driver_class=Module["_winfnt_driver_class"]=8281584;var _pcf_driver_class=Module["_pcf_driver_class"]=8274232;var _psaux_module_class=Module["_psaux_module_class"]=8274960;var _psnames_module_class=Module["_psnames_module_class"]=8275384;var _pshinter_module_class=Module["_pshinter_module_class"]=8275316;var _ft_raster1_renderer_class=Module["_ft_raster1_renderer_class"]=8275464;var _sfnt_module_class=Module["_sfnt_module_class"]=8276108;var _ft_smooth_renderer_class=Module["_ft_smooth_renderer_class"]=8276344;var _ft_smooth_lcd_renderer_class=Module["_ft_smooth_lcd_renderer_class"]=8276404;var _ft_smooth_lcdv_renderer_class=Module["_ft_smooth_lcdv_renderer_class"]=8276464;var _pfr_cmap_class_rec=Module["_pfr_cmap_class_rec"]=8274408;var _ps_table_funcs=Module["_ps_table_funcs"]=8274632;var _ps_parser_funcs=Module["_ps_parser_funcs"]=8274648;var _t1_builder_funcs=Module["_t1_builder_funcs"]=8274700;var _t1_decoder_funcs=Module["_t1_decoder_funcs"]=8274732;var _afm_parser_funcs=Module["_afm_parser_funcs"]=8274744;var _t1_cmap_standard_class_rec=Module["_t1_cmap_standard_class_rec"]=8274756;var _t1_cmap_expert_class_rec=Module["_t1_cmap_expert_class_rec"]=8274796;var _t1_cmap_custom_class_rec=Module["_t1_cmap_custom_class_rec"]=8274836;var _t1_cmap_unicode_class_rec=Module["_t1_cmap_unicode_class_rec"]=8274876;var _t1_cmap_classes=Module["_t1_cmap_classes"]=8274916;var _ft_standard_raster=Module["_ft_standard_raster"]=8275440;var _tt_cmap0_class_rec=Module["_tt_cmap0_class_rec"]=8275524;var _tt_cmap2_class_rec=Module["_tt_cmap2_class_rec"]=8275576;var _tt_cmap4_class_rec=Module["_tt_cmap4_class_rec"]=8275628;var _tt_cmap6_class_rec=Module["_tt_cmap6_class_rec"]=8275680;var _tt_cmap8_class_rec=Module["_tt_cmap8_class_rec"]=8275732;var _tt_cmap10_class_rec=Module["_tt_cmap10_class_rec"]=8275784;var _tt_cmap12_class_rec=Module["_tt_cmap12_class_rec"]=8275836;var _tt_cmap13_class_rec=Module["_tt_cmap13_class_rec"]=8275888;var _tt_cmap14_class_rec=Module["_tt_cmap14_class_rec"]=8275940;var _ft_grays_raster=Module["_ft_grays_raster"]=8276320;var _tt_default_graphics_state=Module["_tt_default_graphics_state"]=7816280;var ___environ=Module["___environ"]=9381620;var ____environ=Module["____environ"]=9381620;var __environ=Module["__environ"]=9381620;var _timezone=Module["_timezone"]=9382280;var _daylight=Module["_daylight"]=9382284;var _tzname=Module["_tzname"]=9382288;var ___progname=Module["___progname"]=9383504;var ___optreset=Module["___optreset"]=9382468;var _optind=Module["_optind"]=8282968;var ___optpos=Module["___optpos"]=9382472;var _optarg=Module["_optarg"]=9382476;var _optopt=Module["_optopt"]=9382480;var _opterr=Module["_opterr"]=8282972;var _optreset=Module["_optreset"]=9382468;var _h_errno=Module["_h_errno"]=9382604;var ___signgam=Module["___signgam"]=9397900;var __ns_flagdata=Module["__ns_flagdata"]=8002800;var ___progname_full=Module["___progname_full"]=9383508;var _program_invocation_short_name=Module["_program_invocation_short_name"]=9383504;var _program_invocation_name=Module["_program_invocation_name"]=9383508;var ___sig_pending=Module["___sig_pending"]=9387880;var ___sig_actions=Module["___sig_actions"]=9388800;var _signgam=Module["_signgam"]=9397900;var ___THREW__=Module["___THREW__"]=9404736;var ___threwValue=Module["___threwValue"]=9404740;var ___wasm_longjmp_args=Module["___wasm_longjmp_args"]=9404748;var __ZTVSt12bad_any_cast=Module["__ZTVSt12bad_any_cast"]=8284168;var __ZTISt12bad_any_cast=Module["__ZTISt12bad_any_cast"]=8284188;var __ZTSSt12bad_any_cast=Module["__ZTSSt12bad_any_cast"]=8022e3;var __ZTVN10__cxxabiv120__si_class_type_infoE=Module["__ZTVN10__cxxabiv120__si_class_type_infoE"]=8300688;var __ZTISt8bad_cast=Module["__ZTISt8bad_cast"]=8301352;var __ZTVNSt12experimental15fundamentals_v112bad_any_castE=Module["__ZTVNSt12experimental15fundamentals_v112bad_any_castE"]=8284200;var __ZTINSt12experimental15fundamentals_v112bad_any_castE=Module["__ZTINSt12experimental15fundamentals_v112bad_any_castE"]=8284220;var __ZTSNSt12experimental15fundamentals_v112bad_any_castE=Module["__ZTSNSt12experimental15fundamentals_v112bad_any_castE"]=8022017;var __ZNSt3__212placeholders2_1E=Module["__ZNSt3__212placeholders2_1E"]=8022067;var __ZNSt3__212placeholders2_2E=Module["__ZNSt3__212placeholders2_2E"]=8022068;var __ZNSt3__212placeholders2_3E=Module["__ZNSt3__212placeholders2_3E"]=8022069;var __ZNSt3__212placeholders2_4E=Module["__ZNSt3__212placeholders2_4E"]=8022070;var __ZNSt3__212placeholders2_5E=Module["__ZNSt3__212placeholders2_5E"]=8022071;var __ZNSt3__212placeholders2_6E=Module["__ZNSt3__212placeholders2_6E"]=8022072;var __ZNSt3__212placeholders2_7E=Module["__ZNSt3__212placeholders2_7E"]=8022073;var __ZNSt3__212placeholders2_8E=Module["__ZNSt3__212placeholders2_8E"]=8022074;var __ZNSt3__212placeholders2_9E=Module["__ZNSt3__212placeholders2_9E"]=8022075;var __ZNSt3__212placeholders3_10E=Module["__ZNSt3__212placeholders3_10E"]=8022076;var __ZNSt3__26__itoa16_Charconv_digitsE=Module["__ZNSt3__26__itoa16_Charconv_digitsE"]=8022080;var __ZNSt3__26__itoa10__pow10_32E=Module["__ZNSt3__26__itoa10__pow10_32E"]=8022128;var __ZNSt3__26__itoa16__digits_base_10E=Module["__ZNSt3__26__itoa16__digits_base_10E"]=8022176;var __ZNSt3__225_General_precision_tablesIfE16_Special_X_tableE=Module["__ZNSt3__225_General_precision_tablesIfE16_Special_X_tableE"]=8022384;var __ZNSt3__225_General_precision_tablesIfE6_Max_PE=Module["__ZNSt3__225_General_precision_tablesIfE6_Max_PE"]=8022816;var __ZNSt3__225_General_precision_tablesIfE17_Ordinary_X_tableE=Module["__ZNSt3__225_General_precision_tablesIfE17_Ordinary_X_tableE"]=8022640;var __ZNSt3__225_General_precision_tablesIdE16_Special_X_tableE=Module["__ZNSt3__225_General_precision_tablesIdE16_Special_X_tableE"]=8022832;var __ZNSt3__225_General_precision_tablesIdE6_Max_PE=Module["__ZNSt3__225_General_precision_tablesIdE6_Max_PE"]=8026912;var __ZNSt3__225_General_precision_tablesIdE17_Ordinary_X_tableE=Module["__ZNSt3__225_General_precision_tablesIdE17_Ordinary_X_tableE"]=8024400;var __ZNSt3__26chrono12system_clock9is_steadyE=Module["__ZNSt3__26chrono12system_clock9is_steadyE"]=8026916;var __ZNSt3__26chrono12steady_clock9is_steadyE=Module["__ZNSt3__26chrono12steady_clock9is_steadyE"]=8026917;var __ZNSt3__214__POW10_OFFSETE=Module["__ZNSt3__214__POW10_OFFSETE"]=8056304;var __ZNSt3__213__POW10_SPLITE=Module["__ZNSt3__213__POW10_SPLITE"]=8026928;var __ZNSt3__213__MIN_BLOCK_2E=Module["__ZNSt3__213__MIN_BLOCK_2E"]=8056432;var __ZNSt3__216__POW10_OFFSET_2E=Module["__ZNSt3__216__POW10_OFFSET_2E"]=8056512;var __ZNSt3__215__POW10_SPLIT_2E=Module["__ZNSt3__215__POW10_SPLIT_2E"]=8056656;var __ZNSt3__223__DOUBLE_POW5_INV_SPLITE=Module["__ZNSt3__223__DOUBLE_POW5_INV_SPLITE"]=8131856;var __ZNSt3__219__DOUBLE_POW5_SPLITE=Module["__ZNSt3__219__DOUBLE_POW5_SPLITE"]=8136528;var __ZZNSt3__210__to_charsB7v160006EPcS0_NS_21__floating_decimal_64ENS_12chars_formatEdE11_Adjustment=Module["__ZZNSt3__210__to_charsB7v160006EPcS0_NS_21__floating_decimal_64ENS_12chars_formatEdE11_Adjustment"]=8141744;var __ZZNSt3__210__to_charsB7v160006EPcS0_NS_21__floating_decimal_64ENS_12chars_formatEdE21_Max_shifted_mantissa=Module["__ZZNSt3__210__to_charsB7v160006EPcS0_NS_21__floating_decimal_64ENS_12chars_formatEdE21_Max_shifted_mantissa"]=8142064;var __ZTVNSt3__28__c_nodeE=Module["__ZTVNSt3__28__c_nodeE"]=8284232;var __ZTINSt3__28__c_nodeE=Module["__ZTINSt3__28__c_nodeE"]=8284264;var __ZTSNSt3__28__c_nodeE=Module["__ZTSNSt3__28__c_nodeE"]=8142248;var __ZTVN10__cxxabiv117__class_type_infoE=Module["__ZTVN10__cxxabiv117__class_type_infoE"]=8300648;var __ZTISt12length_error=Module["__ZTISt12length_error"]=8301136;var __ZTVSt12length_error=Module["__ZTVSt12length_error"]=8301116;var __ZTISt20bad_array_new_length=Module["__ZTISt20bad_array_new_length"]=8300988;var __ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE=Module["__ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE"]=8284272;var __ZTVNSt3__219__shared_weak_countE=Module["__ZTVNSt3__219__shared_weak_countE"]=8291948;var __ZTVNSt3__214__shared_countE=Module["__ZTVNSt3__214__shared_countE"]=8291920;var __ZTINSt3__24__fs10filesystem16filesystem_errorE=Module["__ZTINSt3__24__fs10filesystem16filesystem_errorE"]=8292384;var __ZTVNSt3__24__fs10filesystem16filesystem_errorE=Module["__ZTVNSt3__24__fs10filesystem16filesystem_errorE"]=8292348;var __ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem16filesystem_error8_StorageENS_9allocatorIS4_EEEE=Module["__ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem16filesystem_error8_StorageENS_9allocatorIS4_EEEE"]=8284312;var __ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE=Module["__ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE"]=8284352;var __ZNSt3__26ranges5__cpo9iter_moveE=Module["__ZNSt3__26ranges5__cpo9iter_moveE"]=8142570;var __ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE=Module["__ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE"]=8284300;var __ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE=Module["__ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE"]=8142266;var __ZTINSt3__219__shared_weak_countE=Module["__ZTINSt3__219__shared_weak_countE"]=8291976;var __ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem16filesystem_error8_StorageENS_9allocatorIS4_EEEE=Module["__ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem16filesystem_error8_StorageENS_9allocatorIS4_EEEE"]=8284340;var __ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem16filesystem_error8_StorageENS_9allocatorIS4_EEEE=Module["__ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem16filesystem_error8_StorageENS_9allocatorIS4_EEEE"]=8142353;var __ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE=Module["__ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE"]=8284380;var __ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE=Module["__ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE"]=8142453;var __ZTVSt16nested_exception=Module["__ZTVSt16nested_exception"]=8284392;var __ZTISt16nested_exception=Module["__ZTISt16nested_exception"]=8284408;var __ZTSSt16nested_exception=Module["__ZTSSt16nested_exception"]=8142583;var __ZZNSt3__210__to_charsB7v160006EPcS0_NS_21__floating_decimal_32ENS_12chars_formatEjjE11_Adjustment=Module["__ZZNSt3__210__to_charsB7v160006EPcS0_NS_21__floating_decimal_32ENS_12chars_formatEjjE11_Adjustment"]=8143248;var __ZZNSt3__210__to_charsB7v160006EPcS0_NS_21__floating_decimal_32ENS_12chars_formatEjjE21_Max_shifted_mantissa=Module["__ZZNSt3__210__to_charsB7v160006EPcS0_NS_21__floating_decimal_32ENS_12chars_formatEjjE21_Max_shifted_mantissa"]=8143296;var __ZNSt3__222__FLOAT_POW5_INV_SPLITE=Module["__ZNSt3__222__FLOAT_POW5_INV_SPLITE"]=8142608;var __ZNSt3__218__FLOAT_POW5_SPLITE=Module["__ZNSt3__218__FLOAT_POW5_SPLITE"]=8142864;var __ZTVNSt3__212format_errorE=Module["__ZTVNSt3__212format_errorE"]=8284416;var __ZTINSt3__212format_errorE=Module["__ZTINSt3__212format_errorE"]=8284436;var __ZTSNSt3__212format_errorE=Module["__ZTSNSt3__212format_errorE"]=8143340;var __ZTISt13runtime_error=Module["__ZTISt13runtime_error"]=8301200;var __ZTVNSt3__217bad_function_callE=Module["__ZTVNSt3__217bad_function_callE"]=8284448;var __ZTINSt3__217bad_function_callE=Module["__ZTINSt3__217bad_function_callE"]=8284468;var __ZTSNSt3__217bad_function_callE=Module["__ZTSNSt3__217bad_function_callE"]=8143363;var __ZTISt9exception=Module["__ZTISt9exception"]=8300936;var __ZTVNSt3__212future_errorE=Module["__ZTVNSt3__212future_errorE"]=8284520;var __ZTINSt3__212future_errorE=Module["__ZTINSt3__212future_errorE"]=8284540;var __ZTVNSt3__217__assoc_sub_stateE=Module["__ZTVNSt3__217__assoc_sub_stateE"]=8284552;var __ZTVNSt3__223__future_error_categoryE=Module["__ZTVNSt3__223__future_error_categoryE"]=8284484;var __ZTINSt3__223__future_error_categoryE=Module["__ZTINSt3__223__future_error_categoryE"]=8284588;var __ZTSNSt3__212future_errorE=Module["__ZTSNSt3__212future_errorE"]=8143391;var __ZTISt11logic_error=Module["__ZTISt11logic_error"]=8301060;var __ZTINSt3__217__assoc_sub_stateE=Module["__ZTINSt3__217__assoc_sub_stateE"]=8284576;var __ZTSNSt3__217__assoc_sub_stateE=Module["__ZTSNSt3__217__assoc_sub_stateE"]=8143414;var __ZTINSt3__214__shared_countE=Module["__ZTINSt3__214__shared_countE"]=8291940;var __ZTSNSt3__223__future_error_categoryE=Module["__ZTSNSt3__223__future_error_categoryE"]=8143442;var __ZTINSt3__212__do_messageE=Module["__ZTINSt3__212__do_messageE"]=8294312;var __ZTISt14overflow_error=Module["__ZTISt14overflow_error"]=8301244;var __ZTVSt14overflow_error=Module["__ZTVSt14overflow_error"]=8301224;var __ZTVNSt3__215basic_streambufIcNS_11char_traitsIcEEEE=Module["__ZTVNSt3__215basic_streambufIcNS_11char_traitsIcEEEE"]=8284620;var __ZTTNSt3__213basic_istreamIcNS_11char_traitsIcEEEE=Module["__ZTTNSt3__213basic_istreamIcNS_11char_traitsIcEEEE"]=8284724;var __ZNSt3__25ctypeIcE2idE=Module["__ZNSt3__25ctypeIcE2idE"]=9422496;var __ZTTNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE=Module["__ZTTNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE"]=8284772;var __ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE=Module["__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"]=9422324;var __ZTTNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE=Module["__ZTTNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE"]=8284840;var __ZTVNSt3__215basic_streambufIwNS_11char_traitsIwEEEE=Module["__ZTVNSt3__215basic_streambufIwNS_11char_traitsIwEEEE"]=8284868;var __ZTTNSt3__213basic_istreamIwNS_11char_traitsIwEEEE=Module["__ZTTNSt3__213basic_istreamIwNS_11char_traitsIwEEEE"]=8284972;var __ZNSt3__25ctypeIwE2idE=Module["__ZNSt3__25ctypeIwE2idE"]=9422488;var __ZTTNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE=Module["__ZTTNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE"]=8285020;var __ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE=Module["__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"]=9422332;var __ZTVNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTVNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285028;var __ZTVNSt3__213basic_filebufIcNS_11char_traitsIcEEEE=Module["__ZTVNSt3__213basic_filebufIcNS_11char_traitsIcEEEE"]=8285092;var __ZNSt3__27codecvtIcc11__mbstate_tE2idE=Module["__ZNSt3__27codecvtIcc11__mbstate_tE2idE"]=9422504;var __ZTTNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTTNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285508;var __ZTTNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTTNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285740;var __ZTTNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTTNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285848;var __ZTTNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE=Module["__ZTTNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE"]=8285956;var __ZTTNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE=Module["__ZTTNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE"]=8286064;var __ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE=Module["__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"]=9422308;var __ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE=Module["__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"]=9422316;var __ZTINSt3__215basic_streambufIcNS_11char_traitsIcEEEE=Module["__ZTINSt3__215basic_streambufIcNS_11char_traitsIcEEEE"]=8285184;var __ZTVNSt3__213basic_istreamIcNS_11char_traitsIcEEEE=Module["__ZTVNSt3__213basic_istreamIcNS_11char_traitsIcEEEE"]=8284684;var __ZTINSt3__213basic_istreamIcNS_11char_traitsIcEEEE=Module["__ZTINSt3__213basic_istreamIcNS_11char_traitsIcEEEE"]=8285192;var __ZTVNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE=Module["__ZTVNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE"]=8284732;var __ZTINSt3__213basic_ostreamIcNS_11char_traitsIcEEEE=Module["__ZTINSt3__213basic_ostreamIcNS_11char_traitsIcEEEE"]=8285216;var __ZTVNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE=Module["__ZTVNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE"]=8284780;var __ZTINSt3__214basic_iostreamIcNS_11char_traitsIcEEEE=Module["__ZTINSt3__214basic_iostreamIcNS_11char_traitsIcEEEE"]=8285320;var __ZTCNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE0_NS_13basic_istreamIcS2_EE=Module["__ZTCNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE0_NS_13basic_istreamIcS2_EE"]=8285240;var __ZTCNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE8_NS_13basic_ostreamIcS2_EE=Module["__ZTCNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE8_NS_13basic_ostreamIcS2_EE"]=8285280;var __ZTINSt3__215basic_streambufIwNS_11char_traitsIwEEEE=Module["__ZTINSt3__215basic_streambufIwNS_11char_traitsIwEEEE"]=8285380;var __ZTVNSt3__213basic_istreamIwNS_11char_traitsIwEEEE=Module["__ZTVNSt3__213basic_istreamIwNS_11char_traitsIwEEEE"]=8284932;var __ZTINSt3__213basic_istreamIwNS_11char_traitsIwEEEE=Module["__ZTINSt3__213basic_istreamIwNS_11char_traitsIwEEEE"]=8285388;var __ZTVNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE=Module["__ZTVNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE"]=8284980;var __ZTINSt3__213basic_ostreamIwNS_11char_traitsIwEEEE=Module["__ZTINSt3__213basic_ostreamIwNS_11char_traitsIwEEEE"]=8285412;var __ZTINSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTINSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285436;var __ZTINSt3__213basic_filebufIcNS_11char_traitsIcEEEE=Module["__ZTINSt3__213basic_filebufIcNS_11char_traitsIcEEEE"]=8286132;var __ZTVNSt3__29basic_iosIcNS_11char_traitsIcEEEE=Module["__ZTVNSt3__29basic_iosIcNS_11char_traitsIcEEEE"]=8285156;var __ZTINSt3__29basic_iosIcNS_11char_traitsIcEEEE=Module["__ZTINSt3__29basic_iosIcNS_11char_traitsIcEEEE"]=8285172;var __ZTSNSt3__29basic_iosIcNS_11char_traitsIcEEEE=Module["__ZTSNSt3__29basic_iosIcNS_11char_traitsIcEEEE"]=8143872;var __ZTINSt3__28ios_baseE=Module["__ZTINSt3__28ios_baseE"]=8286224;var __ZTSNSt3__215basic_streambufIcNS_11char_traitsIcEEEE=Module["__ZTSNSt3__215basic_streambufIcNS_11char_traitsIcEEEE"]=8143914;var __ZTSNSt3__213basic_istreamIcNS_11char_traitsIcEEEE=Module["__ZTSNSt3__213basic_istreamIcNS_11char_traitsIcEEEE"]=8143963;var __ZTVN10__cxxabiv121__vmi_class_type_infoE=Module["__ZTVN10__cxxabiv121__vmi_class_type_infoE"]=8300740;var __ZTSNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE=Module["__ZTSNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE"]=8144010;var __ZTSNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE=Module["__ZTSNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE"]=8144057;var __ZTVNSt3__29basic_iosIwNS_11char_traitsIwEEEE=Module["__ZTVNSt3__29basic_iosIwNS_11char_traitsIwEEEE"]=8285352;var __ZTINSt3__29basic_iosIwNS_11char_traitsIwEEEE=Module["__ZTINSt3__29basic_iosIwNS_11char_traitsIwEEEE"]=8285368;var __ZTSNSt3__29basic_iosIwNS_11char_traitsIwEEEE=Module["__ZTSNSt3__29basic_iosIwNS_11char_traitsIwEEEE"]=8144105;var __ZTSNSt3__215basic_streambufIwNS_11char_traitsIwEEEE=Module["__ZTSNSt3__215basic_streambufIwNS_11char_traitsIwEEEE"]=8144147;var __ZTSNSt3__213basic_istreamIwNS_11char_traitsIwEEEE=Module["__ZTSNSt3__213basic_istreamIwNS_11char_traitsIwEEEE"]=8144196;var __ZTSNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE=Module["__ZTSNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE"]=8144243;var __ZTSNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTSNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8144290;var __ZTVNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTVNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285448;var __ZTINSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTINSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285688;var __ZTCNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE0_NS_14basic_iostreamIcS2_EE=Module["__ZTCNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE0_NS_14basic_iostreamIcS2_EE"]=8285548;var __ZTCNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE0_NS_13basic_istreamIcS2_EE=Module["__ZTCNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE0_NS_13basic_istreamIcS2_EE"]=8285608;var __ZTCNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE8_NS_13basic_ostreamIcS2_EE=Module["__ZTCNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE8_NS_13basic_ostreamIcS2_EE"]=8285648;var __ZTSNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTSNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8144356;var __ZTVNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTVNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285700;var __ZTINSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTINSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285796;var __ZTCNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE0_NS_13basic_ostreamIcS2_EE=Module["__ZTCNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE0_NS_13basic_ostreamIcS2_EE"]=8285756;var __ZTSNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTSNSt3__219basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8144425;var __ZTVNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTVNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285808;var __ZTINSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTINSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8285904;var __ZTCNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE0_NS_13basic_istreamIcS2_EE=Module["__ZTCNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE0_NS_13basic_istreamIcS2_EE"]=8285864;var __ZTSNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE=Module["__ZTSNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]=8144495;var __ZTVNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE=Module["__ZTVNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE"]=8285916;var __ZTINSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE=Module["__ZTINSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE"]=8286012;var __ZTCNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE0_NS_13basic_istreamIcS2_EE=Module["__ZTCNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE0_NS_13basic_istreamIcS2_EE"]=8285972;var __ZTSNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE=Module["__ZTSNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE"]=8144565;var __ZTVNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE=Module["__ZTVNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE"]=8286024;var __ZTINSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE=Module["__ZTINSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE"]=8286120;var __ZTCNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE0_NS_13basic_ostreamIcS2_EE=Module["__ZTCNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE0_NS_13basic_ostreamIcS2_EE"]=8286080;var __ZTSNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE=Module["__ZTSNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE"]=8144613;var __ZTSNSt3__213basic_filebufIcNS_11char_traitsIcEEEE=Module["__ZTSNSt3__213basic_filebufIcNS_11char_traitsIcEEEE"]=8144661;var __ZTVNSt3__28ios_base7failureE=Module["__ZTVNSt3__28ios_base7failureE"]=8286184;var __ZNSt3__28ios_base9__xindex_E=Module["__ZNSt3__28ios_base9__xindex_E"]=9421240;var __ZTVNSt3__28ios_baseE=Module["__ZTVNSt3__28ios_baseE"]=8286204;var __ZTINSt3__28ios_base7failureE=Module["__ZTINSt3__28ios_base7failureE"]=8286232;var __ZTVNSt3__219__iostream_categoryE=Module["__ZTVNSt3__219__iostream_categoryE"]=8286148;var __ZTINSt3__219__iostream_categoryE=Module["__ZTINSt3__219__iostream_categoryE"]=8286244;var __ZNSt3__28ios_base9boolalphaE=Module["__ZNSt3__28ios_base9boolalphaE"]=8144708;var __ZNSt3__28ios_base3decE=Module["__ZNSt3__28ios_base3decE"]=8144712;var __ZNSt3__28ios_base5fixedE=Module["__ZNSt3__28ios_base5fixedE"]=8144716;var __ZNSt3__28ios_base3hexE=Module["__ZNSt3__28ios_base3hexE"]=8144720;var __ZNSt3__28ios_base8internalE=Module["__ZNSt3__28ios_base8internalE"]=8144724;var __ZNSt3__28ios_base4leftE=Module["__ZNSt3__28ios_base4leftE"]=8144728;var __ZNSt3__28ios_base3octE=Module["__ZNSt3__28ios_base3octE"]=8144732;var __ZNSt3__28ios_base5rightE=Module["__ZNSt3__28ios_base5rightE"]=8144736;var __ZNSt3__28ios_base10scientificE=Module["__ZNSt3__28ios_base10scientificE"]=8144740;var __ZNSt3__28ios_base8showbaseE=Module["__ZNSt3__28ios_base8showbaseE"]=8144744;var __ZNSt3__28ios_base9showpointE=Module["__ZNSt3__28ios_base9showpointE"]=8144748;var __ZNSt3__28ios_base7showposE=Module["__ZNSt3__28ios_base7showposE"]=8144752;var __ZNSt3__28ios_base6skipwsE=Module["__ZNSt3__28ios_base6skipwsE"]=8144756;var __ZNSt3__28ios_base7unitbufE=Module["__ZNSt3__28ios_base7unitbufE"]=8144760;var __ZNSt3__28ios_base9uppercaseE=Module["__ZNSt3__28ios_base9uppercaseE"]=8144764;var __ZNSt3__28ios_base11adjustfieldE=Module["__ZNSt3__28ios_base11adjustfieldE"]=8144768;var __ZNSt3__28ios_base9basefieldE=Module["__ZNSt3__28ios_base9basefieldE"]=8144772;var __ZNSt3__28ios_base10floatfieldE=Module["__ZNSt3__28ios_base10floatfieldE"]=8144776;var __ZNSt3__28ios_base6badbitE=Module["__ZNSt3__28ios_base6badbitE"]=8144780;var __ZNSt3__28ios_base6eofbitE=Module["__ZNSt3__28ios_base6eofbitE"]=8144784;var __ZNSt3__28ios_base7failbitE=Module["__ZNSt3__28ios_base7failbitE"]=8144788;var __ZNSt3__28ios_base7goodbitE=Module["__ZNSt3__28ios_base7goodbitE"]=8144792;var __ZNSt3__28ios_base3appE=Module["__ZNSt3__28ios_base3appE"]=8144796;var __ZNSt3__28ios_base3ateE=Module["__ZNSt3__28ios_base3ateE"]=8144800;var __ZNSt3__28ios_base6binaryE=Module["__ZNSt3__28ios_base6binaryE"]=8144804;var __ZNSt3__28ios_base2inE=Module["__ZNSt3__28ios_base2inE"]=8144808;var __ZNSt3__28ios_base3outE=Module["__ZNSt3__28ios_base3outE"]=8144812;var __ZNSt3__28ios_base5truncE=Module["__ZNSt3__28ios_base5truncE"]=8144816;var __ZTSNSt3__28ios_baseE=Module["__ZTSNSt3__28ios_baseE"]=8144820;var __ZTSNSt3__28ios_base7failureE=Module["__ZTSNSt3__28ios_base7failureE"]=8144838;var __ZTINSt3__212system_errorE=Module["__ZTINSt3__212system_errorE"]=8294220;var __ZTSNSt3__219__iostream_categoryE=Module["__ZTSNSt3__219__iostream_categoryE"]=8144864;var __ZNSt3__219__start_std_streamsE=Module["__ZNSt3__219__start_std_streamsE"]=9421932;var __ZNSt3__23cinE=Module["__ZNSt3__23cinE"]=9421252;var __ZNSt3__24coutE=Module["__ZNSt3__24coutE"]=9421428;var __ZNSt3__24cerrE=Module["__ZNSt3__24cerrE"]=9421596;var __ZNSt3__24clogE=Module["__ZNSt3__24clogE"]=9421764;var __ZNSt3__24wcinE=Module["__ZNSt3__24wcinE"]=9421340;var __ZNSt3__25wcoutE=Module["__ZNSt3__25wcoutE"]=9421512;var __ZNSt3__25wcerrE=Module["__ZNSt3__25wcerrE"]=9421680;var __ZNSt3__25wclogE=Module["__ZNSt3__25wclogE"]=9421848;var __ZTVNSt3__210__stdinbufIcEE=Module["__ZTVNSt3__210__stdinbufIcEE"]=8286256;var __ZTVNSt3__211__stdoutbufIcEE=Module["__ZTVNSt3__211__stdoutbufIcEE"]=8286332;var __ZTVNSt3__210__stdinbufIwEE=Module["__ZTVNSt3__210__stdinbufIwEE"]=8286408;var __ZTVNSt3__211__stdoutbufIwEE=Module["__ZTVNSt3__211__stdoutbufIwEE"]=8286484;var __ZNSt3__27codecvtIwc11__mbstate_tE2idE=Module["__ZNSt3__27codecvtIwc11__mbstate_tE2idE"]=9422512;var __ZTINSt3__210__stdinbufIcEE=Module["__ZTINSt3__210__stdinbufIcEE"]=8286320;var __ZTSNSt3__210__stdinbufIcEE=Module["__ZTSNSt3__210__stdinbufIcEE"]=8144894;var __ZTINSt3__211__stdoutbufIcEE=Module["__ZTINSt3__211__stdoutbufIcEE"]=8286396;var __ZTSNSt3__211__stdoutbufIcEE=Module["__ZTSNSt3__211__stdoutbufIcEE"]=8144918;var __ZTINSt3__210__stdinbufIwEE=Module["__ZTINSt3__210__stdinbufIwEE"]=8286472;var __ZTSNSt3__210__stdinbufIwEE=Module["__ZTSNSt3__210__stdinbufIwEE"]=8144943;var __ZTINSt3__211__stdoutbufIwEE=Module["__ZTINSt3__211__stdoutbufIwEE"]=8286548;var __ZTSNSt3__211__stdoutbufIwEE=Module["__ZTSNSt3__211__stdoutbufIwEE"]=8144967;var __ZNSt3__223__libcpp_debug_functionE=Module["__ZNSt3__223__libcpp_debug_functionE"]=8286560;var __ZNSt3__28numpunctIcE2idE=Module["__ZNSt3__28numpunctIcE2idE"]=9422552;var __ZNSt3__214__num_get_base5__srcE=Module["__ZNSt3__214__num_get_base5__srcE"]=8144992;var __ZNSt3__28numpunctIwE2idE=Module["__ZNSt3__28numpunctIwE2idE"]=9422560;var __ZNSt3__210moneypunctIcLb1EE2idE=Module["__ZNSt3__210moneypunctIcLb1EE2idE"]=9422380;var __ZNSt3__210moneypunctIcLb0EE2idE=Module["__ZNSt3__210moneypunctIcLb0EE2idE"]=9422372;var __ZNSt3__210moneypunctIwLb1EE2idE=Module["__ZNSt3__210moneypunctIwLb1EE2idE"]=9422396;var __ZNSt3__210moneypunctIwLb0EE2idE=Module["__ZNSt3__210moneypunctIwLb0EE2idE"]=9422388;var __ZTVNSt3__26locale5__impE=Module["__ZTVNSt3__26locale5__impE"]=8286564;var __ZTVNSt3__26locale5facetE=Module["__ZTVNSt3__26locale5facetE"]=8287028;var __ZNSt3__27collateIcE2idE=Module["__ZNSt3__27collateIcE2idE"]=9422292;var __ZNSt3__27collateIwE2idE=Module["__ZNSt3__27collateIwE2idE"]=9422300;var __ZNSt3__27codecvtIDsc11__mbstate_tE2idE=Module["__ZNSt3__27codecvtIDsc11__mbstate_tE2idE"]=9422520;var __ZNSt3__27codecvtIDic11__mbstate_tE2idE=Module["__ZNSt3__27codecvtIDic11__mbstate_tE2idE"]=9422536;var __ZNSt3__27codecvtIDsDu11__mbstate_tE2idE=Module["__ZNSt3__27codecvtIDsDu11__mbstate_tE2idE"]=9422528;var __ZNSt3__27codecvtIDiDu11__mbstate_tE2idE=Module["__ZNSt3__27codecvtIDiDu11__mbstate_tE2idE"]=9422544;var __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE=Module["__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"]=9422404;var __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE=Module["__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"]=9422412;var __ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE=Module["__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"]=9422420;var __ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE=Module["__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"]=9422428;var __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE=Module["__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"]=9422340;var __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE=Module["__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"]=9422348;var __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE=Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"]=9422356;var __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE=Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"]=9422364;var __ZNSt3__28messagesIcE2idE=Module["__ZNSt3__28messagesIcE2idE"]=9422436;var __ZNSt3__28messagesIwE2idE=Module["__ZNSt3__28messagesIwE2idE"]=9422444;var __ZTVNSt3__214codecvt_bynameIcc11__mbstate_tEE=Module["__ZTVNSt3__214codecvt_bynameIcc11__mbstate_tEE"]=8291180;var __ZTVNSt3__214codecvt_bynameIwc11__mbstate_tEE=Module["__ZTVNSt3__214codecvt_bynameIwc11__mbstate_tEE"]=8291240;var __ZTVNSt3__214codecvt_bynameIDsc11__mbstate_tEE=Module["__ZTVNSt3__214codecvt_bynameIDsc11__mbstate_tEE"]=8291300;var __ZTVNSt3__214codecvt_bynameIDic11__mbstate_tEE=Module["__ZTVNSt3__214codecvt_bynameIDic11__mbstate_tEE"]=8291360;var __ZTVNSt3__214codecvt_bynameIDsDu11__mbstate_tEE=Module["__ZTVNSt3__214codecvt_bynameIDsDu11__mbstate_tEE"]=8291420;var __ZTVNSt3__214codecvt_bynameIDiDu11__mbstate_tEE=Module["__ZTVNSt3__214codecvt_bynameIDiDu11__mbstate_tEE"]=8291480;var __ZTVNSt3__217moneypunct_bynameIcLb0EEE=Module["__ZTVNSt3__217moneypunct_bynameIcLb0EEE"]=8290412;var __ZTVNSt3__217moneypunct_bynameIcLb1EEE=Module["__ZTVNSt3__217moneypunct_bynameIcLb1EEE"]=8290480;var __ZTVNSt3__217moneypunct_bynameIwLb0EEE=Module["__ZTVNSt3__217moneypunct_bynameIwLb0EEE"]=8290548;var __ZTVNSt3__217moneypunct_bynameIwLb1EEE=Module["__ZTVNSt3__217moneypunct_bynameIwLb1EEE"]=8290616;var __ZTVNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTVNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289540;var __ZTVNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTVNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289704;var __ZTVNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTVNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289980;var __ZTVNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTVNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8290016;var __ZTVNSt3__215messages_bynameIcEE=Module["__ZTVNSt3__215messages_bynameIcEE"]=8291092;var __ZTVNSt3__215messages_bynameIwEE=Module["__ZTVNSt3__215messages_bynameIwEE"]=8291136;var __ZNSt3__26locale2id9__next_idE=Module["__ZNSt3__26locale2id9__next_idE"]=9422484;var __ZTVNSt3__214collate_bynameIcEE=Module["__ZTVNSt3__214collate_bynameIcEE"]=8286584;var __ZTVNSt3__214collate_bynameIwEE=Module["__ZTVNSt3__214collate_bynameIwEE"]=8286616;var __ZTVNSt3__25ctypeIcEE=Module["__ZTVNSt3__25ctypeIcEE"]=8286648;var __ZTVNSt3__212ctype_bynameIcEE=Module["__ZTVNSt3__212ctype_bynameIcEE"]=8286700;var __ZTVNSt3__212ctype_bynameIwEE=Module["__ZTVNSt3__212ctype_bynameIwEE"]=8286752;var __ZTVNSt3__27codecvtIwc11__mbstate_tEE=Module["__ZTVNSt3__27codecvtIwc11__mbstate_tEE"]=8286820;var __ZTVNSt3__28numpunctIcEE=Module["__ZTVNSt3__28numpunctIcEE"]=8286868;var __ZTVNSt3__28numpunctIwEE=Module["__ZTVNSt3__28numpunctIwEE"]=8286908;var __ZTVNSt3__215numpunct_bynameIcEE=Module["__ZTVNSt3__215numpunct_bynameIcEE"]=8286948;var __ZTVNSt3__215numpunct_bynameIwEE=Module["__ZTVNSt3__215numpunct_bynameIwEE"]=8286988;var __ZTVNSt3__215__time_get_tempIcEE=Module["__ZTVNSt3__215__time_get_tempIcEE"]=8291612;var __ZTVNSt3__215__time_get_tempIwEE=Module["__ZTVNSt3__215__time_get_tempIwEE"]=8291676;var __ZTISt12out_of_range=Module["__ZTISt12out_of_range"]=8301168;var __ZTVSt12out_of_range=Module["__ZTVSt12out_of_range"]=8301148;var __ZTVNSt3__27collateIcEE=Module["__ZTVNSt3__27collateIcEE"]=8288732;var __ZTVNSt3__27collateIwEE=Module["__ZTVNSt3__27collateIwEE"]=8288764;var __ZTVNSt3__25ctypeIwEE=Module["__ZTVNSt3__25ctypeIwEE"]=8287060;var __ZTVNSt3__27codecvtIcc11__mbstate_tEE=Module["__ZTVNSt3__27codecvtIcc11__mbstate_tEE"]=8287168;var __ZTVNSt3__27codecvtIDsc11__mbstate_tEE=Module["__ZTVNSt3__27codecvtIDsc11__mbstate_tEE"]=8287256;var __ZTVNSt3__27codecvtIDic11__mbstate_tEE=Module["__ZTVNSt3__27codecvtIDic11__mbstate_tEE"]=8287416;var __ZTVNSt3__27codecvtIDsDu11__mbstate_tEE=Module["__ZTVNSt3__27codecvtIDsDu11__mbstate_tEE"]=8287336;var __ZTVNSt3__27codecvtIDiDu11__mbstate_tEE=Module["__ZTVNSt3__27codecvtIDiDu11__mbstate_tEE"]=8287496;var __ZTVNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTVNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8288796;var __ZTVNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTVNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8288924;var __ZTVNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTVNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289044;var __ZTVNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTVNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289160;var __ZTVNSt3__210moneypunctIcLb0EEE=Module["__ZTVNSt3__210moneypunctIcLb0EEE"]=8290052;var __ZTVNSt3__210moneypunctIcLb1EEE=Module["__ZTVNSt3__210moneypunctIcLb1EEE"]=8290148;var __ZTVNSt3__210moneypunctIwLb0EEE=Module["__ZTVNSt3__210moneypunctIwLb0EEE"]=8290236;var __ZTVNSt3__210moneypunctIwLb1EEE=Module["__ZTVNSt3__210moneypunctIwLb1EEE"]=8290324;var __ZTVNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTVNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8290684;var __ZTVNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTVNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8290752;var __ZTVNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTVNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8290820;var __ZTVNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTVNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8290888;var __ZTVNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTVNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289268;var __ZTVNSt3__220__time_get_c_storageIcEE=Module["__ZTVNSt3__220__time_get_c_storageIcEE"]=8291540;var __ZTVNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTVNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289408;var __ZTVNSt3__220__time_get_c_storageIwEE=Module["__ZTVNSt3__220__time_get_c_storageIwEE"]=8291576;var __ZTVNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTVNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289860;var __ZTVNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTVNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289924;var __ZTVNSt3__28messagesIcEE=Module["__ZTVNSt3__28messagesIcEE"]=8290956;var __ZTVNSt3__28messagesIwEE=Module["__ZTVNSt3__28messagesIwEE"]=8291028;var __ZNSt3__210moneypunctIcLb0EE4intlE=Module["__ZNSt3__210moneypunctIcLb0EE4intlE"]=8145232;var __ZNSt3__210moneypunctIcLb1EE4intlE=Module["__ZNSt3__210moneypunctIcLb1EE4intlE"]=8145233;var __ZNSt3__210moneypunctIwLb0EE4intlE=Module["__ZNSt3__210moneypunctIwLb0EE4intlE"]=8145234;var __ZNSt3__210moneypunctIwLb1EE4intlE=Module["__ZNSt3__210moneypunctIwLb1EE4intlE"]=8145235;var __ZNSt3__26locale4noneE=Module["__ZNSt3__26locale4noneE"]=8145236;var __ZNSt3__26locale7collateE=Module["__ZNSt3__26locale7collateE"]=8145240;var __ZNSt3__26locale5ctypeE=Module["__ZNSt3__26locale5ctypeE"]=8145244;var __ZNSt3__26locale8monetaryE=Module["__ZNSt3__26locale8monetaryE"]=8145248;var __ZNSt3__26locale7numericE=Module["__ZNSt3__26locale7numericE"]=8145252;var __ZNSt3__26locale4timeE=Module["__ZNSt3__26locale4timeE"]=8145256;var __ZNSt3__26locale8messagesE=Module["__ZNSt3__26locale8messagesE"]=8145260;var __ZNSt3__26locale3allE=Module["__ZNSt3__26locale3allE"]=8145264;var __ZTINSt3__26locale5__impE=Module["__ZTINSt3__26locale5__impE"]=8288568;var __ZTINSt3__214collate_bynameIcEE=Module["__ZTINSt3__214collate_bynameIcEE"]=8288592;var __ZTINSt3__214collate_bynameIwEE=Module["__ZTINSt3__214collate_bynameIwEE"]=8288616;var __ZNSt3__210ctype_base5spaceE=Module["__ZNSt3__210ctype_base5spaceE"]=8145268;var __ZNSt3__210ctype_base5printE=Module["__ZNSt3__210ctype_base5printE"]=8145272;var __ZNSt3__210ctype_base5cntrlE=Module["__ZNSt3__210ctype_base5cntrlE"]=8145276;var __ZNSt3__210ctype_base5upperE=Module["__ZNSt3__210ctype_base5upperE"]=8145280;var __ZNSt3__210ctype_base5lowerE=Module["__ZNSt3__210ctype_base5lowerE"]=8145284;var __ZNSt3__210ctype_base5alphaE=Module["__ZNSt3__210ctype_base5alphaE"]=8145288;var __ZNSt3__210ctype_base5digitE=Module["__ZNSt3__210ctype_base5digitE"]=8145292;var __ZNSt3__210ctype_base5punctE=Module["__ZNSt3__210ctype_base5punctE"]=8145296;var __ZNSt3__210ctype_base6xdigitE=Module["__ZNSt3__210ctype_base6xdigitE"]=8145300;var __ZNSt3__210ctype_base5blankE=Module["__ZNSt3__210ctype_base5blankE"]=8145304;var __ZNSt3__210ctype_base5alnumE=Module["__ZNSt3__210ctype_base5alnumE"]=8145308;var __ZNSt3__210ctype_base5graphE=Module["__ZNSt3__210ctype_base5graphE"]=8145312;var __ZNSt3__25ctypeIcE10table_sizeE=Module["__ZNSt3__25ctypeIcE10table_sizeE"]=8145316;var __ZTINSt3__25ctypeIcEE=Module["__ZTINSt3__25ctypeIcEE"]=8288628;var __ZTINSt3__212ctype_bynameIcEE=Module["__ZTINSt3__212ctype_bynameIcEE"]=8288660;var __ZTINSt3__212ctype_bynameIwEE=Module["__ZTINSt3__212ctype_bynameIwEE"]=8288672;var __ZTINSt3__27codecvtIwc11__mbstate_tEE=Module["__ZTINSt3__27codecvtIwc11__mbstate_tEE"]=8287864;var __ZTINSt3__28numpunctIcEE=Module["__ZTINSt3__28numpunctIcEE"]=8288684;var __ZTINSt3__28numpunctIwEE=Module["__ZTINSt3__28numpunctIwEE"]=8288696;var __ZTINSt3__215numpunct_bynameIcEE=Module["__ZTINSt3__215numpunct_bynameIcEE"]=8288708;var __ZTINSt3__215numpunct_bynameIwEE=Module["__ZTINSt3__215numpunct_bynameIwEE"]=8288720;var __ZTINSt3__26locale5facetE=Module["__ZTINSt3__26locale5facetE"]=8287048;var __ZTSNSt3__26locale5facetE=Module["__ZTSNSt3__26locale5facetE"]=8146612;var __ZTINSt3__25ctypeIwEE=Module["__ZTINSt3__25ctypeIwEE"]=8287136;var __ZTSNSt3__25ctypeIwEE=Module["__ZTSNSt3__25ctypeIwEE"]=8146634;var __ZTSNSt3__210ctype_baseE=Module["__ZTSNSt3__210ctype_baseE"]=8146652;var __ZTINSt3__210ctype_baseE=Module["__ZTINSt3__210ctype_baseE"]=8287128;var __ZTINSt3__27codecvtIcc11__mbstate_tEE=Module["__ZTINSt3__27codecvtIcc11__mbstate_tEE"]=8287224;var __ZTSNSt3__27codecvtIcc11__mbstate_tEE=Module["__ZTSNSt3__27codecvtIcc11__mbstate_tEE"]=8146673;var __ZTSNSt3__212codecvt_baseE=Module["__ZTSNSt3__212codecvt_baseE"]=8146707;var __ZTINSt3__212codecvt_baseE=Module["__ZTINSt3__212codecvt_baseE"]=8287216;var __ZTINSt3__27codecvtIDsc11__mbstate_tEE=Module["__ZTINSt3__27codecvtIDsc11__mbstate_tEE"]=8287304;var __ZTSNSt3__27codecvtIDsc11__mbstate_tEE=Module["__ZTSNSt3__27codecvtIDsc11__mbstate_tEE"]=8146730;var __ZTINSt3__27codecvtIDsDu11__mbstate_tEE=Module["__ZTINSt3__27codecvtIDsDu11__mbstate_tEE"]=8287384;var __ZTSNSt3__27codecvtIDsDu11__mbstate_tEE=Module["__ZTSNSt3__27codecvtIDsDu11__mbstate_tEE"]=8146765;var __ZTINSt3__27codecvtIDic11__mbstate_tEE=Module["__ZTINSt3__27codecvtIDic11__mbstate_tEE"]=8287464;var __ZTSNSt3__27codecvtIDic11__mbstate_tEE=Module["__ZTSNSt3__27codecvtIDic11__mbstate_tEE"]=8146801;var __ZTINSt3__27codecvtIDiDu11__mbstate_tEE=Module["__ZTINSt3__27codecvtIDiDu11__mbstate_tEE"]=8287544;var __ZTSNSt3__27codecvtIDiDu11__mbstate_tEE=Module["__ZTSNSt3__27codecvtIDiDu11__mbstate_tEE"]=8146836;var __ZTVNSt3__216__narrow_to_utf8ILm16EEE=Module["__ZTVNSt3__216__narrow_to_utf8ILm16EEE"]=8287576;var __ZTINSt3__216__narrow_to_utf8ILm16EEE=Module["__ZTINSt3__216__narrow_to_utf8ILm16EEE"]=8287624;var __ZTSNSt3__216__narrow_to_utf8ILm16EEE=Module["__ZTSNSt3__216__narrow_to_utf8ILm16EEE"]=8146872;var __ZTVNSt3__216__narrow_to_utf8ILm32EEE=Module["__ZTVNSt3__216__narrow_to_utf8ILm32EEE"]=8287636;var __ZTINSt3__216__narrow_to_utf8ILm32EEE=Module["__ZTINSt3__216__narrow_to_utf8ILm32EEE"]=8287684;var __ZTSNSt3__216__narrow_to_utf8ILm32EEE=Module["__ZTSNSt3__216__narrow_to_utf8ILm32EEE"]=8146906;var __ZTVNSt3__217__widen_from_utf8ILm16EEE=Module["__ZTVNSt3__217__widen_from_utf8ILm16EEE"]=8287696;var __ZTINSt3__217__widen_from_utf8ILm16EEE=Module["__ZTINSt3__217__widen_from_utf8ILm16EEE"]=8287744;var __ZTSNSt3__217__widen_from_utf8ILm16EEE=Module["__ZTSNSt3__217__widen_from_utf8ILm16EEE"]=8146940;var __ZTVNSt3__217__widen_from_utf8ILm32EEE=Module["__ZTVNSt3__217__widen_from_utf8ILm32EEE"]=8287756;var __ZTINSt3__217__widen_from_utf8ILm32EEE=Module["__ZTINSt3__217__widen_from_utf8ILm32EEE"]=8287804;var __ZTSNSt3__217__widen_from_utf8ILm32EEE=Module["__ZTSNSt3__217__widen_from_utf8ILm32EEE"]=8146975;var __ZTVNSt3__214__codecvt_utf8IwEE=Module["__ZTVNSt3__214__codecvt_utf8IwEE"]=8287816;var __ZTINSt3__214__codecvt_utf8IwEE=Module["__ZTINSt3__214__codecvt_utf8IwEE"]=8287896;var __ZTSNSt3__214__codecvt_utf8IwEE=Module["__ZTSNSt3__214__codecvt_utf8IwEE"]=8147010;var __ZTSNSt3__27codecvtIwc11__mbstate_tEE=Module["__ZTSNSt3__27codecvtIwc11__mbstate_tEE"]=8147038;var __ZTVNSt3__214__codecvt_utf8IDsEE=Module["__ZTVNSt3__214__codecvt_utf8IDsEE"]=8287908;var __ZTINSt3__214__codecvt_utf8IDsEE=Module["__ZTINSt3__214__codecvt_utf8IDsEE"]=8287956;var __ZTSNSt3__214__codecvt_utf8IDsEE=Module["__ZTSNSt3__214__codecvt_utf8IDsEE"]=8147072;var __ZTVNSt3__214__codecvt_utf8IDiEE=Module["__ZTVNSt3__214__codecvt_utf8IDiEE"]=8287968;var __ZTINSt3__214__codecvt_utf8IDiEE=Module["__ZTINSt3__214__codecvt_utf8IDiEE"]=8288016;var __ZTSNSt3__214__codecvt_utf8IDiEE=Module["__ZTSNSt3__214__codecvt_utf8IDiEE"]=8147101;var __ZTVNSt3__215__codecvt_utf16IwLb0EEE=Module["__ZTVNSt3__215__codecvt_utf16IwLb0EEE"]=8288028;var __ZTINSt3__215__codecvt_utf16IwLb0EEE=Module["__ZTINSt3__215__codecvt_utf16IwLb0EEE"]=8288076;var __ZTSNSt3__215__codecvt_utf16IwLb0EEE=Module["__ZTSNSt3__215__codecvt_utf16IwLb0EEE"]=8147130;var __ZTVNSt3__215__codecvt_utf16IwLb1EEE=Module["__ZTVNSt3__215__codecvt_utf16IwLb1EEE"]=8288088;var __ZTINSt3__215__codecvt_utf16IwLb1EEE=Module["__ZTINSt3__215__codecvt_utf16IwLb1EEE"]=8288136;var __ZTSNSt3__215__codecvt_utf16IwLb1EEE=Module["__ZTSNSt3__215__codecvt_utf16IwLb1EEE"]=8147163;var __ZTVNSt3__215__codecvt_utf16IDsLb0EEE=Module["__ZTVNSt3__215__codecvt_utf16IDsLb0EEE"]=8288148;var __ZTINSt3__215__codecvt_utf16IDsLb0EEE=Module["__ZTINSt3__215__codecvt_utf16IDsLb0EEE"]=8288196;var __ZTSNSt3__215__codecvt_utf16IDsLb0EEE=Module["__ZTSNSt3__215__codecvt_utf16IDsLb0EEE"]=8147196;var __ZTVNSt3__215__codecvt_utf16IDsLb1EEE=Module["__ZTVNSt3__215__codecvt_utf16IDsLb1EEE"]=8288208;var __ZTINSt3__215__codecvt_utf16IDsLb1EEE=Module["__ZTINSt3__215__codecvt_utf16IDsLb1EEE"]=8288256;var __ZTSNSt3__215__codecvt_utf16IDsLb1EEE=Module["__ZTSNSt3__215__codecvt_utf16IDsLb1EEE"]=8147230;var __ZTVNSt3__215__codecvt_utf16IDiLb0EEE=Module["__ZTVNSt3__215__codecvt_utf16IDiLb0EEE"]=8288268;var __ZTINSt3__215__codecvt_utf16IDiLb0EEE=Module["__ZTINSt3__215__codecvt_utf16IDiLb0EEE"]=8288316;var __ZTSNSt3__215__codecvt_utf16IDiLb0EEE=Module["__ZTSNSt3__215__codecvt_utf16IDiLb0EEE"]=8147264;var __ZTVNSt3__215__codecvt_utf16IDiLb1EEE=Module["__ZTVNSt3__215__codecvt_utf16IDiLb1EEE"]=8288328;var __ZTINSt3__215__codecvt_utf16IDiLb1EEE=Module["__ZTINSt3__215__codecvt_utf16IDiLb1EEE"]=8288376;var __ZTSNSt3__215__codecvt_utf16IDiLb1EEE=Module["__ZTSNSt3__215__codecvt_utf16IDiLb1EEE"]=8147298;var __ZTVNSt3__220__codecvt_utf8_utf16IwEE=Module["__ZTVNSt3__220__codecvt_utf8_utf16IwEE"]=8288388;var __ZTINSt3__220__codecvt_utf8_utf16IwEE=Module["__ZTINSt3__220__codecvt_utf8_utf16IwEE"]=8288436;var __ZTSNSt3__220__codecvt_utf8_utf16IwEE=Module["__ZTSNSt3__220__codecvt_utf8_utf16IwEE"]=8147332;var __ZTVNSt3__220__codecvt_utf8_utf16IDiEE=Module["__ZTVNSt3__220__codecvt_utf8_utf16IDiEE"]=8288448;var __ZTINSt3__220__codecvt_utf8_utf16IDiEE=Module["__ZTINSt3__220__codecvt_utf8_utf16IDiEE"]=8288496;var __ZTSNSt3__220__codecvt_utf8_utf16IDiEE=Module["__ZTSNSt3__220__codecvt_utf8_utf16IDiEE"]=8147366;var __ZTVNSt3__220__codecvt_utf8_utf16IDsEE=Module["__ZTVNSt3__220__codecvt_utf8_utf16IDsEE"]=8288508;var __ZTINSt3__220__codecvt_utf8_utf16IDsEE=Module["__ZTINSt3__220__codecvt_utf8_utf16IDsEE"]=8288556;var __ZTSNSt3__220__codecvt_utf8_utf16IDsEE=Module["__ZTSNSt3__220__codecvt_utf8_utf16IDsEE"]=8147401;var __ZTSNSt3__26locale5__impE=Module["__ZTSNSt3__26locale5__impE"]=8147436;var __ZTSNSt3__214collate_bynameIcEE=Module["__ZTSNSt3__214collate_bynameIcEE"]=8147458;var __ZTSNSt3__27collateIcEE=Module["__ZTSNSt3__27collateIcEE"]=8147486;var __ZTINSt3__27collateIcEE=Module["__ZTINSt3__27collateIcEE"]=8288580;var __ZTSNSt3__214collate_bynameIwEE=Module["__ZTSNSt3__214collate_bynameIwEE"]=8147506;var __ZTSNSt3__27collateIwEE=Module["__ZTSNSt3__27collateIwEE"]=8147534;var __ZTINSt3__27collateIwEE=Module["__ZTINSt3__27collateIwEE"]=8288604;var __ZTSNSt3__25ctypeIcEE=Module["__ZTSNSt3__25ctypeIcEE"]=8147554;var __ZTSNSt3__212ctype_bynameIcEE=Module["__ZTSNSt3__212ctype_bynameIcEE"]=8147572;var __ZTSNSt3__212ctype_bynameIwEE=Module["__ZTSNSt3__212ctype_bynameIwEE"]=8147598;var __ZTSNSt3__28numpunctIcEE=Module["__ZTSNSt3__28numpunctIcEE"]=8147624;var __ZTSNSt3__28numpunctIwEE=Module["__ZTSNSt3__28numpunctIwEE"]=8147645;var __ZTSNSt3__215numpunct_bynameIcEE=Module["__ZTSNSt3__215numpunct_bynameIcEE"]=8147666;var __ZTSNSt3__215numpunct_bynameIwEE=Module["__ZTSNSt3__215numpunct_bynameIwEE"]=8147695;var __ZTINSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTINSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8288892;var __ZTSNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTSNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8147724;var __ZTSNSt3__29__num_getIcEE=Module["__ZTSNSt3__29__num_getIcEE"]=8147792;var __ZTSNSt3__214__num_get_baseE=Module["__ZTSNSt3__214__num_get_baseE"]=8147814;var __ZTINSt3__214__num_get_baseE=Module["__ZTINSt3__214__num_get_baseE"]=8288860;var __ZTINSt3__29__num_getIcEE=Module["__ZTINSt3__29__num_getIcEE"]=8288868;var __ZTINSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTINSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289012;var __ZTSNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTSNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8147839;var __ZTSNSt3__29__num_getIwEE=Module["__ZTSNSt3__29__num_getIwEE"]=8147907;var __ZTINSt3__29__num_getIwEE=Module["__ZTINSt3__29__num_getIwEE"]=8288988;var __ZTINSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTINSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289128;var __ZTSNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTSNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8147929;var __ZTSNSt3__29__num_putIcEE=Module["__ZTSNSt3__29__num_putIcEE"]=8147997;var __ZTSNSt3__214__num_put_baseE=Module["__ZTSNSt3__214__num_put_baseE"]=8148019;var __ZTINSt3__214__num_put_baseE=Module["__ZTINSt3__214__num_put_baseE"]=8289096;var __ZTINSt3__29__num_putIcEE=Module["__ZTINSt3__29__num_putIcEE"]=8289104;var __ZTINSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTINSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289236;var __ZTSNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTSNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8148044;var __ZTSNSt3__29__num_putIwEE=Module["__ZTSNSt3__29__num_putIwEE"]=8148112;var __ZTINSt3__29__num_putIwEE=Module["__ZTINSt3__29__num_putIwEE"]=8289212;var __ZTINSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTINSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289368;var __ZTSNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTSNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8148134;var __ZTSNSt3__29time_baseE=Module["__ZTSNSt3__29time_baseE"]=8148203;var __ZTINSt3__29time_baseE=Module["__ZTINSt3__29time_baseE"]=8289352;var __ZTSNSt3__220__time_get_c_storageIcEE=Module["__ZTSNSt3__220__time_get_c_storageIcEE"]=8148222;var __ZTINSt3__220__time_get_c_storageIcEE=Module["__ZTINSt3__220__time_get_c_storageIcEE"]=8289360;var __ZTINSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTINSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289500;var __ZTSNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTSNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8148256;var __ZTSNSt3__220__time_get_c_storageIwEE=Module["__ZTSNSt3__220__time_get_c_storageIwEE"]=8148325;var __ZTINSt3__220__time_get_c_storageIwEE=Module["__ZTINSt3__220__time_get_c_storageIwEE"]=8289492;var __ZTINSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTINSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289672;var __ZTSNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTSNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8148359;var __ZTSNSt3__218__time_get_storageIcEE=Module["__ZTSNSt3__218__time_get_storageIcEE"]=8148436;var __ZTSNSt3__210__time_getE=Module["__ZTSNSt3__210__time_getE"]=8148468;var __ZTINSt3__210__time_getE=Module["__ZTINSt3__210__time_getE"]=8289652;var __ZTINSt3__218__time_get_storageIcEE=Module["__ZTINSt3__218__time_get_storageIcEE"]=8289660;var __ZTINSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTINSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289828;var __ZTSNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTSNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8148489;var __ZTSNSt3__218__time_get_storageIwEE=Module["__ZTSNSt3__218__time_get_storageIwEE"]=8148566;var __ZTINSt3__218__time_get_storageIwEE=Module["__ZTINSt3__218__time_get_storageIwEE"]=8289816;var __ZTINSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTINSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8289892;var __ZTSNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTSNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8148598;var __ZTSNSt3__210__time_putE=Module["__ZTSNSt3__210__time_putE"]=8148667;var __ZTINSt3__210__time_putE=Module["__ZTINSt3__210__time_putE"]=8289884;var __ZTINSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTINSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8289948;var __ZTSNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTSNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8148688;var __ZTINSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTINSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8290004;var __ZTSNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTSNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8148757;var __ZTINSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTINSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8290040;var __ZTSNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTSNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8148834;var __ZTINSt3__210moneypunctIcLb0EEE=Module["__ZTINSt3__210moneypunctIcLb0EEE"]=8290116;var __ZTSNSt3__210moneypunctIcLb0EEE=Module["__ZTSNSt3__210moneypunctIcLb0EEE"]=8148911;var __ZTSNSt3__210money_baseE=Module["__ZTSNSt3__210money_baseE"]=8148939;var __ZTINSt3__210money_baseE=Module["__ZTINSt3__210money_baseE"]=8290108;var __ZTINSt3__210moneypunctIcLb1EEE=Module["__ZTINSt3__210moneypunctIcLb1EEE"]=8290204;var __ZTSNSt3__210moneypunctIcLb1EEE=Module["__ZTSNSt3__210moneypunctIcLb1EEE"]=8148960;var __ZTINSt3__210moneypunctIwLb0EEE=Module["__ZTINSt3__210moneypunctIwLb0EEE"]=8290292;var __ZTSNSt3__210moneypunctIwLb0EEE=Module["__ZTSNSt3__210moneypunctIwLb0EEE"]=8148988;var __ZTINSt3__210moneypunctIwLb1EEE=Module["__ZTINSt3__210moneypunctIwLb1EEE"]=8290380;var __ZTSNSt3__210moneypunctIwLb1EEE=Module["__ZTSNSt3__210moneypunctIwLb1EEE"]=8149016;var __ZTINSt3__217moneypunct_bynameIcLb0EEE=Module["__ZTINSt3__217moneypunct_bynameIcLb0EEE"]=8290468;var __ZTSNSt3__217moneypunct_bynameIcLb0EEE=Module["__ZTSNSt3__217moneypunct_bynameIcLb0EEE"]=8149044;var __ZTINSt3__217moneypunct_bynameIcLb1EEE=Module["__ZTINSt3__217moneypunct_bynameIcLb1EEE"]=8290536;var __ZTSNSt3__217moneypunct_bynameIcLb1EEE=Module["__ZTSNSt3__217moneypunct_bynameIcLb1EEE"]=8149079;var __ZTINSt3__217moneypunct_bynameIwLb0EEE=Module["__ZTINSt3__217moneypunct_bynameIwLb0EEE"]=8290604;var __ZTSNSt3__217moneypunct_bynameIwLb0EEE=Module["__ZTSNSt3__217moneypunct_bynameIwLb0EEE"]=8149114;var __ZTINSt3__217moneypunct_bynameIwLb1EEE=Module["__ZTINSt3__217moneypunct_bynameIwLb1EEE"]=8290672;var __ZTSNSt3__217moneypunct_bynameIwLb1EEE=Module["__ZTSNSt3__217moneypunct_bynameIwLb1EEE"]=8149149;var __ZTINSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTINSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8290720;var __ZTSNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTSNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8149184;var __ZTSNSt3__211__money_getIcEE=Module["__ZTSNSt3__211__money_getIcEE"]=8149254;var __ZTINSt3__211__money_getIcEE=Module["__ZTINSt3__211__money_getIcEE"]=8290712;var __ZTINSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTINSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8290788;var __ZTSNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTSNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8149279;var __ZTSNSt3__211__money_getIwEE=Module["__ZTSNSt3__211__money_getIwEE"]=8149349;var __ZTINSt3__211__money_getIwEE=Module["__ZTINSt3__211__money_getIwEE"]=8290780;var __ZTINSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTINSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8290856;var __ZTSNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE=Module["__ZTSNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"]=8149374;var __ZTSNSt3__211__money_putIcEE=Module["__ZTSNSt3__211__money_putIcEE"]=8149444;var __ZTINSt3__211__money_putIcEE=Module["__ZTINSt3__211__money_putIcEE"]=8290848;var __ZTINSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTINSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8290924;var __ZTSNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE=Module["__ZTSNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"]=8149469;var __ZTSNSt3__211__money_putIwEE=Module["__ZTSNSt3__211__money_putIwEE"]=8149539;var __ZTINSt3__211__money_putIwEE=Module["__ZTINSt3__211__money_putIwEE"]=8290916;var __ZTINSt3__28messagesIcEE=Module["__ZTINSt3__28messagesIcEE"]=8290996;var __ZTSNSt3__28messagesIcEE=Module["__ZTSNSt3__28messagesIcEE"]=8149564;var __ZTSNSt3__213messages_baseE=Module["__ZTSNSt3__213messages_baseE"]=8149585;var __ZTINSt3__213messages_baseE=Module["__ZTINSt3__213messages_baseE"]=8290988;var __ZTINSt3__28messagesIwEE=Module["__ZTINSt3__28messagesIwEE"]=8291060;var __ZTSNSt3__28messagesIwEE=Module["__ZTSNSt3__28messagesIwEE"]=8149609;var __ZTINSt3__215messages_bynameIcEE=Module["__ZTINSt3__215messages_bynameIcEE"]=8291124;var __ZTSNSt3__215messages_bynameIcEE=Module["__ZTSNSt3__215messages_bynameIcEE"]=8149630;var __ZTINSt3__215messages_bynameIwEE=Module["__ZTINSt3__215messages_bynameIwEE"]=8291168;var __ZTSNSt3__215messages_bynameIwEE=Module["__ZTSNSt3__215messages_bynameIwEE"]=8149659;var __ZTINSt3__214codecvt_bynameIcc11__mbstate_tEE=Module["__ZTINSt3__214codecvt_bynameIcc11__mbstate_tEE"]=8291228;var __ZTSNSt3__214codecvt_bynameIcc11__mbstate_tEE=Module["__ZTSNSt3__214codecvt_bynameIcc11__mbstate_tEE"]=8149688;var __ZTINSt3__214codecvt_bynameIwc11__mbstate_tEE=Module["__ZTINSt3__214codecvt_bynameIwc11__mbstate_tEE"]=8291288;var __ZTSNSt3__214codecvt_bynameIwc11__mbstate_tEE=Module["__ZTSNSt3__214codecvt_bynameIwc11__mbstate_tEE"]=8149730;var __ZTINSt3__214codecvt_bynameIDsc11__mbstate_tEE=Module["__ZTINSt3__214codecvt_bynameIDsc11__mbstate_tEE"]=8291348;var __ZTSNSt3__214codecvt_bynameIDsc11__mbstate_tEE=Module["__ZTSNSt3__214codecvt_bynameIDsc11__mbstate_tEE"]=8149772;var __ZTINSt3__214codecvt_bynameIDic11__mbstate_tEE=Module["__ZTINSt3__214codecvt_bynameIDic11__mbstate_tEE"]=8291408;var __ZTSNSt3__214codecvt_bynameIDic11__mbstate_tEE=Module["__ZTSNSt3__214codecvt_bynameIDic11__mbstate_tEE"]=8149815;var __ZTINSt3__214codecvt_bynameIDsDu11__mbstate_tEE=Module["__ZTINSt3__214codecvt_bynameIDsDu11__mbstate_tEE"]=8291468;var __ZTSNSt3__214codecvt_bynameIDsDu11__mbstate_tEE=Module["__ZTSNSt3__214codecvt_bynameIDsDu11__mbstate_tEE"]=8149858;var __ZTINSt3__214codecvt_bynameIDiDu11__mbstate_tEE=Module["__ZTINSt3__214codecvt_bynameIDiDu11__mbstate_tEE"]=8291528;var __ZTSNSt3__214codecvt_bynameIDiDu11__mbstate_tEE=Module["__ZTSNSt3__214codecvt_bynameIDiDu11__mbstate_tEE"]=8149902;var __ZTINSt3__215__time_get_tempIcEE=Module["__ZTINSt3__215__time_get_tempIcEE"]=8291664;var __ZTSNSt3__215__time_get_tempIcEE=Module["__ZTSNSt3__215__time_get_tempIcEE"]=8150832;var __ZTINSt3__215__time_get_tempIwEE=Module["__ZTINSt3__215__time_get_tempIwEE"]=8291744;var __ZTSNSt3__215__time_get_tempIwEE=Module["__ZTSNSt3__215__time_get_tempIwEE"]=8150861;var __ZNSt3__213allocator_argE=Module["__ZNSt3__213allocator_argE"]=8150890;var __ZTVNSt3__212bad_weak_ptrE=Module["__ZTVNSt3__212bad_weak_ptrE"]=8291888;var __ZTINSt3__212bad_weak_ptrE=Module["__ZTINSt3__212bad_weak_ptrE"]=8291908;var __ZTSNSt3__212bad_weak_ptrE=Module["__ZTSNSt3__212bad_weak_ptrE"]=8150891;var __ZTSNSt3__214__shared_countE=Module["__ZTSNSt3__214__shared_countE"]=8150914;var __ZTSNSt3__219__shared_weak_countE=Module["__ZTSNSt3__219__shared_weak_countE"]=8150939;var __ZTVNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE=Module["__ZTVNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE"]=8292e3;var __ZTINSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE=Module["__ZTINSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE"]=8292072;var __ZTVNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE=Module["__ZTVNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE"]=8292028;var __ZTINSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE=Module["__ZTINSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE"]=8292084;var __ZTSNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE=Module["__ZTSNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE"]=8150969;var __ZTSNSt12experimental15fundamentals_v13pmr15memory_resourceE=Module["__ZTSNSt12experimental15fundamentals_v13pmr15memory_resourceE"]=8151043;var __ZTINSt12experimental15fundamentals_v13pmr15memory_resourceE=Module["__ZTINSt12experimental15fundamentals_v13pmr15memory_resourceE"]=8292064;var __ZTSNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE=Module["__ZTSNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE"]=8151100;var __ZTVNSt3__23pmr28unsynchronized_pool_resourceE=Module["__ZTVNSt3__23pmr28unsynchronized_pool_resourceE"]=8292164;var __ZTVNSt3__23pmr15memory_resourceE=Module["__ZTVNSt3__23pmr15memory_resourceE"]=8292240;var __ZTVNSt3__23pmr25monotonic_buffer_resourceE=Module["__ZTVNSt3__23pmr25monotonic_buffer_resourceE"]=8292192;var __ZTVNSt3__23pmr26synchronized_pool_resourceE=Module["__ZTVNSt3__23pmr26synchronized_pool_resourceE"]=8292280;var __ZTVNSt3__23pmr32__new_delete_memory_resource_impE=Module["__ZTVNSt3__23pmr32__new_delete_memory_resource_impE"]=8292100;var __ZTINSt3__23pmr32__new_delete_memory_resource_impE=Module["__ZTINSt3__23pmr32__new_delete_memory_resource_impE"]=8292320;var __ZTVNSt3__23pmr26__null_memory_resource_impE=Module["__ZTVNSt3__23pmr26__null_memory_resource_impE"]=8292128;var __ZTINSt3__23pmr26__null_memory_resource_impE=Module["__ZTINSt3__23pmr26__null_memory_resource_impE"]=8292332;var __ZTINSt3__23pmr28unsynchronized_pool_resourceE=Module["__ZTINSt3__23pmr28unsynchronized_pool_resourceE"]=8292268;var __ZTINSt3__23pmr25monotonic_buffer_resourceE=Module["__ZTINSt3__23pmr25monotonic_buffer_resourceE"]=8292228;var __ZTSNSt3__23pmr25monotonic_buffer_resourceE=Module["__ZTSNSt3__23pmr25monotonic_buffer_resourceE"]=8151168;var __ZTSNSt3__23pmr15memory_resourceE=Module["__ZTSNSt3__23pmr15memory_resourceE"]=8151208;var __ZTINSt3__23pmr15memory_resourceE=Module["__ZTINSt3__23pmr15memory_resourceE"]=8292220;var __ZTSNSt3__23pmr28unsynchronized_pool_resourceE=Module["__ZTSNSt3__23pmr28unsynchronized_pool_resourceE"]=8151238;var __ZTINSt3__23pmr26synchronized_pool_resourceE=Module["__ZTINSt3__23pmr26synchronized_pool_resourceE"]=8292308;var __ZTSNSt3__23pmr26synchronized_pool_resourceE=Module["__ZTSNSt3__23pmr26synchronized_pool_resourceE"]=8151281;var __ZTSNSt3__23pmr32__new_delete_memory_resource_impE=Module["__ZTSNSt3__23pmr32__new_delete_memory_resource_impE"]=8151322;var __ZTSNSt3__23pmr26__null_memory_resource_impE=Module["__ZTSNSt3__23pmr26__null_memory_resource_impE"]=8151369;var __ZNSt3__210defer_lockE=Module["__ZNSt3__210defer_lockE"]=8151410;var __ZNSt3__211try_to_lockE=Module["__ZNSt3__211try_to_lockE"]=8151411;var __ZNSt3__210adopt_lockE=Module["__ZNSt3__210adopt_lockE"]=8151412;var __ZTISt9bad_alloc=Module["__ZTISt9bad_alloc"]=8300976;var __ZSt7nothrow=Module["__ZSt7nothrow"]=8151413;var __ZNSt3__24__fs10filesystem16_FilesystemClock9is_steadyE=Module["__ZNSt3__24__fs10filesystem16_FilesystemClock9is_steadyE"]=8151414;var __ZNSt3__24__fs10filesystem4path19preferred_separatorE=Module["__ZNSt3__24__fs10filesystem4path19preferred_separatorE"]=8151415;var __ZTSNSt3__24__fs10filesystem16filesystem_errorE=Module["__ZTSNSt3__24__fs10filesystem16filesystem_errorE"]=8151416;var __ZTSSt19bad_optional_access=Module["__ZTSSt19bad_optional_access"]=8151484;var __ZTVNSt12experimental19bad_optional_accessE=Module["__ZTVNSt12experimental19bad_optional_accessE"]=8292428;var __ZTINSt12experimental19bad_optional_accessE=Module["__ZTINSt12experimental19bad_optional_accessE"]=8292448;var __ZTSNSt12experimental19bad_optional_accessE=Module["__ZTSNSt12experimental19bad_optional_accessE"]=8151508;var __ZNSt3__212__rs_default4__c_E=Module["__ZNSt3__212__rs_default4__c_E"]=9425112;var __ZTVNSt3__211regex_errorE=Module["__ZTVNSt3__211regex_errorE"]=8292460;var __ZTINSt3__211regex_errorE=Module["__ZTINSt3__211regex_errorE"]=8293496;var __ZTSNSt3__211regex_errorE=Module["__ZTSNSt3__211regex_errorE"]=8151548;var __ZTVSt11logic_error=Module["__ZTVSt11logic_error"]=8301e3;var __ZTVSt13runtime_error=Module["__ZTVSt13runtime_error"]=8301020;var __ZTISt16invalid_argument=Module["__ZTISt16invalid_argument"]=8301104;var __ZTVSt16invalid_argument=Module["__ZTVSt16invalid_argument"]=8301084;var __ZNSt3__26__itoa10__pow10_64E=Module["__ZNSt3__26__itoa10__pow10_64E"]=8151616;var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4nposE=Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4nposE"]=8151572;var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4nposE=Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4nposE"]=8151576;var __ZTVNSt3__212strstreambufE=Module["__ZTVNSt3__212strstreambufE"]=8293576;var __ZTTNSt3__210istrstreamE=Module["__ZTTNSt3__210istrstreamE"]=8293680;var __ZTTNSt3__210ostrstreamE=Module["__ZTTNSt3__210ostrstreamE"]=8293736;var __ZTTNSt3__29strstreamE=Module["__ZTTNSt3__29strstreamE"]=8293812;var __ZTINSt3__212strstreambufE=Module["__ZTINSt3__212strstreambufE"]=8293852;var __ZTVNSt3__210istrstreamE=Module["__ZTVNSt3__210istrstreamE"]=8293640;var __ZTINSt3__210istrstreamE=Module["__ZTINSt3__210istrstreamE"]=8293904;var __ZTCNSt3__210istrstreamE0_NS_13basic_istreamIcNS_11char_traitsIcEEEE=Module["__ZTCNSt3__210istrstreamE0_NS_13basic_istreamIcNS_11char_traitsIcEEEE"]=8293864;var __ZTVNSt3__210ostrstreamE=Module["__ZTVNSt3__210ostrstreamE"]=8293696;var __ZTINSt3__210ostrstreamE=Module["__ZTINSt3__210ostrstreamE"]=8293956;var __ZTCNSt3__210ostrstreamE0_NS_13basic_ostreamIcNS_11char_traitsIcEEEE=Module["__ZTCNSt3__210ostrstreamE0_NS_13basic_ostreamIcNS_11char_traitsIcEEEE"]=8293916;var __ZTVNSt3__29strstreamE=Module["__ZTVNSt3__29strstreamE"]=8293752;var __ZTINSt3__29strstreamE=Module["__ZTINSt3__29strstreamE"]=8294108;var __ZTCNSt3__29strstreamE0_NS_14basic_iostreamIcNS_11char_traitsIcEEEE=Module["__ZTCNSt3__29strstreamE0_NS_14basic_iostreamIcNS_11char_traitsIcEEEE"]=8293968;var __ZTCNSt3__29strstreamE0_NS_13basic_istreamIcNS_11char_traitsIcEEEE=Module["__ZTCNSt3__29strstreamE0_NS_13basic_istreamIcNS_11char_traitsIcEEEE"]=8294028;var __ZTCNSt3__29strstreamE8_NS_13basic_ostreamIcNS_11char_traitsIcEEEE=Module["__ZTCNSt3__29strstreamE8_NS_13basic_ostreamIcNS_11char_traitsIcEEEE"]=8294068;var __ZTSNSt3__212strstreambufE=Module["__ZTSNSt3__212strstreambufE"]=8151776;var __ZTSNSt3__210istrstreamE=Module["__ZTSNSt3__210istrstreamE"]=8151799;var __ZTSNSt3__210ostrstreamE=Module["__ZTSNSt3__210ostrstreamE"]=8151820;var __ZTSNSt3__29strstreamE=Module["__ZTSNSt3__29strstreamE"]=8151841;var __ZTVNSt3__212system_errorE=Module["__ZTVNSt3__212system_errorE"]=8294200;var __ZTVNSt3__224__generic_error_categoryE=Module["__ZTVNSt3__224__generic_error_categoryE"]=8294124;var __ZTINSt3__224__generic_error_categoryE=Module["__ZTINSt3__224__generic_error_categoryE"]=8294324;var __ZTVNSt3__223__system_error_categoryE=Module["__ZTVNSt3__223__system_error_categoryE"]=8294164;var __ZTINSt3__223__system_error_categoryE=Module["__ZTINSt3__223__system_error_categoryE"]=8294336;var __ZTSNSt3__212system_errorE=Module["__ZTSNSt3__212system_errorE"]=8151860;var __ZTVNSt3__214error_categoryE=Module["__ZTVNSt3__214error_categoryE"]=8294232;var __ZTINSt3__214error_categoryE=Module["__ZTINSt3__214error_categoryE"]=8294268;var __ZTSNSt3__214error_categoryE=Module["__ZTSNSt3__214error_categoryE"]=8151883;var __ZTVNSt3__212__do_messageE=Module["__ZTVNSt3__212__do_messageE"]=8294276;var __ZTSNSt3__212__do_messageE=Module["__ZTSNSt3__212__do_messageE"]=8151908;var __ZTSNSt3__224__generic_error_categoryE=Module["__ZTSNSt3__224__generic_error_categoryE"]=8151931;var __ZTSNSt3__223__system_error_categoryE=Module["__ZTSNSt3__223__system_error_categoryE"]=8151966;var __ZNSt3__219piecewise_constructE=Module["__ZNSt3__219piecewise_constructE"]=8152e3;var __ZTSSt18bad_variant_access=Module["__ZTSSt18bad_variant_access"]=8152001;var __ZTISt10bad_typeid=Module["__ZTISt10bad_typeid"]=8301364;var ___cxa_unexpected_handler=Module["___cxa_unexpected_handler"]=8294384;var ___cxa_terminate_handler=Module["___cxa_terminate_handler"]=8294380;var ___cxa_new_handler=Module["___cxa_new_handler"]=9427656;var __ZTISt13bad_exception=Module["__ZTISt13bad_exception"]=8300964;var __ZTVSt13bad_exception=Module["__ZTVSt13bad_exception"]=8300944;var __ZTIN10__cxxabiv117__class_type_infoE=Module["__ZTIN10__cxxabiv117__class_type_infoE"]=8299412;var __ZTIN10__cxxabiv116__shim_type_infoE=Module["__ZTIN10__cxxabiv116__shim_type_infoE"]=8299400;var __ZTIN10__cxxabiv117__pbase_type_infoE=Module["__ZTIN10__cxxabiv117__pbase_type_infoE"]=8299424;var __ZTIDn=Module["__ZTIDn"]=8299580;var __ZTIN10__cxxabiv119__pointer_type_infoE=Module["__ZTIN10__cxxabiv119__pointer_type_infoE"]=8299436;var __ZTIv=Module["__ZTIv"]=8299540;var __ZTIN10__cxxabiv120__function_type_infoE=Module["__ZTIN10__cxxabiv120__function_type_infoE"]=8299448;var __ZTIN10__cxxabiv129__pointer_to_member_type_infoE=Module["__ZTIN10__cxxabiv129__pointer_to_member_type_infoE"]=8299460;var __ZTSN10__cxxabiv116__shim_type_infoE=Module["__ZTSN10__cxxabiv116__shim_type_infoE"]=8156232;var __ZTISt9type_info=Module["__ZTISt9type_info"]=8301344;var __ZTSN10__cxxabiv117__class_type_infoE=Module["__ZTSN10__cxxabiv117__class_type_infoE"]=8156265;var __ZTSN10__cxxabiv117__pbase_type_infoE=Module["__ZTSN10__cxxabiv117__pbase_type_infoE"]=8156299;var __ZTSN10__cxxabiv119__pointer_type_infoE=Module["__ZTSN10__cxxabiv119__pointer_type_infoE"]=8156333;var __ZTSN10__cxxabiv120__function_type_infoE=Module["__ZTSN10__cxxabiv120__function_type_infoE"]=8156369;var __ZTSN10__cxxabiv129__pointer_to_member_type_infoE=Module["__ZTSN10__cxxabiv129__pointer_to_member_type_infoE"]=8156406;var __ZTVN10__cxxabiv116__shim_type_infoE=Module["__ZTVN10__cxxabiv116__shim_type_infoE"]=8299472;var __ZTVN10__cxxabiv123__fundamental_type_infoE=Module["__ZTVN10__cxxabiv123__fundamental_type_infoE"]=8299500;var __ZTIN10__cxxabiv123__fundamental_type_infoE=Module["__ZTIN10__cxxabiv123__fundamental_type_infoE"]=8299528;var __ZTSN10__cxxabiv123__fundamental_type_infoE=Module["__ZTSN10__cxxabiv123__fundamental_type_infoE"]=8156464;var __ZTSv=Module["__ZTSv"]=8156504;var __ZTSPv=Module["__ZTSPv"]=8156506;var __ZTIPv=Module["__ZTIPv"]=8299548;var __ZTVN10__cxxabiv119__pointer_type_infoE=Module["__ZTVN10__cxxabiv119__pointer_type_infoE"]=8300820;var __ZTSPKv=Module["__ZTSPKv"]=8156509;var __ZTIPKv=Module["__ZTIPKv"]=8299564;var __ZTSDn=Module["__ZTSDn"]=8156513;var __ZTSPDn=Module["__ZTSPDn"]=8156516;var __ZTIPDn=Module["__ZTIPDn"]=8299588;var __ZTSPKDn=Module["__ZTSPKDn"]=8156520;var __ZTIPKDn=Module["__ZTIPKDn"]=8299604;var __ZTSb=Module["__ZTSb"]=8156525;var __ZTIb=Module["__ZTIb"]=8299620;var __ZTSPb=Module["__ZTSPb"]=8156527;var __ZTIPb=Module["__ZTIPb"]=8299628;var __ZTSPKb=Module["__ZTSPKb"]=8156530;var __ZTIPKb=Module["__ZTIPKb"]=8299644;var __ZTSw=Module["__ZTSw"]=8156534;var __ZTIw=Module["__ZTIw"]=8299660;var __ZTSPw=Module["__ZTSPw"]=8156536;var __ZTIPw=Module["__ZTIPw"]=8299668;var __ZTSPKw=Module["__ZTSPKw"]=8156539;var __ZTIPKw=Module["__ZTIPKw"]=8299684;var __ZTSc=Module["__ZTSc"]=8156543;var __ZTIc=Module["__ZTIc"]=8299700;var __ZTSPc=Module["__ZTSPc"]=8156545;var __ZTIPc=Module["__ZTIPc"]=8299708;var __ZTSPKc=Module["__ZTSPKc"]=8156548;var __ZTIPKc=Module["__ZTIPKc"]=8299724;var __ZTSh=Module["__ZTSh"]=8156552;var __ZTIh=Module["__ZTIh"]=8299740;var __ZTSPh=Module["__ZTSPh"]=8156554;var __ZTIPh=Module["__ZTIPh"]=8299748;var __ZTSPKh=Module["__ZTSPKh"]=8156557;var __ZTIPKh=Module["__ZTIPKh"]=8299764;var __ZTSa=Module["__ZTSa"]=8156561;var __ZTIa=Module["__ZTIa"]=8299780;var __ZTSPa=Module["__ZTSPa"]=8156563;var __ZTIPa=Module["__ZTIPa"]=8299788;var __ZTSPKa=Module["__ZTSPKa"]=8156566;var __ZTIPKa=Module["__ZTIPKa"]=8299804;var __ZTSs=Module["__ZTSs"]=8156570;var __ZTIs=Module["__ZTIs"]=8299820;var __ZTSPs=Module["__ZTSPs"]=8156572;var __ZTIPs=Module["__ZTIPs"]=8299828;var __ZTSPKs=Module["__ZTSPKs"]=8156575;var __ZTIPKs=Module["__ZTIPKs"]=8299844;var __ZTSt=Module["__ZTSt"]=8156579;var __ZTIt=Module["__ZTIt"]=8299860;var __ZTSPt=Module["__ZTSPt"]=8156581;var __ZTIPt=Module["__ZTIPt"]=8299868;var __ZTSPKt=Module["__ZTSPKt"]=8156584;var __ZTIPKt=Module["__ZTIPKt"]=8299884;var __ZTSi=Module["__ZTSi"]=8156588;var __ZTIi=Module["__ZTIi"]=8299900;var __ZTSPi=Module["__ZTSPi"]=8156590;var __ZTIPi=Module["__ZTIPi"]=8299908;var __ZTSPKi=Module["__ZTSPKi"]=8156593;var __ZTIPKi=Module["__ZTIPKi"]=8299924;var __ZTSj=Module["__ZTSj"]=8156597;var __ZTIj=Module["__ZTIj"]=8299940;var __ZTSPj=Module["__ZTSPj"]=8156599;var __ZTIPj=Module["__ZTIPj"]=8299948;var __ZTSPKj=Module["__ZTSPKj"]=8156602;var __ZTIPKj=Module["__ZTIPKj"]=8299964;var __ZTSl=Module["__ZTSl"]=8156606;var __ZTIl=Module["__ZTIl"]=8299980;var __ZTSPl=Module["__ZTSPl"]=8156608;var __ZTIPl=Module["__ZTIPl"]=8299988;var __ZTSPKl=Module["__ZTSPKl"]=8156611;var __ZTIPKl=Module["__ZTIPKl"]=8300004;var __ZTSm=Module["__ZTSm"]=8156615;var __ZTIm=Module["__ZTIm"]=8300020;var __ZTSPm=Module["__ZTSPm"]=8156617;var __ZTIPm=Module["__ZTIPm"]=8300028;var __ZTSPKm=Module["__ZTSPKm"]=8156620;var __ZTIPKm=Module["__ZTIPKm"]=8300044;var __ZTSx=Module["__ZTSx"]=8156624;var __ZTIx=Module["__ZTIx"]=8300060;var __ZTSPx=Module["__ZTSPx"]=8156626;var __ZTIPx=Module["__ZTIPx"]=8300068;var __ZTSPKx=Module["__ZTSPKx"]=8156629;var __ZTIPKx=Module["__ZTIPKx"]=8300084;var __ZTSy=Module["__ZTSy"]=8156633;var __ZTIy=Module["__ZTIy"]=8300100;var __ZTSPy=Module["__ZTSPy"]=8156635;var __ZTIPy=Module["__ZTIPy"]=8300108;var __ZTSPKy=Module["__ZTSPKy"]=8156638;var __ZTIPKy=Module["__ZTIPKy"]=8300124;var __ZTSn=Module["__ZTSn"]=8156642;var __ZTIn=Module["__ZTIn"]=8300140;var __ZTSPn=Module["__ZTSPn"]=8156644;var __ZTIPn=Module["__ZTIPn"]=8300148;var __ZTSPKn=Module["__ZTSPKn"]=8156647;var __ZTIPKn=Module["__ZTIPKn"]=8300164;var __ZTSo=Module["__ZTSo"]=8156651;var __ZTIo=Module["__ZTIo"]=8300180;var __ZTSPo=Module["__ZTSPo"]=8156653;var __ZTIPo=Module["__ZTIPo"]=8300188;var __ZTSPKo=Module["__ZTSPKo"]=8156656;var __ZTIPKo=Module["__ZTIPKo"]=8300204;var __ZTSDh=Module["__ZTSDh"]=8156660;var __ZTIDh=Module["__ZTIDh"]=8300220;var __ZTSPDh=Module["__ZTSPDh"]=8156663;var __ZTIPDh=Module["__ZTIPDh"]=8300228;var __ZTSPKDh=Module["__ZTSPKDh"]=8156667;var __ZTIPKDh=Module["__ZTIPKDh"]=8300244;var __ZTSf=Module["__ZTSf"]=8156672;var __ZTIf=Module["__ZTIf"]=8300260;var __ZTSPf=Module["__ZTSPf"]=8156674;var __ZTIPf=Module["__ZTIPf"]=8300268;var __ZTSPKf=Module["__ZTSPKf"]=8156677;var __ZTIPKf=Module["__ZTIPKf"]=8300284;var __ZTSd=Module["__ZTSd"]=8156681;var __ZTId=Module["__ZTId"]=8300300;var __ZTSPd=Module["__ZTSPd"]=8156683;var __ZTIPd=Module["__ZTIPd"]=8300308;var __ZTSPKd=Module["__ZTSPKd"]=8156686;var __ZTIPKd=Module["__ZTIPKd"]=8300324;var __ZTSe=Module["__ZTSe"]=8156690;var __ZTIe=Module["__ZTIe"]=8300340;var __ZTSPe=Module["__ZTSPe"]=8156692;var __ZTIPe=Module["__ZTIPe"]=8300348;var __ZTSPKe=Module["__ZTSPKe"]=8156695;var __ZTIPKe=Module["__ZTIPKe"]=8300364;var __ZTSg=Module["__ZTSg"]=8156699;var __ZTIg=Module["__ZTIg"]=8300380;var __ZTSPg=Module["__ZTSPg"]=8156701;var __ZTIPg=Module["__ZTIPg"]=8300388;var __ZTSPKg=Module["__ZTSPKg"]=8156704;var __ZTIPKg=Module["__ZTIPKg"]=8300404;var __ZTSDu=Module["__ZTSDu"]=8156708;var __ZTIDu=Module["__ZTIDu"]=8300420;var __ZTSPDu=Module["__ZTSPDu"]=8156711;var __ZTIPDu=Module["__ZTIPDu"]=8300428;var __ZTSPKDu=Module["__ZTSPKDu"]=8156715;var __ZTIPKDu=Module["__ZTIPKDu"]=8300444;var __ZTSDs=Module["__ZTSDs"]=8156720;var __ZTIDs=Module["__ZTIDs"]=8300460;var __ZTSPDs=Module["__ZTSPDs"]=8156723;var __ZTIPDs=Module["__ZTIPDs"]=8300468;var __ZTSPKDs=Module["__ZTSPKDs"]=8156727;var __ZTIPKDs=Module["__ZTIPKDs"]=8300484;var __ZTSDi=Module["__ZTSDi"]=8156732;var __ZTIDi=Module["__ZTIDi"]=8300500;var __ZTSPDi=Module["__ZTSPDi"]=8156735;var __ZTIPDi=Module["__ZTIPDi"]=8300508;var __ZTSPKDi=Module["__ZTSPKDi"]=8156739;var __ZTIPKDi=Module["__ZTIPKDi"]=8300524;var __ZTVN10__cxxabiv117__array_type_infoE=Module["__ZTVN10__cxxabiv117__array_type_infoE"]=8300540;var __ZTIN10__cxxabiv117__array_type_infoE=Module["__ZTIN10__cxxabiv117__array_type_infoE"]=8300568;var __ZTSN10__cxxabiv117__array_type_infoE=Module["__ZTSN10__cxxabiv117__array_type_infoE"]=8156744;var __ZTVN10__cxxabiv120__function_type_infoE=Module["__ZTVN10__cxxabiv120__function_type_infoE"]=8300580;var __ZTVN10__cxxabiv116__enum_type_infoE=Module["__ZTVN10__cxxabiv116__enum_type_infoE"]=8300608;var __ZTIN10__cxxabiv116__enum_type_infoE=Module["__ZTIN10__cxxabiv116__enum_type_infoE"]=8300636;var __ZTSN10__cxxabiv116__enum_type_infoE=Module["__ZTSN10__cxxabiv116__enum_type_infoE"]=8156778;var __ZTIN10__cxxabiv120__si_class_type_infoE=Module["__ZTIN10__cxxabiv120__si_class_type_infoE"]=8300728;var __ZTSN10__cxxabiv120__si_class_type_infoE=Module["__ZTSN10__cxxabiv120__si_class_type_infoE"]=8156811;var __ZTIN10__cxxabiv121__vmi_class_type_infoE=Module["__ZTIN10__cxxabiv121__vmi_class_type_infoE"]=8300780;var __ZTSN10__cxxabiv121__vmi_class_type_infoE=Module["__ZTSN10__cxxabiv121__vmi_class_type_infoE"]=8156848;var __ZTVN10__cxxabiv117__pbase_type_infoE=Module["__ZTVN10__cxxabiv117__pbase_type_infoE"]=8300792;var __ZTVN10__cxxabiv129__pointer_to_member_type_infoE=Module["__ZTVN10__cxxabiv129__pointer_to_member_type_infoE"]=8300848;var __ZTVSt9bad_alloc=Module["__ZTVSt9bad_alloc"]=8300876;var __ZTVSt20bad_array_new_length=Module["__ZTVSt20bad_array_new_length"]=8300896;var __ZTSSt9exception=Module["__ZTSSt9exception"]=8156886;var __ZTSSt13bad_exception=Module["__ZTSSt13bad_exception"]=8156899;var __ZTSSt20bad_array_new_length=Module["__ZTSSt20bad_array_new_length"]=8156917;var __ZTSSt9bad_alloc=Module["__ZTSSt9bad_alloc"]=8156942;var __ZTVSt12domain_error=Module["__ZTVSt12domain_error"]=8301040;var __ZTISt12domain_error=Module["__ZTISt12domain_error"]=8301072;var __ZTSSt12domain_error=Module["__ZTSSt12domain_error"]=8156955;var __ZTSSt11logic_error=Module["__ZTSSt11logic_error"]=8156972;var __ZTSSt16invalid_argument=Module["__ZTSSt16invalid_argument"]=8156988;var __ZTSSt12length_error=Module["__ZTSSt12length_error"]=8157009;var __ZTSSt12out_of_range=Module["__ZTSSt12out_of_range"]=8157026;var __ZTVSt11range_error=Module["__ZTVSt11range_error"]=8301180;var __ZTISt11range_error=Module["__ZTISt11range_error"]=8301212;var __ZTSSt11range_error=Module["__ZTSSt11range_error"]=8157043;var __ZTSSt13runtime_error=Module["__ZTSSt13runtime_error"]=8157059;var __ZTSSt14overflow_error=Module["__ZTSSt14overflow_error"]=8157077;var __ZTVSt15underflow_error=Module["__ZTVSt15underflow_error"]=8301256;var __ZTISt15underflow_error=Module["__ZTISt15underflow_error"]=8301276;var __ZTSSt15underflow_error=Module["__ZTSSt15underflow_error"]=8157096;var __ZTVSt8bad_cast=Module["__ZTVSt8bad_cast"]=8301288;var __ZTVSt10bad_typeid=Module["__ZTVSt10bad_typeid"]=8301308;var __ZTVSt9type_info=Module["__ZTVSt9type_info"]=8301328;var __ZTSSt9type_info=Module["__ZTSSt9type_info"]=8157116;var __ZTSSt8bad_cast=Module["__ZTSSt8bad_cast"]=8157129;var __ZTSSt10bad_typeid=Module["__ZTSSt10bad_typeid"]=8157141;var ___wasm_lpad_context=Module["___wasm_lpad_context"]=9428208;var _in6addr_any=Module["_in6addr_any"]=8157156;var _in6addr_loopback=Module["_in6addr_loopback"]=8157172;function intArrayFromBase64(s){if(typeof ENVIRONMENT_IS_NODE!="undefined"&&ENVIRONMENT_IS_NODE){var buf=Buffer.from(s,"base64");return new Uint8Array(buf.buffer,buf.byteOffset,buf.length)}var decoded=atob(s);var bytes=new Uint8Array(decoded.length);for(var i=0;i<decoded.length;++i){bytes[i]=decoded.charCodeAt(i)}return bytes}function tryParseAsDataURI(filename){if(!isDataURI(filename)){return}return intArrayFromBase64(filename.slice(dataURIPrefix.length))}Module["addRunDependency"]=addRunDependency;Module["removeRunDependency"]=removeRunDependency;Module["FS_createPath"]=FS.createPath;Module["FS_createLazyFile"]=FS.createLazyFile;Module["FS_createDevice"]=FS.createDevice;Module["callMain"]=callMain;Module["ENV"]=ENV;Module["getWasmTableEntry"]=getWasmTableEntry;Module["addFunction"]=addFunction;Module["setValue"]=setValue;Module["getValue"]=getValue;Module["UTF8ToString"]=UTF8ToString;Module["GOT"]=GOT;Module["FS_createPreloadedFile"]=FS.createPreloadedFile;Module["FS"]=FS;Module["FS_createDataFile"]=FS.createDataFile;Module["FS_unlink"]=FS.unlink;Module["allocateUTF8"]=allocateUTF8;Module["allocateUTF8OnStack"]=allocateUTF8OnStack;var calledRun;dependenciesFulfilled=function runCaller(){if(!calledRun)run();if(!calledRun)dependenciesFulfilled=runCaller};function callMain(args=[]){var entryFunction=resolveGlobalSymbol("main").sym;if(!entryFunction)return;args.unshift(thisProgram);var argc=args.length;var argv=stackAlloc((argc+1)*4);var argv_ptr=argv;args.forEach(arg=>{HEAPU32[argv_ptr>>2]=stringToUTF8OnStack(arg);argv_ptr+=4});HEAPU32[argv_ptr>>2]=0;try{var ret=entryFunction(argc,argv);exitJS(ret,true);return ret}catch(e){return handleException(e)}}function run(args=arguments_){if(runDependencies>0){return}preRun();if(runDependencies>0){return}function doRun(){if(calledRun)return;calledRun=true;Module["calledRun"]=true;if(ABORT)return;initRuntime();preMain();if(Module["onRuntimeInitialized"])Module["onRuntimeInitialized"]();if(shouldRunNow)callMain(args);postRun()}if(Module["setStatus"]){Module["setStatus"]("Running...");setTimeout(function(){setTimeout(function(){Module["setStatus"]("")},1);doRun()},1)}else{doRun()}}if(Module["preInit"]){if(typeof Module["preInit"]=="function")Module["preInit"]=[Module["preInit"]];while(Module["preInit"].length>0){Module["preInit"].pop()()}}var shouldRunNow=true;if(Module["noInitialRun"])shouldRunNow=false;run();
